@@ -29,9 +29,6 @@
 
 // header for class SvNumberformat
 #ifndef _ZFORMAT_HXX
-#ifndef _ZFORLIST_DECLARE_TABLE
-#define _ZFORLIST_DECLARE_TABLE
-#endif
 #include <svl/zformat.hxx>
 #endif
 // header for SvNumberFormatter
@@ -359,13 +356,13 @@ void SeriesHeader::SetEditChangedHdl( const Link & rLink )
     m_aChangeLink = rLink;
 }
 
-IMPL_LINK( SeriesHeader, SeriesNameChanged, void * , EMPTYARG )
+IMPL_LINK_NOARG(SeriesHeader, SeriesNameChanged)
 {
     notifyChanges();
     return 0;
 }
 
-IMPL_LINK( SeriesHeader, SeriesNameEdited, void * , EMPTYARG )
+IMPL_LINK_NOARG(SeriesHeader, SeriesNameEdited)
 {
     m_bSeriesNameChangePending = true;
     return 0;
@@ -594,7 +591,7 @@ void DataBrowser::RenewTable()
     InsertHandleColumn( static_cast< sal_uInt16 >(
                             GetDataWindow().LogicToPixel( Size( 42, 0 )).getWidth() ));
 
-    OUString aDefaultSeriesName( ::chart::SchResId::getResString( STR_COLUMN_LABEL ));
+    OUString aDefaultSeriesName(SCH_RESSTR(STR_COLUMN_LABEL));
     replaceParamterInString( aDefaultSeriesName, C2U("%COLUMNNUMBER"), OUString::valueOf( sal_Int32(24) ) );
     sal_Int32 nColumnWidth = GetDataWindow().GetTextWidth( aDefaultSeriesName )
         + GetDataWindow().LogicToPixel( Point( 4 + impl::SeriesHeader::GetRelativeAppFontXPosForNameField(), 0 ), MAP_APPFONT ).X();
@@ -661,7 +658,7 @@ String DataBrowser::GetColString( sal_Int32 nColumnId ) const
 
 String DataBrowser::GetRowString( sal_Int32 nRow ) const
 {
-    return String::CreateFromInt32( nRow + 1 );
+    return rtl::OUString::valueOf(nRow + 1);
 }
 
 String DataBrowser::GetCellText( long nRow, sal_uInt16 nColumnId ) const
@@ -1138,7 +1135,7 @@ bool DataBrowser::isDateString( rtl::OUString aInputString, double& fOutDateValu
 {
     sal_uInt32 nNumberFormat=0;
     SvNumberFormatter* pSvNumberFormatter = m_spNumberFormatterWrapper.get() ? m_spNumberFormatterWrapper->getSvNumberFormatter() : 0;
-    if( aInputString.getLength() > 0 &&  pSvNumberFormatter && pSvNumberFormatter->IsNumberFormat( aInputString, nNumberFormat, fOutDateValue ) )
+    if( !aInputString.isEmpty() &&  pSvNumberFormatter && pSvNumberFormatter->IsNumberFormat( aInputString, nNumberFormat, fOutDateValue ) )
     {
         Reference< util::XNumberFormatsSupplier > xNumberFormatsSupplier( m_xChartDoc, uno::UNO_QUERY );
         Reference< util::XNumberFormats > xNumberFormats;
