@@ -48,18 +48,18 @@
 #include "osl/conditn.hxx"
 #include "osl/file.hxx"
 #include "osl/mutex.hxx"
-#include "osl/thread.hxx"
 #include "rtl/bootstrap.hxx"
 #include "rtl/logfile.h"
 #include "rtl/oustringostreaminserter.hxx"
 #include "rtl/ref.hxx"
 #include "rtl/string.h"
+#include "rtl/ustrbuf.hxx"
 #include "rtl/ustring.h"
 #include "rtl/ustring.hxx"
 #include "rtl/instance.hxx"
 #include "sal/log.hxx"
 #include "sal/types.h"
-#include "salhelper/simplereferenceobject.hxx"
+#include "salhelper/thread.hxx"
 
 #include "additions.hxx"
 #include "components.hxx"
@@ -137,7 +137,7 @@ bool canRemoveFromLayer(int layer, rtl::Reference< Node > const & node) {
     switch (node->kind()) {
     case Node::KIND_LOCALIZED_PROPERTY:
     case Node::KIND_GROUP:
-        for (NodeMap::iterator i(node->getMembers().begin());
+        for (NodeMap::const_iterator i(node->getMembers().begin());
              i != node->getMembers().end(); ++i)
         {
             if (!canRemoveFromLayer(layer, i->second)) {
@@ -154,16 +154,8 @@ bool canRemoveFromLayer(int layer, rtl::Reference< Node > const & node) {
 
 }
 
-class Components::WriteThread:
-    public osl::Thread, public salhelper::SimpleReferenceObject
-{
+class Components::WriteThread: public salhelper::Thread {
 public:
-    static void * operator new(std::size_t size)
-    { return Thread::operator new(size); }
-
-    static void operator delete(void * pointer)
-    { Thread::operator delete(pointer); }
-
     WriteThread(
         rtl::Reference< WriteThread > * reference, Components & components,
         rtl::OUString const & url, Data const & data);
@@ -173,9 +165,7 @@ public:
 private:
     virtual ~WriteThread() {}
 
-    virtual void SAL_CALL run();
-
-    virtual void SAL_CALL onTerminated() { release(); }
+    virtual void execute();
 
     rtl::Reference< WriteThread > * reference_;
     Components & components_;
@@ -188,14 +178,14 @@ private:
 Components::WriteThread::WriteThread(
     rtl::Reference< WriteThread > * reference, Components & components,
     rtl::OUString const & url, Data const & data):
-    reference_(reference), components_(components), url_(url), data_(data)
+    Thread("configmgrWriter"), reference_(reference), components_(components),
+    url_(url), data_(data)
 {
     lock_ = lock();
     assert(reference != 0);
-    acquire();
 }
 
-void Components::WriteThread::run() {
+void Components::WriteThread::execute() {
     TimeValue t = { 1, 0 }; // 1 sec
     delay_.wait(&t); // must not throw; result_error is harmless and ignored
     osl::MutexGuard g(*lock_); // must not throw
@@ -231,7 +221,7 @@ Components & Components::getSingleton(
 }
 
 bool Components::allLocales(rtl::OUString const & locale) {
-    return locale.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("*"));
+    return locale == "*";
 }
 
 rtl::Reference< Node > Components::resolvePathRepresentation(
@@ -310,7 +300,7 @@ void Components::writeModifications() {
     if (!writeThread_.is()) {
         writeThread_ = new WriteThread(
             &writeThread_, *this, modificationFileUrl_, data_);
-        writeThread_->create();
+        writeThread_->launch();
     }
 }
 
@@ -385,7 +375,7 @@ void Components::removeExtensionXcuFile(
              i != item->additions.rend(); ++i)
         {
             rtl::Reference< Node > parent;
-            NodeMap const * map = &data_.components;
+            NodeMap const * map = &data_.getComponents();
             rtl::Reference< Node > node;
             for (Path::const_iterator j(i->begin()); j != i->end(); ++j) {
                 parent = node;
@@ -550,14 +540,14 @@ Components::Components(
         }
         rtl::OUString type(conf.copy(i, c - i));
         rtl::OUString url(expand(conf.copy(c + 1, n - c - 1)));
-        if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("xcsxcu"))) {
+        if ( type == "xcsxcu" ) {
             parseXcsXcuLayer(layer, url);
             layer += 2; //TODO: overflow
-        } else if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("bundledext")))
+        } else if ( type == "bundledext" )
         {
             parseXcsXcuIniLayer(layer, url, false);
             layer += 2; //TODO: overflow
-        } else if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("sharedext"))) {
+        } else if ( type == "sharedext" ) {
             if (sharedExtensionLayer_ != -1) {
                 throw css::uno::RuntimeException(
                     rtl::OUString(
@@ -569,7 +559,7 @@ Components::Components(
             sharedExtensionLayer_ = layer;
             parseXcsXcuIniLayer(layer, url, true);
             layer += 2; //TODO: overflow
-        } else if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("userext"))) {
+        } else if ( type == "userext" ) {
             if (userExtensionLayer_ != -1) {
                 throw css::uno::RuntimeException(
                     rtl::OUString(
@@ -581,13 +571,13 @@ Components::Components(
             userExtensionLayer_ = layer;
             parseXcsXcuIniLayer(layer, url, true);
             layer += 2; //TODO: overflow
-        } else if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("module"))) {
+        } else if ( type == "module" ) {
             parseModuleLayer(layer, url);
             ++layer; //TODO: overflow
-        } else if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("res"))) {
+        } else if ( type == "res" ) {
             parseResLayer(layer, url);
             ++layer; //TODO: overflow
-        } else if (type.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("user"))) {
+        } else if ( type == "user" ) {
             if (url.isEmpty()) {
                 throw css::uno::RuntimeException(
                     rtl::OUString(
@@ -710,7 +700,7 @@ void Components::parseFileList(
 {
     for (sal_Int32 i = 0;;) {
         rtl::OUString url(urls.getToken(0, ' ', i));
-        if (url.getLength() != 0) {
+        if (!url.isEmpty()) {
             ini.expandMacrosFrom(url); //TODO: detect failure
             Additions * adds = 0;
             if (recordAdditions) {
@@ -838,17 +828,38 @@ void Components::parseXcsXcuLayer(int layer, rtl::OUString const & url) {
 void Components::parseXcsXcuIniLayer(
     int layer, rtl::OUString const & url, bool recordAdditions)
 {
-    //TODO: rtl::Bootstrap::getFrom "first trie[s] to retrieve the value via the
-    // global function"
+    // Check if ini file exists (otherwise .override would still read global
+    // SCHEMA/DATA variables, which could interfere with unrelated environment
+    // variables):
     rtl::Bootstrap ini(url);
-    rtl::OUString urls;
-    if (ini.getFrom(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("SCHEMA")), urls))
+    if (ini.getHandle() != 0)
     {
-        parseFileList(layer, &parseXcsFile, urls, ini, false);
-    }
-    if (ini.getFrom(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DATA")), urls))
-    {
-        parseFileList(layer + 1, &parseXcuFile, urls, ini, recordAdditions);
+        rtl::OUStringBuffer prefix("${.override:");
+        for (sal_Int32 i = 0; i != url.getLength(); ++i) {
+            sal_Unicode c = url[i];
+            switch (c) {
+            case '$':
+            case ':':
+            case '\\':
+                prefix.append('\\');
+                // fall through
+            default:
+                prefix.append(c);
+            }
+        }
+        prefix.append(':');
+        rtl::OUString urls(prefix.toString() + rtl::OUString("SCHEMA}"));
+        rtl::Bootstrap::expandMacros(urls);
+        if (!urls.isEmpty())
+        {
+            parseFileList(layer, &parseXcsFile, urls, ini, false);
+        }
+        urls = prefix.makeStringAndClear() + rtl::OUString("DATA}");
+        rtl::Bootstrap::expandMacros(urls);
+        if (!urls.isEmpty())
+        {
+            parseFileList(layer + 1, &parseXcuFile, urls, ini, recordAdditions);
+        }
     }
 }
 
