@@ -34,6 +34,7 @@
 #include "diagnose_ex.h"
 
 #include <algorithm>
+#include <boost/scoped_array.hpp>
 
 
 using namespace connectivity;
@@ -57,7 +58,7 @@ ONDXKey::ONDXKey(const rtl::OUString& aStr, sal_uInt32 nRec)
     : ONDXKey_BASE(::com::sun::star::sdbc::DataType::VARCHAR)
      ,nRecord(nRec)
 {
-    if (aStr.getLength())
+    if (!aStr.isEmpty())
     {
         xValue = aStr;
         xValue.setBound(sal_True);
@@ -74,7 +75,7 @@ ONDXKey::ONDXKey(double aVal, sal_uInt32 nRec)
 // -----------------------------------------------------------------------------
 
 //==================================================================
-// Index Seite
+// index page
 //==================================================================
 ONDXPage::ONDXPage(ODbaseIndex& rInd, sal_uInt32 nPos, ONDXPage* pParent)
            :nPagePos(nPos)
@@ -203,7 +204,7 @@ sal_Bool ONDXPage::Insert(ONDXNode& rNode, sal_uInt32 nRowsLeft)
                     --nCount;   // (otherwise we might get Assertions and GPFs - 60593)
                     bResult = Insert(rIndex.m_nCurNode + 1, rNode);
                 }
-                else  // Position unbekannt
+                else  // position unknown
                 {
                     sal_uInt16 nPos = NODE_NOTFOUND;
                     while (++nPos < nCount && rNode.GetKey() > ((*this)[nPos]).GetKey()) ;
@@ -673,7 +674,7 @@ void ONDXNode::Read(SvStream &rStream, ODbaseIndex& rIndex)
     else
     {
         sal_uInt16 nLen = rIndex.getHeader().db_keylen;
-        rtl::OString aBuf = read_uInt8s_AsOString(rStream, nLen);
+        rtl::OString aBuf = read_uInt8s_ToOString(rStream, nLen);
         //get length minus trailing whitespace
         sal_Int32 nContentLen = aBuf.getLength();
         while (nContentLen && aBuf[nContentLen-1] == ' ')
@@ -683,8 +684,6 @@ void ONDXNode::Read(SvStream &rStream, ODbaseIndex& rIndex)
     rStream >> aChild;
 }
 
-char aData[128];
-
 //------------------------------------------------------------------
 void ONDXNode::Write(SvStream &rStream, const ONDXPage& rPage) const
 {
@@ -696,24 +695,32 @@ void ONDXNode::Write(SvStream &rStream, const ONDXPage& rPage) const
 
     if (rIndex.getHeader().db_keytype) // double
     {
+        if (sizeof(double) != rIndex.getHeader().db_keylen)
+        {
+            OSL_TRACE("this key length cannot possibly be right?");
+        }
         if (aKey.getValue().isNull())
         {
-            memset(aData,0,rIndex.getHeader().db_keylen);
-            rStream.Write((sal_uInt8*)aData,rIndex.getHeader().db_keylen);
+            sal_uInt8 buf[sizeof(double)];
+            memset(&buf[0], 0, sizeof(double));
+            rStream.Write(&buf[0], sizeof(double));
         }
         else
             rStream << (double) aKey.getValue();
     }
     else
     {
-        memset(aData,0x20,rIndex.getHeader().db_keylen);
+        sal_uInt16 const nLen(rIndex.getHeader().db_keylen);
+        ::boost::scoped_array<sal_uInt8> pBuf(new sal_uInt8[nLen]);
+        memset(&pBuf[0], 0x20, nLen);
         if (!aKey.getValue().isNull())
         {
             ::rtl::OUString sValue = aKey.getValue();
             rtl::OString aText(rtl::OUStringToOString(sValue, rIndex.m_pTable->getConnection()->getTextEncoding()));
-            strncpy(aData, aText.getStr(), std::min<size_t>(rIndex.getHeader().db_keylen, aText.getLength()));
+            strncpy(reinterpret_cast<char *>(&pBuf[0]), aText.getStr(),
+                std::min<size_t>(nLen, aText.getLength()));
         }
-        rStream.Write((sal_uInt8*)aData,rIndex.getHeader().db_keylen);
+        rStream.Write(&pBuf[0], nLen);
     }
     rStream << aChild;
 }
@@ -745,14 +752,14 @@ StringCompare ONDXKey::Compare(const ONDXKey& rKey) const
 
     if (getValue().isNull())
     {
-        if (rKey.getValue().isNull() || (rKey.IsText(getDBType()) && !rKey.getValue().getString().getLength()))
+        if (rKey.getValue().isNull() || (rKey.IsText(getDBType()) && rKey.getValue().getString().isEmpty()))
             eResult = COMPARE_EQUAL;
         else
             eResult = COMPARE_LESS;
     }
     else if (rKey.getValue().isNull())
     {
-        if (getValue().isNull() || (IsText(getDBType()) && !getValue().getString().getLength()))
+        if (getValue().isNull() || (IsText(getDBType()) && getValue().getString().isEmpty()))
             eResult = COMPARE_EQUAL;
         else
             eResult = COMPARE_GREATER;
@@ -911,7 +918,7 @@ void ONDXPage::PrintPage()
         }
         else
         {
-            OSL_TRACE("SDB: [%d,%s,%d]",rKey.GetRecord(), (const char* )ByteString(rKey.getValue().getString().getStr(), rIndex.m_pTable->getConnection()->getTextEncoding()).GetBuffer(),rNode.GetChild().GetPagePos());
+            OSL_TRACE("SDB: [%d,%s,%d]",rKey.GetRecord(), rtl::OUStringToOString(rKey.getValue().getString(), rIndex.m_pTable->getConnection()->getTextEncoding()).getStr(),rNode.GetChild().GetPagePos());
         }
     }
     OSL_TRACE("SDB: -----------------------------------------------");
