@@ -258,7 +258,7 @@ void HexColorControl::Paste()
                 ::rtl::OUString aText;
                 aData >>= aText;
 
-                if( aText.getLength() && aText.matchAsciiL( "#", 1, 0 ) )
+                if( !aText.isEmpty() && aText.matchAsciiL( "#", 1, 0 ) )
                     aText = aText.copy(1);
 
                 if( aText.getLength() > 6 )
@@ -1425,7 +1425,7 @@ IMPL_LINK( ColorPickerDialog, ColorModifyHdl, void *, p )
 
 // --------------------------------------------------------------------
 
-IMPL_LINK( ColorPickerDialog, ModeModifyHdl, void *, EMPTYARG )
+IMPL_LINK_NOARG(ColorPickerDialog, ModeModifyHdl)
 {
     ColorMode eMode = HUE;
 
@@ -1588,7 +1588,7 @@ OUString SAL_CALL ColorPicker::getImplementationName(  ) throw (RuntimeException
 
 sal_Bool SAL_CALL ColorPicker::supportsService( const OUString& sServiceName ) throw (RuntimeException)
 {
-    return sServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.ui.dialogs.ColorPicker" ) );
+    return sServiceName == "com.sun.star.ui.dialogs.ColorPicker";
 }
 
 // --------------------------------------------------------------------
