@@ -35,7 +35,6 @@
 #include <sfx2/app.hxx>
 #include <svl/aeitem.hxx>
 #include <svtools/svtabbx.hxx>
-#include <tools/config.hxx>
 #include <tools/urlobj.hxx>
 #include <vcl/svapp.hxx>
 #include <unotools/defaultoptions.hxx>
@@ -51,14 +50,16 @@
 #include "optpath.hrc"
 #include <cuires.hrc>
 #include "helpid.hrc"
+#include <comphelper/configuration.hxx>
 #include <comphelper/processfactory.hxx>
-#include <comphelper/configurationhelper.hxx>
+#include <comphelper/string.hxx>
 #include <com/sun/star/uno/Exception.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/ui/dialogs/ExecutableDialogResults.hpp>
 #include <com/sun/star/ui/dialogs/XAsynchronousExecutableDialog.hpp>
+#include <officecfg/Office/Common.hxx>
 #include "optHeaderTabListbox.hxx"
 #include <readonlyimage.hxx>
 #include <vcl/help.hxx>
@@ -80,7 +81,6 @@ using namespace svx;
 #define POSTFIX_INTERNAL    String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "_internal" ) )
 #define POSTFIX_USER        String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "_user" ) )
 #define POSTFIX_WRITABLE    String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "_writable" ) )
-#define POSTFIX_READONLY    String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "_readonly" ) )
 #define VAR_ONE             String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "%1" ) )
 #define IODLG_CONFIGNAME    String(DEFINE_CONST_UNICODE("FilePicker_Save"))
 
@@ -158,7 +158,7 @@ static String getCfgName_Impl( sal_uInt16 _nHandle )
 String Convert_Impl( const String& rValue )
 {
     char cDelim = MULTIPATH_DELIMITER;
-    sal_uInt16 nCount = rValue.GetTokenCount( cDelim );
+    sal_uInt16 nCount = comphelper::string::getTokenCount(rValue, cDelim);
     String aReturn;
     for ( sal_uInt16 i=0; i<nCount ; ++i )
     {
@@ -362,10 +362,10 @@ void SvxPathTabPage::Reset( const SfxItemSet& )
     String aUserData = GetUserData();
     if ( aUserData.Len() )
     {
-        // Spaltenbreite restaurieren
+        // restore column width
         pHeaderBar->SetItemSize( ITEMID_TYPE, aUserData.GetToken(0).ToInt32() );
         HeaderEndDrag_Impl( NULL );
-        // Sortierrichtung restaurieren
+        // restore sort direction
         sal_Bool bUp = (sal_Bool)(sal_uInt16)aUserData.GetToken(1).ToInt32();
         HeaderBarItemBits nBits = pHeaderBar->GetItemBits(ITEMID_TYPE);
 
@@ -399,7 +399,7 @@ void SvxPathTabPage::FillUserData()
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxPathTabPage, PathSelect_Impl, svx::OptHeaderTabListBox *, EMPTYARG )
+IMPL_LINK_NOARG(SvxPathTabPage, PathSelect_Impl)
 {
     sal_uInt16 nSelCount = 0;
     SvLBoxEntry* pEntry = pPathBox->FirstSelected();
@@ -422,7 +422,7 @@ IMPL_LINK( SvxPathTabPage, PathSelect_Impl, svx::OptHeaderTabListBox *, EMPTYARG
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxPathTabPage, StandardHdl_Impl, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG(SvxPathTabPage, StandardHdl_Impl)
 {
     SvLBoxEntry* pEntry = pPathBox->FirstSelected();
     while ( pEntry )
@@ -437,8 +437,8 @@ IMPL_LINK( SvxPathTabPage, StandardHdl_Impl, PushButton *, EMPTYARG )
             GetPathList( pPathImpl->nRealId, sInternal, sUser, sWritable, bReadOnly );
 
             sal_uInt16 i;
-            sal_uInt16 nOldCount = aOldPath.GetTokenCount( MULTIPATH_DELIMITER );
-            sal_uInt16 nIntCount = sInternal.GetTokenCount( MULTIPATH_DELIMITER );
+            sal_uInt16 nOldCount = comphelper::string::getTokenCount(aOldPath, MULTIPATH_DELIMITER);
+            sal_uInt16 nIntCount = comphelper::string::getTokenCount(sInternal, MULTIPATH_DELIMITER);
             for ( i = 0; i < nOldCount; ++i )
             {
                 bool bFound = false;
@@ -457,7 +457,7 @@ IMPL_LINK( SvxPathTabPage, StandardHdl_Impl, PushButton *, EMPTYARG )
             }
 
             String sUserPath, sWritablePath;
-            nOldCount = sTemp.GetTokenCount( MULTIPATH_DELIMITER );
+            nOldCount = comphelper::string::getTokenCount(sTemp, MULTIPATH_DELIMITER);
             for ( i = 0; nOldCount > 0 && i < nOldCount - 1; ++i )
             {
                 if ( sUserPath.Len() > 0 )
@@ -483,7 +483,7 @@ void SvxPathTabPage::ChangeCurrentEntry( const String& _rFolder )
     SvLBoxEntry* pEntry = pPathBox->GetCurEntry();
     if ( !pEntry )
     {
-        DBG_ERRORFILE( "SvxPathTabPage::ChangeCurrentEntry(): no entry" );
+        SAL_WARN( "cui.options", "SvxPathTabPage::ChangeCurrentEntry(): no entry" );
         return;
     }
 
@@ -532,20 +532,18 @@ void SvxPathTabPage::ChangeCurrentEntry( const String& _rFolder )
 
             // Set configuration flag to notify file picker that it's necessary
             // to take over the path provided.
-            Reference < XMultiServiceFactory > xFactory( ::comphelper::getProcessServiceFactory() );
-            ::comphelper::ConfigurationHelper::writeDirectKey(xFactory,
-                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("org.openoffice.Office.Common/")),
-                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("Path/Info")),
-                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("WorkPathChanged")),
-                ::com::sun::star::uno::makeAny(true),
-                ::comphelper::ConfigurationHelper::E_STANDARD);
+            boost::shared_ptr< comphelper::ConfigurationChanges > batch(
+                comphelper::ConfigurationChanges::create());
+            officecfg::Office::Common::Path::Info::WorkPathChanged::set(
+                true, batch);
+            batch->commit();
         }
     }
 }
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxPathTabPage, PathHdl_Impl, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG(SvxPathTabPage, PathHdl_Impl)
 {
     SvLBoxEntry* pEntry = pPathBox->GetCurEntry();
     sal_uInt16 nPos = ( pEntry != NULL ) ? ( (PathUserData_Impl*)pEntry->GetUserData() )->nRealId : 0;
@@ -590,7 +588,7 @@ IMPL_LINK( SvxPathTabPage, PathHdl_Impl, PushButton *, EMPTYARG )
                 String sFullPath;
                 String sNewPath = pMultiDlg->GetPath();
                 char cDelim = MULTIPATH_DELIMITER;
-                sal_uInt16 nCount = sNewPath.GetTokenCount( cDelim );
+                sal_uInt16 nCount = comphelper::string::getTokenCount(sNewPath, cDelim);
                 if ( nCount > 0 )
                 {
                     sal_uInt16 i = 0;
@@ -646,7 +644,7 @@ IMPL_LINK( SvxPathTabPage, PathHdl_Impl, PushButton *, EMPTYARG )
         }
         catch( Exception& )
         {
-            DBG_ERRORFILE( "SvxPathTabPage::PathHdl_Impl: exception from folder picker" );
+            SAL_WARN( "cui.options", "SvxPathTabPage::PathHdl_Impl: exception from folder picker" );
         }
     }
     return 0;
@@ -824,7 +822,7 @@ void SvxPathTabPage::SetPathList(
         {
             // save user paths
             char cDelim = MULTIPATH_DELIMITER;
-            sal_uInt16 nCount = _rUserPath.GetTokenCount( cDelim );
+            sal_uInt16 nCount = comphelper::string::getTokenCount(_rUserPath, cDelim);
             Sequence< ::rtl::OUString > aPathSeq( nCount );
             ::rtl::OUString* pArray = aPathSeq.getArray();
             for ( sal_uInt16 i = 0; i < nCount; ++i )
@@ -841,9 +839,9 @@ void SvxPathTabPage::SetPathList(
             pImpl->m_xPathSettings->setPropertyValue( sProp, aValue );
         }
     }
-    catch( const Exception& )
+    catch( const Exception& e )
     {
-        OSL_FAIL( "SvxPathTabPage::SetPathList(): caught an exception!" );
+        SAL_WARN("cui", "caught: " << e.Message);
     }
 }
 
