@@ -68,7 +68,6 @@
 #include <comphelper/interaction.hxx>
 #include <comphelper/namedvaluecollection.hxx>
 #include <comphelper/proparrhlp.hxx>
-#include <comphelper/string.hxx>
 #include <connectivity/dbexception.hxx>
 #include <connectivity/dbtools.hxx>
 #include <cppuhelper/exc_hlp.hxx>
@@ -737,7 +736,7 @@ namespace
         {
             OSL_VERIFY( _rxDescriptor->getPropertyValue( _rPropertyName ) >>= sValue );
         }
-        return sValue.getLength() > 0;
+        return !sValue.isEmpty();
     }
 }
 
@@ -751,7 +750,7 @@ void CopyTableWizard::impl_checkForUnsupportedSettings_throw( const Reference< X
     const ::rtl::OUString aSettings[] = {
         PROPERTY_FILTER, PROPERTY_ORDER, PROPERTY_HAVING_CLAUSE, PROPERTY_GROUP_BY
     };
-    for ( size_t i=0; i < SAL_N_ELEMENTS( aSettings ); ++i )
+    for ( size_t i=0; i < sizeof( aSettings ) / sizeof( aSettings[0] ); ++i )
     {
         if ( lcl_hasNonEmptyStringValue_throw( _rxSourceDescriptor, xPSI, aSettings[i] ) )
         {
@@ -760,10 +759,11 @@ void CopyTableWizard::impl_checkForUnsupportedSettings_throw( const Reference< X
         }
     }
 
-    if ( sUnsupportedSetting.getLength() != 0 )
+    if ( !sUnsupportedSetting.isEmpty() )
     {
-        ::rtl::OUString sMessage( String(ModuleRes( STR_CTW_ERROR_UNSUPPORTED_SETTING )) );
-        ::comphelper::string::searchAndReplaceAsciiI( sMessage, "$name$", sUnsupportedSetting );
+        ::rtl::OUString sMessage(
+            rtl::OUString(String(ModuleRes(STR_CTW_ERROR_UNSUPPORTED_SETTING))).
+            replaceFirst("$name$", sUnsupportedSetting));
         throw IllegalArgumentException(
             sMessage,
             *const_cast< CopyTableWizard* >( this ),
@@ -924,9 +924,9 @@ SharedConnection CopyTableWizard::impl_extractConnection_throw( const Reference<
     // need a DatabaseContext for loading the data source
     Reference< XNameAccess > xDatabaseContext( m_aContext.createComponent( "com.sun.star.sdb.DatabaseContext" ), UNO_QUERY_THROW );
     Reference< XDataSource > xDataSource;
-    if ( sDataSource.getLength() )
+    if ( !sDataSource.isEmpty() )
         xDataSource.set( xDatabaseContext->getByName( sDataSource ), UNO_QUERY_THROW );
-    if ( !xDataSource.is() && sDatabaseLocation.getLength() )
+    if ( !xDataSource.is() && !sDatabaseLocation.isEmpty() )
         xDataSource.set( xDatabaseContext->getByName( sDatabaseLocation ), UNO_QUERY_THROW );
 
     if ( xDataSource.is() )
@@ -983,7 +983,7 @@ SharedConnection CopyTableWizard::impl_extractConnection_throw( const Reference<
 {
     OSL_PRECOND( m_xSourceConnection.is(), "CopyTableWizard::impl_createSourceStatement_throw: illegal call!" );
     if ( !m_xSourceConnection.is() )
-        throw RuntimeException( ::rtl::OUString(), *const_cast< CopyTableWizard* >( this ) );
+        throw RuntimeException( "CopyTableWizard::impl_createSourceStatement_throw: illegal call!", *const_cast< CopyTableWizard* >( this ));
 
     ::utl::SharedUNOComponent< XPreparedStatement > xStatement;
     switch ( m_nCommandType )
@@ -1029,7 +1029,7 @@ SharedConnection CopyTableWizard::impl_extractConnection_throw( const Reference<
 
     default:
         // this should not have survived initialization phase
-        throw RuntimeException( ::rtl::OUString(), *const_cast< CopyTableWizard* >( this ) );
+        throw RuntimeException("No case matched, this should not have survived the initialization phase", *const_cast< CopyTableWizard* >( this ));
     }
 
     return xStatement;
@@ -1165,7 +1165,7 @@ void CopyTableWizard::impl_copyRows_throw( const Reference< XResultSet >& _rxSou
 {
     OSL_PRECOND( m_xDestConnection.is(), "CopyTableWizard::impl_copyRows_throw: illegal call!" );
     if ( !m_xDestConnection.is() )
-        throw RuntimeException( ::rtl::OUString(), *this );
+        throw RuntimeException( "m_xDestConnection is set to null, CopyTableWizard::impl_copyRows_throw: illegal call!", *this );
 
     Reference< XDatabaseMetaData > xDestMetaData( m_xDestConnection->getMetaData(), UNO_QUERY_THROW );
 
