@@ -493,7 +493,7 @@ IMPL_LINK( ExtBoxWithBtns_Impl, ScrollHdl, ScrollBar*, pScrBar )
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtBoxWithBtns_Impl, HandleOptionsBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtBoxWithBtns_Impl, HandleOptionsBtn)
 {
     const sal_Int32 nActive = getSelIndex();
 
@@ -516,7 +516,7 @@ IMPL_LINK( ExtBoxWithBtns_Impl, HandleOptionsBtn, void*, EMPTYARG )
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtBoxWithBtns_Impl, HandleEnableBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtBoxWithBtns_Impl, HandleEnableBtn)
 {
     const sal_Int32 nActive = getSelIndex();
 
@@ -537,7 +537,7 @@ IMPL_LINK( ExtBoxWithBtns_Impl, HandleEnableBtn, void*, EMPTYARG )
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtBoxWithBtns_Impl, HandleRemoveBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtBoxWithBtns_Impl, HandleRemoveBtn)
 {
     const sal_Int32 nActive = getSelIndex();
 
@@ -626,7 +626,7 @@ bool DialogHelper::continueOnSharedExtension( const uno::Reference< deployment::
 //------------------------------------------------------------------------------
 void DialogHelper::openWebBrowser( const OUString & sURL, const OUString &sTitle ) const
 {
-    if ( ! sURL.getLength() ) // Nothing to do, when the URL is empty
+    if ( sURL.isEmpty() ) // Nothing to do, when the URL is empty
         return;
 
     try
@@ -948,7 +948,7 @@ uno::Sequence< OUString > ExtMgrDialog::raiseAddPicker()
     {
         uno::Reference< deployment::XPackageTypeInfo > const & xPackageType = packageTypes[ pos ];
         const OUString filter( xPackageType->getFileFilter() );
-        if (filter.getLength() > 0)
+        if (!filter.isEmpty())
         {
             const OUString title( xPackageType->getShortDescription() );
             const ::std::pair< t_string2string::iterator, bool > insertion(
@@ -994,7 +994,7 @@ uno::Sequence< OUString > ExtMgrDialog::raiseAddPicker()
 }
 
 //------------------------------------------------------------------------------
-IMPL_LINK( ExtMgrDialog, HandleCancelBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtMgrDialog, HandleCancelBtn)
 {
     if ( m_xAbortChannel.is() )
     {
@@ -1092,7 +1092,7 @@ void ExtMgrDialog::updatePackageInfo( const uno::Reference< deployment::XPackage
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtMgrDialog, HandleAddBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtMgrDialog, HandleAddBtn)
 {
     setBusy( true );
 
@@ -1108,14 +1108,14 @@ IMPL_LINK( ExtMgrDialog, HandleAddBtn, void*, EMPTYARG )
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtMgrDialog, HandleExtTypeCbx, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtMgrDialog, HandleExtTypeCbx)
 {
 	// re-creates the list of packages with addEntry selecting the packages
 	m_pManager->createPackageList();
     return 1;
 }
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtMgrDialog, HandleUpdateBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(ExtMgrDialog, HandleUpdateBtn)
 {
     m_pManager->checkUpdates( false, true );
 
@@ -1131,7 +1131,7 @@ IMPL_LINK( ExtMgrDialog, HandleHyperlink, svt::FixedHyperlink*, pHyperlink )
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( ExtMgrDialog, TimeOutHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(ExtMgrDialog, TimeOutHdl)
 {
     if ( m_bStopProgress )
     {
@@ -1466,7 +1466,7 @@ bool UpdateRequiredDialog::enablePackage( const uno::Reference< deployment::XPac
 }
 
 //------------------------------------------------------------------------------
-IMPL_LINK( UpdateRequiredDialog, HandleCancelBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(UpdateRequiredDialog, HandleCancelBtn)
 {
     if ( m_xAbortChannel.is() )
     {
@@ -1572,7 +1572,7 @@ void UpdateRequiredDialog::updatePackageInfo( const uno::Reference< deployment::
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( UpdateRequiredDialog, HandleUpdateBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(UpdateRequiredDialog, HandleUpdateBtn)
 {
     ::osl::ClearableMutexGuard aGuard( m_aMutex );
 
@@ -1593,7 +1593,7 @@ IMPL_LINK( UpdateRequiredDialog, HandleUpdateBtn, void*, EMPTYARG )
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( UpdateRequiredDialog, HandleCloseBtn, void*, EMPTYARG )
+IMPL_LINK_NOARG(UpdateRequiredDialog, HandleCloseBtn)
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -1619,7 +1619,7 @@ IMPL_LINK( UpdateRequiredDialog, HandleHyperlink, svt::FixedHyperlink*, pHyperli
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( UpdateRequiredDialog, TimeOutHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(UpdateRequiredDialog, TimeOutHdl)
 {
     if ( m_bStopProgress )
     {
