@@ -64,12 +64,12 @@ namespace drawinglayer
 
                 if(xSet.is())
                 {
-                    uno::Any aValue(xSet->getPropertyValue(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultControl"))));
+                    uno::Any aValue(xSet->getPropertyValue("DefaultControl"));
                     rtl::OUString aUnoControlTypeName;
 
                     if(aValue >>= aUnoControlTypeName)
                     {
-                        if(aUnoControlTypeName.getLength())
+                        if(!aUnoControlTypeName.isEmpty())
                         {
                             uno::Reference< lang::XMultiServiceFactory > xFactory( comphelper::getProcessServiceFactory() );
 
