@@ -74,12 +74,12 @@ void OleEmbeddedObject::SwitchComponentToRunningState_Impl()
         {
             m_pOleComponent->RunObject();
         }
-        catch( embed::UnreachableStateException& )
+        catch( const embed::UnreachableStateException& )
         {
             GetRidOfComponent();
             throw;
         }
-        catch( embed::WrongStateException& )
+        catch( const embed::WrongStateException& )
         {
             GetRidOfComponent();
             throw;
@@ -144,7 +144,7 @@ void OleEmbeddedObject::MoveListeners()
                         {
                             xWrappedObject->addStateChangeListener( (embed::XStateChangeListener*)pIterator.next() );
                         }
-                        catch( uno::RuntimeException& )
+                        catch( const uno::RuntimeException& )
                         {
                             pIterator.remove();
                         }
@@ -169,7 +169,7 @@ void OleEmbeddedObject::MoveListeners()
                         {
                             xWrappedObject->addEventListener( (document::XEventListener*)pIterator.next() );
                         }
-                        catch( uno::RuntimeException& )
+                        catch( const uno::RuntimeException& )
                         {
                             pIterator.remove();
                         }
@@ -194,7 +194,7 @@ void OleEmbeddedObject::MoveListeners()
                         {
                             xWrappedObject->addCloseListener( (util::XCloseListener*)pIterator.next() );
                         }
-                        catch( uno::RuntimeException& )
+                        catch( const uno::RuntimeException& )
                         {
                             pIterator.remove();
                         }
@@ -238,7 +238,7 @@ uno::Reference< embed::XStorage > OleEmbeddedObject::CreateTemporarySubstorage(
 ::rtl::OUString OleEmbeddedObject::MoveToTemporarySubstream()
 {
     ::rtl::OUString aResult;
-    for ( sal_Int32 nInd = 0; nInd < 32000 && !aResult.getLength(); nInd++ )
+    for ( sal_Int32 nInd = 0; nInd < 32000 && aResult.isEmpty(); nInd++ )
     {
         ::rtl::OUString aName = ::rtl::OUString::valueOf( nInd );
         aName += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "TMPSTREAM" ) );
@@ -250,7 +250,7 @@ uno::Reference< embed::XStorage > OleEmbeddedObject::CreateTemporarySubstorage(
         }
     }
 
-    if ( !aResult.getLength() )
+    if ( aResult.isEmpty() )
         throw uno::RuntimeException();
 
     return aResult;
@@ -278,10 +278,8 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
         ::rtl::OUString aFilterName = OwnView_Impl::GetFilterNameFromExtentionAndInStream( m_xFactory, ::rtl::OUString(), m_xObjectStream->getInputStream() );
 
         // use the solution only for OOXML format currently
-        if ( aFilterName.getLength()
-          && ( aFilterName.equals( ::rtl::OUString ( RTL_CONSTASCII_USTRINGPARAM( "Calc MS Excel 2007 XML" ) ) )
-            || aFilterName.equals( ::rtl::OUString ( RTL_CONSTASCII_USTRINGPARAM( "Impress MS PowerPoint 2007 XML" ) ) )
-            || aFilterName.equals( ::rtl::OUString ( RTL_CONSTASCII_USTRINGPARAM( "MS Word 2007 XML" ) ) ) ) )
+        if ( !aFilterName.isEmpty()
+          && ( aFilterName == "Calc MS Excel 2007 XML" || aFilterName == "Impress MS PowerPoint 2007 XML" || aFilterName == "MS Word 2007 XML" ) )
         {
             uno::Reference< container::XNameAccess > xFilterFactory(
                 m_xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.document.FilterFactory" ) )),
@@ -293,11 +291,11 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
             if ( aFilterAnyData >>= aFilterData )
             {
                 for ( sal_Int32 nInd = 0; nInd < aFilterData.getLength(); nInd++ )
-                    if ( aFilterData[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "DocumentService" ) ) )
+                    if ( aFilterData[nInd].Name == "DocumentService" )
                         aFilterData[nInd].Value >>= aDocServiceName;
             }
 
-            if ( aDocServiceName.getLength() )
+            if ( !aDocServiceName.isEmpty() )
             {
                 // create the model
                 uno::Sequence< uno::Any > aArguments(1);
@@ -342,10 +340,10 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
                 // look for the related embedded object factory
                 ::comphelper::MimeConfigurationHelper aConfigHelper( m_xFactory );
                 ::rtl::OUString aEmbedFactory;
-                if ( aMediaType.getLength() )
+                if ( !aMediaType.isEmpty() )
                     aEmbedFactory = aConfigHelper.GetFactoryNameByMediaType( aMediaType );
 
-                if ( !aEmbedFactory.getLength() )
+                if ( aEmbedFactory.isEmpty() )
                     throw uno::RuntimeException();
 
                 uno::Reference< uno::XInterface > xFact = m_xFactory->createInstance( aEmbedFactory );
@@ -373,32 +371,32 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
                 {
                     m_xParentStorage->removeElement( aTmpStreamName );
                 }
-                catch( uno::Exception& )
+                catch( const uno::Exception& )
                 {
                     // the success of the removing is not so important
                 }
             }
         }
     }
-    catch( uno::Exception& )
+    catch( const uno::Exception& )
     {
         // repair the object if necessary
         switch( nStep )
         {
             case 4:
             case 3:
-            if ( aTmpStreamName.getLength() && aTmpStreamName != m_aEntryName )
+            if ( !aTmpStreamName.isEmpty() && aTmpStreamName != m_aEntryName )
                 try
                 {
                     if ( m_xParentStorage->hasByName( m_aEntryName ) )
                         m_xParentStorage->removeElement( m_aEntryName );
                     m_xParentStorage->renameElement( aTmpStreamName, m_aEntryName );
                 }
-                catch ( uno::Exception& )
+                catch ( const uno::Exception& )
                 {
                     try {
                         close( sal_True );
-                    } catch( uno::Exception& ) {}
+                    } catch( const uno::Exception& ) {}
 
                     m_xParentStorage->dispose(); // ??? the storage has information loss, it should be closed without commiting!
                     throw uno::RuntimeException(); // the repairing is not possible
@@ -409,11 +407,11 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
                     m_xObjectStream = m_xParentStorage->openStreamElement( m_aEntryName, m_bReadOnly ? embed::ElementModes::READ : embed::ElementModes::READWRITE );
                     m_nObjectState = embed::EmbedStates::LOADED;
                 }
-                catch( uno::Exception& )
+                catch( const uno::Exception& )
                 {
                     try {
                         close( sal_True );
-                    } catch( uno::Exception& ) {}
+                    } catch( const uno::Exception& ) {}
 
                     throw uno::RuntimeException(); // the repairing is not possible
                 }
@@ -421,10 +419,10 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
 
             case 1:
             case 0:
-                if ( aStorageName.getLength() )
+                if ( !aStorageName.isEmpty() )
                     try {
                         m_xParentStorage->removeElement( aStorageName );
-                    } catch( uno::Exception& ) { OSL_FAIL( "Can not remove temporary storage!" ); }
+                    } catch( const uno::Exception& ) { OSL_FAIL( "Can not remove temporary storage!" ); }
                 break;
         }
     }
@@ -546,7 +544,7 @@ void SAL_CALL OleEmbeddedObject::changeState( sal_Int32 nNewState )
                             m_pOleComponent->SetExtent( m_aSizeToSet, m_nAspectToSet );
                             m_bHasSizeToSet = sal_False;
                         }
-                        catch( uno::Exception& ) {}
+                        catch( const uno::Exception& ) {}
                         aGuard.reset();
                     }
 
@@ -750,6 +748,9 @@ namespace
             xNativeTempFile->setPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RemoveFile")),
                 uno::makeAny(sal_True));
         }
+#else
+        (void) xFactory;
+        (void) xObjectStream;
 #endif
         return sUrl;
     }
@@ -871,10 +872,10 @@ void SAL_CALL OleEmbeddedObject::doVerb( sal_Int32 nVerbID )
             {
                 //Make a RO copy and see if the OS can find something to at
                 //least display the content for us
-                if (!m_aTempDumpURL.getLength())
+                if (m_aTempDumpURL.isEmpty())
                     m_aTempDumpURL = lcl_ExtractObject(m_xFactory, m_xObjectStream);
 
-                if (m_aTempDumpURL.getLength())
+                if (!m_aTempDumpURL.isEmpty())
                 {
                     uno::Reference< ::com::sun::star::system::XSystemShellExecute > xSystemShellExecute( m_xFactory->createInstance(
                         ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.system.SystemShellExecute"))),
