@@ -62,7 +62,6 @@
 #undef GradientStyle_RECT
 #include <odma_lib.hxx>
 #endif
-#include <dispatch/uieventloghelper.hxx>
 #include <osl/mutex.hxx>
 
 //_________________________________________________________________________________________________________________
@@ -133,7 +132,7 @@ void RecentFilesMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >
         int nPickListMenuItems = ( aHistoryList.getLength() > 99 ) ? 99 : aHistoryList.getLength();
 
         // New vnd.sun.star.popup: command URL to support direct dispatches
-        const rtl::OUString aCmdPrefix( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.popup:RecentFileList?entry=" ));
+        const rtl::OUString aCmdPrefix( "vnd.sun.star.popup:RecentFileList?entry=" );
 
         m_aRecentFilesItems.clear();
         if (( nPickListMenuItems > 0 ) && !m_bDisabled )
@@ -149,8 +148,6 @@ void RecentFilesMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >
 
                     if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_URL )
                         a >>= aRecentFile.aURL;
-                    else if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_FILTER )
-                        a >>= aRecentFile.aFilter;
                     else if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_TITLE )
                         a >>= aRecentFile.aTitle;
                     else if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_PASSWORD )
@@ -174,17 +171,17 @@ void RecentFilesMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >
                 if ( i <= 9 )
                 {
                     if ( i == 9 )
-                        aMenuShortCut = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "1~0: " ));
+                        aMenuShortCut = rtl::OUString( "1~0: " );
                     else
                     {
                         menuShortCut[1] = (char)( '1' + i );
-                        aMenuShortCut = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( menuShortCut ));
+                        aMenuShortCut = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(menuShortCut) );
                     }
                 }
                 else
                 {
                     aMenuShortCut = rtl::OUString::valueOf((sal_Int32)( i + 1 ));
-                    aMenuShortCut += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ": " ));
+                    aMenuShortCut += rtl::OUString( ": " );
                 }
 
                 // Abbreviate URL
@@ -275,8 +272,6 @@ void RecentFilesMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >
 
 void RecentFilesMenuController::executeEntry( sal_Int32 nIndex )
 {
-    static int NUM_OF_PICKLIST_ARGS = 3;
-
     Reference< css::awt::XPopupMenu > xPopupMenu;
     Reference< XDispatch >            xDispatch;
     Reference< XDispatchProvider >    xDispatchProvider;
@@ -299,34 +294,24 @@ void RecentFilesMenuController::executeEntry( sal_Int32 nIndex )
         aTargetURL.Complete = rRecentFile.aURL;
         m_xURLTransformer->parseStrict( aTargetURL );
 
-        aArgsList.realloc( NUM_OF_PICKLIST_ARGS );
-        aArgsList[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Referer" ));
-        aArgsList[0].Value = makeAny( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SFX_REFERER_USER )));
+        sal_Int32 nSize = 2;
+        aArgsList.realloc(nSize);
+        aArgsList[0].Name = ::rtl::OUString( "Referer" );
+        aArgsList[0].Value = makeAny( ::rtl::OUString(SFX_REFERER_USER ));
 
         // documents in the picklist will never be opened as templates
-        aArgsList[1].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "AsTemplate" ));
+        aArgsList[1].Name = ::rtl::OUString( "AsTemplate" );
         aArgsList[1].Value = makeAny( (sal_Bool) sal_False );
 
-        ::rtl::OUString  aFilter( rRecentFile.aFilter );
-        sal_Int32 nPos = aFilter.indexOf( '|' );
-        if ( nPos >= 0 )
+        if (!m_aModuleName.isEmpty())
         {
-            ::rtl::OUString aFilterOptions;
-
-            if ( nPos < ( aFilter.getLength() - 1 ) )
-                aFilterOptions = aFilter.copy( nPos+1 );
-
-            aArgsList[2].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterOptions" ));
-            aArgsList[2].Value <<= aFilterOptions;
-
-            aFilter = aFilter.copy( 0, nPos-1 );
-            aArgsList.realloc( ++NUM_OF_PICKLIST_ARGS );
+            // Type detection needs to know which app we are opening it from.
+            aArgsList.realloc(++nSize);
+            aArgsList[nSize-1].Name = "DocumentService";
+            aArgsList[nSize-1].Value <<= m_aModuleName;
         }
 
-        aArgsList[NUM_OF_PICKLIST_ARGS-1].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterName" ));
-        aArgsList[NUM_OF_PICKLIST_ARGS-1].Value <<= aFilter;
-
-        xDispatch = xDispatchProvider->queryDispatch( aTargetURL, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("_default")), 0 );
+        xDispatch = xDispatchProvider->queryDispatch( aTargetURL, ::rtl::OUString("_default"), 0 );
     }
 
     if ( xDispatch.is() )
@@ -338,8 +323,6 @@ void RecentFilesMenuController::executeEntry( sal_Int32 nIndex )
         pLoadRecentFile->xDispatch  = xDispatch;
         pLoadRecentFile->aTargetURL = aTargetURL;
         pLoadRecentFile->aArgSeq    = aArgsList;
-        if(::comphelper::UiEventsLogger::isEnabled()) //#i88653#
-            UiEventLogHelper(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RecentFilesMenuController"))).log(m_xServiceManager, m_xFrame, aTargetURL, aArgsList);
         Application::PostUserEvent( STATIC_LINK(0, RecentFilesMenuController, ExecuteHdl_Impl), pLoadRecentFile );
     }
 }
@@ -457,7 +440,7 @@ throw( RuntimeException )
         sal_Int32 nQueryPart = aURL.Complete.indexOf( '?', m_aBaseURL.getLength() );
         if ( nQueryPart > 0 )
         {
-            const rtl::OUString aEntryArgStr( RTL_CONSTASCII_USTRINGPARAM( "entry=" ));
+            const rtl::OUString aEntryArgStr( "entry=" );
             sal_Int32 nEntryArg = aURL.Complete.indexOf( aEntryArgStr, nQueryPart );
             sal_Int32 nEntryPos = nEntryArg + aEntryArgStr.getLength();
             if (( nEntryArg > 0 ) && ( nEntryPos < aURL.Complete.getLength() ))
@@ -506,7 +489,7 @@ IMPL_STATIC_LINK_NOINSTANCE( RecentFilesMenuController, ExecuteHdl_Impl, LoadRec
         // elements if a component gets detached from its frame!
         pLoadRecentFile->xDispatch->dispatch( pLoadRecentFile->aTargetURL, pLoadRecentFile->aArgSeq );
     }
-    catch ( Exception& )
+    catch ( const Exception& )
     {
     }
 
