@@ -67,7 +67,7 @@ static sal_Bool lcl_SeqHasString( const uno::Sequence< OUString > &rSeq, const O
     sal_Bool bRes = sal_False;
 
     sal_Int32 nLen = rSeq.getLength();
-    if (nLen == 0 || rText.getLength() == 0)
+    if (nLen == 0 || rText.isEmpty())
         return bRes;
 
     const OUString *pSeq = rSeq.getConstArray();
@@ -459,7 +459,7 @@ sal_Bool LngSvcMgrListenerHelper::RemoveLngSvcEvtBroadcaster(
 
 
 LngSvcMgr::LngSvcMgr()
-    : utl::ConfigItem(OUString(RTL_CONSTASCII_USTRINGPARAM("Office.Linguistic")))
+    : utl::ConfigItem("Office.Linguistic")
     , aEvtListeners(GetLinguMutex())
 {
     bDisposing = sal_False;
@@ -478,10 +478,10 @@ LngSvcMgr::LngSvcMgr()
     // request notify events when properties (i.e. something in the subtree) changes
     uno::Sequence< OUString > aNames(4);
     OUString *pNames = aNames.getArray();
-    pNames[0] = A2OU( "ServiceManager/SpellCheckerList" );
-    pNames[1] = A2OU( "ServiceManager/GrammarCheckerList" );
-    pNames[2] = A2OU( "ServiceManager/HyphenatorList" );
-    pNames[3] = A2OU( "ServiceManager/ThesaurusList" );
+    pNames[0] = "ServiceManager/SpellCheckerList";
+    pNames[1] = "ServiceManager/GrammarCheckerList";
+    pNames[2] = "ServiceManager/HyphenatorList";
+    pNames[3] = "ServiceManager/ThesaurusList";
     EnableNotification( aNames );
 }
 
@@ -501,10 +501,10 @@ LngSvcMgr::~LngSvcMgr()
 
 void LngSvcMgr::Notify( const uno::Sequence< OUString > &rPropertyNames )
 {
-    const OUString aSpellCheckerList( A2OU("ServiceManager/SpellCheckerList") );
-    const OUString aGrammarCheckerList( A2OU("ServiceManager/GrammarCheckerList") );
-    const OUString aHyphenatorList( A2OU("ServiceManager/HyphenatorList") );
-    const OUString aThesaurusList( A2OU("ServiceManager/ThesaurusList") );
+    const OUString aSpellCheckerList( "ServiceManager/SpellCheckerList" );
+    const OUString aGrammarCheckerList( "ServiceManager/GrammarCheckerList" );
+    const OUString aHyphenatorList( "ServiceManager/HyphenatorList" );
+    const OUString aThesaurusList( "ServiceManager/ThesaurusList" );
 
     const uno::Sequence< OUString > aSpellCheckerListEntries( GetNodeNames( aSpellCheckerList ) );
     const uno::Sequence< OUString > aGrammarCheckerListEntries( GetNodeNames( aGrammarCheckerList ) );
@@ -528,7 +528,7 @@ void LngSvcMgr::Notify( const uno::Sequence< OUString > &rPropertyNames )
         OUString aKeyText;
         if (nKeyStart != -1)
             aKeyText = rName.copy( nKeyStart + 1 );
-        DBG_ASSERT( aKeyText.getLength() != 0, "unexpected key (lang::Locale) string" );
+        DBG_ASSERT( !aKeyText.isEmpty(), "unexpected key (lang::Locale) string" );
         if (0 == rName.compareTo( aSpellCheckerList, aSpellCheckerList.getLength() ))
         {
             // delete old cached data, needs to be acquired new on demand
@@ -547,7 +547,7 @@ void LngSvcMgr::Notify( const uno::Sequence< OUString > &rPropertyNames )
                     aSvcImplNames = GetLangSvcList( aValues.getConstArray()[0] );
 
                 LanguageType nLang = LANGUAGE_NONE;
-                if (0 != aKeyText.getLength())
+                if (!aKeyText.isEmpty())
                     nLang = MsLangId::convertIsoStringToLanguage( aKeyText );
 
                 GetSpellCheckerDsp_Impl( sal_False );     // don't set service list, it will be done below
@@ -572,7 +572,7 @@ void LngSvcMgr::Notify( const uno::Sequence< OUString > &rPropertyNames )
                     aSvcImplNames = GetLangSvc( aValues.getConstArray()[0] );
 
                 LanguageType nLang = LANGUAGE_NONE;
-                if (0 != aKeyText.getLength())
+                if (!aKeyText.isEmpty())
                     nLang = MsLangId::convertIsoStringToLanguage( aKeyText );
 
                 if (SvtLinguConfig().HasGrammarChecker())
@@ -600,7 +600,7 @@ void LngSvcMgr::Notify( const uno::Sequence< OUString > &rPropertyNames )
                     aSvcImplNames = GetLangSvc( aValues.getConstArray()[0] );
 
                 LanguageType nLang = LANGUAGE_NONE;
-                if (0 != aKeyText.getLength())
+                if (!aKeyText.isEmpty())
                     nLang = MsLangId::convertIsoStringToLanguage( aKeyText );
 
                 GetHyphenatorDsp_Impl( sal_False );   // don't set service list, it will be done below
@@ -625,7 +625,7 @@ void LngSvcMgr::Notify( const uno::Sequence< OUString > &rPropertyNames )
                     aSvcImplNames = GetLangSvcList( aValues.getConstArray()[0] );
 
                 LanguageType nLang = LANGUAGE_NONE;
-                if (0 != aKeyText.getLength())
+                if (!aKeyText.isEmpty())
                     nLang = MsLangId::convertIsoStringToLanguage( aKeyText );
 
                 GetThesaurusDsp_Impl( sal_False );  // don't set service list, it will be done below
@@ -682,7 +682,7 @@ void LngSvcMgr::GetGrammarCheckerDsp_Impl( sal_Bool bSetSvcList  )
             uno::Reference< lang::XMultiServiceFactory > xMgr(
                     comphelper::getProcessServiceFactory(), uno::UNO_QUERY_THROW );
             xGCI = uno::Reference< linguistic2::XProofreadingIterator >(
-                    xMgr->createInstance( A2OU( SN_GRAMMARCHECKINGITERATOR ) ), uno::UNO_QUERY_THROW );
+                    xMgr->createInstance( SN_GRAMMARCHECKINGITERATOR ), uno::UNO_QUERY_THROW );
         }
         catch (uno::Exception &)
         {
@@ -737,8 +737,7 @@ void LngSvcMgr::GetAvailableSpellSvcs_Impl()
             uno::Reference< container::XContentEnumerationAccess > xEnumAccess( xFac, uno::UNO_QUERY );
             uno::Reference< container::XEnumeration > xEnum;
             if (xEnumAccess.is())
-                xEnum = xEnumAccess->createContentEnumeration(
-                        A2OU( SN_SPELLCHECKER ) );
+                xEnum = xEnumAccess->createContentEnumeration( SN_SPELLCHECKER );
 
             if (xEnum.is())
             {
@@ -756,12 +755,11 @@ void LngSvcMgr::GetAvailableSpellSvcs_Impl()
                             uno::Reference < uno::XComponentContext > xContext;
                             uno::Reference< beans::XPropertySet > xProps( xFac, uno::UNO_QUERY );
 
-                            xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ))) >>= xContext;
+                            xProps->getPropertyValue( "DefaultContext" ) >>= xContext;
                             xSvc = uno::Reference< linguistic2::XSpellChecker >( ( xCompFactory.is() ? xCompFactory->createInstanceWithContext( xContext ) : xFactory->createInstance() ), uno::UNO_QUERY );
                         }
-                        catch (uno::Exception &rEx)
+                        catch (const uno::Exception &)
                         {
-                            (void) rEx;
                             DBG_ASSERT( 0, "createInstance failed" );
                         }
                     }
@@ -773,7 +771,7 @@ void LngSvcMgr::GetAvailableSpellSvcs_Impl()
                         uno::Reference< XServiceInfo > xInfo( xSvc, uno::UNO_QUERY );
                         if (xInfo.is())
                             aImplName = xInfo->getImplementationName();
-                        DBG_ASSERT( aImplName.getLength(),
+                        DBG_ASSERT( !aImplName.isEmpty(),
                                 "empty implementation name" );
                         uno::Reference< linguistic2::XSupportedLocales > xSuppLoc( xSvc, uno::UNO_QUERY );
                         DBG_ASSERT( xSuppLoc.is(), "interfaces not supported" );
@@ -803,8 +801,7 @@ void LngSvcMgr::GetAvailableGrammarSvcs_Impl()
             uno::Reference< container::XContentEnumerationAccess > xEnumAccess( xFac, uno::UNO_QUERY );
             uno::Reference< container::XEnumeration > xEnum;
             if (xEnumAccess.is())
-                xEnum = xEnumAccess->createContentEnumeration(
-                        A2OU( SN_GRAMMARCHECKER ) );
+                xEnum = xEnumAccess->createContentEnumeration( SN_GRAMMARCHECKER );
 
             if (xEnum.is())
             {
@@ -822,12 +819,11 @@ void LngSvcMgr::GetAvailableGrammarSvcs_Impl()
                             uno::Reference < uno::XComponentContext > xContext;
                             uno::Reference< beans::XPropertySet > xProps( xFac, uno::UNO_QUERY );
 
-                            xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ))) >>= xContext;
+                            xProps->getPropertyValue( "DefaultContext" ) >>= xContext;
                             xSvc = uno::Reference< linguistic2::XProofreader >( ( xCompFactory.is() ? xCompFactory->createInstanceWithContext( xContext ) : xFactory->createInstance() ), uno::UNO_QUERY );
                         }
-                        catch (uno::Exception &rEx)
+                        catch (const uno::Exception &)
                         {
-                            (void) rEx;
                             DBG_ASSERT( 0, "createInstance failed" );
                         }
                     }
@@ -839,7 +835,7 @@ void LngSvcMgr::GetAvailableGrammarSvcs_Impl()
                         uno::Reference< XServiceInfo > xInfo( xSvc, uno::UNO_QUERY );
                         if (xInfo.is())
                             aImplName = xInfo->getImplementationName();
-                        DBG_ASSERT( aImplName.getLength(),
+                        DBG_ASSERT( !aImplName.isEmpty(),
                                 "empty implementation name" );
                         uno::Reference< linguistic2::XSupportedLocales > xSuppLoc( xSvc, uno::UNO_QUERY );
                         DBG_ASSERT( xSuppLoc.is(), "interfaces not supported" );
@@ -868,7 +864,7 @@ void LngSvcMgr::GetAvailableHyphSvcs_Impl()
             uno::Reference< container::XContentEnumerationAccess > xEnumAccess( xFac, uno::UNO_QUERY );
             uno::Reference< container::XEnumeration > xEnum;
             if (xEnumAccess.is())
-                xEnum = xEnumAccess->createContentEnumeration( A2OU( SN_HYPHENATOR ) );
+                xEnum = xEnumAccess->createContentEnumeration( SN_HYPHENATOR );
 
             if (xEnum.is())
             {
@@ -886,13 +882,12 @@ void LngSvcMgr::GetAvailableHyphSvcs_Impl()
                             uno::Reference < uno::XComponentContext > xContext;
                             uno::Reference< beans::XPropertySet > xProps( xFac, uno::UNO_QUERY );
 
-                            xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ))) >>= xContext;
+                            xProps->getPropertyValue( "DefaultContext" ) >>= xContext;
                             xSvc = uno::Reference< linguistic2::XHyphenator >( ( xCompFactory.is() ? xCompFactory->createInstanceWithContext( xContext ) : xFactory->createInstance() ), uno::UNO_QUERY );
 
                         }
-                        catch (uno::Exception &rEx)
+                        catch (const uno::Exception &)
                         {
-                            (void) rEx;
                             DBG_ASSERT( 0, "createInstance failed" );
                         }
                     }
@@ -904,7 +899,7 @@ void LngSvcMgr::GetAvailableHyphSvcs_Impl()
                         uno::Reference< XServiceInfo > xInfo( xSvc, uno::UNO_QUERY );
                         if (xInfo.is())
                             aImplName = xInfo->getImplementationName();
-                        DBG_ASSERT( aImplName.getLength(),
+                        DBG_ASSERT( !aImplName.isEmpty(),
                                 "empty implementation name" );
                         uno::Reference< linguistic2::XSupportedLocales > xSuppLoc( xSvc, uno::UNO_QUERY );
                         DBG_ASSERT( xSuppLoc.is(), "interfaces not supported" );
@@ -934,8 +929,7 @@ void LngSvcMgr::GetAvailableThesSvcs_Impl()
             uno::Reference< container::XContentEnumerationAccess > xEnumAccess( xFac, uno::UNO_QUERY );
             uno::Reference< container::XEnumeration > xEnum;
             if (xEnumAccess.is())
-                xEnum = xEnumAccess->createContentEnumeration(
-                        A2OU( SN_THESAURUS ) );
+                xEnum = xEnumAccess->createContentEnumeration( SN_THESAURUS );
 
             if (xEnum.is())
             {
@@ -954,12 +948,11 @@ void LngSvcMgr::GetAvailableThesSvcs_Impl()
                             uno::Reference < uno::XComponentContext > xContext;
                             uno::Reference< beans::XPropertySet > xProps( xFac, uno::UNO_QUERY );
 
-                            xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ))) >>= xContext;
+                            xProps->getPropertyValue( "DefaultContext" ) >>= xContext;
                             xSvc = uno::Reference< linguistic2::XThesaurus >( ( xCompFactory.is() ? xCompFactory->createInstanceWithContext( xContext ) : xFactory->createInstance() ), uno::UNO_QUERY );
                         }
-                        catch (uno::Exception &rEx)
+                        catch (const uno::Exception &)
                         {
-                            (void) rEx;
                             DBG_ASSERT( 0, "createInstance failed" );
                         }
                     }
@@ -971,7 +964,7 @@ void LngSvcMgr::GetAvailableThesSvcs_Impl()
                         uno::Reference< XServiceInfo > xInfo( xSvc, uno::UNO_QUERY );
                         if (xInfo.is())
                             aImplName = xInfo->getImplementationName();
-                        DBG_ASSERT( aImplName.getLength(),
+                        DBG_ASSERT( !aImplName.isEmpty(),
                                 "empty implementation name" );
                         uno::Reference< linguistic2::XSupportedLocales > xSuppLoc( xSvc, uno::UNO_QUERY );
                         DBG_ASSERT( xSuppLoc.is(), "interfaces not supported" );
@@ -1159,7 +1152,7 @@ uno::Reference< linguistic2::XSpellChecker > SAL_CALL
 {
     osl::MutexGuard aGuard( GetLinguMutex() );
 #if OSL_DEBUG_LEVEL > 1
-    getAvailableLocales( A2OU( SN_SPELLCHECKER ));
+    getAvailableLocales( SN_SPELLCHECKER );
 #endif
 
     uno::Reference< linguistic2::XSpellChecker > xRes;
@@ -1179,7 +1172,7 @@ uno::Reference< linguistic2::XHyphenator > SAL_CALL
 {
     osl::MutexGuard aGuard( GetLinguMutex() );
 #if OSL_DEBUG_LEVEL > 1
-    getAvailableLocales( A2OU( SN_HYPHENATOR ));
+    getAvailableLocales( SN_HYPHENATOR );
 #endif
 
     uno::Reference< linguistic2::XHyphenator >   xRes;
@@ -1199,7 +1192,7 @@ uno::Reference< linguistic2::XThesaurus > SAL_CALL
 {
     osl::MutexGuard aGuard( GetLinguMutex() );
 #if OSL_DEBUG_LEVEL > 1
-    getAvailableLocales( A2OU( SN_THESAURUS ));
+    getAvailableLocales( SN_THESAURUS );
 #endif
 
     uno::Reference< linguistic2::XThesaurus >    xRes;
@@ -1271,9 +1264,8 @@ uno::Sequence< OUString > SAL_CALL
     }
     else if (0 == rServiceName.compareToAscii( SN_GRAMMARCHECKER ))
     {
-        // don't used cached data here (force re-evaluation in order to have downloaded dictionaries
-        // already found without the need to restart the office
-        delete pAvailGrammarSvcs;  pAvailGrammarSvcs = 0;
+// disable force re-loading of the cache - re-start needed for new grammer checkers: fdo#35270
+//        delete pAvailGrammarSvcs;  pAvailGrammarSvcs = 0;
         GetAvailableGrammarSvcs_Impl();
         pInfoArray = pAvailGrammarSvcs;
     }
@@ -1401,7 +1393,7 @@ void SAL_CALL
             if (bChanged)
             {
                 pSpellDsp->SetServiceList( rLocale, rServiceImplNames );
-                SaveCfgSvcs( A2OU( SN_SPELLCHECKER ) );
+                SaveCfgSvcs( rtl::OUString(SN_SPELLCHECKER) );
 
                 if (pListenerHelper  &&  bChanged)
                     pListenerHelper->AddLngSvcEvt(
@@ -1418,7 +1410,7 @@ void SAL_CALL
             if (bChanged)
             {
                 pGrammarDsp->SetServiceList( rLocale, rServiceImplNames );
-                SaveCfgSvcs( A2OU( SN_GRAMMARCHECKER ) );
+                SaveCfgSvcs( rtl::OUString(SN_GRAMMARCHECKER) );
 
                 if (pListenerHelper  &&  bChanged)
                     pListenerHelper->AddLngSvcEvt(
@@ -1434,7 +1426,7 @@ void SAL_CALL
             if (bChanged)
             {
                 pHyphDsp->SetServiceList( rLocale, rServiceImplNames );
-                SaveCfgSvcs( A2OU( SN_HYPHENATOR ) );
+                SaveCfgSvcs( rtl::OUString(SN_HYPHENATOR) );
 
                 if (pListenerHelper  &&  bChanged)
                     pListenerHelper->AddLngSvcEvt(
@@ -1450,7 +1442,7 @@ void SAL_CALL
             if (bChanged)
             {
                 pThesDsp->SetServiceList( rLocale, rServiceImplNames );
-                SaveCfgSvcs( A2OU( SN_THESAURUS ) );
+                SaveCfgSvcs( rtl::OUString(SN_THESAURUS) );
             }
         }
     }
@@ -1471,28 +1463,28 @@ sal_Bool LngSvcMgr::SaveCfgSvcs( const String &rServiceName )
         if (!pSpellDsp)
             GetSpellCheckerDsp_Impl();
         pDsp = pSpellDsp;
-        aLocales = getAvailableLocales( A2OU( SN_SPELLCHECKER ) );
+        aLocales = getAvailableLocales( SN_SPELLCHECKER );
     }
     else if (0 == rServiceName.CompareToAscii( SN_GRAMMARCHECKER ))
     {
         if (!pGrammarDsp)
             GetGrammarCheckerDsp_Impl();
         pDsp = pGrammarDsp;
-        aLocales = getAvailableLocales( A2OU( SN_GRAMMARCHECKER ) );
+        aLocales = getAvailableLocales( SN_GRAMMARCHECKER );
     }
     else if (0 == rServiceName.CompareToAscii( SN_HYPHENATOR ))
     {
         if (!pHyphDsp)
             GetHyphenatorDsp_Impl();
         pDsp = pHyphDsp;
-        aLocales = getAvailableLocales( A2OU( SN_HYPHENATOR ) );
+        aLocales = getAvailableLocales( SN_HYPHENATOR );
     }
     else if (0 == rServiceName.CompareToAscii( SN_THESAURUS ))
     {
         if (!pThesDsp)
             GetThesaurusDsp_Impl();
         pDsp = pThesDsp;
-        aLocales = getAvailableLocales( A2OU( SN_THESAURUS ) );
+        aLocales = getAvailableLocales( SN_THESAURUS );
     }
 
     if (pDsp  &&  aLocales.getLength())
@@ -1574,7 +1566,7 @@ static uno::Sequence< OUString > GetLangSvcList( const uno::Any &rVal )
             for (sal_Int32 j = 0;  j < nSvcs;  ++j)
             {
                 OUString aImplName( pSvcName[j] );
-                DBG_ASSERT( aImplName.getLength(), "service impl-name missing" );
+                DBG_ASSERT( !aImplName.isEmpty(), "service impl-name missing" );
             }
         }
 #endif
@@ -1603,7 +1595,7 @@ static uno::Sequence< OUString > GetLangSvc( const uno::Any &rVal )
     else
     {
         OUString aImplName;
-        if ((rVal >>= aImplName) && aImplName.getLength() != 0)
+        if ((rVal >>= aImplName) && !aImplName.isEmpty())
         {
             aRes.realloc(1);
             aRes.getArray()[0] = aImplName;
@@ -1637,7 +1629,7 @@ uno::Sequence< OUString > SAL_CALL
     OUString *pNames = aNames.getArray();
     if ( 0 == rServiceName.compareToAscii( SN_SPELLCHECKER ) )
     {
-        OUString aNode( RTL_CONSTASCII_USTRINGPARAM("ServiceManager/SpellCheckerList"));
+        OUString aNode( "ServiceManager/SpellCheckerList");
         const uno::Sequence< OUString > aNodeEntries( GetNodeNames( aNode ) );
         if (lcl_SeqHasString( aNodeEntries, aCfgLocale ))
         {
@@ -1652,7 +1644,7 @@ uno::Sequence< OUString > SAL_CALL
     }
     else if ( 0 == rServiceName.compareToAscii( SN_GRAMMARCHECKER ) )
     {
-        OUString aNode( RTL_CONSTASCII_USTRINGPARAM("ServiceManager/GrammarCheckerList"));
+        OUString aNode( "ServiceManager/GrammarCheckerList");
         const uno::Sequence< OUString > aNodeEntries( GetNodeNames( aNode ) );
         if (lcl_SeqHasString( aNodeEntries, aCfgLocale ))
         {
@@ -1667,7 +1659,7 @@ uno::Sequence< OUString > SAL_CALL
     }
     else if ( 0 == rServiceName.compareToAscii( SN_HYPHENATOR ) )
     {
-        OUString aNode( RTL_CONSTASCII_USTRINGPARAM("ServiceManager/HyphenatorList"));
+        OUString aNode( "ServiceManager/HyphenatorList");
         const uno::Sequence< OUString > aNodeEntries( GetNodeNames( aNode ) );
         if (lcl_SeqHasString( aNodeEntries, aCfgLocale ))
         {
@@ -1682,7 +1674,7 @@ uno::Sequence< OUString > SAL_CALL
     }
     else if ( 0 == rServiceName.compareToAscii( SN_THESAURUS ) )
     {
-        OUString aNode( RTL_CONSTASCII_USTRINGPARAM("ServiceManager/ThesaurusList"));
+        OUString aNode( "ServiceManager/ThesaurusList");
         const uno::Sequence< OUString > aNodeEntries( GetNodeNames( aNode ) );
         if (lcl_SeqHasString( aNodeEntries, aCfgLocale ))
         {
@@ -1766,21 +1758,6 @@ sal_Bool LngSvcMgr::AddLngSvcEvtBroadcaster(
 }
 
 
-sal_Bool LngSvcMgr::RemoveLngSvcEvtBroadcaster(
-            const uno::Reference< linguistic2::XLinguServiceEventBroadcaster > &rxBroadcaster )
-{
-    sal_Bool bRes = sal_False;
-    if (rxBroadcaster.is())
-    {
-        DBG_ASSERT( pListenerHelper, "pListenerHelper non existent" );
-        if (!pListenerHelper)
-            GetListenerHelper_Impl();
-        bRes = pListenerHelper->RemoveLngSvcEvtBroadcaster( rxBroadcaster );
-    }
-    return bRes;
-}
-
-
 OUString SAL_CALL
     LngSvcMgr::getImplementationName()
         throw(uno::RuntimeException)
@@ -1820,7 +1797,7 @@ uno::Sequence< OUString > LngSvcMgr::getSupportedServiceNames_Static()
     osl::MutexGuard aGuard( GetLinguMutex() );
 
     uno::Sequence< OUString > aSNS( 1 );    // more than 1 service possible
-    aSNS.getArray()[0] = A2OU( SN_LINGU_SERVCICE_MANAGER );
+    aSNS.getArray()[0] = SN_LINGU_SERVCICE_MANAGER;
     return aSNS;
 }
 
