@@ -120,7 +120,7 @@ void OConnection::construct(const OUString& url, const Sequence< PropertyValue >
     sal_Int32 nIndex;
     sal_Bool  bEmbedded = sal_False;
     OUString token;
-    OUString aHostName(RTL_CONSTASCII_USTRINGPARAM("localhost"));
+    OUString aHostName("localhost");
     sal_Int32 nPort = 3306;
     OUString aDbName;
 
@@ -130,7 +130,7 @@ void OConnection::construct(const OUString& url, const Sequence< PropertyValue >
     // parse url. Url has the following format:
     // external server: sdbc:mysqlc:[hostname]:[port]/[dbname]
 
-    if (!url.compareTo(OUString(RTL_CONSTASCII_USTRINGPARAM(MYSQLC_URI_PREFIX)), sizeof(MYSQLC_URI_PREFIX)-1)) {
+    if (!url.compareTo(OUString(MYSQLC_URI_PREFIX), sizeof(MYSQLC_URI_PREFIX)-1)) {
         nIndex = 12;
     } else {
         bEmbedded = sal_True;
@@ -139,17 +139,17 @@ void OConnection::construct(const OUString& url, const Sequence< PropertyValue >
     }
 
     token = url.getToken(0, '/', nIndex);
-    if (token.getLength()) {
+    if (!token.isEmpty()) {
         sal_Int32 nIndex1 = 0;
         OUString hostandport = token.getToken(0,':', nIndex1);
-        if (hostandport.getLength()) {
+        if (!hostandport.isEmpty()) {
             aHostName = hostandport;
             hostandport = token.getToken(0, ':', nIndex1);
-            if (hostandport.getLength() && nIndex1) {
+            if (!hostandport.isEmpty() && nIndex1) {
                 nPort = hostandport.toInt32();
             }
             token = url.getToken(0, '/', nIndex);
-            if (token.getLength() && nIndex) {
+            if (!token.isEmpty() && nIndex) {
                 aDbName = token;
             }
         }
@@ -202,7 +202,7 @@ void OConnection::construct(const OUString& url, const Sequence< PropertyValue >
             }
 
 #ifndef SYSTEM_MYSQL
-            ::rtl::OUString sMySQLClientLib( RTL_CONSTASCII_USTRINGPARAM( MYSQL_LIB ) );
+            ::rtl::OUString sMySQLClientLib( MYSQL_LIB  );
 
             ::rtl::OUString moduleBase;
             OSL_VERIFY( ::osl::Module::getUrlFromAddress( &thisModule, moduleBase ) );
@@ -237,7 +237,7 @@ void OConnection::construct(const OUString& url, const Sequence< PropertyValue >
             OSL_TRACE("schema=%s", schema_str.c_str());
 
             m_settings.cppConnection.reset(cppDriver->connect(connProps));
-        } catch (sql::SQLException &e) {
+        } catch (const sql::SQLException &e) {
             mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
         }
     } else {
@@ -250,7 +250,7 @@ void OConnection::construct(const OUString& url, const Sequence< PropertyValue >
     // Check if the server is 4.1 or above
     if (this->getMysqlVersion() < 40100) {
         throw SQLException(
-            ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "MySQL Connector/OO.org requires MySQL Server 4.1 or above" ) ),
+            ::rtl::OUString( "MySQL Connector/OO.org requires MySQL Server 4.1 or above"  ),
             *this,
             ::rtl::OUString(),
             0,
@@ -282,7 +282,7 @@ Reference< XStatement > SAL_CALL OConnection::createStatement()
         xReturn = new OStatement(this, m_settings.cppConnection->createStatement());
         m_aStatements.push_back(WeakReferenceHelper(xReturn));
         return xReturn;
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return xReturn;
@@ -306,7 +306,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareStatement(const OUS
         xStatement = new OPreparedStatement(this,
                     m_settings.cppConnection->prepareStatement(OUStringToOString(sSqlStatement, getConnectionEncoding()).getStr()));
         m_aStatements.push_back( WeakReferenceHelper( xStatement ) );
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return xStatement;
@@ -340,7 +340,7 @@ OUString SAL_CALL OConnection::nativeSQL(const OUString& _sSql)
     try {
         sNativeSQL = mysqlc_sdbc_driver::convert(m_settings.cppConnection->nativeSQL(mysqlc_sdbc_driver::convert(sSqlStatement, getConnectionEncoding())),
                                                                                 getConnectionEncoding());
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return sNativeSQL;
@@ -357,7 +357,7 @@ void SAL_CALL OConnection::setAutoCommit(sal_Bool autoCommit)
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     try {
         m_settings.cppConnection->setAutoCommit(autoCommit == sal_True? true:false);
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
 }
@@ -378,7 +378,7 @@ sal_Bool SAL_CALL OConnection::getAutoCommit()
     sal_Bool autoCommit = sal_False;
     try {
         autoCommit = m_settings.cppConnection->getAutoCommit() == true ? sal_True : sal_False;
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return autoCommit;
@@ -395,7 +395,7 @@ void SAL_CALL OConnection::commit()
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     try {
         m_settings.cppConnection->commit();
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
 }
@@ -411,7 +411,7 @@ void SAL_CALL OConnection::rollback()
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     try {
         m_settings.cppConnection->rollback();
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
 }
@@ -443,7 +443,7 @@ Reference< XDatabaseMetaData > SAL_CALL OConnection::getMetaData()
     if (!xMetaData.is()) {
         try {
             xMetaData = new ODatabaseMetaData(*this); // need the connection because it can return it
-        } catch (sql::SQLException & e) {
+        } catch (const sql::SQLException & e) {
             mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
         }
         m_xMetaData = xMetaData;
@@ -510,7 +510,7 @@ OUString SAL_CALL OConnection::getCatalog()
     OUString catalog;
     try {
         catalog = mysqlc_sdbc_driver::convert(m_settings.cppConnection->getSchema(), getConnectionEncoding());
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return catalog;
@@ -549,7 +549,7 @@ void SAL_CALL OConnection::setTransactionIsolation(sal_Int32 level)
     }
     try {
         m_settings.cppConnection->setTransactionIsolation(cpplevel);
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
 }
@@ -573,7 +573,7 @@ sal_Int32 SAL_CALL OConnection::getTransactionIsolation()
             default:
                 ;
         }
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return TransactionIsolation::NONE;
@@ -710,7 +710,7 @@ OUString OConnection::getMysqlVariable(const char *varname)
             Reference< XRow > xRow(rs, UNO_QUERY);
             ret = xRow->getString(2);
         }
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
 
@@ -732,7 +732,7 @@ sal_Int32 OConnection::getMysqlVersion()
         version = 10000 * m_settings.cppConnection->getMetaData()->getDatabaseMajorVersion();
         version += 100 * m_settings.cppConnection->getMetaData()->getDatabaseMinorVersion();
         version += m_settings.cppConnection->getMetaData()->getDatabasePatchVersion();
-    } catch (sql::SQLException & e) {
+    } catch (const sql::SQLException & e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
     }
     return version;
@@ -764,9 +764,9 @@ sal_Int32 OConnection::getMysqlVersion()
         try {
             Sequence< Any > aArgs(1);
             Reference< XConnection> xCon = this;
-            aArgs[0] <<= NamedValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ActiveConnection")), makeAny(xCon));
+            aArgs[0] <<= NamedValue(::rtl::OUString("ActiveConnection"), makeAny(xCon));
 
-            m_xParameterSubstitution.set(m_rDriver.getFactory()->createInstanceWithArguments(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("org.openoffice.comp.helper.ParameterSubstitution")),aArgs),UNO_QUERY);
+            m_xParameterSubstitution.set(m_rDriver.getFactory()->createInstanceWithArguments(::rtl::OUString("org.openoffice.comp.helper.ParameterSubstitution"),aArgs),UNO_QUERY);
         } catch(const Exception&) {}
     }
     if ( m_xParameterSubstitution.is() ) {
