@@ -117,41 +117,6 @@ namespace drawingml {
 #define GET(variable, propName) \
     if ( GETA(propName) ) \
         mAny >>= variable;
-DBG(
-void lcl_dump_pset(Reference< XPropertySet > rXPropSet)
-{
-    Reference< XPropertySetInfo > info = rXPropSet->getPropertySetInfo ();
-    Sequence< beans::Property > props = info->getProperties ();
-
-    for (int i=0; i < props.getLength (); i++) {
-        OString name = OUStringToOString( props [i].Name, RTL_TEXTENCODING_UTF8);
-        fprintf (stderr,"%30s = ", name.getStr() );
-
-    try {
-        Any value = rXPropSet->getPropertyValue( props [i].Name );
-
-        OUString strValue;
-        sal_Int32 intValue;
-        bool boolValue;
-    LineSpacing spacing;
-
-        if( value >>= strValue )
-            fprintf (stderr,"\"%s\"\n", USS( strValue ) );
-        else if( value >>= intValue )
-            fprintf (stderr,"%" SAL_PRIdINT32 "            (hex: %" SAL_PRIxUINT32 ")\n", intValue, intValue);
-        else if( value >>= boolValue )
-            fprintf (stderr,"%d            (bool)\n", boolValue);
-    else if( value >>= spacing ) {
-        fprintf (stderr, "mode: %d value: %d\n", spacing.Mode, spacing.Height);
-    }
-        else
-            fprintf (stderr,"???           <unhandled type>\n");
-    } catch(const Exception &) {
-        fprintf (stderr,"unable to get '%s' value\n", USS(props [i].Name));
-    }
-    }
-}
-);
 
 // not thread safe
 int DrawingML::mnImageCounter = 1;
@@ -447,15 +412,15 @@ void DrawingML::WriteOutline( Reference< XPropertySet > rXPropSet )
 
 OUString DrawingML::WriteImage( const OUString& rURL )
 {
-    ByteString aURLBS(rtl::OUStringToOString(rURL, RTL_TEXTENCODING_UTF8));
+    rtl::OString aURLBS(rtl::OUStringToOString(rURL, RTL_TEXTENCODING_UTF8));
 
     const char aURLBegin[] = "vnd.sun.star.GraphicObject:";
-    int index = aURLBS.Search( aURLBegin );
+    sal_Int32 index = aURLBS.indexOfL(RTL_CONSTASCII_STRINGPARAM(aURLBegin));
 
-    if ( index != STRING_NOTFOUND ) {
-        DBG(printf ("begin: %ld %s\n", long( sizeof( aURLBegin ) ), USS( rURL ) + sizeof( aURLBegin ) - 1 ));
-        aURLBS.Erase( 0, sizeof( aURLBegin ) - 1 );
-        Graphic aGraphic = GraphicObject( aURLBS ).GetTransformedGraphic ();
+    if ( index != -1 )
+    {
+        DBG(printf ("begin: %ld %s\n", long( sizeof( aURLBegin ) ), USS( rURL ) + RTL_CONSTASCII_LENGTH( aURLBegin ) ));
+        Graphic aGraphic = GraphicObject( aURLBS.copy(RTL_CONSTASCII_LENGTH(aURLBegin)) ).GetTransformedGraphic ();
 
         return WriteImage( aGraphic );
     } else {
@@ -620,7 +585,7 @@ void DrawingML::WriteBlipFill( Reference< XPropertySet > rXPropSet, String sURLP
 
         DBG(printf ("URL: %s\n", OUStringToOString( aURL, RTL_TEXTENCODING_UTF8 ).getStr() ));
 
-        if( !aURL.getLength() )
+        if( aURL.isEmpty() )
             return;
 
         mpFS->startElementNS( nXmlNamespace , XML_blipFill, FSEND );
@@ -762,7 +727,7 @@ void DrawingML::WriteRunProperties( Reference< XPropertySet > rRun, sal_Bool bIs
         mAny >>= eLocale;
 
         OUStringBuffer usLanguageBuffer = eLocale.Language;
-        if( eLocale.Country.getLength() ) {
+        if( !eLocale.Country.isEmpty() ) {
             usLanguageBuffer.appendAscii( "-" );
             usLanguageBuffer.append( eLocale.Country );
         }
@@ -774,7 +739,7 @@ void DrawingML::WriteRunProperties( Reference< XPropertySet > rRun, sal_Bool bIs
     mpFS->startElementNS( XML_a, XML_rPr,
                           XML_b, bold,
                           XML_i, italic,
-                          XML_lang, usLanguage.getLength() ? USS( usLanguage ) : NULL,
+                          XML_lang, usLanguage.isEmpty() ? NULL : USS( usLanguage ),
                           XML_sz, nSize == 1800 ? NULL : IS( nSize ),
                           XML_u, underline,
                           FSEND );
@@ -848,7 +813,7 @@ void DrawingML::WriteRunProperties( Reference< XPropertySet > rRun, sal_Bool bIs
     OUString sURL;
 
     mAny >>= sURL;
-    if( sURL.getLength() ) {
+    if( !sURL.isEmpty() ) {
         OUString sRelId = mpFB->addRelation( mpFS->getOutputStream(),
                               US( "http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink" ),
                               sURL, true );
@@ -906,27 +871,27 @@ void DrawingML::GetUUID( OStringBuffer& rBuffer )
     rBuffer.append( '{' );
     for( i = 0; i < 4; i++ ) {
         rBuffer.append( cDigits[ aSeq[i] >> 4 ] );
-        rBuffer.append( cDigits[ aSeq[i] && 0xf ] );
+        rBuffer.append( cDigits[ aSeq[i] & 0xf ] );
     }
     rBuffer.append( '-' );
     for( ; i < 6; i++ ) {
         rBuffer.append( cDigits[ aSeq[i] >> 4 ] );
-        rBuffer.append( cDigits[ aSeq[i] && 0xf ] );
+        rBuffer.append( cDigits[ aSeq[i] & 0xf ] );
     }
     rBuffer.append( '-' );
     for( ; i < 8; i++ ) {
         rBuffer.append( cDigits[ aSeq[i] >> 4 ] );
-        rBuffer.append( cDigits[ aSeq[i] && 0xf ] );
+        rBuffer.append( cDigits[ aSeq[i] & 0xf ] );
     }
     rBuffer.append( '-' );
     for( ; i < 10; i++ ) {
         rBuffer.append( cDigits[ aSeq[i] >> 4 ] );
-        rBuffer.append( cDigits[ aSeq[i] && 0xf ] );
+        rBuffer.append( cDigits[ aSeq[i] & 0xf ] );
     }
     rBuffer.append( '-' );
     for( ; i < 16; i++ ) {
         rBuffer.append( cDigits[ aSeq[i] >> 4 ] );
-        rBuffer.append( cDigits[ aSeq[i] && 0xf ] );
+        rBuffer.append( cDigits[ aSeq[i] & 0xf ] );
     }
     rBuffer.append( '}' );
 }
@@ -937,13 +902,13 @@ void DrawingML::WriteRun( Reference< XTextRange > rRun )
     sal_Bool bIsField = sal_False;
     OUString sText = rRun->getString();
 
-    if( sText.getLength() < 1) {
+    if( sText.isEmpty()) {
         Reference< XPropertySet > xPropSet( rRun, UNO_QUERY );
 
         try {
         if( !xPropSet.is() || !( xPropSet->getPropertyValue( S( "PlaceholderText" ) ) >>= sText ) )
             return;
-        if( sText.getLength() < 1 )
+        if( sText.isEmpty() )
             return;
         }
         catch (const Exception &) {
@@ -1050,22 +1015,22 @@ void DrawingML::WriteParagraphNumbering( Reference< XPropertySet > rXPropSet, sa
                     if ( pValue ) {
                         OUString aPropName( pPropValue[ i ].Name );
                         DBG(printf ("pro name: %s\n", OUStringToOString( aPropName, RTL_TEXTENCODING_UTF8 ).getStr()));
-                        if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "NumberingType" ) ) )
+                        if ( aPropName == "NumberingType" )
                             nNumberingType = *( (sal_Int16*)pValue );
-                        else if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Prefix" ) ) ) {
+                        else if ( aPropName == "Prefix" ) {
                             if( *(OUString*)pValue == US( ")" ) )
                                 bPBoth = true;
-                        } else if  ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Suffix" ) ) ) {
+                        } else if ( aPropName == "Suffix" ) {
                             if( *(OUString*)pValue == US( "." ) )
                                 bSDot = true;
                             else if( *(OUString*)pValue == US( ")" ) )
                                 bPBehind = true;
-                        } else if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "BulletChar" ) ) )
+                        } else if ( aPropName == "BulletChar" )
                         {
                             aBulletChar = String ( *( (String*)pValue ) ).GetChar( 0 );
                             //printf ("bullet char: %d\n", aBulletChar.getStr());
                         }
-                        else if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "BulletFont" ) ) )
+                        else if ( aPropName == "BulletFont" )
                         {
                             aFontDesc = *( (awt::FontDescriptor*)pValue );
                             bHasFontDesc = true;
@@ -1074,15 +1039,15 @@ void DrawingML::WriteParagraphNumbering( Reference< XPropertySet > rXPropSet, sa
                             // instead of a Unicode encoding the encoding RTL_TEXTENCODING_SYMBOL was used.
                             // Because there might exist a lot of damaged documemts I added this two lines
                             // which fixes the bullet problem for the export.
-                            if ( aFontDesc.Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "StarSymbol" ) ) )
+                            if ( aFontDesc.Name == "StarSymbol" )
                                 aFontDesc.CharSet = RTL_TEXTENCODING_MS_1252;
 
-                        } else if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "BulletRelSize" ) ) ) {
+                        } else if ( aPropName == "BulletRelSize" ) {
                             nBulletRelSize = *( (sal_Int16*)pValue );
-                        } else if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "GraphicURL" ) ) ) {
+                        } else if ( aPropName == "GraphicURL" ) {
                             aGraphicURL = ( *(OUString*)pValue );
                             DBG(printf ("graphic url: %s\n", OUStringToOString( aGraphicURL, RTL_TEXTENCODING_UTF8 ).getStr()));
-                        } else if ( aPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "GraphicSize" ) ) )
+                        } else if ( aPropName == "GraphicSize" )
                         {
                             if ( pPropValue[ i ].Value.getValueType() == ::getCppuType( (awt::Size*)0) )
                             {
@@ -1100,7 +1065,7 @@ void DrawingML::WriteParagraphNumbering( Reference< XPropertySet > rXPropSet, sa
                 const char* pAutoNumType = GetAutoNumType( nNumberingType, bSDot, bPBehind, bPBoth );
 
                 if( nLevel >= 0 ) {
-                    if( aGraphicURL.getLength() > 0 ) {
+                    if( !aGraphicURL.isEmpty() ) {
                         OUString sRelId = WriteImage( aGraphicURL );
 
                         mpFS->startElementNS( XML_a, XML_buBlip, FSEND );
@@ -1497,8 +1462,8 @@ sal_Unicode DrawingML::SubstituteBullet( sal_Unicode cBulletId, ::com::sun::star
 {
     String sNumStr = cBulletId;
 
-    if ( rFontDesc.Name.equalsIgnoreAsciiCaseAscii("starsymbol") ||
-         rFontDesc.Name.equalsIgnoreAsciiCaseAscii("opensymbol") )  {
+    if ( rFontDesc.Name.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("starsymbol")) ||
+         rFontDesc.Name.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("opensymbol")) )  {
         String sFontName = rFontDesc.Name;
         rtl_TextEncoding aCharSet = rFontDesc.CharSet;
 
