@@ -29,22 +29,17 @@
 #include "GroupsSorting.hrc"
 #include <connectivity/dbtools.hxx>
 #include <svtools/editbrowsebox.hxx>
+#include <svtools/imgdef.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/container/XContainerListener.hpp>
 #include <com/sun/star/report/GroupOn.hpp>
 #include <com/sun/star/sdbc/DataType.hpp>
 
-#include <sal/macros.h>
 #include <tools/debug.hxx>
 #include "RptResId.hrc"
 #include "rptui_slotid.hrc"
 #include "ModuleHelper.hxx"
 #include "helpids.hrc"
-
-#include <svx/globlmn.hrc>
-#include <svx/svxids.hrc>
-#include <svtools/imgdef.hxx>
-
 #include "GroupExchange.hxx"
 #include "UITools.hxx"
 #include "UndoActions.hxx"
@@ -57,7 +52,6 @@
 #include <vcl/mnemonic.hxx>
 #include <vcl/msgbox.hxx>
 #include <algorithm>
-#include <boost/bind.hpp>
 
 #include <cppuhelper/bootstrap.hxx>
 
@@ -84,7 +78,7 @@ using namespace ::comphelper;
             if ( xColumn->getPropertySetInfo()->hasPropertyByName(PROPERTY_LABEL) )
                 xColumn->getPropertyValue(PROPERTY_LABEL) >>= sLabel;
             o_aColumnList.push_back( ColumnInfo(*pEntries,sLabel) );
-            if ( sLabel.getLength() )
+            if ( !sLabel.isEmpty() )
                 _rListBox.InsertEntry( sLabel );
             else
                 _rListBox.InsertEntry( *pEntries );
@@ -169,8 +163,6 @@ protected:
 
 private:
 
-    DECL_LINK( AsynchActivate, void* );
-    DECL_LINK( AsynchDeactivate, void* );
     DECL_LINK( DelayedPaste, void* );
     DECL_LINK( CBChangeHdl,ComboBox*);
 
@@ -382,7 +374,7 @@ void OFieldExpressionControl::lateInit()
         m_pComboCell->SetHelpId(HID_RPT_FIELDEXPRESSION);
 
         Control* pControls[] = {m_pComboCell};
-        for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+        for (size_t i = 0; i < sizeof(pControls)/sizeof(pControls[0]); ++i)
         {
             pControls[i]->SetGetFocusHdl(LINK(m_pParent, OGroupsSortingDialog, OnControlFocusGot));
             pControls[i]->SetLoseFocusHdl(LINK(m_pParent, OGroupsSortingDialog, OnControlFocusLost));
@@ -412,19 +404,6 @@ IMPL_LINK( OFieldExpressionControl, CBChangeHdl, ComboBox*, /*pComboBox*/ )
     SaveModified();
     return 0L;
 }
-//------------------------------------------------------------------------------
-IMPL_LINK(OFieldExpressionControl, AsynchActivate, void*, EMPTYARG)
-{
-    ActivateCell();
-    return 0L;
-}
-
-//------------------------------------------------------------------------------
-IMPL_LINK(OFieldExpressionControl, AsynchDeactivate, void*, EMPTYARG)
-{
-    DeactivateCell();
-    return 0L;
-}
 
 //------------------------------------------------------------------------------
 sal_Bool OFieldExpressionControl::IsTabAllowed(sal_Bool /*bForward*/) const
@@ -535,7 +514,7 @@ String OFieldExpressionControl::GetCellText( long nRow, sal_uInt16 /*nColId*/ )
             {
                 if ( aIter->sColumnName == sExpression )
                 {
-                    if ( aIter->sLabel.getLength() )
+                    if ( !aIter->sLabel.isEmpty() )
                         sExpression = aIter->sLabel;
                     break;
                 }
@@ -994,24 +973,24 @@ OGroupsSortingDialog::OGroupsSortingDialog( Window* _pParent
     DBG_CTOR( rpt_OGroupsSortingDialog,NULL);
 
     Control* pControlsLst[] = { &m_aHeaderLst, &m_aFooterLst, &m_aGroupOnLst, &m_aKeepTogetherLst, &m_aOrderLst, &m_aGroupIntervalEd};
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControlsLst); ++i)
+    for (size_t i = 0; i < sizeof (pControlsLst) / sizeof (pControlsLst[0]); ++i)
     {
         pControlsLst[i]->SetGetFocusHdl(LINK(this, OGroupsSortingDialog, OnControlFocusGot));
         pControlsLst[i]->SetLoseFocusHdl(LINK(this, OGroupsSortingDialog, OnControlFocusLost));
         pControlsLst[i]->Show(sal_True);
     }
 
-    for (size_t i = 0; i < (SAL_N_ELEMENTS(pControlsLst))-1; ++i)
+    for (size_t i = 0; i < (sizeof (pControlsLst) / sizeof (pControlsLst[0])) - 1; ++i)
         static_cast<ListBox*>(pControlsLst[i])->SetSelectHdl(LINK(this,OGroupsSortingDialog,LBChangeHdl));
 
     Control* pControls[]    = { &m_aHeader, &m_aFooter, &m_aGroupOn, &m_aGroupInterval, &m_aKeepTogether, &m_aOrder
                                 , &m_aMove,&m_aFL2};
     sal_Int32 nMaxTextWidth = 0;
     MnemonicGenerator aMnemonicGenerator;
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+    for (size_t i = 0; i < sizeof (pControlsLst) / sizeof (pControlsLst[0]); ++i)
         aMnemonicGenerator.RegisterMnemonic( pControls[i]->GetText() );
 
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+    for (size_t i = 0; i < sizeof (pControlsLst) / sizeof (pControlsLst[0]); ++i)
     {
         pControls[i]->Show(sal_True);
         String sText = pControls[i]->GetText();
@@ -1141,7 +1120,7 @@ void OGroupsSortingDialog::SaveData( sal_Int32 _nRow)
         xGroup->setSortAscending( m_aOrderLst.GetSelectEntryPos() == 0 );
 
     ListBox* pControls[] = { &m_aHeaderLst,&m_aFooterLst,&m_aGroupOnLst,&m_aKeepTogetherLst,&m_aOrderLst};
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+    for (size_t i = 0; i < sizeof(pControls)/sizeof(pControls[0]); ++i)
         pControls[i]->SaveValue();
 }
 
@@ -1173,7 +1152,7 @@ IMPL_LINK(OGroupsSortingDialog, OnControlFocusGot, Control*, pControl )
     if ( m_pFieldExpression && m_pFieldExpression->getExpressionControl() )
     {
         Control* pControls[] = { m_pFieldExpression->getExpressionControl(),&m_aHeaderLst,&m_aFooterLst,&m_aGroupOnLst,&m_aGroupIntervalEd,&m_aKeepTogetherLst,&m_aOrderLst};
-        for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+        for (size_t i = 0; i < sizeof(pControls)/sizeof(pControls[0]); ++i)
         {
             if ( pControl == pControls[i] )
             {
@@ -1325,7 +1304,7 @@ void OGroupsSortingDialog::displayGroup(const uno::Reference<report::XGroup>& _x
         case sdbc::DataType::TIMESTAMP:
             {
                 sal_uInt16 nIds[] = { STR_RPT_YEAR, STR_RPT_QUARTER,STR_RPT_MONTH,STR_RPT_WEEK,STR_RPT_DAY,STR_RPT_HOUR,STR_RPT_MINUTE };
-                for (sal_uInt16 i = 0; i < SAL_N_ELEMENTS(nIds); ++i)
+                for (sal_uInt16 i = 0; i < sizeof (nIds) / sizeof (nIds[0]); ++i)
                 {
                     m_aGroupOnLst.InsertEntry(String(ModuleRes(nIds[i])));
                     m_aGroupOnLst.SetEntryData(i+1,reinterpret_cast<void*>(i+2));
@@ -1374,19 +1353,19 @@ void OGroupsSortingDialog::displayGroup(const uno::Reference<report::XGroup>& _x
             nPos = 0;
     }
     m_aGroupOnLst.SelectEntryPos(nPos);
-    m_aGroupIntervalEd.SetText(String::CreateFromInt32(_xGroup->getGroupInterval()));
+    m_aGroupIntervalEd.SetText(rtl::OUString::valueOf(_xGroup->getGroupInterval()));
     m_aGroupIntervalEd.SaveValue();
     m_aGroupIntervalEd.Enable( nPos != 0 );
     m_aKeepTogetherLst.SelectEntryPos(_xGroup->getKeepTogether());
     m_aOrderLst.SelectEntryPos(_xGroup->getSortAscending() ? 0 : 1);
 
     ListBox* pControls[] = { &m_aHeaderLst,&m_aFooterLst,&m_aGroupOnLst,&m_aKeepTogetherLst,&m_aOrderLst};
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+    for (size_t i = 0; i < sizeof(pControls)/sizeof(pControls[0]); ++i)
         pControls[i]->SaveValue();
 
     ListBox* pControlsLst2[] = { &m_aHeaderLst, &m_aFooterLst,  &m_aGroupOnLst, &m_aKeepTogetherLst,&m_aOrderLst};
     sal_Bool bReadOnly = !m_pController->isEditable();
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControlsLst2); ++i)
+    for (size_t i = 0; i < sizeof(pControlsLst2)/sizeof(pControlsLst2[0]); ++i)
         pControlsLst2[i]->SetReadOnly(bReadOnly);
     m_aGroupIntervalEd.SetReadOnly(bReadOnly);
 }
@@ -1401,12 +1380,12 @@ void OGroupsSortingDialog::Resize()
     Control* pControlsLst[] = { &m_aHeaderLst,  &m_aFooterLst,  &m_aGroupOnLst, &m_aGroupIntervalEd,&m_aKeepTogetherLst,&m_aOrderLst};
     Control* pControls[]    = { &m_aHeader,     &m_aFooter,     &m_aGroupOn,    &m_aGroupInterval,  &m_aKeepTogether,   &m_aOrder};
     sal_Int32 nMaxTextWidth = 0;
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+    for (size_t i = 0; i < sizeof (pControlsLst) / sizeof (pControlsLst[0]); ++i)
     {
         nMaxTextWidth = ::std::max<sal_Int32>(static_cast<sal_Int32>(GetTextWidth(pControls[i]->GetText())),nMaxTextWidth);
     }
 
-    for (size_t i = 0; i < SAL_N_ELEMENTS(pControls); ++i)
+    for (size_t i = 0; i < sizeof (pControlsLst) / sizeof (pControlsLst[0]); ++i)
     {
         pControls[i]->SetSizePixel(Size(nMaxTextWidth,pControls[i]->GetSizePixel().Height()));
         Point aPos = pControls[i]->GetPosPixel();
