@@ -74,6 +74,7 @@ using ::rtl::OString;
 using ::rtl::OStringBuffer;
 using ::rtl::OStringToOUString;
 using comphelper::string::getToken;
+using comphelper::string::getTokenCount;
 
 /*************** F o r w a r d s *****************************************/
 /*************** G l o b a l e   V a r i a b l e n **********************/
@@ -118,7 +119,6 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
     char *          pStr;
     char **         ppStr;
     RscPtrPtr       aCmdLine;       // Kommandozeile
-    ByteString      aString;
     sal_uInt32      i;
     sal_Bool        bOutputSrsIsSet = sal_False;
 
@@ -215,7 +215,7 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
             }
             else if( !rsc_strnicmp( (*ppStr) + 1, "fs=", 3 ) )
             { // anderer Name fuer .rc-file
-                if( m_aOutputFiles.back().aOutputRc.Len() )
+                if( m_aOutputFiles.back().aOutputRc.getLength() )
                     m_aOutputFiles.push_back( OutputFile() );
                 m_aOutputFiles.back().aOutputRc = (*ppStr) + 4;
             }
@@ -224,17 +224,20 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
                 const rtl::OString aSysSearchDir( (*ppStr)+5 );
 
                 // ignore empty -lip= arguments that we get lots of these days
-                if (aSysSearchDir.getLength())
+                if (!aSysSearchDir.isEmpty())
                 {
-                    DirEntry aSysDir( String( aSysSearchDir, RTL_TEXTENCODING_ASCII_US ) );
+                    DirEntry aSysDir(rtl::OStringToOUString(aSysSearchDir, RTL_TEXTENCODING_ASCII_US));
                     m_aOutputFiles.back().aSysSearchDirs.push_back(
                         rtl::OUStringToOString(aSysDir.GetFull(), RTL_TEXTENCODING_ASCII_US) );
-                    if( m_aOutputFiles.back().aLangSearchPath.Len() )
+                    rtl::OString aLangSearchPath = m_aOutputFiles.back().aLangSearchPath;
+                    if( !aLangSearchPath.isEmpty() )
                     {
-                        m_aOutputFiles.back().aLangSearchPath.Append(
-                        rtl::OUStringToOString(DirEntry::GetSearchDelimiter(), RTL_TEXTENCODING_ASCII_US) );
+                        aLangSearchPath = aLangSearchPath +
+                        rtl::OUStringToOString(DirEntry::GetSearchDelimiter(), RTL_TEXTENCODING_ASCII_US);
                     }
-                    m_aOutputFiles.back().aLangSearchPath.Append( aSysSearchDir );
+                    aLangSearchPath = aLangSearchPath + aSysSearchDir;
+
+                    m_aOutputFiles.back().aLangSearchPath = aLangSearchPath;
                 }
             }
             else if( !rsc_strnicmp( (*ppStr) + 1, "fp=", 3 ) )
@@ -284,11 +287,11 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
             }
             else if( !rsc_stricmp( (*ppStr) + 1, "lg" ) )
             {
-                m_aOutputFiles.back().aLangName = ByteString();
+                m_aOutputFiles.back().aLangName = rtl::OString();
             }
             else if( !rsc_strnicmp( (*ppStr) + 1, "lg", 2 ) )
             {
-                if( m_aOutputFiles.back().aLangName.Len() )
+                if( !m_aOutputFiles.back().aLangName.isEmpty() )
                     m_aOutputFiles.push_back( OutputFile() );
                 m_aOutputFiles.back().aLangName = rtl::OString((*ppStr)+3);
             }
@@ -312,7 +315,7 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
         ::std::list<OutputFile>::iterator it;
         for( it = m_aOutputFiles.begin(); it != m_aOutputFiles.end(); ++it )
         {
-            if( ! it->aOutputRc.Len() )
+            if( it->aOutputRc.isEmpty() )
                 it->aOutputRc  = ::OutputFile( *aInputList.front(), "rc"  );
         }
         if( ! bOutputSrsIsSet )
@@ -394,10 +397,10 @@ RscCompiler::RscCompiler( RscCmdLine * pLine, RscTypCont * pTypCont )
     pCL = pLine;
     pTC = pTypCont;
 
-    if( pCL->aOutputLst.Len() )
+    if( !pCL->aOutputLst.isEmpty() )
     {
-        if ( NULL == (fListing = fopen( pCL->aOutputLst.GetBuffer(), "w" )) )
-            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), pCL->aOutputLst.GetBuffer() );
+        if ( NULL == (fListing = fopen( pCL->aOutputLst.getStr(), "w" )) )
+            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), pCL->aOutputLst.getStr() );
         pTC->pEH->SetListFile( fListing );
     }
 }
@@ -416,14 +419,14 @@ RscCompiler::~RscCompiler()
 
     if( fExitFile )
         fclose( fExitFile );
-    if( aTmpOutputHxx.Len() )
-        unlink( aTmpOutputHxx.GetBuffer() );
-    if( aTmpOutputCxx.Len() )
-        unlink( aTmpOutputCxx.GetBuffer() );
-    if( aTmpOutputRcCtor.Len() )
-        unlink( aTmpOutputRcCtor.GetBuffer() );
-    if( aTmpOutputSrc.Len() )
-        unlink( aTmpOutputSrc.GetBuffer() );
+    if( !aTmpOutputHxx.isEmpty() )
+        unlink( aTmpOutputHxx.getStr() );
+    if( !aTmpOutputCxx.isEmpty() )
+        unlink( aTmpOutputCxx.getStr() );
+    if( !aTmpOutputRcCtor.isEmpty() )
+        unlink( aTmpOutputRcCtor.getStr() );
+    if( !aTmpOutputSrc.isEmpty() )
+        unlink( aTmpOutputSrc.getStr() );
 }
 
 /*************************************************************************
@@ -510,21 +513,21 @@ ERRTYPE RscCompiler::Start()
 *************************************************************************/
 void RscCompiler::EndCompile()
 {
-    if( pCL->aOutputSrs.Len() && (pCL->nCommands & NOLINK_FLAG) )
+    if( !pCL->aOutputSrs.isEmpty() && (pCL->nCommands & NOLINK_FLAG) )
     {
         pTC->pEH->StdOut( "Writing file ", RscVerbosityVerbose );
-        pTC->pEH->StdOut( pCL->aOutputSrs.GetBuffer(), RscVerbosityVerbose );
+        pTC->pEH->StdOut( pCL->aOutputSrs.getStr(), RscVerbosityVerbose );
         pTC->pEH->StdOut( ".\n", RscVerbosityVerbose );
 
         // kopiere von TMP auf richtigen Namen
-        unlink( pCL->aOutputSrs.GetBuffer() );   // Zieldatei loeschen
+        unlink( pCL->aOutputSrs.getStr() );   // Zieldatei loeschen
         if( !(pCL->nCommands & NOSYNTAX_FLAG) )
         {
             FILE        * foutput;
             RscFile     * pFN;
 
-            if( NULL == (foutput = fopen( pCL->aOutputSrs.GetBuffer(), "w" )) )
-                pTC->pEH->FatalError( ERR_OPENFILE, RscId(), pCL->aOutputSrs.GetBuffer() );
+            if( NULL == (foutput = fopen( pCL->aOutputSrs.getStr(), "w" )) )
+                pTC->pEH->FatalError( ERR_OPENFILE, RscId(), pCL->aOutputSrs.getStr() );
             else
             {
                 // Schreibe Datei
@@ -533,8 +536,7 @@ void RscCompiler::EndCompile()
                 {
                     if( !pFN->IsIncFile() )
                     {
-                        pTC->WriteSrc( foutput, NOFILE_INDEX,
-                                       RTL_TEXTENCODING_UNICODE, sal_False );
+                        pTC->WriteSrc( foutput, NOFILE_INDEX, sal_False );
                         break; // ?T 281091MM nur eine Src-Datei
                     }
                 };
@@ -544,64 +546,64 @@ void RscCompiler::EndCompile()
         };
     }
 
-    if ( aTmpOutputHxx.Len() )
+    if ( !aTmpOutputHxx.isEmpty() )
     {
         pTC->pEH->StdOut( "Writing file ", RscVerbosityVerbose );
-        pTC->pEH->StdOut( pCL->aOutputHxx.GetBuffer(), RscVerbosityVerbose );
+        pTC->pEH->StdOut( pCL->aOutputHxx.getStr(), RscVerbosityVerbose );
         pTC->pEH->StdOut( ".\n", RscVerbosityVerbose );
 
         // kopiere von TMP auf richtigen Namen
-        unlink( pCL->aOutputHxx.GetBuffer() );   // Zieldatei loeschen
+        unlink( pCL->aOutputHxx.getStr() );   // Zieldatei loeschen
         Append( pCL->aOutputHxx, aTmpOutputHxx );
-        unlink( aTmpOutputHxx.GetBuffer() );// TempDatei  loeschen
-        aTmpOutputHxx = ByteString();
+        unlink( aTmpOutputHxx.getStr() );// TempDatei  loeschen
+        aTmpOutputHxx = rtl::OString();
     }
 
-    if( aTmpOutputCxx.Len() )
+    if( !aTmpOutputCxx.isEmpty() )
     {
         pTC->pEH->StdOut( "Writing file ", RscVerbosityVerbose );
-        pTC->pEH->StdOut( pCL->aOutputCxx.GetBuffer(), RscVerbosityVerbose );
+        pTC->pEH->StdOut( pCL->aOutputCxx.getStr(), RscVerbosityVerbose );
         pTC->pEH->StdOut( ".\n", RscVerbosityVerbose );
 
         // kopiere von TMP auf richtigen Namen
-        unlink( pCL->aOutputCxx.GetBuffer() );   // Zieldatei loeschen
+        unlink( pCL->aOutputCxx.getStr() );   // Zieldatei loeschen
         Append( pCL->aOutputCxx, aTmpOutputCxx );
-        unlink( aTmpOutputCxx.GetBuffer() );// TempDatei  loeschen
-        aTmpOutputCxx = ByteString();
+        unlink( aTmpOutputCxx.getStr() );// TempDatei  loeschen
+        aTmpOutputCxx = rtl::OString();
     }
 
-    if( aTmpOutputRcCtor.Len() )
+    if( !aTmpOutputRcCtor.isEmpty() )
     {
         pTC->pEH->StdOut( "Writing file ", RscVerbosityVerbose );
-        pTC->pEH->StdOut( pCL->aOutputRcCtor.GetBuffer(), RscVerbosityVerbose );
+        pTC->pEH->StdOut( pCL->aOutputRcCtor.getStr(), RscVerbosityVerbose );
         pTC->pEH->StdOut( ".\n", RscVerbosityVerbose );
 
         // kopiere von TMP auf richtigen Namen
-        unlink( pCL->aOutputRcCtor.GetBuffer() );   // Zieldatei loeschen
+        unlink( pCL->aOutputRcCtor.getStr() );   // Zieldatei loeschen
         Append( pCL->aOutputRcCtor, aTmpOutputRcCtor );
-        unlink( aTmpOutputRcCtor.GetBuffer() );// TempDatei  loeschen
-        aTmpOutputRcCtor = ByteString();
+        unlink( aTmpOutputRcCtor.getStr() );// TempDatei  loeschen
+        aTmpOutputRcCtor = rtl::OString();
     }
 
-    if( aTmpOutputSrc.Len() )
+    if( !aTmpOutputSrc.isEmpty() )
     {
         // kopiere von TMP auf richtigen Namen
-        unlink( pCL->aOutputSrc.GetBuffer() );   // Zieldatei loeschen
+        unlink( pCL->aOutputSrc.getStr() );   // Zieldatei loeschen
         Append( pCL->aOutputSrc, aTmpOutputSrc );
-        unlink( aTmpOutputSrc.GetBuffer() );// TempDatei  loeschen
-        aTmpOutputSrc = ByteString();
+        unlink( aTmpOutputSrc.getStr() );// TempDatei  loeschen
+        aTmpOutputSrc = rtl::OString();
     }
 
-    if( pCL->aTouchFile.Len() )
+    if( !pCL->aTouchFile.isEmpty() )
     {
-        FILE* fp = fopen( pCL->aTouchFile.GetBuffer(), "w" );
+        FILE* fp = fopen( pCL->aTouchFile.getStr(), "w" );
         if( fp )
         {
             fprintf( fp, "Done\n" );
             fclose( fp );
         }
         else
-            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), pCL->aTouchFile.GetBuffer() );
+            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), pCL->aTouchFile.getStr() );
     }
 }
 
@@ -631,7 +633,6 @@ ERRTYPE RscCompiler :: IncludeParser( sal_uLong lFileKey )
         else
         {
             RscFile         * pFNTmp;
-            ByteString        aPathName;
             RscDepend       * pDep;
             RscFileInst       aFileInst( pTC, lFileKey, lFileKey, finput );
 
@@ -822,7 +823,7 @@ ERRTYPE RscCompiler::Link()
                 OSL_TRACE("temporary rc file: %s", aRcTmp.getStr());
 
                 OUString sOilDirUrl;
-                if(pCL->aILDir.Len())
+                if(!pCL->aILDir.isEmpty())
                     sOilDirUrl = lcl_getAbsoluteUrl(sPwdUrl, pCL->aILDir);
                 else
                     sOilDirUrl = sTempDirUrl;
@@ -858,11 +859,11 @@ ERRTYPE RscCompiler::Link()
             pTC->SetSourceCharSet( RTL_TEXTENCODING_UTF8 );
             pTC->ClearSysNames();
             rtl::OStringBuffer aSysSearchPath(it->aLangSearchPath);
-            xub_StrLen nIndex = 0;
-            ByteString aSearchPath = pTC->GetSearchPath();
-            while( nIndex != STRING_NOTFOUND )
+            sal_Int32 nIndex = 0;
+            rtl::OString aSearchPath = pTC->GetSearchPath();
+            do
             {
-                ByteString aToken = aSearchPath.GetToken( 0, cSearchDelim, nIndex );
+                rtl::OString aToken = aSearchPath.getToken( 0, cSearchDelim, nIndex );
                 if (aSysSearchPath.getLength())
                     aSysSearchPath.append(cSearchDelim);
                 aSysSearchPath.append(aToken);
@@ -871,7 +872,8 @@ ERRTYPE RscCompiler::Link()
                 aSysSearchPath.append(cSearchDelim);
                 aSysSearchPath.append(aToken);
             }
-            OSL_TRACE( "setting search path for language %s: %s", it->aLangName.GetBuffer(), aSysSearchPath.getStr() );
+            while ( nIndex >= 0 );
+            OSL_TRACE( "setting search path for language %s: %s", it->aLangName.getStr(), aSysSearchPath.getStr() );
             pTC->SetSysSearchPath(aSysSearchPath.makeStringAndClear());
 
             WriteRcContext  aContext;
@@ -882,7 +884,7 @@ ERRTYPE RscCompiler::Link()
             aContext.pCmdLine = pCL;
 
             // create empty sys list
-            if( aContext.aOutputSysList.getLength() )
+            if( !aContext.aOutputSysList.isEmpty() )
             {
                 FILE* pSysListFile = fopen( aContext.aOutputSysList.getStr(), "wb" );
 
@@ -906,8 +908,8 @@ ERRTYPE RscCompiler::Link()
 
             fclose( foutput );
             fExitFile = NULL;
-            unlink( it->aOutputRc.GetBuffer() );
-            if( rename( aRcTmp.getStr(), it->aOutputRc.GetBuffer() ) )
+            unlink( it->aOutputRc.getStr() );
+            if( rename( aRcTmp.getStr(), it->aOutputRc.getStr() ) )
             {
                 OStringBuffer aBuf;
                 aBuf.append( aRcTmp );
@@ -918,7 +920,7 @@ ERRTYPE RscCompiler::Link()
             else
             {
 #ifdef UNX
-                chmod( it->aOutputRc.GetBuffer(), S_IRWXU | S_IRWXG | S_IROTH );
+                chmod( it->aOutputRc.getStr(), S_IRWXU | S_IRWXG | S_IROTH );
 #endif
             }
 
@@ -953,11 +955,11 @@ ERRTYPE RscCompiler::Link()
     }
 
     // hxx-Datei schreiben
-    if( pCL->aOutputHxx.Len() && aError.IsOk() )
+    if( !pCL->aOutputHxx.isEmpty() && aError.IsOk() )
     {
         aTmpOutputHxx = ::GetTmpFileName();
-        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputHxx.GetBuffer(), "w" )) )
-            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputHxx.GetBuffer() );
+        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputHxx.getStr(), "w" )) )
+            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputHxx.getStr() );
 
         pTC->pEH->StdOut( "Generating .hxx file\n" );
 
@@ -969,20 +971,20 @@ ERRTYPE RscCompiler::Link()
     }
 
     // cxx-Datei schreiben
-    if( pCL->aOutputCxx.Len() && aError.IsOk() )
+    if( !pCL->aOutputCxx.isEmpty() && aError.IsOk() )
     {
         aTmpOutputCxx = ::GetTmpFileName();
-        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputCxx.GetBuffer(), "w" )) )
-            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputCxx.GetBuffer() );
+        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputCxx.getStr(), "w" )) )
+            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputCxx.getStr() );
 
         pTC->pEH->StdOut( "Generating .cxx file\n" );
 
-        ByteString aHxx = pCL->aOutputHxx;
-        if( !aHxx.Len() )
+        rtl::OString aHxx = pCL->aOutputHxx;
+        if( aHxx.isEmpty() )
         {
             UniString aUniOutputCxx( pCL->aOutputCxx, RTL_TEXTENCODING_ASCII_US );
-            aHxx = rtl::OUStringToOString(DirEntry( aUniOutputCxx ).GetBase(), RTL_TEXTENCODING_ASCII_US);
-            aHxx += ".hxx";
+            aHxx = rtl::OStringBuffer(rtl::OUStringToOString(DirEntry(aUniOutputCxx).GetBase(),
+                RTL_TEXTENCODING_ASCII_US)).append(".hxx").makeStringAndClear();
         }
 
         // Schreibe Datei
@@ -993,11 +995,11 @@ ERRTYPE RscCompiler::Link()
     }
 
     // RcCtor-Datei schreiben
-    if( pCL->aOutputRcCtor.Len() && aError.IsOk() )
+    if( !pCL->aOutputRcCtor.isEmpty() && aError.IsOk() )
     {
         aTmpOutputRcCtor = ::GetTmpFileName();
-        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputRcCtor.GetBuffer(), "w" )) )
-            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputRcCtor.GetBuffer() );
+        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputRcCtor.getStr(), "w" )) )
+            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputRcCtor.getStr() );
 
         pTC->pEH->StdOut( "Generating .cxx ressource constructor file\n" );
 
@@ -1009,14 +1011,14 @@ ERRTYPE RscCompiler::Link()
     }
 
     // src-Datei schreiben
-    if( pCL->aOutputSrc.Len() && aError.IsOk() )
+    if( !pCL->aOutputSrc.isEmpty() && aError.IsOk() )
     {
         aTmpOutputSrc = ::GetTmpFileName();
-        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputSrc.GetBuffer(), "w" )) )
-            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputSrc.GetBuffer() );
+        if ( NULL == (fExitFile = foutput = fopen( aTmpOutputSrc.getStr(), "w" )) )
+            pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputSrc.getStr() );
 
         // Schreibe Datei
-        pTC->WriteSrc( foutput, NOFILE_INDEX, RTL_TEXTENCODING_UNICODE );
+        pTC->WriteSrc( foutput, NOFILE_INDEX );
 
         fclose( foutput );
         fExitFile = NULL;
@@ -1033,15 +1035,14 @@ ERRTYPE RscCompiler::Link()
 /*                                                                  */
 /*  Description :   appends text files                              */
 /********************************************************************/
-void RscCompiler::Append( const ByteString& rOutputSrs,
-                          const ByteString& rTmpFile )
+void RscCompiler::Append( const rtl::OString& rOutputSrs,
+                          const rtl::OString& rTmpFile )
 {
     if( !::Append( rOutputSrs, rTmpFile ) )
     {
-        ByteString aTemp = rOutputSrs;
-        aTemp += " or ";
-        aTemp += rTmpFile;
-        pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTemp.GetBuffer() );
+        rtl::OStringBuffer aTemp(rOutputSrs);
+        aTemp.append(" or ").append(rTmpFile);
+        pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTemp.getStr() );
     }
 }
 
@@ -1053,24 +1054,21 @@ void RscCompiler::Append( const ByteString& rOutputSrs,
 
 bool RscCompiler::GetImageFilePath( const RscCmdLine::OutputFile& rOutputFile,
                                     const WriteRcContext& rContext,
-                                    const ByteString& rBaseFileName,
-                                    ByteString& rImagePath,
+                                    const rtl::OString& rBaseFileName,
+                                    rtl::OString& rImagePath,
                                     FILE* pSysListFile )
 {
-    ::std::list< ByteString >                   aFileNames;
-    bool                                        bFound = false;
+    ::std::list< rtl::OString >  aFileNames;
+    bool bFound = false;
 
-    ByteString  aFileName( rBaseFileName );
-    aFileNames.push_back( aFileName += ".png" );
+    aFileNames.push_back( rBaseFileName + rtl::OString(".png") );
+    aFileNames.push_back( rBaseFileName + rtl::OString(".bmp") );
 
-    aFileName = rBaseFileName;
-    aFileNames.push_back( aFileName += ".bmp" );
-
-    ::std::list< ByteString >::iterator aFileIter( aFileNames.begin() );
+    ::std::list< rtl::OString >::iterator aFileIter( aFileNames.begin() );
 
     while( ( aFileIter != aFileNames.end() ) && !bFound )
     {
-        ::std::list< ByteString >::const_iterator aDirIter( rOutputFile.aSysSearchDirs.begin() );
+        ::std::list< rtl::OString >::const_iterator aDirIter( rOutputFile.aSysSearchDirs.begin() );
 
         while( ( aDirIter != rOutputFile.aSysSearchDirs.end() ) && !bFound )
         {
@@ -1082,7 +1080,7 @@ bool RscCompiler::GetImageFilePath( const RscCmdLine::OutputFile& rOutputFile,
             const FileStat aFS( aAbsPath.GetFull() );
 
 #if OSL_DEBUG_LEVEL > 1
-            fprintf( stderr, "Searching image: %s\n", ByteString( aRelPath.GetFull(), RTL_TEXTENCODING_ASCII_US ).GetBuffer() );
+            fprintf( stderr, "Searching image: %s\n", rtl::OUStringToOString(aRelPath.GetFull(), RTL_TEXTENCODING_ASCII_US).getStr() );
 #endif
 
             if( aFS.IsKind( FSYS_KIND_FILE ) )
@@ -1093,11 +1091,9 @@ bool RscCompiler::GetImageFilePath( const RscCmdLine::OutputFile& rOutputFile,
 
                 while( ( aReplIter != rContext.pCmdLine->m_aReplacements.end() ) && !bFound )
                 {
-                    ByteString aSearch( aReplIter->second );
-                    aSearch.ToLowerAscii();
-                    ByteString aSearchIn( aRelPathStr );
-                    aSearchIn.ToLowerAscii();
-                    if( aSearchIn.Search( aSearch ) == 0 )
+                    rtl::OString aSearch(aReplIter->second.toAsciiLowerCase());
+                    rtl::OString aSearchIn(aRelPathStr.toAsciiLowerCase());
+                    if( aSearchIn.indexOf(aSearch) == 0 )
                     {
                         sal_Int32       nCopyPos = aReplIter->second.getLength(), nLength = aRelPathStr.getLength();
                         const sal_Char* pChars = aRelPathStr.getStr();
@@ -1126,7 +1122,7 @@ bool RscCompiler::GetImageFilePath( const RscCmdLine::OutputFile& rOutputFile,
                 }
 
 #if OSL_DEBUG_LEVEL > 1
-                fprintf( stderr, "ImagePath to add: %s\n", rImagePath.GetBuffer() );
+                fprintf( stderr, "ImagePath to add: %s\n", rImagePath.getStr() );
 #endif
             }
 
@@ -1148,58 +1144,63 @@ void RscCompiler::PreprocessSrsFile( const RscCmdLine::OutputFile& rOutputFile,
 {
     SvFileStream                aIStm( rSrsInPath.GetFull(), STREAM_READ );
     SvFileStream                aOStm( rSrsOutPath.GetFull(), STREAM_WRITE | STREAM_TRUNC );
-    ::std::vector< ByteString > aMissingImages;
-    FILE*                       pSysListFile = rContext.aOutputSysList.getLength() ? fopen( rContext.aOutputSysList.getStr(), "ab" ) : NULL;
+    ::std::vector< rtl::OString > aMissingImages;
+    FILE*                       pSysListFile = rContext.aOutputSysList.isEmpty() ? NULL : fopen( rContext.aOutputSysList.getStr(), "ab" );
 
     if( !aIStm.GetError() && !aOStm.GetError() )
     {
-        ByteString aLine, aFilePath;
+        rtl::OString aLine;
+        rtl::OString aFilePath;
 
         while( aIStm.ReadLine( aLine ) )
         {
-            if( ( aLine.GetTokenCount( '=' ) == 2 ) &&
+            if( ( getTokenCount(aLine, '=') == 2 ) &&
                 ( getToken(aLine, 0, '=').indexOf("File") != -1 ) )
             {
-                ByteString aBaseFileName( getToken(getToken(aLine, 1, '"'), 0, '.') );
+                rtl::OString aBaseFileName( getToken(getToken(aLine, 1, '"'), 0, '.') );
 
                 if( GetImageFilePath( rOutputFile, rContext, aBaseFileName, aFilePath, pSysListFile ) )
-                    ( ( aLine = "File = \"" ) += aFilePath ) += "\";";
+                {
+                    aLine = rtl::OStringBuffer(RTL_CONSTASCII_STRINGPARAM("File = \"")).
+                        append(aFilePath).append(RTL_CONSTASCII_STRINGPARAM("\";")).
+                        makeStringAndClear();
+                }
                 else
                     aMissingImages.push_back( aBaseFileName );
 
-                aOStm.WriteLine( aLine );
+                aOStm.WriteLine(aLine);
             }
-            else if( aLine.Search( "ImageList" ) != STRING_NOTFOUND )
+            else if (aLine.indexOfL(RTL_CONSTASCII_STRINGPARAM("ImageList")) != -1)
             {
-                ::std::vector< ::std::pair< ByteString, sal_Int32 > > aEntryVector;
+                ::std::vector< ::std::pair< rtl::OString, sal_Int32 > > aEntryVector;
 
-                aOStm.WriteLine( aLine );
+                aOStm.WriteLine(aLine);
 
-                if( aLine.Search( ';' ) == STRING_NOTFOUND )
+                if (aLine.indexOf(';') == -1)
                 {
                     const sal_uInt32 nImgListStartPos = aIStm.Tell();
 
                     do
                     {
-                        if( !aIStm.ReadLine( aLine ) )
+                        if( !aIStm.ReadLine(aLine) )
                             break;
                     }
-                    while( aLine.Search( "Prefix" ) == STRING_NOTFOUND );
+                    while (aLine.indexOfL(RTL_CONSTASCII_STRINGPARAM("Prefix")) == -1);
 
-                    const ByteString aPrefix( getToken(aLine, 1, '"') );
+                    const rtl::OString aPrefix( getToken(aLine, 1, '"') );
                     aIStm.Seek( nImgListStartPos );
 
                     do
                     {
-                        if (!aIStm.ReadLine( aLine ) )
+                        if (!aIStm.ReadLine(aLine) )
                             break;
                     }
-                    while( aLine.Search( "IdList" ) == STRING_NOTFOUND );
+                    while (aLine.indexOfL(RTL_CONSTASCII_STRINGPARAM("IdList")) == -1);
 
                     // scan all ids and collect images
-                    while( aLine.Search( '}' ) == STRING_NOTFOUND )
+                    while (aLine.indexOf('}') == -1)
                     {
-                        if( !aIStm.ReadLine( aLine ) )
+                        if( !aIStm.ReadLine(aLine) )
                             break;
 
                         aLine = comphelper::string::stripStart(aLine, ' ');
@@ -1208,7 +1209,7 @@ void RscCompiler::PreprocessSrsFile( const RscCmdLine::OutputFile& rOutputFile,
 
                         if (comphelper::string::isdigitAsciiString(aLine))
                         {
-                            sal_Int32 nNumber = atoi( aLine.GetBuffer() );
+                            sal_Int32 nNumber = atoi(aLine.getStr());
 
                             rtl::OStringBuffer aBuf(aPrefix);
                             if( nNumber < 10000 )
@@ -1217,7 +1218,7 @@ void RscCompiler::PreprocessSrsFile( const RscCmdLine::OutputFile& rOutputFile,
                             rtl::OString aBaseFileName = aBuf.makeStringAndClear();
 
                             if( GetImageFilePath( rOutputFile, rContext, aBaseFileName, aFilePath, pSysListFile ) )
-                                aEntryVector.push_back( ::std::pair< ByteString, sal_Int32 >( aFilePath, nNumber ) );
+                                aEntryVector.push_back( ::std::pair< rtl::OString, sal_Int32 >( aFilePath, nNumber ) );
                             else
                                 aMissingImages.push_back( aBaseFileName );
                         }
@@ -1229,13 +1230,13 @@ void RscCompiler::PreprocessSrsFile( const RscCmdLine::OutputFile& rOutputFile,
                     {
                         aIStm.ReadLine( aLine );
 
-                        if( aLine.Search( "IdList" ) != STRING_NOTFOUND )
+                        if (aLine.indexOfL(RTL_CONSTASCII_STRINGPARAM("IdList")) != -1)
                         {
-                            while( aLine.Search( '}' ) == STRING_NOTFOUND )
-                                aIStm.ReadLine( aLine );
+                            while (aLine.indexOf('}') == -1)
+                                aIStm.ReadLine(aLine);
                         }
                         else
-                            aOStm.WriteLine( aLine );
+                            aOStm.WriteLine(aLine);
                     }
 
                     aOStm.WriteLine(rtl::OString(RTL_CONSTASCII_STRINGPARAM("FileList = {")));
@@ -1256,10 +1257,10 @@ void RscCompiler::PreprocessSrsFile( const RscCmdLine::OutputFile& rOutputFile,
                     aOStm.WriteLine(rtl::OString(RTL_CONSTASCII_STRINGPARAM("};")));
                 }
                 else
-                    aOStm.WriteLine( aLine );
+                    aOStm.WriteLine(aLine);
             }
             else
-                aOStm.WriteLine( aLine );
+                aOStm.WriteLine(aLine);
         }
     }
 
