@@ -38,6 +38,7 @@
 #endif
 #include <osl_Security_Const.h>
 #include <osl/thread.h>
+#include <rtl/process.h>
 #include <rtl/strbuf.hxx>
 
 using namespace osl;
@@ -129,12 +130,12 @@ namespace osl_Security
 
 
         SAL_CPPUNIT_TEST_SUITE( logonUser );
-        if  ( !aStringForward.equals( aNullUrl )  && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 && ( aStringForward.indexOf( ( sal_Unicode ) ' ' ) ==  aStringForward.lastIndexOf( ( sal_Unicode ) ' ' ) ) )
+        if  ( !aStringForward.isEmpty() && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 && ( aStringForward.indexOf( ( sal_Unicode ) ' ' ) ==  aStringForward.lastIndexOf( ( sal_Unicode ) ' ' ) ) )
         /// if user name and passwd are forwarded
         {
             CPPUNIT_TEST( logonUser_user_pwd );
         }
-        if  ( !aStringForward.equals( aNullUrl )  && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 && ( aStringForward.indexOf( ( sal_Unicode ) ' ' ) !=  aStringForward.lastIndexOf( ( sal_Unicode ) ' ' ) ) )
+        if  ( !aStringForward.isEmpty() && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 && ( aStringForward.indexOf( ( sal_Unicode ) ' ' ) !=  aStringForward.lastIndexOf( ( sal_Unicode ) ' ' ) ) )
         /// if user name and passwd and file server are forwarded
         {
             CPPUNIT_TEST( logonUser_user_pwd_server );
@@ -193,7 +194,7 @@ namespace osl_Security
             bRes = aSec.getUserName( strGetName );
 
             sal_Int32 nPos = -1;
-            if (strName.getLength() > 0)
+            if (!strName.isEmpty())
             {
                 nPos = strGetName.indexOf(strName);
             }
@@ -353,7 +354,7 @@ class MyTestPlugInImpl: public CPPUNIT_NS::TestPlugInDefaultImpl
 
 
 void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
-                   const CPPUNIT_NS::PlugInParameters & parameters)
+                   const CPPUNIT_NS::PlugInParameters & )
 {
     /// start message
     t_print("#Initializing ...\n" );
@@ -564,14 +565,14 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     strUserID = ::rtl::OUString::createFromAscii( Ident );
 
     free(Ident);
-     delete pSid;
+    delete [] reinterpret_cast<BYTE*>(pSid);
     delete [] wszDomainName;
 
 
     /// check if logged in user is administrator:
 
     BOOL b;
-    SID_IDENTIFIER_AUTHORITY NtAuthority = SECURITY_NT_AUTHORITY;
+    SID_IDENTIFIER_AUTHORITY NtAuthority = { SECURITY_NT_AUTHORITY };
     PSID AdministratorsGroup;
     b = AllocateAndInitializeSid(
         &NtAuthority,
@@ -597,31 +598,31 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     t_print("#\n#Retrived system information is below:\n");
 
     t_print("Computer Name:              ");
-    if ( strComputerName == aNullUrl )
+    if ( strComputerName.isEmpty())
         t_print("Not retrived\n" );
     else
         printUString( strComputerName );
 
     t_print("Current User Name:          ");
-    if ( strUserName == aNullUrl )
+    if ( strUserName.isEmpty())
         t_print("Not retrived\n" );
     else
         printUString( strUserName );
 
     t_print("Current User Home Directory:");
-    if ( strHomeDirectory == aNullUrl )
+    if ( strHomeDirectory.isEmpty())
         t_print("Not retrived\n" );
     else
         printUString( strHomeDirectory );
 
     t_print("Current Config Directory:   ");
-    if ( strConfigDirectory == aNullUrl )
+    if ( strConfigDirectory.isEmpty())
         t_print("Not retrived\n" );
     else
         printUString( strConfigDirectory );
 
     t_print("Current UserID:             ");
-    if ( strUserID == aNullUrl )
+    if ( strUserID.isEmpty())
         t_print("Not retrived\n" );
     else
         printUString( strUserID );
@@ -633,44 +634,52 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
         t_print("Administrator.\n" );
 
     /// get and display forwarded text if available.
-    aStringForward = ::rtl::OUString::createFromAscii( parameters.getCommandLine().c_str() );
-    if ( !aStringForward.equals( aNullUrl ) && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 )
+    rtl::OUString args[ 3 ];
+    int argsCount = 0;
+    sal_uInt32 n = rtl_getAppCommandArgCount();
+    for (sal_uInt32 i = 0; i < n; ++i)
     {
-        sal_Int32 nFirstSpacePoint = aStringForward.indexOf( (sal_Unicode)' ' );;
-        sal_Int32 nLastSpacePoint = aStringForward.lastIndexOf( (sal_Unicode)' ' );;
-        if ( nFirstSpacePoint == nLastSpacePoint )
-        /// only forwarded two parameters, username and password.
+        rtl::OUString arg;
+        rtl_getAppCommandArg(i, &arg.pData);
+        if( !arg.isEmpty() && arg[ 0 ] == '-' )
+            continue;
+        if( argsCount >= 3 )
         {
-            aLogonUser = aStringForward.copy( 0, nFirstSpacePoint );
-            t_print("\n#Forwarded username: ");
-            printUString( aLogonUser);
-
-            aLogonPasswd = aStringForward.copy( nFirstSpacePoint +1, aStringForward.getLength( ) - 1 );
-            t_print("#Forwarded password: ");
-            for (int i = nFirstSpacePoint+1; i <= aStringForward.getLength()-1; ++i)
-                t_print("*");
-            t_print("\n" );
-        }
-        else
-        /// forwarded three parameters, username, password and fileserver.
-        {
-            aLogonUser = aStringForward.copy( 0, nFirstSpacePoint );
-            t_print("#Forwarded username: ");
-            printUString( aLogonUser);
-
-            aLogonPasswd = aStringForward.copy( nFirstSpacePoint +1, nLastSpacePoint );
-            t_print("#Forwarded password: ");
-            for (int i = nFirstSpacePoint+1; i <= nLastSpacePoint; ++i)
-                t_print("*");
-            t_print("\n" );
-
-            aFileServer = aStringForward.copy( nLastSpacePoint +1, aStringForward.getLength( ) - 1 );
-            t_print("#Forwarded FileServer: ");
-            printUString( aFileServer );
-
+            SAL_WARN( "sal", "Too many test arguments" );
+            continue;
         }
+        args[ argsCount++ ] = arg;
     }
+    /// only forwarded two parameters, username and password.
+    if( argsCount == 2 )
+    {
+        aLogonUser = args[ 0 ];
+        t_print("\n#Forwarded username: ");
+        printUString( aLogonUser);
 
+        aLogonPasswd = args[ 1 ];
+        t_print("#Forwarded password: ");
+        for (int i = 0; i < aLogonPasswd.getLength(); ++i)
+            t_print("*");
+        t_print("\n" );
+    }
+    else if( argsCount == 3 )
+    /// forwarded three parameters, username, password and fileserver.
+    {
+        aLogonUser = args[ 0 ];
+        t_print("#Forwarded username: ");
+        printUString( aLogonUser);
+
+        aLogonPasswd = args[ 1 ];
+        t_print("#Forwarded password: ");
+        for (int i = 0; i < aLogonPasswd.getLength(); ++i)
+            t_print("*");
+        t_print("\n" );
+
+        aFileServer = args[ 2 ];
+        t_print("#Forwarded FileServer: ");
+        printUString( aFileServer );
+    }
     t_print("#\n#Initialization Done.\n" );
 
 }
