@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-
-#include "rtl/uri.h"
-
 #include "surrogates.hxx"
 
 #include "osl/diagnose.h"
@@ -391,7 +388,9 @@ void parseUriRef(rtl_uString const * pUriRef, Components * pComponents)
     sal_Unicode const * pPos = pBegin;
 
     if (pPos != pEnd && isAlpha(*pPos))
+    {
         for (sal_Unicode const * p = pPos + 1; p != pEnd; ++p)
+        {
             if (*p == ':')
             {
                 pComponents->aScheme.pBegin = pBegin;
@@ -401,7 +400,11 @@ void parseUriRef(rtl_uString const * pUriRef, Components * pComponents)
             }
             else if (!isAlpha(*p) && !isDigit(*p) && *p != '+' && *p != '-'
                      && *p != '.')
+            {
                 break;
+            }
+        }
+    }
 
     if (pEnd - pPos >= 2 && pPos[0] == '/' && pPos[1] == '/')
     {
@@ -606,8 +609,8 @@ void SAL_CALL rtl_uriEncode(rtl_uString * pText, sal_Bool const * pCharClass,
 
     sal_Unicode const * p = pText->buffer;
     sal_Unicode const * pEnd = p + pText->length;
-    sal_Int32 nCapacity = 0;
-    rtl_uString_new(pResult);
+    sal_Int32 nCapacity = pText->length;
+    rtl_uString_new_WithLength(pResult, nCapacity);
     while (p < pEnd)
     {
         EscapeType eType;
@@ -653,6 +656,7 @@ void SAL_CALL rtl_uriEncode(rtl_uString * pText, sal_Bool const * pCharClass,
             break;
         }
     }
+    *pResult = rtl_uStringBuffer_makeStringAndClear( pResult, &nCapacity );
 }
 
 void SAL_CALL rtl_uriDecode(rtl_uString * pText,
@@ -672,8 +676,8 @@ void SAL_CALL rtl_uriDecode(rtl_uString * pText,
         {
             sal_Unicode const * p = pText->buffer;
             sal_Unicode const * pEnd = p + pText->length;
-            sal_Int32 nCapacity = 0;
-            rtl_uString_new(pResult);
+            sal_Int32 nCapacity = pText->length;
+            rtl_uString_new_WithLength(pResult, nCapacity);
             while (p < pEnd)
             {
                 EscapeType eType;
@@ -699,6 +703,7 @@ void SAL_CALL rtl_uriDecode(rtl_uString * pText,
                     break;
                 }
             }
+            *pResult = rtl_uStringBuffer_makeStringAndClear( pResult, &nCapacity );
         }
         break;
     }
