@@ -147,14 +147,6 @@ void ScAttrArray::Reset( const ScPatternAttr* pPattern, bool bAlloc )
                 aAdrEnd  .SetRow( pData[i].nRow );
                 pDocument->InvalidateTextWidth( &aAdrStart, &aAdrEnd, bNumFormatChanged );
             }
-            // conditional format or deleted?
-            if ( &pPattern->GetItem(ATTR_CONDITIONAL) != &pOldPattern->GetItem(ATTR_CONDITIONAL) )
-            {
-                pDocument->ConditionalChanged( ((const SfxUInt32Item&)
-                                pOldPattern->GetItem(ATTR_CONDITIONAL)).GetValue() );
-                pDocument->ConditionalChanged( ((const SfxUInt32Item&)
-                                pPattern->GetItem(ATTR_CONDITIONAL)).GetValue() );
-            }
             pDocPool->Remove(*pOldPattern);
         }
         delete[] pData;
@@ -373,13 +365,6 @@ void ScAttrArray::SetPatternArea(SCROW nStartRow, SCROW nEndRow, const ScPattern
                     aAdrEnd  .SetRow( Min(nEndRow,pData[nx].nRow) );
                     pDocument->InvalidateTextWidth( &aAdrStart, &aAdrEnd, bNumFormatChanged );
                 }
-                if ( &rNewSet.Get(ATTR_CONDITIONAL) != &rOldSet.Get(ATTR_CONDITIONAL) )
-                {
-                    pDocument->ConditionalChanged( ((const SfxUInt32Item&)
-                                    rOldSet.Get(ATTR_CONDITIONAL)).GetValue() );
-                    pDocument->ConditionalChanged( ((const SfxUInt32Item&)
-                                    rNewSet.Get(ATTR_CONDITIONAL)).GetValue() );
-                }
                 ns = pData[nx].nRow + 1;
                 nx++;
             }
@@ -588,7 +573,7 @@ void ScAttrArray::ApplyStyleArea( SCROW nStartRow, SCROW nEndRow, ScStyleSheet*
     if ((dest))                                        \
     {                                                  \
         SvxBorderLine* pCast = (SvxBorderLine*)(dest); \
-        pCast->SetStyle( (src)->GetStyle( ) );         \
+        pCast->SetBorderLineStyle( (src)->GetBorderLineStyle() ); \
         pCast->SetWidth( (src)->GetWidth( ) );         \
     }
 
@@ -776,16 +761,6 @@ void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCac
                         pDocument->InvalidateTextWidth( &aAdrStart, &aAdrEnd, bNumFormatChanged );
                     }
 
-                    // Reset conditional formats or delete ?
-
-                    if ( &rNewSet.Get(ATTR_CONDITIONAL) != &rOldSet.Get(ATTR_CONDITIONAL) )
-                    {
-                        pDocument->ConditionalChanged( ((const SfxUInt32Item&)
-                                        rOldSet.Get(ATTR_CONDITIONAL)).GetValue() );
-                        pDocument->ConditionalChanged( ((const SfxUInt32Item&)
-                                        rNewSet.Get(ATTR_CONDITIONAL)).GetValue() );
-                    }
-
                     pDocument->GetPool()->Remove(*pData[nPos].pPattern);
                     pData[nPos].pPattern = pNewPattern;
                     if (Concat(nPos))
@@ -1161,77 +1136,6 @@ long lcl_LineSize( const SvxBorderLine& rLine )
     return nTotal;
 }
 
-bool ScAttrArray::HasLines( SCROW nRow1, SCROW nRow2, Rectangle& rSizes,
-                                bool bLeft, bool bRight ) const
-{
-    SCSIZE nStartIndex;
-    SCSIZE nEndIndex;
-    Search( nRow1, nStartIndex );
-    Search( nRow2, nEndIndex );
-    bool bFound = false;
-
-    const SvxBoxItem* pItem = 0;
-    const SvxBorderLine* pLine = 0;
-    long nCmp;
-
-    // top
-
-    pItem = (const SvxBoxItem*) &pData[nStartIndex].pPattern->GetItem(ATTR_BORDER);
-    pLine = pItem->GetTop();
-    if (pLine)
-    {
-        nCmp = lcl_LineSize(*pLine);
-        if ( nCmp > rSizes.Top() )
-            rSizes.Top() = nCmp;
-        bFound = true;
-    }
-
-    // down
-
-    if ( nEndIndex != nStartIndex )
-        pItem = (const SvxBoxItem*) &pData[nEndIndex].pPattern->GetItem(ATTR_BORDER);
-    pLine = pItem->GetBottom();
-    if (pLine)
-    {
-        nCmp = lcl_LineSize(*pLine);
-        if ( nCmp > rSizes.Bottom() )
-            rSizes.Bottom() = nCmp;
-        bFound = true;
-    }
-
-    if ( bLeft || bRight )
-        for ( SCSIZE i=nStartIndex; i<=nEndIndex; i++)
-        {
-            pItem = (const SvxBoxItem*) &pData[i].pPattern->GetItem(ATTR_BORDER);
-
-            if (bLeft)
-            {
-                pLine = pItem->GetLeft();
-                if (pLine)
-                {
-                    nCmp = lcl_LineSize(*pLine);
-                    if ( nCmp > rSizes.Left() )
-                        rSizes.Left() = nCmp;
-                    bFound = true;
-                }
-            }
-
-            if (bRight)
-            {
-                pLine = pItem->GetRight();
-                if (pLine)
-                {
-                    nCmp = lcl_LineSize(*pLine);
-                    if ( nCmp > rSizes.Right() )
-                        rSizes.Right() = nCmp;
-                    bFound = true;
-                }
-            }
-        }
-
-    return bFound;
-}
-
 // Test if field contains specific attribute
 
 bool ScAttrArray::HasAttrib( SCROW nRow1, SCROW nRow2, sal_uInt16 nMask ) const
@@ -1831,8 +1735,10 @@ bool ScAttrArray::GetFirstVisibleAttr( SCROW& rFirstRow ) const
 
 const SCROW SC_VISATTR_STOP = 84;
 
-bool ScAttrArray::GetLastVisibleAttr( SCROW& rLastRow, SCROW nLastData ) const
+bool ScAttrArray::GetLastVisibleAttr( SCROW& rLastRow, SCROW nLastData, bool bFullFormattedArea ) const
 {
+    OSL_ENSURE( nCount, "nCount == 0" );
+
     //  #i30830# changed behavior:
     //  ignore all attributes starting with the first run of SC_VISATTR_STOP equal rows
     //  below the last content cell
@@ -1843,36 +1749,48 @@ bool ScAttrArray::GetLastVisibleAttr( SCROW& rLastRow, SCROW nLastData ) const
         return true;
     }
 
-    bool bFound = false;
-
-    //  loop backwards from the end instead of using Search, assuming that
-    //  there usually aren't many attributes below the last cell
-
-    SCSIZE nPos = nCount;
-    while ( nPos > 0 && pData[nPos-1].nRow > nLastData )
+    // Quick check: last data row in or immediately preceding a run that is the
+    // last attribution down to the end, e.g. default style or column style.
+    SCSIZE nPos = nCount - 1;
+    SCROW nStartRow = (nPos ? pData[nPos-1].nRow + 1 : 0);
+    if (nStartRow <= nLastData + 1)
     {
-        SCSIZE nEndPos = nPos - 1;
-        SCSIZE nStartPos = nEndPos;         // find range of visually equal formats
-        while ( nStartPos > 0 &&
-                pData[nStartPos-1].nRow > nLastData &&
-                pData[nStartPos-1].pPattern->IsVisibleEqual(*pData[nStartPos].pPattern) )
-            --nStartPos;
+        if (bFullFormattedArea && pData[nPos].pPattern->IsVisible())
+        {
+            rLastRow = pData[nPos].nRow;
+            return true;
+        }
+        else
+        {
+            // Ignore here a few rows if data happens to end within
+            // SC_VISATTR_STOP rows before MAXROW.
+            rLastRow = nLastData;
+            return false;
+        }
+    }
 
-        SCROW nAttrStartRow = ( nStartPos > 0 ) ? ( pData[nStartPos-1].nRow + 1 ) : 0;
+    // Find a run below last data row.
+    bool bFound = false;
+    Search( nLastData, nPos );
+    while ( nPos < nCount )
+    {
+        // find range of visually equal formats
+        SCSIZE nEndPos = nPos;
+        while ( nEndPos < nCount-1 &&
+                pData[nEndPos].pPattern->IsVisibleEqual( *pData[nEndPos+1].pPattern))
+            ++nEndPos;
+        SCROW nAttrStartRow = ( nPos > 0 ) ? ( pData[nPos-1].nRow + 1 ) : 0;
         if ( nAttrStartRow <= nLastData )
             nAttrStartRow = nLastData + 1;
         SCROW nAttrSize = pData[nEndPos].nRow + 1 - nAttrStartRow;
-        if ( nAttrSize >= SC_VISATTR_STOP )
-        {
-            bFound = false;        // ignore this range and below
-        }
-        else if ( !bFound && pData[nEndPos].pPattern->IsVisible() )
+        if ( nAttrSize >= SC_VISATTR_STOP && !bFullFormattedArea )
+            break;  // while, ignore this range and below
+        else if ( pData[nEndPos].pPattern->IsVisible() )
         {
             rLastRow = pData[nEndPos].nRow;
             bFound = true;
         }
-
-        nPos = nStartPos;           // look further from the top of the range
+        nPos = nEndPos + 1;
     }
 
     return bFound;
