@@ -401,8 +401,11 @@ void ScColumn::DeleteRange( SCSIZE nStartIndex, SCSIZE nEndIndex, sal_uInt16 nDe
                 SvtBroadcaster* pBC = pOldCell->GetBroadcaster();
                 bool bKeepBC = pBC && pBC->HasListeners();
                 // #i99844# do not release broadcaster from old cell, it still has to notify deleted content
-                if ( bKeepBC)
-                        pNoteCell = new ScNoteCell( pBC );
+                if (bKeepBC)
+                {
+                    pNoteCell = new ScNoteCell( pBC );
+                    pOldCell->ReleaseBroadcaster();
+                }
 
                 // remove cell entry in cell item list
                 SCROW nOldRow = maItems[nIdx].nRow;
@@ -424,7 +427,10 @@ void ScColumn::DeleteRange( SCSIZE nStartIndex, SCSIZE nEndIndex, sal_uInt16 nDe
                 else
                 {
                     aHint.GetAddress().SetRow( nOldRow );
-                    aHint.SetCell( pOldCell );
+                    if(bKeepBC)
+                        aHint.SetCell( pNoteCell );
+                    else
+                        aHint.SetCell( pOldCell );
                     pDocument->Broadcast( aHint );
                     if (pNoteCell != pOldCell)
                     {
@@ -1341,7 +1347,7 @@ bool ScColumn::SetString( SCROW nRow, SCTAB nTabP, const String& rString,
                         }
                     }
                 }
-                else if (!aParam.mbSetTextCellFormat)
+                else if (aParam.meSetTextNumFormat != ScSetStringParam::Always)
                 {
                     // Only check if the string is a regular number.
                     const LocaleDataWrapper* pLocale = aParam.mpNumFormatter->GetLocaleData();
@@ -1367,7 +1373,7 @@ bool ScColumn::SetString( SCROW nRow, SCTAB nTabP, const String& rString,
 
             if (!pNewCell)
             {
-                if (aParam.mbSetTextCellFormat && aParam.mpNumFormatter->IsNumberFormat(rString, nIndex, nVal))
+                if (aParam.meSetTextNumFormat != ScSetStringParam::Never && aParam.mpNumFormatter->IsNumberFormat(rString, nIndex, nVal))
                 {
                     // Set the cell format type to Text.
                     sal_uInt32 nFormat = aParam.mpNumFormatter->GetStandardFormat(NUMBERFORMAT_TEXT);
