@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-
-
-#define _ZFORLIST_DECLARE_TABLE
 #include "scitems.hxx"
 #include <editeng/eeitem.hxx>
 
@@ -48,7 +45,6 @@
 #include <sfx2/viewsh.hxx>
 #include <svl/flagitem.hxx>
 #include <svl/intitem.hxx>
-#define _SVSTDARR_USHORTS
 #include <svl/svstdarr.hxx>
 #include <svl/zforlist.hxx>
 #include <svl/zformat.hxx>
@@ -730,8 +726,7 @@ bool ScDocument::OnlineSpellInRange( const ScRange& rSpellRange, ScAddress& rSpe
 
             if ( eType == CELLTYPE_STRING )
             {
-                rtl::OUString aText;
-                static_cast<ScStringCell*>(pCell)->GetString(aText);
+                rtl::OUString aText = static_cast<ScStringCell*>(pCell)->GetString();
                 pEngine->SetText( aText );
             }
             else
@@ -1035,7 +1030,7 @@ void ScDocument::UpdateExternalRefLinks(Window* pWin)
             {
                 // Update failed.  Notify the user.
 
-                String aFile;
+                rtl::OUString aFile;
                 pLinkManager->GetDisplayNames(pRefLink, NULL, &aFile, NULL, NULL);
                 // Decode encoded URL for display friendliness.
                 INetURLObject aUrl(aFile,INetURLObject::WAS_ENCODED);
@@ -1468,7 +1463,7 @@ void ScDocument::UpdateRefAreaLinks( UpdateRefMode eUpdateRefMode,
 // TimerDelays etc.
 void ScDocument::KeyInput( const KeyEvent& )
 {
-    if ( pChartListenerCollection->GetCount() )
+    if ( pChartListenerCollection->hasListeners() )
         pChartListenerCollection->StartTimer();
     if( apTemporaryChartLock.get() )
         apTemporaryChartLock->StartOrContinueLocking();
@@ -1550,7 +1545,7 @@ void ScDocument::TransliterateText( const ScMarkData& rMultiMark, sal_Int32 nTyp
                                                      nType == com::sun::star::i18n::TransliterationModulesExtra::TITLE_CASE ) ) )
                 {
                     if (!pEngine)
-                        pEngine = new ScFieldEditEngine( GetEnginePool(), GetEditPool() );
+                        pEngine = new ScFieldEditEngine(this, GetEnginePool(), GetEditPool());
 
                     // defaults from cell attributes must be set so right language is used
                     const ScPatternAttr* pPattern = GetPattern( nCol, nRow, nTab );
@@ -1599,8 +1594,7 @@ void ScDocument::TransliterateText( const ScMarkData& rMultiMark, sal_Int32 nTyp
 
                 else if ( eType == CELLTYPE_STRING )
                 {
-                    rtl::OUString aOldStr;
-                    ((const ScStringCell*)pCell)->GetString(aOldStr);
+                    rtl::OUString aOldStr = ((const ScStringCell*)pCell)->GetString();
                     sal_Int32 nOldLen = aOldStr.getLength();
 
                     if ( bConsiderLanguage )
