@@ -282,7 +282,7 @@ struct EqualByValue : std::binary_function<Bucket, Bucket, bool>
 {
     bool operator() (const Bucket& left, const Bucket& right) const
     {
-        return left.maValue == right.maValue;
+        return left.maValue.IsCaseInsEqual(right.maValue);
     }
 };
 
@@ -338,7 +338,7 @@ void processBuckets(std::vector<Bucket>& aBuckets, ScDPCache::Field& rField)
         it->mnOrderIndex = nCurIndex;
         for (++it; it != itEnd; ++it)
         {
-            if (aPrev != it->maValue)
+            if (!aPrev.IsCaseInsEqual(it->maValue))
                 ++nCurIndex;
 
             it->mnOrderIndex = nCurIndex;
@@ -461,24 +461,27 @@ bool ScDPCache::InitFromDataBase (const Reference<sdbc::XRowSet>& xRowSet, const
         Reference<sdbc::XRow> xRow(xRowSet, UNO_QUERY_THROW);
 
         std::vector<Bucket> aBuckets;
+        ScDPItemData aData;
         for (sal_Int32 nCol = 0; nCol < mnColumnCount; ++nCol)
         {
             xRowSet->first();
-            ScDPItemData aData;
             aBuckets.clear();
             Field& rField = maFields[nCol];
+            SCROW nRow = 0;
             do
             {
-                SCROW nRow = 0;
                 short nFormatType = NUMBERFORMAT_UNDEFINED;
+                aData.SetEmpty();
                 getItemValue(*this, aData, xRow, aColTypes[nCol], nCol+1, rNullDate, nFormatType);
-                aBuckets.push_back(Bucket(aData, 0, nRow++));
+                aBuckets.push_back(Bucket(aData, 0, nRow));
                 if (!aData.IsEmpty())
                 {
                     maEmptyRows.insert_back(nRow, nRow+1, false);
                     SvNumberFormatter* pFormatter = mpDoc->GetFormatTable();
                     rField.mnNumFormat = pFormatter ? pFormatter->GetStandardFormat(nFormatType) : 0;
                 }
+
+                ++nRow;
             }
             while (xRowSet->next());
 
