@@ -60,6 +60,7 @@
 #include "queryentry.hxx"
 #include "segmenttree.hxx"
 #include "subtotalparam.hxx"
+#include "docpool.hxx"
 
 #include <vector>
 #include <boost/unordered_set.hpp>
@@ -562,7 +563,9 @@ void ScTable::QuickSort( ScSortInfoArray* pArray, SCsCOLROW nLo, SCsCOLROW nHi )
 
 void ScTable::SwapCol(SCCOL nCol1, SCCOL nCol2)
 {
-    for (SCROW nRow = aSortParam.nRow1; nRow <= aSortParam.nRow2; nRow++)
+    SCROW nRowStart = aSortParam.nRow1;
+    SCROW nRowEnd = aSortParam.nRow2;
+    for (SCROW nRow = nRowStart; nRow <= nRowEnd; nRow++)
     {
         aCol[nCol1].SwapCell(nRow, aCol[nCol2]);
         if (aSortParam.bIncludePattern)
@@ -571,8 +574,10 @@ void ScTable::SwapCol(SCCOL nCol1, SCCOL nCol2)
             const ScPatternAttr* pPat2 = GetPattern(nCol2, nRow);
             if (pPat1 != pPat2)
             {
+                pDocument->GetPool()->Put(*pPat1);
                 SetPattern(nCol1, nRow, *pPat2, true);
                 SetPattern(nCol2, nRow, *pPat1, true);
+                pDocument->GetPool()->Remove(*pPat1);
             }
         }
     }
@@ -586,16 +591,19 @@ void ScTable::SwapCol(SCCOL nCol1, SCCOL nCol2)
         ScPostIt* pPostIt = itr->second;
         ++itr;
 
-        if (nCol == nCol1)
+        if(nRow >= nRowStart && nRow <= nRowEnd)
         {
-            aNoteMap.insert(nCol, nRow, pPostIt);
-            maNotes.ReleaseNote(nCol2, nRow);
-        }
-        else if (nCol == nCol2)
-        {
-            aNoteMap.insert(nCol, nRow, pPostIt);
-            maNotes.ReleaseNote(nCol1, nRow);
+            if (nCol == nCol1)
+            {
+                aNoteMap.insert(nCol2, nRow, pPostIt);
+                maNotes.ReleaseNote(nCol, nRow);
+            }
+            else if (nCol == nCol2)
+            {
+                aNoteMap.insert(nCol1, nRow, pPostIt);
+                maNotes.ReleaseNote(nCol, nRow);
 
+            }
         }
     }
 
@@ -606,6 +614,7 @@ void ScTable::SwapCol(SCCOL nCol1, SCCOL nCol2)
         SCCOL nCol = itr->first.first;
         SCROW nRow = itr->first.second;
         ScPostIt* pPostIt = itr->second;
+        ++itr;
 
         maNotes.insert(nCol, nRow, pPostIt);
         aNoteMap.ReleaseNote(nCol, nRow);
@@ -614,7 +623,9 @@ void ScTable::SwapCol(SCCOL nCol1, SCCOL nCol2)
 
 void ScTable::SwapRow(SCROW nRow1, SCROW nRow2)
 {
-    for (SCCOL nCol = aSortParam.nCol1; nCol <= aSortParam.nCol2; nCol++)
+    SCCOL nColStart = aSortParam.nCol1;
+    SCCOL nColEnd = aSortParam.nCol2;
+    for (SCCOL nCol = nColStart; nCol <= nColEnd; nCol++)
     {
         aCol[nCol].SwapRow(nRow1, nRow2);
         if (aSortParam.bIncludePattern)
@@ -623,8 +634,10 @@ void ScTable::SwapRow(SCROW nRow1, SCROW nRow2)
             const ScPatternAttr* pPat2 = GetPattern(nCol, nRow2);
             if (pPat1 != pPat2)
             {
+                pDocument->GetPool()->Put(*pPat1);
                 SetPattern(nCol, nRow1, *pPat2, true);
                 SetPattern(nCol, nRow2, *pPat1, true);
+                pDocument->GetPool()->Remove(*pPat1);
             }
         }
     }
@@ -650,16 +663,18 @@ void ScTable::SwapRow(SCROW nRow1, SCROW nRow2)
         ScPostIt* pPostIt = itr->second;
         ++itr;
 
-        if (nRow == nRow1)
+        if( nCol >= nColStart && nCol <= nColEnd )
         {
-            aNoteMap.insert(nCol, nRow, pPostIt);
-            maNotes.ReleaseNote(nCol, nRow2);
-        }
-        else if (nRow == nRow2)
-        {
-            aNoteMap.insert(nCol, nRow, pPostIt);
-            maNotes.ReleaseNote(nCol, nRow1);
-
+            if (nRow == nRow1)
+            {
+                aNoteMap.insert(nCol, nRow2, pPostIt);
+                maNotes.ReleaseNote(nCol, nRow);
+            }
+            else if (nRow == nRow2)
+            {
+                aNoteMap.insert(nCol, nRow1, pPostIt);
+                maNotes.ReleaseNote(nCol, nRow);
+            }
         }
     }
 
@@ -670,6 +685,7 @@ void ScTable::SwapRow(SCROW nRow1, SCROW nRow2)
         SCCOL nCol = itr->first.first;
         SCROW nRow = itr->first.second;
         ScPostIt* pPostIt = itr->second;
+        ++itr;
 
         maNotes.insert(nCol, nRow, pPostIt);
         aNoteMap.ReleaseNote(nCol, nRow);
