@@ -36,7 +36,6 @@
 #include <editeng/editobj.hxx>
 
 #include "table.hxx"
-#include "collect.hxx"
 #include "cell.hxx"
 #include "document.hxx"
 #include "stlpool.hxx"
@@ -50,7 +49,9 @@
 
 using ::com::sun::star::util::SearchOptions;
 
-bool lcl_GetTextWithBreaks( const ScEditCell& rCell, ScDocument* pDoc, String& rVal )
+namespace {
+
+bool lcl_GetTextWithBreaks( const ScEditCell& rCell, ScDocument* pDoc, rtl::OUString& rVal )
 {
     //  true = more than 1 paragraph
 
@@ -62,6 +63,8 @@ bool lcl_GetTextWithBreaks( const ScEditCell& rCell, ScDocument* pDoc, String& r
     return ( rEngine.GetParagraphCount() > 1 );
 }
 
+}
+
 bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRow,
                          const ScMarkData& rMark, rtl::OUString& rUndoStr, ScDocument* pUndoDoc)
 {
@@ -69,7 +72,7 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
     bool    bDoSearch = true;
     bool    bDoBack = rSearchItem.GetBackward();
 
-    String  aString;
+    rtl::OUString  aString;
     ScBaseCell* pCell;
     if (rSearchItem.GetSelection())
         bDoSearch = rMark.IsCellMarked(nCol, nRow);
@@ -88,9 +91,7 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
                         *(const ScEditCell*)pCell, pDocument, aString );
                 else
                 {
-                    rtl::OUString aOUString = aString;
-                    aCol[nCol].GetInputString( nRow, aOUString );
-                    aString = aOUString;
+                    aCol[nCol].GetInputString( nRow, aString );
                 }
             }
             break;
@@ -100,25 +101,16 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
                         *(const ScEditCell*)pCell, pDocument, aString );
                 else
                 {
-                    rtl::OUString aOUString = aString;
-                    aCol[nCol].GetInputString( nRow, aOUString );
-                    aString = aOUString;
+                    aCol[nCol].GetInputString( nRow, aString );
                 }
                 break;
             case SVX_SEARCHIN_NOTE:
-                {
-                    if(const ScPostIt* pNote = pCell->GetNote())
-                    {
-                        aString = pNote->GetText();
-                        bMultiLine = pNote->HasMultiLineText();
-                    }
-                }
-                break;
+                break; // don't search this case here
             default:
                 break;
         }
         xub_StrLen nStart = 0;
-        xub_StrLen nEnd = aString.Len();
+        xub_StrLen nEnd = aString.getLength();
         ::com::sun::star::util::SearchResult aSearchResult;
         if (pSearchText)
         {
@@ -137,7 +129,7 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
             }
 
             if (bFound && rSearchItem.GetWordOnly())
-                bFound = (nStart == 0 && nEnd == aString.Len() - 1);
+                bFound = (nStart == 0 && nEnd == aString.getLength() - 1);
         }
         else
         {
@@ -162,7 +154,7 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
             else if (pUndoDoc)
             {
                 ScAddress aAdr( nCol, nRow, nTab );
-                ScBaseCell* pUndoCell = pCell->CloneWithoutNote( *pUndoDoc );
+                ScBaseCell* pUndoCell = pCell->Clone( *pUndoDoc );
                 pUndoDoc->PutCell( aAdr, pUndoCell);
             }
             bool bRepeat = !rSearchItem.GetWordOnly();
@@ -176,15 +168,18 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
                 String sReplStr = rSearchItem.GetReplaceString();
                 if (rSearchItem.GetRegExp())
                 {
-                    String sFndStr = aString.Copy(nStart, nEnd-nStart+1);
                     pSearchText->ReplaceBackReferences( sReplStr, aString, aSearchResult );
-                    aString.Erase(nStart, nEnd-nStart+1);
-                    aString.Insert(sReplStr, nStart);
+                    rtl::OUStringBuffer aStrBuffer(aString);
+                    aStrBuffer.remove(nStart, nEnd-nStart+1);
+                    aStrBuffer.insert(nStart, sReplStr);
+                    aString = aStrBuffer.makeStringAndClear();
                 }
                 else
                 {
-                    aString.Erase(nStart, nEnd - nStart + 1);
-                    aString.Insert(rSearchItem.GetReplaceString(), nStart);
+                    rtl::OUStringBuffer aStrBuffer(aString);
+                    aStrBuffer.remove(nStart, nEnd-nStart+1);
+                    aStrBuffer.insert(nStart, rSearchItem.GetReplaceString());
+                    aString = aStrBuffer.makeStringAndClear();
                 }
 
                         //  Indizes anpassen
@@ -196,7 +191,7 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
                 else
                 {
                     nStart = sal::static_int_cast<xub_StrLen>( nStart + sReplStr.Len() );
-                    nEnd = aString.Len();
+                    nEnd = aString.getLength();
                 }
 
                         //  weitersuchen ?
@@ -207,34 +202,28 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
                     else if (bDoBack)
                     {
                         xub_StrLen nTemp=nStart; nStart=nEnd; nEnd=nTemp;
-                        bRepeat = ((bool)(pSearchText->SearchBkwrd(aString, &nStart, &nEnd)));
+                        bRepeat = ((bool)(pSearchText->SearchBkwrd(aString, &nStart, &nEnd, &aSearchResult)));
                         // change results to definition before 614:
                         --nEnd;
                     }
                     else
                     {
-                        bRepeat = ((bool)(pSearchText->SearchFrwrd(aString, &nStart, &nEnd)));
+                        bRepeat = ((bool)(pSearchText->SearchFrwrd(aString, &nStart, &nEnd, &aSearchResult)));
                         // change results to definition before 614:
                         --nEnd;
                     }
                 }
             }
             while (bRepeat);
-            if (rSearchItem.GetCellType() == SVX_SEARCHIN_NOTE)
-            {
-                // NB: rich text format is lost.
-                // This is also true of Cells.
-                if( ScPostIt* pNote = pCell->GetNote() )
-                    pNote->SetText( ScAddress( nCol, nRow, nTab ), aString );
-            }
-            else if ( cMatrixFlag != MM_NONE )
+
+            if ( cMatrixFlag != MM_NONE )
             {   // Matrix nicht zerreissen
-                if ( aString.Len() > 2 )
+                if ( aString.getLength() > 2 )
                 {   // {} raus, erst hier damit auch "{=" durch "{=..." ersetzt werden kann
-                    if ( aString.GetChar( aString.Len()-1 ) == '}' )
-                        aString.Erase( aString.Len()-1, 1 );
-                    if ( aString.GetChar(0) == '{' )
-                        aString.Erase( 0, 1 );
+                    if ( aString[ aString.getLength()-1 ] == '}' )
+                        aString = aString.copy( 0, aString.getLength()-1 );
+                    if ( aString[0] == '{' )
+                        aString = aString.copy( 1 );
                 }
                 ScAddress aAdr( nCol, nRow, nTab );
                 ScFormulaCell* pFCell = new ScFormulaCell( pDocument, aAdr,
@@ -245,7 +234,7 @@ bool ScTable::SearchCell(const SvxSearchItem& rSearchItem, SCCOL nCol, SCROW nRo
                 pFCell->SetMatColsRows( nMatCols, nMatRows );
                 aCol[nCol].Insert( nRow, pFCell );
             }
-            else if ( bMultiLine && aString.Search('\n') != STRING_NOTFOUND )
+            else if ( bMultiLine && aString.indexOf('\n') != -1 )
                 PutCell( nCol, nRow, new ScEditCell( aString, pDocument ) );
             else
                 aCol[nCol].SetString(nRow, nTab, aString, pDocument->GetAddressConvention());
@@ -718,7 +707,7 @@ bool ScTable::SearchAndReplace(
             com::sun::star::util::SearchOptions aSearchOptions = rSearchItem.GetSearchOptions();
             aSearchOptions.Locale = *ScGlobal::GetLocale();
 
-            if (!aSearchOptions.searchString.getLength())
+            if (aSearchOptions.searchString.isEmpty())
             {
                 // Search for empty cells.
                 return SearchAndReplaceEmptyCells(rSearchItem, rCol, rRow, rMark, rMatchedRanges, rUndoStr, pUndoDoc);
@@ -1040,7 +1029,13 @@ bool ScTable::SearchRangeForAllEmptyCells(
                     if (pUndoDoc)
                     {
                         ScAddress aCellPos(nCol, nRow, nTab);
-                        pUndoDoc->PutCell(nCol, nRow, nTab, pCell->CloneWithNote(aCellPos, *pUndoDoc, aCellPos));
+                        pUndoDoc->PutCell(nCol, nRow, nTab, pCell->Clone(*pUndoDoc, aCellPos));
+                        ScNotes* pNotes = pUndoDoc->GetNotes(nTab);
+                        ScPostIt* pPostIt = maNotes.findByAddress(nCol, nRow);
+                        if (pPostIt)
+                        {
+                            pNotes->insert(nCol, nRow, pPostIt->Clone(ScAddress(nCol, nRow, nTab), *pUndoDoc, ScAddress(nCol, nRow, nTab), true));
+                        }
                     }
                     aCol[nCol].SetString(nRow, nTab, rSearchItem.GetReplaceString(), pDocument->GetAddressConvention());
                 }
