@@ -546,19 +546,6 @@ void lclSkipExpression( const sal_Unicode*& rpcString, const sal_Unicode* pcEnd,
     @param cEndChar
         The termination character following the expression.
   */
-OUString lclGetExpression( const sal_Unicode*& rpcString, const sal_Unicode* pcEnd, sal_Unicode cEndChar )
-{
-    OUString aExp;
-    const sal_Unicode* pcExpStart = rpcString;
-    lclSkipExpression( rpcString, pcEnd, cEndChar );
-    if( rpcString < pcEnd )
-    {
-        aExp = OUString( pcExpStart, static_cast< sal_Int32 >( rpcString - pcExpStart ) ).trim();
-        ++rpcString;
-    }
-    return aExp;
-}
-
 /** Tries to skip an empty pair of parentheses (which may contain whitespace
     characters).
 
@@ -634,8 +621,8 @@ void ScXMLConditionHelper::parseCondition(
                 // format is <condition>(<expression>)
                 if( (pcString < pcEnd) && (*pcString == '(') )
                 {
-                    rParseResult.maOperand1 = lclGetExpression( ++pcString, pcEnd, ')' );
-                    if( rParseResult.maOperand1.getLength() > 0 )
+                    rParseResult.maOperand1 = getExpression( ++pcString, pcEnd, ')' );
+                    if( !rParseResult.maOperand1.isEmpty() )
                         rParseResult.meToken = pCondInfo->meToken;
                 }
             break;
@@ -644,11 +631,11 @@ void ScXMLConditionHelper::parseCondition(
                 // format is <condition>(<expression1>,<expression2>)
                 if( (pcString < pcEnd) && (*pcString == '(') )
                 {
-                    rParseResult.maOperand1 = lclGetExpression( ++pcString, pcEnd, ',' );
-                    if( rParseResult.maOperand1.getLength() > 0 )
+                    rParseResult.maOperand1 = getExpression( ++pcString, pcEnd, ',' );
+                    if( !rParseResult.maOperand1.isEmpty() )
                     {
-                        rParseResult.maOperand2 = lclGetExpression( pcString, pcEnd, ')' );
-                        if( rParseResult.maOperand2.getLength() > 0 )
+                        rParseResult.maOperand2 = getExpression( pcString, pcEnd, ')' );
+                        if( !rParseResult.maOperand2.isEmpty() )
                             rParseResult.meToken = pCondInfo->meToken;
                     }
                 }
@@ -658,6 +645,19 @@ void ScXMLConditionHelper::parseCondition(
     }
 }
 
+OUString ScXMLConditionHelper::getExpression( const sal_Unicode*& rpcString, const sal_Unicode* pcEnd, sal_Unicode cEndChar )
+{
+    OUString aExp;
+    const sal_Unicode* pcExpStart = rpcString;
+    lclSkipExpression( rpcString, pcEnd, cEndChar );
+    if( rpcString < pcEnd )
+    {
+        aExp = OUString( pcExpStart, static_cast< sal_Int32 >( rpcString - pcExpStart ) ).trim();
+        ++rpcString;
+    }
+    return aExp;
+}
+
 // ============================================================================
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
