@@ -49,7 +49,7 @@ using ::boost::unordered_map;
 using ::std::auto_ptr;
 
 ScMenuFloatingWindow::MenuItemData::MenuItemData() :
-    mbEnabled(true),
+    mbEnabled(true), mbSeparator(false),
     mpAction(static_cast<ScCheckListMenuWindow::Action*>(NULL)),
     mpSubMenuWin(static_cast<ScMenuFloatingWindow*>(NULL))
 {
@@ -73,7 +73,7 @@ void ScMenuFloatingWindow::SubMenuItemData::reset()
     maTimer.Stop();
 }
 
-IMPL_LINK( ScMenuFloatingWindow::SubMenuItemData, TimeoutHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG(ScMenuFloatingWindow::SubMenuItemData, TimeoutHdl)
 {
     mpParent->handleMenuTimeout(this);
     return 0;
@@ -141,6 +141,12 @@ void ScMenuFloatingWindow::MouseButtonUp(const MouseEvent& rMEvt)
 
 void ScMenuFloatingWindow::KeyInput(const KeyEvent& rKEvt)
 {
+    if (maMenuItems.empty())
+    {
+        Window::KeyInput(rKEvt);
+        return;
+    }
+
     const KeyCode& rKeyCode = rKEvt.GetKeyCode();
     bool bHandled = true;
     size_t nSelectedMenu = mnSelectedMenu;
@@ -148,18 +154,64 @@ void ScMenuFloatingWindow::KeyInput(const KeyEvent& rKEvt)
     switch (rKeyCode.GetCode())
     {
         case KEY_UP:
+        {
+            if (nLastMenuPos == 0)
+                // There is only one menu item.  Do nothing.
+                break;
+
+            size_t nOldPos = nSelectedMenu;
+
             if (nSelectedMenu == MENU_NOT_SELECTED || nSelectedMenu == 0)
                 nSelectedMenu = nLastMenuPos;
             else
                 --nSelectedMenu;
+
+            // Loop until a non-separator menu item is found.
+            while (nSelectedMenu != nOldPos)
+            {
+                if (maMenuItems[nSelectedMenu].mbSeparator)
+                {
+                    if (nSelectedMenu)
+                        --nSelectedMenu;
+                    else
+                        nSelectedMenu = nLastMenuPos;
+                }
+                else
+                    break;
+            }
+
             setSelectedMenuItem(nSelectedMenu, false, false);
+        }
         break;
         case KEY_DOWN:
+        {
+            if (nLastMenuPos == 0)
+                // There is only one menu item.  Do nothing.
+                break;
+
+            size_t nOldPos = nSelectedMenu;
+
             if (nSelectedMenu == MENU_NOT_SELECTED || nSelectedMenu == nLastMenuPos)
                 nSelectedMenu = 0;
             else
                 ++nSelectedMenu;
+
+            // Loop until a non-separator menu item is found.
+            while (nSelectedMenu != nOldPos)
+            {
+                if (maMenuItems[nSelectedMenu].mbSeparator)
+                {
+                    if (nSelectedMenu == nLastMenuPos)
+                        nSelectedMenu = 0;
+                    else
+                        ++nSelectedMenu;
+                }
+                else
+                    break;
+            }
+
             setSelectedMenuItem(nSelectedMenu, false, false);
+        }
         break;
         case KEY_LEFT:
             if (mpParentMenu)
@@ -254,6 +306,13 @@ void ScMenuFloatingWindow::addMenuItem(const OUString& rText, bool bEnabled, Act
     maMenuItems.push_back(aItem);
 }
 
+void ScMenuFloatingWindow::addSeparator()
+{
+    MenuItemData aItem;
+    aItem.mbSeparator = true;
+    maMenuItems.push_back(aItem);
+}
+
 ScMenuFloatingWindow* ScMenuFloatingWindow::addSubMenuItem(const OUString& rText, bool bEnabled)
 {
     MenuItemData aItem;
@@ -278,7 +337,12 @@ Size ScMenuFloatingWindow::getMenuSize() const
     vector<MenuItemData>::const_iterator itr = maMenuItems.begin(), itrEnd = maMenuItems.end();
     long nTextWidth = 0;
     for (; itr != itrEnd; ++itr)
+    {
+        if (itr->mbSeparator)
+            continue;
+
         nTextWidth = ::std::max(GetTextWidth(itr->maText), nTextWidth);
+    }
 
     size_t nLastPos = maMenuItems.size()-1;
     Point aPos;
@@ -316,11 +380,64 @@ void ScMenuFloatingWindow::drawMenuItem(size_t nPos)
     }
 }
 
+void ScMenuFloatingWindow::drawSeparator(size_t nPos)
+{
+    Point aPos;
+    Size aSize;
+    getMenuItemPosSize(nPos, aPos, aSize);
+    Rectangle aRegion(aPos,aSize);
+
+    if (IsNativeControlSupported(CTRL_MENU_POPUP, PART_ENTIRE_CONTROL))
+    {
+        Push(PUSH_CLIPREGION);
+        IntersectClipRegion(aRegion);
+        Rectangle aCtrlRect(Point(0,0), GetOutputSizePixel());
+        DrawNativeControl(
+            CTRL_MENU_POPUP, PART_ENTIRE_CONTROL, aCtrlRect, CTRL_STATE_ENABLED,
+            ImplControlValue(), OUString());
+
+        Pop();
+    }
+
+    bool bNativeDrawn = false;
+    if (IsNativeControlSupported(CTRL_MENU_POPUP, PART_MENU_SEPARATOR))
+    {
+        ControlState nState = 0;
+        const MenuItemData& rData = maMenuItems[nPos];
+        if (rData.mbEnabled)
+            nState |= CTRL_STATE_ENABLED;
+
+        bNativeDrawn = DrawNativeControl(
+            CTRL_MENU_POPUP, PART_MENU_SEPARATOR,
+            aRegion, nState, ImplControlValue(), OUString());
+    }
+
+    if (!bNativeDrawn)
+    {
+        const StyleSettings& rStyle = GetSettings().GetStyleSettings();
+        Point aTmpPos = aPos;
+        aTmpPos.Y() += aSize.Height()/2;
+        SetLineColor(rStyle.GetShadowColor());
+        DrawLine(aTmpPos, Point(aSize.Width()+aTmpPos.X(), aTmpPos.Y()));
+        ++aTmpPos.Y();
+        SetLineColor(rStyle.GetLightColor());
+        DrawLine(aTmpPos, Point(aSize.Width()+aTmpPos.X(), aTmpPos.Y()));
+        SetLineColor();
+    }
+}
+
 void ScMenuFloatingWindow::drawAllMenuItems()
 {
     size_t n = maMenuItems.size();
     for (size_t i = 0; i < n; ++i)
-        highlightMenuItem(i, i == mnSelectedMenu);
+    {
+        if (maMenuItems[i].mbSeparator)
+            // Separator
+            drawSeparator(i);
+        else
+            // Normal menu item
+            highlightMenuItem(i, i == mnSelectedMenu);
+    }
 }
 
 const Font& ScMenuFloatingWindow::getLabelFont() const
@@ -622,18 +739,23 @@ void ScMenuFloatingWindow::highlightMenuItem(size_t nPos, bool bSelected)
 
 void ScMenuFloatingWindow::getMenuItemPosSize(size_t nPos, Point& rPos, Size& rSize) const
 {
+    size_t nCount = maMenuItems.size();
+    if (nPos >= nCount)
+        return;
+
     const sal_uInt16 nLeftMargin = 5;
     const sal_uInt16 nTopMargin = 5;
-    const sal_uInt16 nMenuItemHeight = static_cast< sal_uInt16 >( maLabelFont.GetHeight()*1.8 );
-
-    Size aWndSize = GetSizePixel();
+    const sal_uInt16 nMenuItemHeight = static_cast<sal_uInt16>(maLabelFont.GetHeight()*1.8);
+    const sal_uInt16 nSepHeight = static_cast<sal_uInt16>(maLabelFont.GetHeight()*0.8);
 
     Point aPos1(nLeftMargin, nTopMargin);
-    Size aSize1(aWndSize.Width() - nLeftMargin*2, nMenuItemHeight);
-
     rPos = aPos1;
-    rPos.Y() += aSize1.Height()*nPos;
-    rSize = aSize1;
+    for (size_t i = 0; i < nPos; ++i)
+        rPos.Y() += maMenuItems[i].mbSeparator ? nSepHeight : nMenuItemHeight;
+
+    Size aWndSize = GetSizePixel();
+    sal_uInt16 nH = maMenuItems[nPos].mbSeparator ? nSepHeight : nMenuItemHeight;
+    rSize = Size(aWndSize.Width() - nLeftMargin*2, nH);
 }
 
 ScMenuFloatingWindow* ScMenuFloatingWindow::getParentMenuWindow() const
@@ -651,7 +773,7 @@ size_t ScMenuFloatingWindow::getEnclosingMenuItem(const Point& rPos) const
         getMenuItemPosSize(i, aPos, aSize);
         Rectangle aRect(aPos, aSize);
         if (aRect.IsInside(rPos))
-            return i;
+            return maMenuItems[i].mbSeparator ? MENU_NOT_SELECTED : i;
     }
     return MENU_NOT_SELECTED;
 }
@@ -909,6 +1031,13 @@ void ScCheckListMenuWindow::packWindow()
         // Widen the window to fit the menu items.
         maWndSize.Width() = maMenuSize.Width();
 
+    // Set proper window height based on the number of menu items.
+    if (maWndSize.Height() < maMenuSize.Height()*2.8)
+        maWndSize.Height() = maMenuSize.Height()*2.8;
+
+    // TODO: Make sure the window height never exceeds the height of the
+    // screen. Also do adjustment based on the number of check box items.
+
     SetOutputSizePixel(maWndSize);
 
     const StyleSettings& rStyle = GetSettings().GetStyleSettings();
@@ -1018,7 +1147,7 @@ IMPL_LINK( ScCheckListMenuWindow, ButtonHdl, Button*, pBtn )
     return 0;
 }
 
-IMPL_LINK( ScCheckListMenuWindow, TriStateHdl, TriStateBox*, EMPTYARG )
+IMPL_LINK_NOARG(ScCheckListMenuWindow, TriStateHdl)
 {
     switch (mePrevToggleAllState)
     {
