@@ -44,6 +44,7 @@
 #include "viewdata.hxx"
 #include "tabvwsh.hxx"
 #include "sc.hrc"
+#include "globstr.hrc"
 
 #include "sfx2/app.hxx"
 #include "sfx2/docfilt.hxx"
@@ -61,6 +62,7 @@
 #include "tools/urlobj.hxx"
 #include "unotools/ucbhelper.hxx"
 #include "unotools/localfilehelper.hxx"
+#include "vcl/msgbox.hxx"
 
 #include <memory>
 #include <algorithm>
@@ -89,7 +91,7 @@ class TabNameSearchPredicate : public unary_function<ScExternalRefCache::TableNa
 {
 public:
     explicit TabNameSearchPredicate(const OUString& rSearchName) :
-        maSearchName(ScGlobal::pCharClass->upper(rSearchName))
+        maSearchName(ScGlobal::pCharClass->uppercase(rSearchName))
     {
     }
 
@@ -192,8 +194,7 @@ public:
         else
         {
             // string cell otherwise.
-            String aVal;
-            pCell->GetString(aVal);
+            rtl::OUString aVal = pCell->GetString();
             mpDoc->PutCell(aPos, new ScStringCell(aVal));
         }
     }
@@ -516,7 +517,7 @@ const OUString* ScExternalRefCache::getRealTableName(sal_uInt16 nFileId, const O
 
     const DocItem& rDoc = itrDoc->second;
     TableNameIndexMap::const_iterator itrTabId = rDoc.maTableNameIndex.find(
-        ScGlobal::pCharClass->upper(rTabName));
+        ScGlobal::pCharClass->uppercase(rTabName));
     if (itrTabId == rDoc.maTableNameIndex.end())
     {
         // the specified table is not in cache.
@@ -537,7 +538,7 @@ const OUString* ScExternalRefCache::getRealRangeName(sal_uInt16 nFileId, const O
 
     const DocItem& rDoc = itrDoc->second;
     NamePairMap::const_iterator itr = rDoc.maRealRangeNameMap.find(
-        ScGlobal::pCharClass->upper(rRangeName));
+        ScGlobal::pCharClass->uppercase(rRangeName));
     if (itr == rDoc.maRealRangeNameMap.end())
         // range name not found.
         return NULL;
@@ -557,7 +558,7 @@ ScExternalRefCache::TokenRef ScExternalRefCache::getCellData(
 
     const DocItem& rDoc = itrDoc->second;
     TableNameIndexMap::const_iterator itrTabId = rDoc.maTableNameIndex.find(
-        ScGlobal::pCharClass->upper(rTabName));
+        ScGlobal::pCharClass->uppercase(rTabName));
     if (itrTabId == rDoc.maTableNameIndex.end())
     {
         // the specified table is not in cache.
@@ -585,7 +586,7 @@ ScExternalRefCache::TokenArrayRef ScExternalRefCache::getCellRangeData(
     DocItem& rDoc = itrDoc->second;
 
     TableNameIndexMap::iterator itrTabId = rDoc.maTableNameIndex.find(
-        ScGlobal::pCharClass->upper(rTabName));
+        ScGlobal::pCharClass->uppercase(rTabName));
     if (itrTabId == rDoc.maTableNameIndex.end())
         // the specified table is not in cache.
         return TokenArrayRef();
@@ -693,7 +694,7 @@ ScExternalRefCache::TokenArrayRef ScExternalRefCache::getRangeNameTokens(sal_uIn
 
     RangeNameMap& rMap = pDoc->maRangeNames;
     RangeNameMap::const_iterator itr = rMap.find(
-        ScGlobal::pCharClass->upper(rName));
+        ScGlobal::pCharClass->uppercase(rName));
     if (itr == rMap.end())
         return TokenArrayRef();
 
@@ -706,7 +707,7 @@ void ScExternalRefCache::setRangeNameTokens(sal_uInt16 nFileId, const OUString&
     if (!pDoc)
         return;
 
-    String aUpperName = ScGlobal::pCharClass->upper(rName);
+    String aUpperName = ScGlobal::pCharClass->uppercase(rName);
     RangeNameMap& rMap = pDoc->maRangeNames;
     rMap.insert(RangeNameMap::value_type(aUpperName, pArray));
     pDoc->maRealRangeNameMap.insert(NamePairMap::value_type(aUpperName, rName));
@@ -727,7 +728,7 @@ void ScExternalRefCache::setCellData(sal_uInt16 nFileId, const OUString& rTabNam
 
     // See if the table by this name already exists.
     TableNameIndexMap::iterator itrTabName = rDoc.maTableNameIndex.find(
-        ScGlobal::pCharClass->upper(rTabName));
+        ScGlobal::pCharClass->uppercase(rTabName));
     if (itrTabName == rDoc.maTableNameIndex.end())
         // Table not found.  Maybe the table name or the file id is wrong ???
         return;
@@ -758,7 +759,7 @@ void ScExternalRefCache::setCellRangeData(sal_uInt16 nFileId, const ScRange& rRa
     // Now, find the table position of the first table to cache.
     const String& rFirstTabName = rData.front().maTableName;
     TableNameIndexMap::iterator itrTabName = rDoc.maTableNameIndex.find(
-        ScGlobal::pCharClass->upper(rFirstTabName));
+        ScGlobal::pCharClass->uppercase(rFirstTabName));
     if (itrTabName == rDoc.maTableNameIndex.end())
     {
         // table index not found.
@@ -842,7 +843,7 @@ void ScExternalRefCache::initializeDoc(sal_uInt16 nFileId, const vector<OUString
     for (vector<OUString>::const_iterator itr = rTabNames.begin(), itrEnd = rTabNames.end();
           itr != itrEnd; ++itr)
     {
-        TableName aNameItem(ScGlobal::pCharClass->upper(*itr), *itr);
+        TableName aNameItem(ScGlobal::pCharClass->uppercase(*itr), *itr);
         aNewTabNames.push_back(aNameItem);
     }
     pDoc->maTableNames.swap(aNewTabNames);
@@ -948,7 +949,7 @@ bool ScExternalRefCache::hasCacheTable(sal_uInt16 nFileId, const OUString& rTabN
     if (!pDoc)
         return false;
 
-    String aUpperName = ScGlobal::pCharClass->upper(rTabName);
+    String aUpperName = ScGlobal::pCharClass->uppercase(rTabName);
     vector<TableName>::const_iterator itrBeg = pDoc->maTableNames.begin(), itrEnd = pDoc->maTableNames.end();
     vector<TableName>::const_iterator itr = ::std::find_if(
         itrBeg, itrEnd, TabNameSearchPredicate(aUpperName));
@@ -984,7 +985,7 @@ bool ScExternalRefCache::setCacheTableReferenced( sal_uInt16 nFileId, const OUSt
     if (pDoc)
     {
         size_t nIndex = 0;
-        String aTabNameUpper = ScGlobal::pCharClass->upper( rTabName);
+        String aTabNameUpper = ScGlobal::pCharClass->uppercase( rTabName);
         if (lcl_getTableDataIndex( pDoc->maTableNameIndex, aTabNameUpper, nIndex))
         {
             size_t nStop = ::std::min( nIndex + nSheets, pDoc->maTables.size());
@@ -1169,7 +1170,7 @@ ScExternalRefCache::TableTypeRef ScExternalRefCache::getCacheTable(sal_uInt16 nF
     DocItem& rDoc = *pDoc;
 
     size_t nIndex;
-    String aTabNameUpper = ScGlobal::pCharClass->upper(rTabName);
+    String aTabNameUpper = ScGlobal::pCharClass->uppercase(rTabName);
     if (lcl_getTableDataIndex(rDoc.maTableNameIndex, aTabNameUpper, nIndex))
     {
         // specified table found.
@@ -1248,7 +1249,7 @@ void ScExternalRefLink::Closed()
     if (!mbDoRefresh)
         return SUCCESS;
 
-    String aFile, aFilter;
+    rtl::OUString aFile, aFilter;
     mpDoc->GetLinkManager()->GetDisplayNames(this, NULL, &aFile, NULL, &aFilter);
     ScExternalRefManager* pMgr = mpDoc->GetExternalRefManager();
 
@@ -1287,7 +1288,7 @@ void ScExternalRefLink::SetDoReferesh(bool b)
     mbDoRefresh = b;
 }
 
-IMPL_LINK( ScExternalRefLink, ExternalRefEndEditHdl, ::sfx2::SvBaseLink*, EMPTYARG )
+IMPL_LINK_NOARG(ScExternalRefLink, ExternalRefEndEditHdl)
 {
     return 0;
 }
@@ -1306,14 +1307,12 @@ static FormulaToken* lcl_convertToToken(ScBaseCell* pCell)
     {
         case CELLTYPE_EDIT:
         {
-            String aStr;
-            static_cast<ScEditCell*>(pCell)->GetString(aStr);
+            rtl::OUString aStr = static_cast<ScEditCell*>(pCell)->GetString();
             return new formula::FormulaStringToken(aStr);
         }
         case CELLTYPE_STRING:
         {
-            String aStr;
-            static_cast<ScStringCell*>(pCell)->GetString(aStr);
+            rtl::OUString aStr = static_cast<ScStringCell*>(pCell)->GetString();
             return new formula::FormulaStringToken(aStr);
         }
         case CELLTYPE_VALUE:
@@ -1334,8 +1333,7 @@ static FormulaToken* lcl_convertToToken(ScBaseCell* pCell)
             }
             else
             {
-                String aStr;
-                pFCell->GetString(aStr);
+                rtl::OUString aStr = pFCell->GetString();
                 return new formula::FormulaStringToken(aStr);
             }
         }
@@ -1408,15 +1406,13 @@ static ScTokenArray* lcl_convertToTokenArray(const ScDocument* pSrcDoc, ScRange&
                 {
                     case CELLTYPE_EDIT:
                     {
-                        String aStr;
-                        static_cast<ScEditCell*>(pCell)->GetString(aStr);
+                        rtl::OUString aStr = static_cast<ScEditCell*>(pCell)->GetString();
                         xMat->PutString(aStr, nC, nR);
                     }
                     break;
                     case CELLTYPE_STRING:
                     {
-                        String aStr;
-                        static_cast<ScStringCell*>(pCell)->GetString(aStr);
+                        rtl::OUString aStr = static_cast<ScStringCell*>(pCell)->GetString();
                         xMat->PutString(aStr, nC, nR);
                     }
                     break;
@@ -1439,8 +1435,7 @@ static ScTokenArray* lcl_convertToTokenArray(const ScDocument* pSrcDoc, ScRange&
                         }
                         else
                         {
-                            String aStr;
-                            pFCell->GetString(aStr);
+                            rtl::OUString aStr = pFCell->GetString();
                             xMat->PutString(aStr, nC, nR);
                         }
                     }
@@ -2004,7 +1999,7 @@ ScExternalRefCache::TokenArrayRef ScExternalRefManager::getDoubleRefTokensFromSr
     vector<ScExternalRefCache::SingleRangeData> aCacheData;
     aCacheData.reserve(nTabSpan+1);
     aCacheData.push_back(ScExternalRefCache::SingleRangeData());
-    aCacheData.back().maTableName = ScGlobal::pCharClass->upper(rTabName);
+    aCacheData.back().maTableName = ScGlobal::pCharClass->uppercase(rTabName);
 
     for (SCTAB i = 1; i < nTabSpan + 1; ++i)
     {
@@ -2014,7 +2009,7 @@ ScExternalRefCache::TokenArrayRef ScExternalRefManager::getDoubleRefTokensFromSr
             break;
 
         aCacheData.push_back(ScExternalRefCache::SingleRangeData());
-        aCacheData.back().maTableName = ScGlobal::pCharClass->upper(aTabName);
+        aCacheData.back().maTableName = ScGlobal::pCharClass->uppercase(aTabName);
     }
 
     aRange.aStart.SetTab(nTab1);
@@ -2030,7 +2025,7 @@ ScExternalRefCache::TokenArrayRef ScExternalRefManager::getRangeNameTokensFromSr
     sal_uInt16 nFileId, const ScDocument* pSrcDoc, OUString& rName)
 {
     ScRangeName* pExtNames = pSrcDoc->GetRangeName();
-    String aUpperName = ScGlobal::pCharClass->upper(rName);
+    String aUpperName = ScGlobal::pCharClass->uppercase(rName);
     const ScRangeData* pRangeData = pExtNames->findByUpperName(aUpperName);
     if (!pRangeData)
         return ScExternalRefCache::TokenArrayRef();
@@ -2092,7 +2087,7 @@ const ScDocument* ScExternalRefManager::getInMemorySrcDocument(sal_uInt16 nFileI
     while (pShell)
     {
         SfxMedium* pMedium = pShell->GetMedium();
-        if (pMedium)
+        if (pMedium && pMedium->GetName().Len())
         {
             OUString aName = pMedium->GetName();
             // TODO: We should make the case sensitivity platform dependent.
@@ -2103,6 +2098,21 @@ const ScDocument* ScExternalRefManager::getInMemorySrcDocument(sal_uInt16 nFileI
                 break;
             }
         }
+        else
+        {
+            // handle unsaved documents here
+            OUString aName = pShell->GetName();
+            if (pFileName->equalsIgnoreAsciiCase(aName))
+            {
+                // Found !
+                SrcShell aSrcDoc;
+                aSrcDoc.maShell = pShell;
+                maUnsavedDocShells.insert(DocShellMap::value_type(nFileId, aSrcDoc));
+                StartListening(*pShell);
+                pSrcDoc = pShell->GetDocument();
+                break;
+            }
+        }
         pShell = static_cast<ScDocShell*>(SfxObjectShell::GetNext(*pShell, &aType, false));
     }
 
@@ -2127,6 +2137,17 @@ const ScDocument* ScExternalRefManager::getSrcDocument(sal_uInt16 nFileId)
         return static_cast<ScDocShell*>(p)->GetDocument();
     }
 
+    itrEnd = maUnsavedDocShells.end();
+    itr = maUnsavedDocShells.find(nFileId);
+    if (itr != itrEnd)
+    {
+        //document is unsaved document
+
+        SfxObjectShell* p = itr->second.maShell;
+        itr->second.maLastAccess = Time( Time::SYSTEM );
+        return static_cast<ScDocShell*>(p)->GetDocument();
+    }
+
     const OUString* pFile = getExternalFileName(nFileId);
     if (!pFile)
         // no file name associated with this ID.
@@ -2173,7 +2194,7 @@ SfxObjectShellRef ScExternalRefManager::loadSrcDocument(sal_uInt16 nFileId, OUSt
         return NULL;
 
     OUString aOptions = pFileData->maFilterOptions;
-    if ( pFileData->maFilterName.getLength() )
+    if ( !pFileData->maFilterName.isEmpty() )
         rFilter = pFileData->maFilterName;      // don't overwrite stored filter with guessed filter
     else
         ScDocumentLoader::GetFilterName(aFile, rFilter, aOptions, true, false);;
@@ -2200,7 +2221,7 @@ SfxObjectShellRef ScExternalRefManager::loadSrcDocument(sal_uInt16 nFileId, OUSt
     pSet->Put( SfxBoolItem(SID_HIDDEN, true) );
 
     SAL_WNODEPRECATED_DECLARATIONS_PUSH
-    auto_ptr<SfxMedium> pMedium(new SfxMedium(aFile, STREAM_STD_READ, false, pFilter, pSet));
+    auto_ptr<SfxMedium> pMedium(new SfxMedium(aFile, STREAM_STD_READ, pFilter, pSet));
     SAL_WNODEPRECATED_DECLARATIONS_POP
     if (pMedium->GetError() != ERRCODE_NONE)
         return NULL;
@@ -2246,7 +2267,7 @@ bool ScExternalRefManager::isFileLoadable(const OUString& rFile) const
     if (isOwnDocument(rFile))
         return false;
     rtl::OUString aPhysical;
-    if (utl::LocalFileHelper::ConvertURLToPhysicalName(rFile, aPhysical) && aPhysical.getLength())
+    if (utl::LocalFileHelper::ConvertURLToPhysicalName(rFile, aPhysical) && !aPhysical.isEmpty())
     {
         // #i114504# try IsFolder/Exists only for file URLs
 
@@ -2279,7 +2300,7 @@ void ScExternalRefManager::maybeLinkExternalFile(sal_uInt16 nFileId)
     }
     // If a filter was already set (for example, loading the cached table),
     // don't call GetFilterName which has to access the source file.
-    if (!aFilter.getLength())
+    if (aFilter.isEmpty())
         ScDocumentLoader::GetFilterName(*pFileName, aFilter, aOptions, true, false);
     sfx2::LinkManager* pLinkMgr = mpDoc->GetLinkManager();
     ScExternalRefLink* pLink = new ScExternalRefLink(mpDoc, nFileId, aFilter);
@@ -2341,6 +2362,17 @@ bool ScExternalRefManager::isOwnDocument(const OUString& rFile) const
 
 void ScExternalRefManager::convertToAbsName(OUString& rFile) const
 {
+    // unsaved documents have no AbsName
+    TypeId aType(TYPE(ScDocShell));
+    ScDocShell* pShell = static_cast<ScDocShell*>(SfxObjectShell::GetFirst(&aType, false));
+    while (pShell)
+    {
+        if (rFile == rtl::OUString(pShell->GetName()))
+            return;
+
+        pShell = static_cast<ScDocShell*>(SfxObjectShell::GetNext(*pShell, &aType, false));
+    }
+
     SfxObjectShell* pDocShell = mpDoc->GetDocumentShell();
     rFile = ScGlobal::GetAbsDocName(rFile, pDocShell);
 }
@@ -2644,6 +2676,51 @@ sal_uInt32 ScExternalRefManager::getMappedNumberFormat(sal_uInt16 nFileId, sal_u
     return nNumFmt;
 }
 
+void ScExternalRefManager::transformUnsavedRefToSavedRef( SfxObjectShell* pShell )
+{
+    DocShellMap::iterator itr = maUnsavedDocShells.begin();
+    while( itr != maUnsavedDocShells.end() )
+    {
+        if (&(itr->second.maShell) == pShell)
+        {
+            // found that the shell is marked as unsaved
+            rtl::OUString aFileURL = pShell->GetMedium()->GetURLObject().GetMainURL(INetURLObject::DECODE_TO_IURI);
+            switchSrcFile(itr->first, aFileURL, rtl::OUString());
+            EndListening(*pShell);
+            maUnsavedDocShells.erase(itr++);
+        }
+    }
+}
+
+void ScExternalRefManager::Notify( SfxBroadcaster&, const SfxHint& rHint )
+{
+    if ( rHint.ISA( SfxEventHint ) )
+    {
+        sal_uLong nEventId = ((SfxEventHint&)rHint).GetEventId();
+        switch ( nEventId )
+        {
+            case SFX_EVENT_PREPARECLOSEDOC:
+                {
+                    SfxObjectShell* pObjShell = static_cast<const SfxEventHint&>( rHint ).GetObjShell();
+                    ScDocShell* pDocShell = static_cast< ScDocShell* >( pObjShell );
+                    WarningBox aBox(  pDocShell->GetActiveDialogParent(), WinBits( WB_OK ),
+                                        ScGlobal::GetRscString( STR_CLOSE_WITH_UNSAVED_REFS ) );
+                    aBox.Execute();
+                }
+                break;
+            case SFX_EVENT_SAVEDOCDONE:
+            case SFX_EVENT_SAVEASDOCDONE:
+                {
+                    SfxObjectShell* pObjShell = static_cast<const SfxEventHint&>( rHint ).GetObjShell();
+                    transformUnsavedRefToSavedRef(pObjShell);
+                }
+                break;
+            default:
+                break;
+        }
+    }
+}
+
 IMPL_LINK(ScExternalRefManager, TimeOutHdl, AutoTimer*, pTimer)
 {
     if (pTimer == &maSrcDocTimer)
