@@ -29,7 +29,7 @@
 
 #undef SC_DLLIMPLEMENTATION
 
-//------------------------------------------------------------------
+#include <comphelper/string.hxx>
 #include <vcl/msgbox.hxx>
 
 #include "global.hxx"
@@ -54,16 +54,8 @@
 #define CR  (sal_Unicode)13
 #define LF  (sal_Unicode)10
 
-static sal_uInt16 pUserListsRanges[] =
-{
-    SID_SCUSERLISTS,
-    SID_SCUSERLISTS,
-    0
-};
-
 static const sal_Unicode cDelimiter = ',';
 
-
 //========================================================================
 // Benutzerdefinierte Listen:
 
@@ -165,13 +157,6 @@ void ScTpUserLists::Init()
 
 // -----------------------------------------------------------------------
 
-sal_uInt16* ScTpUserLists::GetRanges()
-{
-    return pUserListsRanges;
-}
-
-// -----------------------------------------------------------------------
-
 SfxTabPage* ScTpUserLists::Create( Window* pParent, const SfxItemSet& rAttrSet )
 {
     return ( new ScTpUserLists( pParent, rAttrSet ) );
@@ -321,8 +306,7 @@ void ScTpUserLists::UpdateEntries( size_t nList )
             aEntryListStr += String(pList->GetSubStr(i));
         }
 
-        aEntryListStr.ConvertLineEnd();
-        aEdEntries.SetText( aEntryListStr );
+        aEdEntries.SetText(convertLineEnd(aEntryListStr, GetSystemLineEnd()));
     }
     else
     {
@@ -334,15 +318,9 @@ void ScTpUserLists::UpdateEntries( size_t nList )
 
 void ScTpUserLists::MakeListStr( String& rListStr )
 {
-    String  aInputStr(rListStr);
     String  aStr;
 
-    xub_StrLen  nLen    = aStr.Len();
-    xub_StrLen  c       = 0;
-
-    aInputStr.ConvertLineEnd( LINEEND_LF );
-
-    xub_StrLen nToken=rListStr.GetTokenCount(LF);
+    xub_StrLen nToken = comphelper::string::getTokenCount(rListStr, LF);
 
     for(xub_StrLen i=0;i<nToken;i++)
     {
@@ -355,12 +333,12 @@ void ScTpUserLists::MakeListStr( String& rListStr )
 
     aStr.EraseLeadingChars( cDelimiter );
     aStr.EraseTrailingChars( cDelimiter );
-    nLen = aStr.Len();
+    xub_StrLen nLen = aStr.Len();
 
     rListStr.Erase();
 
     // Alle Doppelten cDelimiter entfernen:
-    c=0;
+    xub_StrLen c = 0;
     while ( c < nLen )
     {
         rListStr += aStr.GetChar(c);
