@@ -276,7 +276,7 @@ sal_Bool lcl_GetCaptionPoint( uno::Reference< drawing::XShape >& xShape, awt::Po
 {
     sal_Bool bReturn = false;
     rtl::OUString sType(xShape->getShapeType());
-    sal_Bool bCaptionShape(sType.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.CaptionShape")));
+    sal_Bool bCaptionShape( sType == "com.sun.star.drawing.CaptionShape" );
     if (bCaptionShape)
     {
         uno::Reference < beans::XPropertySet > xShapeProp (xShape, uno::UNO_QUERY);
@@ -470,7 +470,7 @@ void SAL_CALL ScShapeObj::setPropertyValue(
             else
             {
                 // insert new user data with image map
-                pObj->InsertUserData(new ScIMapInfo(aImageMap) );
+                pObj->AppendUserData(new ScIMapInfo(aImageMap) );
             }
         }
     }
@@ -1124,14 +1124,14 @@ void SAL_CALL ScShapeObj::insertTextContent( const uno::Reference<text::XTextRan
 
     uno::Reference<text::XTextContent> xEffContent;
 
-    ScCellFieldObj* pCellField = ScCellFieldObj::getImplementation( xContent );
+    ScEditFieldObj* pCellField = ScEditFieldObj::getImplementation( xContent );
     if ( pCellField )
     {
         //  createInstance("TextField.URL") from the document creates a ScCellFieldObj.
         //  To insert it into drawing text, a SvxUnoTextField is needed instead.
         //  The ScCellFieldObj object is left in non-inserted state.
 
-        SvxUnoTextField* pDrawField = new SvxUnoTextField( ID_URLFIELD );
+        SvxUnoTextField* pDrawField = new SvxUnoTextField( text::textfield::Type::URL );
         xEffContent.set(pDrawField);
         lcl_CopyOneProperty( *pDrawField, *pCellField, SC_UNONAME_URL );
         lcl_CopyOneProperty( *pDrawField, *pCellField, SC_UNONAME_REPR );
@@ -1427,7 +1427,7 @@ public:
 
         if ( aName == SC_EVENTACC_ONCLICK )
         {
-            if ( pInfo && (pInfo->GetMacro().getLength() > 0) )
+            if ( pInfo && !pInfo->GetMacro().isEmpty() )
             {
                 aProperties.realloc( 2 );
                 aProperties[ 0 ].Name = SC_EVENTACC_EVENTTYPE;
