@@ -149,15 +149,14 @@
 #include <string>
 #include <algorithm>
 
+#include <basegfx/tools/zoomtools.hxx>
+
 #define SPLIT_MARGIN    30
 #define SC_ICONSIZE     36
 
 #define SC_SCROLLBAR_MIN    30
 #define SC_TABBAR_MIN       6
 
-//  fuer Rad-Maus
-#define SC_DELTA_ZOOM   10
-
 using namespace ::com::sun::star;
 
 // STATIC DATA -----------------------------------------------------------
@@ -360,7 +359,7 @@ void ScTabView::ResetTimer()
     pTimerWindow = NULL;
 }
 
-IMPL_LINK( ScTabView, TimerHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(ScTabView, TimerHdl)
 {
     if (pTimerWindow)
         pTimerWindow->MouseMove( aTimerMEvt );
@@ -408,13 +407,6 @@ void ScTabView::DoResize( const Point& rOffset, const Size& rSize, bool bInner )
     bool bHOutline   = bOutlMode && lcl_HasColOutline(aViewData);
     bool bVOutline   = bOutlMode && lcl_HasRowOutline(aViewData);
 
-    //  Scrollbar-Einstellungen koennen vom Sfx ueberschrieben werden:
-    SfxScrollingMode eMode = aViewData.GetViewShell()->GetScrollingMode();
-    if ( eMode == SCROLLING_NO )
-        bHScroll = bVScroll = false;
-    else if ( eMode == SCROLLING_YES || eMode == SCROLLING_AUTO )   //! Auto ???
-        bHScroll = bVScroll = true;
-
     if ( aViewData.GetDocShell()->IsPreview() )
         bHScroll = bVScroll = bTabControl = bHeaders = bOutlMode = bHOutline = bVOutline = false;
 
@@ -898,18 +890,9 @@ void ScTabView::GetBorderSize( SvBorder& rBorder, const Size& /* rSize */ )
         ::std::swap( rBorder.Left(), rBorder.Right() );
 }
 
-IMPL_LINK( ScTabView, TabBarResize, void*, EMPTYARG )
+IMPL_LINK_NOARG(ScTabView, TabBarResize)
 {
-    sal_Bool bHScrollMode = aViewData.IsHScrollMode();
-
-    //  Scrollbar-Einstellungen koennen vom Sfx ueberschrieben werden:
-    SfxScrollingMode eMode = aViewData.GetViewShell()->GetScrollingMode();
-    if ( eMode == SCROLLING_NO )
-        bHScrollMode = false;
-    else if ( eMode == SCROLLING_YES || eMode == SCROLLING_AUTO )   //! Auto ???
-        bHScrollMode = sal_True;
-
-    if( bHScrollMode )
+    if (aViewData.IsHScrollMode())
     {
         const long nOverlap = 0;    // ScrollBar::GetWindowOverlapPixel();
         long nSize = pTabControl->GetSplitSize();
@@ -1060,9 +1043,9 @@ bool ScTabView::ScrollCommand( const CommandEvent& rCEvt, ScSplitPos ePos )
             long nOld = (long)(( rOldY.GetNumerator() * 100 ) / rOldY.GetDenominator());
             long nNew = nOld;
             if ( pData->GetDelta() < 0 )
-                nNew = Max( (long) MINZOOM, (long)( nOld - SC_DELTA_ZOOM ) );
+                nNew = Max( (long) MINZOOM, basegfx::zoomtools::zoomOut( nOld ));
             else
-                nNew = Min( (long) MAXZOOM, (long)( nOld + SC_DELTA_ZOOM ) );
+                nNew = Min( (long) MAXZOOM, basegfx::zoomtools::zoomIn( nOld ));
 
             if ( nNew != nOld )
             {
@@ -1112,7 +1095,7 @@ IMPL_LINK( ScTabView, EndScrollHdl, ScrollBar*, pScroll )
 
             if ( pScroll == &aHScrollLeft || pScroll == &aHScrollRight )
             {
-                sal_Bool bMirror = aViewData.GetDocument()->IsLayoutRTL( aViewData.GetTabNo() ) != Application::GetSettings().GetLayoutRTL();
+                bool bMirror = aViewData.GetDocument()->IsLayoutRTL( aViewData.GetTabNo() ) != Application::GetSettings().GetLayoutRTL();
                 ScHSplitPos eWhich = (pScroll == &aHScrollLeft) ? SC_SPLIT_LEFT : SC_SPLIT_RIGHT;
                 long nDelta = GetScrollBarPos( *pScroll, bMirror ) + nScrollMin - aViewData.GetPosX(eWhich);
                 if (nDelta) ScrollX( nDelta, eWhich );
@@ -1133,7 +1116,7 @@ IMPL_LINK( ScTabView, ScrollHdl, ScrollBar*, pScroll )
 {
     sal_Bool bOnlineScroll = sal_True;      //! Optionen
 
-    sal_Bool bHoriz = ( pScroll == &aHScrollLeft || pScroll == &aHScrollRight );
+    bool bHoriz = ( pScroll == &aHScrollLeft || pScroll == &aHScrollRight );
     long nViewPos;
     if ( bHoriz )
         nViewPos = aViewData.GetPosX( (pScroll == &aHScrollLeft) ?
@@ -1142,8 +1125,8 @@ IMPL_LINK( ScTabView, ScrollHdl, ScrollBar*, pScroll )
         nViewPos = aViewData.GetPosY( (pScroll == &aVScrollTop) ?
                                         SC_SPLIT_TOP : SC_SPLIT_BOTTOM );
 
-    sal_Bool bLayoutRTL = aViewData.GetDocument()->IsLayoutRTL( aViewData.GetTabNo() );
-    sal_Bool bMirror = bHoriz && (bLayoutRTL != Application::GetSettings().GetLayoutRTL());
+    bool bLayoutRTL = aViewData.GetDocument()->IsLayoutRTL( aViewData.GetTabNo() );
+    bool bMirror = bHoriz && (bLayoutRTL != Application::GetSettings().GetLayoutRTL());
 
     ScrollType eType = pScroll->GetType();
     if ( eType == SCROLL_DRAG )
@@ -1573,13 +1556,6 @@ void ScTabView::UpdateShow()
     sal_Bool bShowH = ( aViewData.GetHSplitMode() != SC_SPLIT_NONE );
     sal_Bool bShowV = ( aViewData.GetVSplitMode() != SC_SPLIT_NONE );
 
-    //  Scrollbar-Einstellungen koennen vom Sfx ueberschrieben werden:
-    SfxScrollingMode eMode = aViewData.GetViewShell()->GetScrollingMode();
-    if ( eMode == SCROLLING_NO )
-        bHScrollMode = bVScrollMode = false;
-    else if ( eMode == SCROLLING_YES || eMode == SCROLLING_AUTO )   //! Auto ???
-        bHScrollMode = bVScrollMode = sal_True;
-
     if ( aViewData.GetDocShell()->IsPreview() )
         bHScrollMode = bVScrollMode = bTabMode = bHeader = bOutlMode = bHOutline = bVOutline = false;
 
