@@ -247,43 +247,43 @@ ShapeExport& PowerPointShapeExport::WriteTextShape( Reference< XShape > xShape )
 
     DBG(printf( "shape(text): %s\n", USS(sShapeType) ));
 
-    if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.drawing.TextShape" ) ) )
+    if ( sShapeType == "com.sun.star.drawing.TextShape" )
     {
     ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.DateTimeShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.DateTimeShape" )
     {
         if( !WritePlaceholder( xShape, DateAndTime, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.FooterShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.FooterShape" )
     {
         if( !WritePlaceholder( xShape, Footer, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.HeaderShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.HeaderShape" )
     {
         if( !WritePlaceholder( xShape, Header, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.NotesShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.NotesShape" )
     {
         if( mePageType == NOTICE && mrExport.GetPresObj() )
             WritePlaceholderShape( xShape, Notes );
         else
             ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.OutlinerShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.OutlinerShape" )
     {
         if( !WritePlaceholder( xShape, Outliner, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.SlideNumberShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.SlideNumberShape" )
     {
         if( !WritePlaceholder( xShape, SlideNumber, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.TitleTextShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.TitleTextShape" )
     {
         if( !WritePlaceholder( xShape, Title, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
@@ -298,18 +298,18 @@ ShapeExport& PowerPointShapeExport::WriteUnknownShape( Reference< XShape > xShap
 
     DBG(printf( "shape(unknown): %s\n", USS(sShapeType) ));
 
-    if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.drawing.GroupShape" ) ) )
+    if ( sShapeType == "com.sun.star.drawing.GroupShape" )
     {
         Reference< XIndexAccess > rXIndexAccess( xShape, UNO_QUERY );
 
         mrExport.EnterGroup( rXIndexAccess );
         DBG(printf( "enter group\n" ));
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.drawing.PageShape" ) ) )
+    else if ( sShapeType == "com.sun.star.drawing.PageShape" )
     {
         WritePageShape( xShape, mePageType, mrExport.GetPresObj() );
     }
-    else if( sShapeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.SubtitleShape" ) ) )
+    else if ( sShapeType == "com.sun.star.presentation.SubtitleShape" )
     {
         if( !WritePlaceholder( xShape, Subtitle, mbMaster ) )
             ShapeExport::WriteTextShape( xShape );
@@ -357,7 +357,7 @@ bool PowerPointExport::exportDocument() throw()
     mXModel.set( getModel(), UNO_QUERY );
     mXStatusIndicator.set( getStatusIndicator(), UNO_QUERY );
 
-    rtl::OUString sBaseURI( RTL_CONSTASCII_USTRINGPARAM("BaseURI") );
+    rtl::OUString sBaseURI( "BaseURI");
     std::vector< PropertyValue > aProperties;
     PropertyValue aProperty;
     aProperty.Name = sBaseURI;
@@ -391,7 +391,7 @@ bool PowerPointExport::exportDocument() throw()
 
 ::oox::ole::VbaProject* PowerPointExport::implCreateVbaProject() const
 {
-    return new ::oox::ole::VbaProject( getComponentContext(), getModel(), CREATE_OUSTRING( "Impress" ) );
+    return new ::oox::ole::VbaProject( getComponentContext(), getModel(), "Impress" );
 }
 
 void PowerPointExport::ImplWriteBackground( FSHelperPtr pFS, Reference< XPropertySet > rXPropSet )
@@ -446,7 +446,7 @@ void PowerPointExport::ImplWriteBackground( FSHelperPtr pFS, Reference< XPropert
       </p:grpSpPr>"
 
 #define GETA(propName) \
-    ImplGetPropertyValue( mXPagePropSet, String( RTL_CONSTASCII_USTRINGPARAM( #propName ) ) )
+    ImplGetPropertyValue( mXPagePropSet, rtl::OUString( #propName ) )
 
 #define GET(variable, propName) \
     if ( GETA(propName) ) \
@@ -696,7 +696,7 @@ void PowerPointExport::WriteAnimateValues( FSHelperPtr pFS, const Reference< XAn
     DBG(printf("animate value %d: %f\n", i, aKeyTimes[ i ]));
     if( aValues[ i ].hasValue() ) {
         pFS->startElementNS( XML_p, XML_tav,
-                 XML_fmla, sFormula.getLength() > 0 ? USS( sFormula ) : NULL,
+                 XML_fmla, sFormula.isEmpty() ? NULL : USS( sFormula ),
                  XML_tm, I32S( ( sal_Int32 )( aKeyTimes[ i ]*100000.0 ) ),
                  FSEND );
         pFS->startElementNS( XML_p, XML_val, FSEND );
@@ -731,7 +731,7 @@ void PowerPointExport::WriteAnimateTo( FSHelperPtr pFS, Any aValue, const OUStri
 
 void PowerPointExport::WriteAnimationAttributeName( FSHelperPtr pFS, const OUString& rAttributeName )
 {
-    if( ! rAttributeName.getLength() )
+    if( rAttributeName.isEmpty() )
     return;
 
     pFS->startElementNS( XML_p, XML_attrNameLst, FSEND );
@@ -739,11 +739,11 @@ void PowerPointExport::WriteAnimationAttributeName( FSHelperPtr pFS, const OUStr
     DBG(printf("write attribute name: %s\n", USS( rAttributeName )));
 
     const char* sAttributeName = NULL;
-    if( rAttributeName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Visibility" ) ) ) {
+    if ( rAttributeName == "Visibility" ) {
     sAttributeName = "style.visibility";
-    } else if( rAttributeName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "X" ) ) ) {
+    } else if ( rAttributeName == "X" ) {
     sAttributeName = "ppt_x";
-    } else if( rAttributeName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Y" ) ) ) {
+    } else if ( rAttributeName == "Y" ) {
     sAttributeName = "ppt_y";
     }
 
@@ -986,7 +986,11 @@ void PowerPointExport::WriteAnimationNodeCommonPropsStart( FSHelperPtr pFS, cons
     }
 
     const Sequence< NamedValue > aUserData = rXNode->getUserData();
-    const Any* pAny[ DFF_ANIM_PROPERTY_ID_COUNT ];
+
+    // ids start from 1, DFF_ANIM_PROPERTY_ID_COUNT is the highest id
+    // number
+    const Any* pAny[ DFF_ANIM_PROPERTY_ID_COUNT + 1];
+
     AnimationExporter::GetUserData( aUserData, pAny, sizeof( pAny ) );
 
     sal_Int16 nType = 0;
@@ -1141,11 +1145,6 @@ void PowerPointExport::WriteAnimationNodeCommonPropsStart( FSHelperPtr pFS, cons
     pFS->endElementNS( XML_p, XML_cTn );
 }
 
-void PowerPointExport::WriteAnimationNodeCommonPropsEnd( FSHelperPtr pFS )
-{
-    pFS->endElementNS( XML_p, XML_cTn );
-}
-
 void PowerPointExport::WriteAnimationNodeSeq( FSHelperPtr pFS, const Reference< XAnimationNode >& rXNode, sal_Int32, sal_Bool bMainSeqChild )
 {
     DBG(printf ("write animation node SEQ\n"));
@@ -1256,7 +1255,7 @@ static OUString lcl_GetInitials( OUString sName )
 {
     OUStringBuffer sRet;
 
-    if ( sName.getLength() > 0 ) {
+    if ( !sName.isEmpty() ) {
         sRet.append ( sName[0] );
         sal_Int32 nStart = 0, nOffset;
 
@@ -1538,41 +1537,6 @@ sal_Int32 PowerPointExport::nStyleLevelToken[5] =
     XML_lvl5pPr
 };
 
-void PowerPointExport::WriteTextStyleLevel( FSHelperPtr pFS, int nInstance, int nLevel )
-{
-    OSL_ASSERT( nLevel >= 0 && nLevel < 5 );
-    OSL_ASSERT( nInstance >= 0 && nInstance < 9 );
-
-    PPTExParaLevel rParaLevel = mpStyleSheet->GetParaSheet( nInstance ).maParaLevel[ nLevel ];
-
-    pFS->startElementNS( XML_a, PowerPointExport::nStyleLevelToken[ nLevel ],
-             XML_algn, DrawingML::GetAlignment( rParaLevel.mnOOAdjust ),
-             FSEND );
-
-    pFS->endElementNS( XML_a, PowerPointExport::nStyleLevelToken[ nLevel ] );
-}
-
-void PowerPointExport::WriteTextStyle( FSHelperPtr pFS, int nInstance, sal_Int32 xmlToken )
-{
-    pFS->startElementNS( XML_p, xmlToken, FSEND );
-
-    for( int nLevel = 0; nLevel < 5; nLevel ++ )
-    WriteTextStyleLevel( pFS, nInstance, nLevel );
-
-    pFS->endElementNS( XML_p, xmlToken );
-}
-
-void PowerPointExport::WriteTextStyles( FSHelperPtr pFS )
-{
-    pFS->startElementNS( XML_p, XML_txBody, FSEND );
-
-    WriteTextStyle( pFS, EPP_TEXTTYPE_Title, XML_titleStyle );
-    WriteTextStyle( pFS, EPP_TEXTTYPE_Body, XML_bodyStyle );
-    WriteTextStyle( pFS, EPP_TEXTTYPE_Other, XML_otherStyle );
-
-    pFS->endElementNS( XML_p, XML_txBody );
-}
-
 void PowerPointExport::ImplWriteSlideMaster( sal_uInt32 nPageNum, Reference< XPropertySet > aXBackgroundPropSet )
 {
     DBG(printf("write slide master: %" SAL_PRIuUINT32 "\n----------------\n", nPageNum));
@@ -2159,7 +2123,7 @@ sal_Bool PowerPointExport::WriteNotesMaster()
     pFS->startElementNS( XML_p, XML_cSld, FSEND );
 
     Reference< XPropertySet > aXBackgroundPropSet;
-    if( ImplGetPropertyValue( mXPagePropSet, String( RTL_CONSTASCII_USTRINGPARAM( "Background" ) ) ) &&
+    if( ImplGetPropertyValue( mXPagePropSet, rtl::OUString( "Background" ) ) &&
     ( mAny >>= aXBackgroundPropSet ) )
     ImplWriteBackground( pFS, aXBackgroundPropSet );
 
@@ -2198,16 +2162,14 @@ sal_Bool PowerPointExport::ImplCreateMainNotes()
     return sal_True;
 }
 
-#define IMPL_NAME "com.sun.star.comp.Impress.oox.PowerPointExport"
-
 OUString SAL_CALL PowerPointExport_getImplementationName() throw()
 {
-    return CREATE_OUSTRING( IMPL_NAME );
+    return OUString( "com.sun.star.comp.Impress.oox.PowerPointExport" );
 }
 
 uno::Sequence< OUString > SAL_CALL PowerPointExport_getSupportedServiceNames() throw()
 {
-    const OUString aServiceName = CREATE_OUSTRING( "com.sun.star.comp.ooxpptx" );
+    const OUString aServiceName( "com.sun.star.comp.ooxpptx" );
     const Sequence< OUString > aSeq( &aServiceName, 1 );
     return aSeq;
 }
