@@ -729,7 +729,7 @@ void SAL_CALL AccessibleSlideSorterView::deselectAccessibleChild (sal_Int32 nChi
        AccessibleSlideSorterView::getImplementationName (void)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    return OUString(RTL_CONSTASCII_USTRINGPARAM("AccessibleSlideSorterView"));
+    return OUString("AccessibleSlideSorterView");
 }
 
 
@@ -761,12 +761,9 @@ uno::Sequence< ::rtl::OUString> SAL_CALL
     ThrowIfDisposed ();
 
     static const OUString sServiceNames[3] = {
-        OUString(RTL_CONSTASCII_USTRINGPARAM(
-            "com.sun.star.accessibility.Accessible")),
-        OUString(RTL_CONSTASCII_USTRINGPARAM(
-            "com.sun.star.accessibility.AccessibleContext")),
-        OUString(RTL_CONSTASCII_USTRINGPARAM(
-            "com.sun.star.drawing.AccessibleSlideSorterView"))
+            OUString("com.sun.star.accessibility.Accessible"),
+            OUString("com.sun.star.accessibility.AccessibleContext"),
+            OUString("com.sun.star.drawing.AccessibleSlideSorterView")
     };
     return uno::Sequence<OUString> (sServiceNames, 3);
 }
@@ -780,8 +777,7 @@ void AccessibleSlideSorterView::ThrowIfDisposed (void)
     if (rBHelper.bDisposed || rBHelper.bInDispose)
     {
         OSL_TRACE ("Calling disposed object. Throwing exception:");
-        throw lang::DisposedException (
-            OUString(RTL_CONSTASCII_USTRINGPARAM("object has been already disposed")),
+        throw lang::DisposedException ("object has been already disposed",
             static_cast<uno::XWeak*>(this));
     }
 }
@@ -1069,7 +1065,7 @@ IMPL_LINK(AccessibleSlideSorterView::Implementation, WindowEventListener, VclWin
 
 
 
-IMPL_LINK(AccessibleSlideSorterView::Implementation, SelectionChangeListener, void*, EMPTYARG )
+IMPL_LINK_NOARG(AccessibleSlideSorterView::Implementation, SelectionChangeListener)
 {
     if (mnSelectionChangeUserEventId == 0)
         mnSelectionChangeUserEventId = Application::PostUserEvent(
@@ -1080,7 +1076,7 @@ IMPL_LINK(AccessibleSlideSorterView::Implementation, SelectionChangeListener, vo
 
 
 
-IMPL_LINK(AccessibleSlideSorterView::Implementation, BroadcastSelectionChange, void*, EMPTYARG )
+IMPL_LINK_NOARG(AccessibleSlideSorterView::Implementation, BroadcastSelectionChange)
 {
     mnSelectionChangeUserEventId = 0;
     mrAccessibleSlideSorter.FireAccessibleEvent(
@@ -1093,7 +1089,7 @@ IMPL_LINK(AccessibleSlideSorterView::Implementation, BroadcastSelectionChange, v
 
 
 
-IMPL_LINK(AccessibleSlideSorterView::Implementation, FocusChangeListener, void*, EMPTYARG )
+IMPL_LINK_NOARG(AccessibleSlideSorterView::Implementation, FocusChangeListener)
 {
     sal_Int32 nNewFocusedIndex (
         mrSlideSorter.GetController().GetFocusManager().GetFocusedPageIndex());
@@ -1126,7 +1122,7 @@ IMPL_LINK(AccessibleSlideSorterView::Implementation, FocusChangeListener, void*,
 
 
 
-IMPL_LINK(AccessibleSlideSorterView::Implementation, UpdateChildrenCallback, void*, EMPTYARG )
+IMPL_LINK_NOARG(AccessibleSlideSorterView::Implementation, UpdateChildrenCallback)
 {
     mnUpdateChildrenUserEventId = 0;
     UpdateChildren();
@@ -1137,7 +1133,7 @@ IMPL_LINK(AccessibleSlideSorterView::Implementation, UpdateChildrenCallback, voi
 
 
 
-IMPL_LINK(AccessibleSlideSorterView::Implementation, VisibilityChangeListener, void*, EMPTYARG )
+IMPL_LINK_NOARG(AccessibleSlideSorterView::Implementation, VisibilityChangeListener)
 {
     UpdateChildren();
     return 1;
