@@ -114,7 +114,7 @@ void OptimizerDialog::InitRoadmap()
         Sequence< rtl::OUString >   aNames( pNames, nCount );
         Sequence< Any >             aValues( pValues, nCount );
 
-        mxRoadmapControlModel = insertControlModel( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.UnoControlRoadmapModel" ) ),
+        mxRoadmapControlModel = insertControlModel( OUString( "com.sun.star.awt.UnoControlRoadmapModel"  ),
                                                               TKGet( TK_rdmNavi ), aNames, aValues  );
 
         Reference< XPropertySet > xPropertySet( mxRoadmapControlModel, UNO_QUERY_THROW );
@@ -127,7 +127,7 @@ void OptimizerDialog::InitRoadmap()
         InsertRoadmapItem( 4, sal_True, getString( STR_SUMMARY ), ITEM_ID_SUMMARY );
 
         rtl::OUString sBitmapPath( getPath( TK_BitmapPath ) );
-        rtl::OUString sBitmap( RTL_CONSTASCII_USTRINGPARAM("/minimizepresi_80.png") );
+        rtl::OUString sBitmap( "/minimizepresi_80.png" );
         rtl::OUString sURL( sBitmapPath += sBitmap );
 
         xPropertySet->setPropertyValue( TKGet( TK_ImageURL ), Any( sURL ) );
@@ -539,7 +539,7 @@ void ActionListener::actionPerformed( const ActionEvent& rEvent )
                 if ( xStorable.is() && xStorable->hasLocation() )
                 {
                     rtl::OUString aLocation( xStorable->getLocation() );
-                    if ( aLocation.getLength() )
+                    if ( !aLocation.isEmpty() )
                     {
                         sal_Int32 nIndex = aLocation.lastIndexOf( '/', aLocation.getLength() - 1 );
                         if ( nIndex >= 0 )
@@ -553,7 +553,7 @@ void ActionListener::actionPerformed( const ActionEvent& rEvent )
                                 aLocation = aLocation.copy( 0, nIndex );
 
                             // adding .mini
-                            aLocation = aLocation.concat( OUString(RTL_CONSTASCII_USTRINGPARAM(".mini")) );
+                            aLocation = aLocation.concat( OUString(".mini") );
                             aFileOpenDialog.setDefaultName( aLocation );
                         }
                     }
@@ -565,7 +565,7 @@ void ActionListener::actionPerformed( const ActionEvent& rEvent )
                     mrOptimizerDialog.SetConfigProperty( TK_SaveAsURL, Any( aSaveAsURL ) );
                     mrOptimizerDialog.SetConfigProperty( TK_FilterName, Any( aFileOpenDialog.getFilterName() ) );
                 }
-                if ( !aSaveAsURL.getLength() )
+                if ( aSaveAsURL.isEmpty() )
                 {
                     // something goes wrong...
                     bSuccessfullyExecuted = sal_False;
@@ -585,7 +585,7 @@ void ActionListener::actionPerformed( const ActionEvent& rEvent )
                 OUString aSettingsName;
                 mrOptimizerDialog.getControlProperty( TKGet( TK_CheckBox1Pg4 ), TKGet( TK_State ) ) >>= nInt16;
                 mrOptimizerDialog.getControlProperty( TKGet( TK_ComboBox0Pg4 ), TKGet( TK_Text ) ) >>= aSettingsName;
-                if ( nInt16 && aSettingsName.getLength() )
+                if ( nInt16 && !aSettingsName.isEmpty() )
                 {
                     std::vector< OptimizerSettings >::iterator aIter( mrOptimizerDialog.GetOptimizerSettingsByName( aSettingsName ) );
                     std::vector< OptimizerSettings >& rSettings( mrOptimizerDialog.GetOptimizerSettings() );
@@ -603,11 +603,11 @@ void ActionListener::actionPerformed( const ActionEvent& rEvent )
                 aArgs[ 0 ] <<= mrOptimizerDialog.GetFrame();
 
                 Reference < XDispatch > xDispatch( mrOptimizerDialog.GetComponentContext()->getServiceManager()->createInstanceWithArgumentsAndContext(
-                    OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.PPPOptimizer")), aArgs, mrOptimizerDialog.GetComponentContext() ), UNO_QUERY );
+                    OUString("com.sun.star.comp.PPPOptimizer"), aArgs, mrOptimizerDialog.GetComponentContext() ), UNO_QUERY );
 
                 URL aURL;
-                aURL.Protocol = OUString( RTL_CONSTASCII_USTRINGPARAM( "vnd.com.sun.star.comp.PPPOptimizer:" ) );
-                aURL.Path = OUString( RTL_CONSTASCII_USTRINGPARAM( "optimize" ) );
+                aURL.Protocol = OUString( "vnd.com.sun.star.comp.PPPOptimizer:"  );
+                aURL.Path = OUString( "optimize"  );
 
                 Sequence< PropertyValue > lArguments( 3 );
                 lArguments[ 0 ].Name = TKGet( TK_Settings );
@@ -636,7 +636,7 @@ void ActionListener::actionPerformed( const ActionEvent& rEvent )
         case TK_Button0Pg0 :    // delete configuration
         {
             OUString aSelectedItem( mrOptimizerDialog.GetSelectedString( TK_ListBox0Pg0 ) );
-            if ( aSelectedItem.getLength() )
+            if ( !aSelectedItem.isEmpty() )
             {
                 std::vector< OptimizerSettings >::iterator aIter( mrOptimizerDialog.GetOptimizerSettingsByName( aSelectedItem ) );
                 std::vector< OptimizerSettings >& rList( mrOptimizerDialog.GetOptimizerSettings() );
@@ -661,7 +661,7 @@ void ActionListener::disposing( const ::com::sun::star::lang::EventObject& /* So
 void ActionListenerListBox0Pg0::actionPerformed( const ActionEvent& rEvent )
     throw ( com::sun::star::uno::RuntimeException )
 {
-    if ( rEvent.ActionCommand.getLength() )
+    if ( !rEvent.ActionCommand.isEmpty() )
     {
         std::vector< OptimizerSettings >::iterator aIter( mrOptimizerDialog.GetOptimizerSettingsByName( rEvent.ActionCommand ) );
         std::vector< OptimizerSettings >& rList( mrOptimizerDialog.GetOptimizerSettings() );
