@@ -99,7 +99,6 @@
 #define CMD_SID_FOCUSURLBOX                         ".uno:FocusUrlBox"
 #define CMD_SID_FORMATMENU                          ".uno:FormatMenu"
 #define CMD_SID_STYLE_FAMILY3                       ".uno:FrameStyle"
-#define CMD_SID_FRAMETITLE                          ".uno:FrameTitle"
 #define CMD_SID_PROGFILENAME                        ".uno:FullName"
 #define CMD_SID_DOCFULLNAME                         ".uno:FullName"
 #define CMD_SID_WIN_FULLSCREEN                      ".uno:FullScreen"
@@ -201,6 +200,10 @@
 #define CMD_SID_PASTE                               ".uno:Paste"
 #define CMD_SID_CLIPBOARD_FORMAT_ITEMS              ".uno:ClipboardFormatItems"
 #define CMD_SID_PASTE_SPECIAL                       ".uno:PasteSpecial"
+#define CMD_SID_PASTE_ONLY                          ".uno:PasteOnly"
+#define CMD_SID_PASTE_ONLY_VALUE                    ".uno:PasteOnlyValue"
+#define CMD_SID_PASTE_ONLY_TEXT                     ".uno:PasteOnlyText"
+#define CMD_SID_PASTE_ONLY_FORMULA                  ".uno:PasteOnlyFormula"
 #define CMD_SID_DOCPATH                             ".uno:DocPath"
 #define CMD_SID_PICKLIST                            ".uno:PickList"
 #define CMD_SID_PLUGINS_ACTIVE                      ".uno:PlugInsActive"
