@@ -71,7 +71,6 @@
 #include <sfx2/objsh.hxx>
 #include <sfx2/msgpool.hxx>
 
-#include <comphelper/uieventslogger.hxx>
 #include <com/sun/star/frame/XModuleManager.hpp>
 
 #include <boost/scoped_ptr.hpp>
@@ -98,9 +97,6 @@ static sal_uInt16 nTimeOut = 300;
 #define TIMEOUT_UPDATING     20
 #define TIMEOUT_IDLE       2500
 
-static sal_uInt32 nCache1 = 0;
-static sal_uInt32 nCache2 = 0;
-
 typedef boost::unordered_map< sal_uInt16, bool > InvalidateSlotMap;
 
 //====================================================================
@@ -209,7 +205,7 @@ struct SfxFoundCache_Impl
 
 //--------------------------------------------------------------------------
 
-SV_DECL_PTRARR_SORT_DEL(SfxFoundCacheArr_Impl, SfxFoundCache_Impl*, 16, 16 )
+SV_DECL_PTRARR_SORT_DEL(SfxFoundCacheArr_Impl, SfxFoundCache_Impl*, 16)
 SV_IMPL_OP_PTRARR_SORT(SfxFoundCacheArr_Impl, SfxFoundCache_Impl*);
 
 //==========================================================================
@@ -472,7 +468,6 @@ void SfxBindings::Update
     sal_uInt16      nId     // the bound and up-to-date Slot-Id
 )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     if ( pDispatcher )
@@ -535,7 +530,6 @@ void SfxBindings::Update
 
 void SfxBindings::Update()
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     if ( pImp->pSubBindings )
@@ -653,7 +647,6 @@ SfxStateCache* SfxBindings::GetStateCache
                            or where it was inserted. */
 )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
     // is the specified function bound?
     const sal_uInt16 nStart = ( pPos ? *pPos : 0 );
@@ -680,8 +673,6 @@ void SfxBindings::InvalidateAll
     DBG_PROFSTART(SfxBindingsInvalidateAll);
     DBG_ASSERT( !pImp->bInUpdate, "SfxBindings::Invalidate while in update" );
 
-    DBG_MEMTEST();
-
     if ( pImp->pSubBindings )
         pImp->pSubBindings->InvalidateAll( bWithMsg );
 
@@ -721,7 +712,6 @@ void SfxBindings::Invalidate
 )
 {
     DBG_PROFSTART(SfxBindingsInvalidateAll);
-    DBG_MEMTEST();
 
     if ( pImp->bInUpdate )
     {
@@ -793,7 +783,6 @@ void SfxBindings::InvalidateShell
         return;
 
     DBG_PROFSTART(SfxBindingsInvalidateAll);
-    DBG_MEMTEST();
 
     // flush now already, it is done in GetShellLevel (rsh) anyway,
     // important so that is set correctly: pimp-> ball(Msg)Dirty
@@ -840,8 +829,6 @@ void SfxBindings::Invalidate
     sal_uInt16 nId              // Status value to be set
 )
 {
-    DBG_MEMTEST();
-
     if ( pImp->bInUpdate )
     {
         AddSlotToInvalidateSlotsMap_Impl( nId );
@@ -879,7 +866,6 @@ void SfxBindings::Invalidate
     sal_Bool    bWithMsg            // Get new SlotServer?
 )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( !pImp->bInUpdate, "SfxBindings::Invalidate while in update" );
 
     if ( pImp->pSubBindings )
@@ -912,7 +898,6 @@ void SfxBindings::Invalidate
 
 sal_Bool SfxBindings::IsBound( sal_uInt16 nSlotId, sal_uInt16 nStartSearchAt )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
     return GetStateCache(nSlotId, &nStartSearchAt ) != 0;
 }
@@ -921,7 +906,6 @@ sal_Bool SfxBindings::IsBound( sal_uInt16 nSlotId, sal_uInt16 nStartSearchAt )
 
 sal_uInt16 SfxBindings::GetSlotPos( sal_uInt16 nId, sal_uInt16 nStartSearchAt )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
     DBG_PROFSTART(SfxBindingsMsgPos);
 
@@ -929,15 +913,12 @@ sal_uInt16 SfxBindings::GetSlotPos( sal_uInt16 nId, sal_uInt16 nStartSearchAt )
     if ( pImp->nCachedFunc1 < pImp->pCaches->Count() &&
          (*pImp->pCaches)[pImp->nCachedFunc1]->GetId() == nId )
     {
-        ++nCache1;
         DBG_PROFSTOP(SfxBindingsMsgPos);
         return pImp->nCachedFunc1;
     }
     if ( pImp->nCachedFunc2 < pImp->pCaches->Count() &&
          (*pImp->pCaches)[pImp->nCachedFunc2]->GetId() == nId )
     {
-        ++nCache2;
-
         // swap the caches
         sal_uInt16 nTemp = pImp->nCachedFunc1;
         pImp->nCachedFunc1 = pImp->nCachedFunc2;
@@ -1007,7 +988,6 @@ void SfxBindings::Register( SfxControllerItem& rItem )
 
 void SfxBindings::Register_Impl( SfxControllerItem& rItem, sal_Bool bInternal )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( nRegLevel > 0, "registration without EnterRegistrations" );
     DBG_ASSERT( !pImp->bInNextJob, "SfxBindings::Register while status-updating" );
 
@@ -1044,7 +1024,6 @@ void SfxBindings::Register_Impl( SfxControllerItem& rItem, sal_Bool bInternal )
 
 void SfxBindings::Release( SfxControllerItem& rItem )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
     DBG_ASSERT( !pImp->bInNextJob, "SfxBindings::Release while status-updating" );
     ENTERREGISTRATIONS();
@@ -1091,7 +1070,6 @@ void SfxBindings::Release( SfxControllerItem& rItem )
 const SfxPoolItem* SfxBindings::ExecuteSynchron( sal_uInt16 nId, const SfxPoolItem** ppItems, sal_uInt16 nModi,
             const SfxPoolItem **ppInternalArgs )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     if( !nId || !pDispatcher )
@@ -1103,7 +1081,6 @@ const SfxPoolItem* SfxBindings::ExecuteSynchron( sal_uInt16 nId, const SfxPoolIt
 sal_Bool SfxBindings::Execute( sal_uInt16 nId, const SfxPoolItem** ppItems, sal_uInt16 nModi, SfxCallMode nCallMode,
                         const SfxPoolItem **ppInternalArgs )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     if( !nId || !pDispatcher )
@@ -1315,7 +1292,6 @@ void SfxBindings::Execute_Impl( SfxRequest& aReq, const SfxSlot* pSlot, SfxShell
 void SfxBindings::UpdateSlotServer_Impl()
 {
     DBG_PROFSTART(SfxBindingsUpdateServers);
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     // synchronize
@@ -1356,7 +1332,6 @@ SfxItemSet* SfxBindings::CreateSet_Impl
     SfxFoundCacheArr_Impl&  rFound      // out: List of Caches for Siblings
 )
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     DBG_ASSERT( !pImp->bMsgDirty, "CreateSet_Impl with dirty MessageServer" );
@@ -1612,7 +1587,6 @@ IMPL_LINK( SfxBindings, NextJob_Impl, Timer *, pTimer )
 #endif
     const unsigned MAX_INPUT_DELAY = 200;
 
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     DBG_PROFSTART(SfxBindingsNextJob_Impl0);
@@ -1740,7 +1714,6 @@ IMPL_LINK( SfxBindings, NextJob_Impl, Timer *, pTimer )
 
 sal_uInt16 SfxBindings::EnterRegistrations(const char *pFile, int nLine)
 {
-    DBG_MEMTEST();
     SAL_INFO(
         "sfx2",
         std::setw(Min(nRegLevel, sal_uInt16(8))) << ' ' << "this = " << this
@@ -1783,7 +1756,6 @@ sal_uInt16 SfxBindings::EnterRegistrations(const char *pFile, int nLine)
 void SfxBindings::LeaveRegistrations( sal_uInt16 nLevel, const char *pFile, int nLine )
 {
     (void)nLevel; // unused variable
-    DBG_MEMTEST();
     DBG_ASSERT( nRegLevel, "Leave without Enter" );
     DBG_ASSERT( nLevel == USHRT_MAX || nLevel == nRegLevel, "wrong Leave" );
 
@@ -1854,7 +1826,6 @@ void SfxBindings::LeaveRegistrations( sal_uInt16 nLevel, const char *pFile, int
 
 const SfxSlot* SfxBindings::GetSlot(sal_uInt16 nSlotId)
 {
-    DBG_MEMTEST();
     DBG_ASSERT( pImp->pCaches != 0, "SfxBindings not initialized" );
 
     // synchronizing
@@ -2218,30 +2189,11 @@ sal_Bool SfxBindings::ExecuteCommand_Impl( const String& rCommand )
 {
     ::com::sun::star::util::URL aURL;
     aURL.Complete = rCommand;
-    Reference < XURLTransformer > xTrans( ::comphelper::getProcessServiceFactory()->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.util.URLTransformer"))), UNO_QUERY );
+    Reference < XURLTransformer > xTrans( ::comphelper::getProcessServiceFactory()->createInstance( rtl::OUString("com.sun.star.util.URLTransformer")), UNO_QUERY );
     xTrans->parseStrict( aURL );
     ::com::sun::star::uno::Reference< ::com::sun::star::frame::XDispatch >  xDisp = pImp->xProv->queryDispatch( aURL, ::rtl::OUString(), 0 );
     if ( xDisp.is() )
     {
-        if(::comphelper::UiEventsLogger::isEnabled()) //#i88653#
-        {
-            ::rtl::OUString sAppName;
-            try
-            {
-                static ::rtl::OUString our_aModuleManagerName(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.ModuleManager"));
-                ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > xServiceManager =
-                    ::comphelper::getProcessServiceFactory();
-                ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModuleManager > xModuleManager(
-                    xServiceManager->createInstance(our_aModuleManagerName)
-                    , ::com::sun::star::uno::UNO_QUERY_THROW);
-                ::com::sun::star::uno::Reference < ::com::sun::star::frame::XFrame > xFrame(
-                    pDispatcher->GetFrame()->GetFrame().GetFrameInterface(), UNO_QUERY_THROW);
-                sAppName = xModuleManager->identify(xFrame);
-            } catch(::com::sun::star::uno::Exception&) {}
-            Sequence<beans::PropertyValue> source;
-            ::comphelper::UiEventsLogger::appendDispatchOrigin(source, sAppName, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("SfxAsyncExec")));
-            ::comphelper::UiEventsLogger::logDispatch(aURL, source);
-        }
         new SfxAsyncExec_Impl( aURL, xDisp );
         return sal_True;
     }
