@@ -119,7 +119,7 @@ static OUString xdg_user_dir_lookup (const char *type)
 
     if (!aSecurity.getHomeDir( aHomeDirURL ) )
     {
-        osl::FileBase::getFileURLFromSystemPath(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/tmp")), aDocumentsDirURL);
+        osl::FileBase::getFileURLFromSystemPath(rtl::OUString("/tmp"), aDocumentsDirURL);
         return aDocumentsDirURL;
     }
 
@@ -127,12 +127,12 @@ static OUString xdg_user_dir_lookup (const char *type)
     if (config_home == NULL || config_home[0] == 0)
     {
         aConfigFileURL = OUString(aHomeDirURL);
-        aConfigFileURL += OUString(RTL_CONSTASCII_USTRINGPARAM("/.config/user-dirs.dirs"));
+        aConfigFileURL += OUString("/.config/user-dirs.dirs");
     }
     else
     {
         aConfigFileURL = OUString::createFromAscii(config_home);
-        aConfigFileURL += OUString(RTL_CONSTASCII_USTRINGPARAM("/user-dirs.dirs"));
+        aConfigFileURL += OUString("/user-dirs.dirs");
     }
 
     if(osl_File_E_None == osl_openFile(aConfigFileURL.pData, &handle, osl_File_OpenFlag_Read))
@@ -272,9 +272,9 @@ uno::Any translateToOOo( const ConfigurationValue &rValue, GConfValue *pGconfVal
             uno::Any aOriginalValue = makeAnyOfGconfValue( pGconfValue );
             aOriginalValue >>= aProxyMode;
 
-            if( aProxyMode.equals( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("manual")) ) )
+            if( aProxyMode == "manual" )
                 return uno::makeAny( (sal_Int32) 1 );
-            else if( aProxyMode.equals( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("none")) ) )
+            else if( aProxyMode == "none" )
                 return uno::makeAny( (sal_Int32) 0 );
         }
             break;
@@ -401,7 +401,7 @@ sal_Bool SAL_CALL isDependencySatisfied( GConfClient* pClient, const Configurati
 
             if ( pGconfValue != NULL )
             {
-                bool bOk = g_strcasecmp( "manual", gconf_value_get_string( pGconfValue ) ) == 0;
+                bool bOk = g_ascii_strcasecmp( "manual", gconf_value_get_string( pGconfValue ) ) == 0;
                 gconf_value_free( pGconfValue );
                 if (bOk) return sal_True;
             }
@@ -422,7 +422,7 @@ sal_Bool SAL_CALL isDependencySatisfied( GConfClient* pClient, const Configurati
         {
             rtl::OUString aCompleteName( rtl::OStringToOUString(
                 g_get_real_name(), osl_getThreadTextEncoding() ) );
-            if( !aCompleteName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Unknown")) )
+            if( aCompleteName != "Unknown" )
                 return sal_True;
         }
             break;
@@ -431,9 +431,9 @@ sal_Bool SAL_CALL isDependencySatisfied( GConfClient* pClient, const Configurati
         {
             rtl::OUString aCompleteName( rtl::OStringToOUString(
                 g_get_real_name(), osl_getThreadTextEncoding() ) );
-            if( !aCompleteName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Unknown")) )
+            if( aCompleteName != "Unknown" )
             {
-                if( aCompleteName.trim().indexOf(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(" ")), 0) != -1 )
+                if( aCompleteName.trim().indexOf(rtl::OUString(" "), 0) != -1 )
                     return sal_True;
             }
         }
@@ -812,7 +812,8 @@ ConfigurationValue const ConfigurationValues[] =
 #endif // ENABLE_LOCKDOWN
 };
 
-std::size_t const nConfigurationValues = SAL_N_ELEMENTS(ConfigurationValues);
+std::size_t const nConfigurationValues =
+    sizeof ConfigurationValues / sizeof ConfigurationValues[0];
 
 css::beans::Optional< css::uno::Any > getValue(ConfigurationValue const & data)
 {
