@@ -82,14 +82,14 @@ OLESimpleStorage::~OLESimpleStorage()
 uno::Sequence< ::rtl::OUString > SAL_CALL OLESimpleStorage::impl_staticGetSupportedServiceNames()
 {
     uno::Sequence< ::rtl::OUString > aRet(1);
-    aRet[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.embed.OLESimpleStorage"));
+    aRet[0] = ::rtl::OUString("com.sun.star.embed.OLESimpleStorage");
     return aRet;
 }
 
 //-------------------------------------------------------------------------
 ::rtl::OUString SAL_CALL OLESimpleStorage::impl_staticGetImplementationName()
 {
-    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.embed.OLESimpleStorage"));
+    return ::rtl::OUString("com.sun.star.comp.embed.OLESimpleStorage");
 }
 
 //-------------------------------------------------------------------------
@@ -129,7 +129,7 @@ void OLESimpleStorage::UpdateOriginal_Impl()
 void OLESimpleStorage::InsertInputStreamToStorage_Impl( BaseStorage* pStorage, ::rtl::OUString aName, const uno::Reference< io::XInputStream >& xInputStream )
     throw ( uno::Exception )
 {
-    if ( !pStorage || !aName.getLength() || !xInputStream.is() )
+    if ( !pStorage || aName.isEmpty() || !xInputStream.is() )
         throw uno::RuntimeException();
 
     if ( pStorage->IsContained( aName ) )
@@ -174,7 +174,7 @@ void OLESimpleStorage::InsertInputStreamToStorage_Impl( BaseStorage* pStorage, :
 void OLESimpleStorage::InsertNameAccessToStorage_Impl( BaseStorage* pStorage, ::rtl::OUString aName, const uno::Reference< container::XNameAccess >& xNameAccess )
     throw ( uno::Exception )
 {
-    if ( !pStorage || !aName.getLength() || !xNameAccess.is() )
+    if ( !pStorage || aName.isEmpty() || !xNameAccess.is() )
         throw uno::RuntimeException();
 
     if ( pStorage->IsContained( aName ) )
@@ -265,7 +265,7 @@ void SAL_CALL OLESimpleStorage::initialize( const uno::Sequence< uno::Any >& aAr
     else
     {
         uno::Reference < io::XStream > xTempFile(
-                m_xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.io.TempFile")) ),
+                m_xFactory->createInstance( ::rtl::OUString("com.sun.star.io.TempFile") ),
                 uno::UNO_QUERY_THROW );
         uno::Reference < io::XSeekable > xTempSeek( xTempFile, uno::UNO_QUERY_THROW );
         uno::Reference< io::XOutputStream > xTempOut = xTempFile->getOutputStream();
@@ -365,9 +365,9 @@ void SAL_CALL OLESimpleStorage::insertByName( const ::rtl::OUString& aName, cons
     {
         throw;
     }
-    catch( uno::Exception& e )
+    catch( const uno::Exception& e )
     {
-        throw lang::WrappedTargetException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Insert has failed!" ) ),
+        throw lang::WrappedTargetException( ::rtl::OUString(  "Insert has failed!"  ),
                                             uno::Reference< uno::XInterface >(),
                                             uno::makeAny( e ) );
     }
@@ -424,7 +424,7 @@ void SAL_CALL OLESimpleStorage::replaceByName( const ::rtl::OUString& aName, con
     {
            uno::Any aCaught( ::cppu::getCaughtException() );
 
-        throw lang::WrappedTargetException( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Can't copy raw stream")),
+        throw lang::WrappedTargetException( ::rtl::OUString("Can't copy raw stream"),
                                             uno::Reference< uno::XInterface >(),
                                             aCaught );
     }
@@ -450,7 +450,7 @@ uno::Any SAL_CALL OLESimpleStorage::getByName( const ::rtl::OUString& aName )
     uno::Any aResult;
 
     uno::Reference< io::XStream > xTempFile(
-        m_xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.io.TempFile")) ),
+        m_xFactory->createInstance( ::rtl::OUString("com.sun.star.io.TempFile") ),
         uno::UNO_QUERY );
     uno::Reference< io::XSeekable > xSeekable( xTempFile, uno::UNO_QUERY_THROW );
     uno::Reference< io::XOutputStream > xOutputStream = xTempFile->getOutputStream();
@@ -486,7 +486,7 @@ uno::Any SAL_CALL OLESimpleStorage::getByName( const ::rtl::OUString& aName )
 
         uno::Reference< container::XNameContainer > xResultNameContainer(
             m_xFactory->createInstanceWithArguments(
-                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.embed.OLESimpleStorage")),
+                    ::rtl::OUString("com.sun.star.embed.OLESimpleStorage"),
                     aArgs ),
             uno::UNO_QUERY_THROW );
 
