@@ -36,8 +36,6 @@
 #include <vcl/sound.hxx>
 #include <vcl/salnativewidgets.hxx>
 
-#define TABOFFS_NOT_VALID -2000000
-
 struct SvLBoxButtonData_Impl
 {
     SvLBoxEntry*    pEntry;
@@ -77,13 +75,6 @@ SvLBoxButtonData::SvLBoxButtonData( const Control* pControlForSettings, bool _bR
     InitData( sal_True, _bRadioBtn, pControlForSettings );
 }
 
-SvLBoxButtonData::SvLBoxButtonData()
-{
-    DBG_CTOR(SvLBoxButtonData,0);
-
-    InitData( sal_False, false );
-}
-
 SvLBoxButtonData::~SvLBoxButtonData()
 {
     DBG_DTOR(SvLBoxButtonData,0);
@@ -280,13 +271,6 @@ void SvLBoxString::InitViewData( SvLBox* pView,SvLBoxEntry* pEntry,
 
 DBG_NAME(SvLBoxBmp);
 
-SvLBoxBmp::SvLBoxBmp( SvLBoxEntry* pEntry, sal_uInt16 nFlags, Image aBitmap ) :
-    SvLBoxItem( pEntry, nFlags )
-{
-    DBG_CTOR(SvLBoxBmp,0);
-    SetBitmap( pEntry, aBitmap);
-}
-
 SvLBoxBmp::SvLBoxBmp() : SvLBoxItem()
 {
     DBG_CTOR(SvLBoxBmp,0);
@@ -303,12 +287,6 @@ sal_uInt16 SvLBoxBmp::IsA()
     return SV_ITEM_ID_LBOXBMP;
 }
 
-void SvLBoxBmp::SetBitmap( SvLBoxEntry*, Image aBitmap)
-{
-    DBG_CHKTHIS(SvLBoxBmp,0);
-    aBmp = aBitmap;
-}
-
 void SvLBoxBmp::InitViewData( SvLBox* pView,SvLBoxEntry* pEntry,
     SvViewDataItem* pViewData)
 {
@@ -478,9 +456,11 @@ void SvLBoxButton::ImplAdjustBoxSize( Size& io_rSize, ControlType i_eType, Windo
         if( bNativeOK )
         {
             Size aContentSize( aNativeContent.GetSize() );
-            // leave a little space around the box image (looks better
+            // leave a little space around the box image (looks better)
             if( aContentSize.Height() + 2 > io_rSize.Height() )
                 io_rSize.Height() = aContentSize.Height() + 2;
+            if( aContentSize.Width() + 2 > io_rSize.Width() )
+                io_rSize.Width() = aContentSize.Width() + 2;
         }
     }
 }
