@@ -28,7 +28,7 @@
 
 #include "templwin.hxx"
 #include <svtools/templdlg.hxx>
-#include <svtools/svtdata.hxx>
+#include <svtools/svtresid.hxx>
 #include <svtools/langhelp.hxx>
 #include <unotools/pathoptions.hxx>
 #include <unotools/dynamicmenuoptions.hxx>
@@ -43,7 +43,6 @@
 #include <svtools/svtools.hrc>
 #include "templwin.hrc"
 #include <svtools/helpid.hrc>
-#include <unotools/pathoptions.hxx>
 #include <unotools/viewoptions.hxx>
 #include <unotools/ucbhelper.hxx>
 #include "unotools/configmgr.hxx"
@@ -55,13 +54,13 @@
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/util/XOfficeInstallationDirectories.hpp>
 #include <com/sun/star/frame/XDispatchProvider.hpp>
+#include <com/sun/star/frame/DocumentTemplates.hpp>
 #include <com/sun/star/frame/XDocumentTemplates.hpp>
 #include <com/sun/star/frame/XComponentLoader.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/ucb/XContent.hpp>
 #include <com/sun/star/ucb/XCommandEnvironment.hpp>
 #include <com/sun/star/view/XPrintable.hpp>
-#include <com/sun/star/awt/XWindow.hpp>
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/XMultiPropertySet.hpp>
@@ -97,7 +96,6 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::view;
 using namespace svtools;
 
-extern ::rtl::OUString CreateExactSizeText_Impl( sal_Int64 nSize ); // fileview.cxx
 #define aSeparatorStr   "----------------------------------"
 
 #define SPLITSET_ID         0
@@ -129,163 +127,6 @@ struct FolderHistory
 
 typedef ::std::vector< ::rtl::OUString* > NewDocList_Impl;
 
-ODocumentInfoPreview::ODocumentInfoPreview( Window* pParent ,WinBits _nBits) : Window(pParent,WB_DIALOGCONTROL)
-{
-    m_pEditWin = new SvtExtendedMultiLineEdit_Impl(this,_nBits);
-    m_pEditWin->Show();
-    m_pEditWin->EnableCursor( sal_False );
-    m_pInfoTable = new SvtDocInfoTable_Impl();
-    // detect application language
-    m_aLocale = SvtPathOptions().GetLocale();
-}
-// -----------------------------------------------------------------------------
-ODocumentInfoPreview::~ODocumentInfoPreview()
-{
-    delete m_pEditWin;
-    delete m_pInfoTable;
-}
-// -----------------------------------------------------------------------------
-void ODocumentInfoPreview::Resize()
-{
-    Size aOutputSize( GetOutputSize() );
-    m_pEditWin->SetPosSizePixel( Point(0,0),aOutputSize);
-}
-// -----------------------------------------------------------------------------
-void ODocumentInfoPreview::Clear()
-{
-    m_pEditWin->Clear();
-}
-// -----------------------------------------------------------------------------
-
-void lcl_insertDateTimeEntry(SvtExtendedMultiLineEdit_Impl* i_pEditWin,
-    const ::rtl::OUString & i_rName, const util::DateTime & i_rUDT)
-{
-    DateTime aToolsDT =
-        DateTime( Date( i_rUDT.Day, i_rUDT.Month, i_rUDT.Year ),
-                Time( i_rUDT.Hours, i_rUDT.Minutes,
-                      i_rUDT.Seconds, i_rUDT.HundredthSeconds ) );
-    if ( aToolsDT.IsValidAndGregorian() )
-    {
-        LocaleDataWrapper aLocaleWrapper(
-            ::comphelper::getProcessServiceFactory(),
-            Application::GetSettings().GetLocale() );
-        String aDateStr = aLocaleWrapper.getDate( aToolsDT );
-        aDateStr += String( RTL_CONSTASCII_USTRINGPARAM(", ") );
-        aDateStr += aLocaleWrapper.getTime( aToolsDT );
-        i_pEditWin->InsertEntry( i_rName, aDateStr );
-    }
-}
-
-void ODocumentInfoPreview::fill(
-    const Reference< XDocumentProperties >& i_xDocProps, const String& i_rURL)
-{
-    if (!i_xDocProps.is()) throw RuntimeException();
-
-    ::rtl::OUString aStr;
-    m_pEditWin->SetAutoScroll( sal_False );
-
-    aStr = i_xDocProps->getTitle();
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_TITLE ), aStr );
-    }
-
-    aStr = i_xDocProps->getAuthor();
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_FROM ), aStr );
-    }
-
-    lcl_insertDateTimeEntry(m_pEditWin,
-            m_pInfoTable->GetString( DI_DATE ),
-            i_xDocProps->getCreationDate());
-
-    aStr = i_xDocProps->getModifiedBy();
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString(DI_MODIFIEDBY), aStr );
-    }
-
-    lcl_insertDateTimeEntry(m_pEditWin,
-            m_pInfoTable->GetString( DI_MODIFIEDDATE ),
-            i_xDocProps->getModificationDate());
-
-    aStr = i_xDocProps->getPrintedBy();
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_PRINTBY ), aStr );
-    }
-
-    lcl_insertDateTimeEntry(m_pEditWin,
-            m_pInfoTable->GetString( DI_PRINTDATE ),
-            i_xDocProps->getPrintDate());
-
-    aStr = i_xDocProps->getSubject();
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_THEME ), aStr );
-    }
-
-    aStr =
-        ::comphelper::string::convertCommaSeparated(i_xDocProps->getKeywords());
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_KEYWORDS ), aStr );
-    }
-
-    aStr = i_xDocProps->getDescription();
-    if (aStr.getLength()) {
-        m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_DESCRIPTION ),
-            aStr );
-    }
-
-    // size
-    if ( i_rURL.Len() > 0 )
-    {
-        m_pEditWin->InsertEntry(
-            m_pInfoTable->GetString( DI_SIZE ),
-            CreateExactSizeText_Impl( utl::UCBContentHelper::GetSize( i_rURL ) ) );
-    }
-
-    // MIMEType
-    if ( i_rURL.Len() > 0 )
-    {
-        INetContentType eTypeID =
-            INetContentTypes::GetContentTypeFromURL( i_rURL );
-        if ( eTypeID != CONTENT_TYPE_APP_OCTSTREAM ) {
-            aStr = INetContentTypes::GetPresentation( eTypeID, m_aLocale );
-        } else {
-            aStr = SvFileInformationManager::GetDescription(
-                        INetURLObject(i_rURL) );
-        }
-        if (aStr.getLength()) {
-            m_pEditWin->InsertEntry( m_pInfoTable->GetString( DI_MIMETYPE ),
-                aStr );
-        }
-    }
-
-    // user-defined (custom) properties
-    Reference< XPropertySet > xUserDefined(
-        i_xDocProps->getUserDefinedProperties(), UNO_QUERY_THROW );
-    Reference< XPropertySetInfo > xUDInfo = xUserDefined->getPropertySetInfo();
-    Sequence< Property > props = xUDInfo->getProperties();
-    for (sal_Int32 i = 0; i < props.getLength(); ++i) {
-        const ::rtl::OUString name = props[i].Name;
-        uno::Any aAny;
-        try {
-            aAny = xUserDefined->getPropertyValue(name);
-            uno::Reference < script::XTypeConverter > xConverter(
-                comphelper::getProcessServiceFactory()->createInstance(
-                    ASCII_STR("com.sun.star.script.Converter")),
-                UNO_QUERY );
-            uno::Any aNew;
-            aNew = xConverter->convertToSimpleType( aAny, TypeClass_STRING );
-            if ((aNew >>= aStr) && aStr.getLength()) {
-                m_pEditWin->InsertEntry( name, aStr);
-            }
-        } catch (uno::Exception &) {
-            // ignore
-        }
-    }
-
-    m_pEditWin->SetSelection( Selection( 0, 0 ) );
-    m_pEditWin->SetAutoScroll( sal_True );
-}
-
 // class SvtDummyHeaderBar_Impl ------------------------------------------
 
 void SvtDummyHeaderBar_Impl::UpdateBackgroundColor()
@@ -336,27 +177,23 @@ SvtIconWindow_Impl::SvtIconWindow_Impl( Window* pParent ) :
     aIconCtrl.Show();
 
     // detect the root URL of templates
-    Reference< XDocumentTemplates > xTemplates( ::comphelper::getProcessServiceFactory()->
-        createInstance( ASCII_STR("com.sun.star.frame.DocumentTemplates") ), UNO_QUERY );
+    Reference< XDocumentTemplates > xTemplates( frame::DocumentTemplates::create(::comphelper::getProcessComponentContext()) );
 
-    if ( xTemplates.is() )
-    {
-        Reference < XContent > aRootContent = xTemplates->getContent();
-        Reference < XCommandEnvironment > aCmdEnv;
+    Reference < XContent > aRootContent = xTemplates->getContent();
+    Reference < XCommandEnvironment > aCmdEnv;
 
-        if ( aRootContent.is() )
-            aTemplateRootURL = aRootContent->getIdentifier()->getContentIdentifier();
-    }
+    if ( aRootContent.is() )
+        aTemplateRootURL = aRootContent->getIdentifier()->getContentIdentifier();
 
     // insert the categories
     // "New Document"
     Image aImage( SvtResId( IMG_SVT_NEWDOC ) );
     nMaxTextLength = aImage.GetSizePixel().Width();
-    String aEntryStr = String( SvtResId( STR_SVT_NEWDOC ) );
+    String aEntryStr = SVT_RESSTR(STR_SVT_NEWDOC);
     SvxIconChoiceCtrlEntry* pEntry =
         aIconCtrl.InsertEntry( aEntryStr, aImage, ICON_POS_NEWDOC );
     pEntry->SetUserData( new String( aNewDocumentRootURL ) );
-    pEntry->SetQuickHelpText( String( SvtResId( STR_SVT_NEWDOC_HELP ) ) );
+    pEntry->SetQuickHelpText( SVT_RESSTR(STR_SVT_NEWDOC_HELP) );
     DBG_ASSERT( !pEntry->GetBoundRect().IsEmpty(), "empty rectangle" );
     long nTemp = pEntry->GetBoundRect().GetSize().Width();
     if (nTemp > nMaxTextLength)
@@ -365,11 +202,11 @@ SvtIconWindow_Impl::SvtIconWindow_Impl( Window* pParent ) :
     // "Templates"
     if( aTemplateRootURL.Len() > 0 )
     {
-        aEntryStr = String( SvtResId( STR_SVT_TEMPLATES ) );
+        aEntryStr = SVT_RESSTR(STR_SVT_TEMPLATES);
         pEntry = aIconCtrl.InsertEntry(
             aEntryStr, Image( SvtResId( IMG_SVT_TEMPLATES ) ), ICON_POS_TEMPLATES );
         pEntry->SetUserData( new String( aTemplateRootURL ) );
-        pEntry->SetQuickHelpText( String( SvtResId( STR_SVT_TEMPLATES_HELP ) ) );
+        pEntry->SetQuickHelpText(SVT_RESSTR(STR_SVT_TEMPLATES_HELP));
         DBG_ASSERT( !pEntry->GetBoundRect().IsEmpty(), "empty rectangle" );
         nTemp = pEntry->GetBoundRect().GetSize().Width();
         if (nTemp > nMaxTextLength)
@@ -377,22 +214,22 @@ SvtIconWindow_Impl::SvtIconWindow_Impl( Window* pParent ) :
     }
 
     // "My Documents"
-    aEntryStr = String( SvtResId( STR_SVT_MYDOCS ) );
+    aEntryStr = SVT_RESSTR(STR_SVT_MYDOCS);
     pEntry = aIconCtrl.InsertEntry(
         aEntryStr, Image( SvtResId( IMG_SVT_MYDOCS ) ), ICON_POS_MYDOCS );
     pEntry->SetUserData( new String( aMyDocumentsRootURL ) );
-    pEntry->SetQuickHelpText( String( SvtResId( STR_SVT_MYDOCS_HELP ) ) );
+    pEntry->SetQuickHelpText( SVT_RESSTR(STR_SVT_MYDOCS_HELP) );
     DBG_ASSERT( !pEntry->GetBoundRect().IsEmpty(), "empty rectangle" );
     nTemp = pEntry->GetBoundRect().GetSize().Width();
     if( nTemp > nMaxTextLength )
         nMaxTextLength = nTemp;
 
     // "Samples"
-    aEntryStr = String( SvtResId( STR_SVT_SAMPLES ) );
+    aEntryStr = SVT_RESSTR(STR_SVT_SAMPLES);
     pEntry = aIconCtrl.InsertEntry(
         aEntryStr, Image( SvtResId( IMG_SVT_SAMPLES ) ), ICON_POS_SAMPLES );
     pEntry->SetUserData( new String( aSamplesFolderRootURL ) );
-    pEntry->SetQuickHelpText( String( SvtResId( STR_SVT_SAMPLES_HELP ) ) );
+    pEntry->SetQuickHelpText( SVT_RESSTR(STR_SVT_SAMPLES_HELP));
     DBG_ASSERT( !pEntry->GetBoundRect().IsEmpty(), "empty rectangle" );
     nTemp = pEntry->GetBoundRect().GetSize().Width();
     if (nTemp > nMaxTextLength)
@@ -459,12 +296,6 @@ String SvtIconWindow_Impl::GetSelectedIconURL() const
     return aURL;
 }
 
-String SvtIconWindow_Impl::GetSelectedIconText() const
-{
-    sal_uLong nPos;
-    return MnemonicGenerator::EraseAllMnemonicChars( aIconCtrl.GetSelectedEntry( nPos )->GetText() );
-}
-
 String SvtIconWindow_Impl::GetIconText( const String& rURL ) const
 {
     String aText;
@@ -592,7 +423,6 @@ SvtFileViewWindow_Impl::SvtFileViewWindow_Impl( SvtTemplateWindow* pParent ) :
     aFileView.SetStyle( aFileView.GetStyle() | WB_DIALOGCONTROL | WB_TABSTOP );
     aFileView.SetHelpId( HID_TEMPLATEDLG_FILEVIEW );
     aFileView.Show();
-    aFileView.SetPosPixel( Point( 0, 0 ) );
     aFileView.EnableAutoResize();
     aFileView.EnableContextMenu( sal_False );
     aFileView.EnableDelete( sal_False );
@@ -667,7 +497,7 @@ Sequence< ::rtl::OUString > SvtFileViewWindow_Impl::GetNewDocContents() const
             // folder == false
             aRow += '0';
             // image url?
-            if ( aImageURL.getLength() > 0 )
+            if ( !aImageURL.isEmpty() )
             {
                 aRow += '\t';
                 aRow += String( aImageURL );
@@ -693,14 +523,7 @@ Sequence< ::rtl::OUString > SvtFileViewWindow_Impl::GetNewDocContents() const
 
 void SvtFileViewWindow_Impl::Resize()
 {
-    Size aWinSize = GetOutputSizePixel();
-
-    static int  x = 0;
-    static int  y = 0;
-
-    aWinSize.nA += x;
-    aWinSize.nB += y;
-    aFileView.SetSizePixel( aWinSize );
+    aFileView.SetSizePixel(GetOutputSizePixel());
 }
 
 String SvtFileViewWindow_Impl::GetSelectedFile() const
@@ -766,45 +589,16 @@ SvtDocInfoTable_Impl::SvtDocInfoTable_Impl() :
 
 {
 }
-// -----------------------------------------------------------------------------
-// class SvtExtendedMultiLineEdit_Impl --------------------------------------------
-SvtExtendedMultiLineEdit_Impl::SvtExtendedMultiLineEdit_Impl( Window* pParent,WinBits _nBits ) :
-
-    ExtMultiLineEdit( pParent, _nBits )
-
-{
-    SetLeftMargin( 10 );
-}
-// -----------------------------------------------------------------------------
-void SvtExtendedMultiLineEdit_Impl::InsertEntry( const String& rTitle, const String& rValue )
-{
-    String aText( '\n' );
-    aText += rTitle;
-    aText += ':';
-    InsertText( aText );
-    sal_uLong nPara = GetParagraphCount() - 1;
-    SetAttrib( TextAttribFontWeight( WEIGHT_BOLD ), nPara, 0, aText.Len() );
-
-    aText = '\n';
-    aText += rValue;
-    InsertText( aText );
-    nPara = GetParagraphCount() - 1;
-    SetAttrib( TextAttribFontWeight( WEIGHT_NORMAL ), nPara, 0, aText.Len() );
-
-    InsertText( String( '\n' ) );
-}
-// -----------------------------------------------------------------------------
-
 // -----------------------------------------------------------------------
 
-const String& SvtDocInfoTable_Impl::GetString( long nId ) const
+rtl::OUString SvtDocInfoTable_Impl::GetString( long nId ) const
 {
     sal_uInt32 nPos( FindIndex( nId ) );
 
     if ( RESARRAY_INDEX_NOTFOUND != nPos )
         return ResStringArray::GetString( nPos );
-    else
-        return aEmptyString;
+
+    return rtl::OUString();
 }
 
 // class SvtFrameWindow_Impl ---------------------------------------------
@@ -872,20 +666,6 @@ void SvtFrameWindow_Impl::ViewNonEmptyWin()
         ViewTextWin();
 }
 
-IMPL_STATIC_LINK_NOINSTANCE( SvtFrameWindow_Impl, ExecuteHdl_Impl, SvtExecuteInfo*, pExecuteInfo )
-{
-    try
-    {
-        pExecuteInfo->xDispatch->dispatch( pExecuteInfo->aTargetURL, Sequence < PropertyValue >() );
-    }
-    catch ( Exception& )
-    {
-    }
-
-    delete pExecuteInfo;
-    return 0;
-}
-
 void SvtFrameWindow_Impl::ShowDocInfo( const String& rURL )
 {
     try
@@ -916,7 +696,7 @@ void SvtFrameWindow_Impl::OpenFile( const String& rURL, sal_Bool bPreview, sal_B
         aCurrentURL = rURL;
 
     ViewNonEmptyWin();
-    pEditWin->Clear();
+    pEditWin->clear();
 
     if ( rURL.Len() > 0 && bPreview && m_xDocProps.is() )
         ShowDocInfo( rURL );
@@ -1012,13 +792,6 @@ void SvtFrameWindow_Impl::OpenFile( const String& rURL, sal_Bool bPreview, sal_B
             }
             else
             {
-            /*
-                SvtExecuteInfo* pExecuteInfo = new SvtExecuteInfo;
-                pExecuteInfo->xDispatch = xDisp;
-                pExecuteInfo->aTargetURL = aURL;
-                Application::PostUserEvent(
-                    STATIC_LINK(0, SvtFrameWindow_Impl, ExecuteHdl_Impl), pExecuteInfo );
-            */
                 Sequence < PropertyValue > aArgs;
                 xDisp->dispatch( aURL, aArgs );
                 m_aOpenURL = rtl::OUString();
@@ -1109,7 +882,7 @@ SvtTemplateWindow::~SvtTemplateWindow()
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtTemplateWindow , IconClickHdl_Impl, SvtIconChoiceCtrl *, EMPTYARG )
+IMPL_LINK_NOARG(SvtTemplateWindow , IconClickHdl_Impl)
 {
     String aURL = pIconWin->GetSelectedIconURL();
     if ( !aURL.Len() )
@@ -1125,7 +898,7 @@ IMPL_LINK ( SvtTemplateWindow , IconClickHdl_Impl, SvtIconChoiceCtrl *, EMPTYARG
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtTemplateWindow , FileSelectHdl_Impl, SvtFileView *, EMPTYARG )
+IMPL_LINK_NOARG(SvtTemplateWindow , FileSelectHdl_Impl)
 {
     aSelectTimer.Start();
     return 0;
@@ -1133,7 +906,7 @@ IMPL_LINK ( SvtTemplateWindow , FileSelectHdl_Impl, SvtFileView *, EMPTYARG )
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtTemplateWindow , FileDblClickHdl_Impl, SvtFileView *, EMPTYARG )
+IMPL_LINK_NOARG(SvtTemplateWindow , FileDblClickHdl_Impl)
 {
     if ( aSelectTimer.IsActive() )
         aSelectTimer.Stop();
@@ -1152,7 +925,7 @@ IMPL_LINK ( SvtTemplateWindow , FileDblClickHdl_Impl, SvtFileView *, EMPTYARG )
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtTemplateWindow , NewFolderHdl_Impl, SvtFileView *, EMPTYARG )
+IMPL_LINK_NOARG(SvtTemplateWindow , NewFolderHdl_Impl)
 {
     pFrameWin->OpenFile( String(), sal_True, sal_False, sal_False );
     aFileViewTB.EnableItem( TI_DOCTEMPLATE_PRINT, sal_False );
@@ -1167,7 +940,7 @@ IMPL_LINK ( SvtTemplateWindow , NewFolderHdl_Impl, SvtFileView *, EMPTYARG )
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtTemplateWindow , TimeoutHdl_Impl, Timer *, EMPTYARG )
+IMPL_LINK_NOARG(SvtTemplateWindow , TimeoutHdl_Impl)
 {
     aSelectHdl.Call( this );
     String sURL = pFileWin->GetSelectedFile();
@@ -1197,7 +970,7 @@ IMPL_LINK ( SvtTemplateWindow , ClickHdl_Impl, ToolBox *, pToolBox )
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtTemplateWindow , ResizeHdl_Impl, SplitWindow *, EMPTYARG )
+IMPL_LINK_NOARG(SvtTemplateWindow , ResizeHdl_Impl)
 {
     Resize();
     return 0;
@@ -1588,7 +1361,7 @@ void SvtTemplateWindow::ReadViewSettings()
     pIconWin->SetCursorPos( nSelectedGroup );
 
     // open the last folder or the selected group
-    if ( sLastFolder.getLength() > 0 )
+    if ( !sLastFolder.isEmpty() )
         pFileWin->OpenFolder( sLastFolder );
     else
         IconClickHdl_Impl( NULL );
@@ -1752,10 +1525,10 @@ sal_Bool SvtDocumentTemplateDialog::CanEnableEditBtn() const
     sal_Bool bEnable = sal_False;
 
     ::rtl::OUString aFolderURL = pImpl->pWin->GetFolderURL();
-    if ( pImpl->pWin->IsFileSelected() && aFolderURL.getLength() )
+    if ( pImpl->pWin->IsFileSelected() && !aFolderURL.isEmpty() )
     {
         ::rtl::OUString aFileTargetURL = pImpl->pWin->GetSelectedFile();
-        bEnable = aFileTargetURL.getLength() > 0;
+        bEnable = !aFileTargetURL.isEmpty();
     }
 
     return bEnable;
@@ -1763,7 +1536,7 @@ sal_Bool SvtDocumentTemplateDialog::CanEnableEditBtn() const
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtDocumentTemplateDialog , SelectHdl_Impl, SvtTemplateWindow *, EMPTYARG )
+IMPL_LINK_NOARG(SvtDocumentTemplateDialog , SelectHdl_Impl)
 {
     aEditBtn.Enable( pImpl->pWin->IsTemplateFolderOpen() && CanEnableEditBtn() );
     aOKBtn.Enable( pImpl->pWin->IsFileSelected() );
@@ -1772,7 +1545,7 @@ IMPL_LINK ( SvtDocumentTemplateDialog , SelectHdl_Impl, SvtTemplateWindow *, EMP
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtDocumentTemplateDialog , DoubleClickHdl_Impl, SvtTemplateWindow *, EMPTYARG )
+IMPL_LINK_NOARG(SvtDocumentTemplateDialog , DoubleClickHdl_Impl)
 {
     EndDialog( RET_OK );
 
@@ -1783,7 +1556,7 @@ IMPL_LINK ( SvtDocumentTemplateDialog , DoubleClickHdl_Impl, SvtTemplateWindow *
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtDocumentTemplateDialog , NewFolderHdl_Impl, SvtTemplateWindow *, EMPTYARG )
+IMPL_LINK_NOARG(SvtDocumentTemplateDialog , NewFolderHdl_Impl)
 {
     String aNewTitle( pImpl->aTitle );
     aNewTitle += String( ASCII_STR(" - ") );
@@ -1796,7 +1569,7 @@ IMPL_LINK ( SvtDocumentTemplateDialog , NewFolderHdl_Impl, SvtTemplateWindow *,
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtDocumentTemplateDialog , SendFocusHdl_Impl, SvtTemplateWindow *, EMPTYARG )
+IMPL_LINK_NOARG(SvtDocumentTemplateDialog , SendFocusHdl_Impl)
 {
     if ( pImpl->pWin->HasIconWinFocus() )
         aHelpBtn.GrabFocus();
@@ -1829,7 +1602,7 @@ IMPL_LINK ( SvtDocumentTemplateDialog , OKHdl_Impl, PushButton *, pBtn )
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtDocumentTemplateDialog , OrganizerHdl_Impl, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG(SvtDocumentTemplateDialog , OrganizerHdl_Impl)
 {
     Window* pOldDefWin = Application::GetDefDialogParent();
     Application::SetDefDialogParent( this );
@@ -1868,35 +1641,31 @@ IMPL_LINK ( SvtDocumentTemplateDialog , OrganizerHdl_Impl, PushButton *, EMPTYAR
 IMPL_LINK ( SvtDocumentTemplateDialog, UpdateHdl_Impl, Timer*, _pEventSource )
 {
     pImpl->pWin->SetFocus( sal_False );
-    Reference< XDocumentTemplates > xTemplates( ::comphelper::getProcessServiceFactory()->
-        createInstance( ASCII_STR("com.sun.star.frame.DocumentTemplates") ), UNO_QUERY );
-    if ( xTemplates.is() )
-    {
-        if ( _pEventSource )
-        {   // it was no direct call, which means it was triggered by the timer, which means we alread checked the necessity
-            WaitObject aWaitCursor( this );
-            xTemplates->update();
-            if ( pImpl->pWin->IsTemplateFolderOpen() )
-            {
-                pImpl->pWin->ClearHistory();
-                pImpl->pWin->OpenTemplateRoot();
-            }
-        }
-        else
+    Reference< XDocumentTemplates > xTemplates( frame::DocumentTemplates::create(::comphelper::getProcessComponentContext()) );
+    if ( _pEventSource )
+    {   // it was no direct call, which means it was triggered by the timer, which means we alread checked the necessity
+        WaitObject aWaitCursor( this );
+        xTemplates->update();
+        if ( pImpl->pWin->IsTemplateFolderOpen() )
         {
-            // check if we really need to do the update
-            ::svt::TemplateFolderCache aCache;
-            if ( aCache.needsUpdate() )
-            {   // yes -> do it asynchronous (it will take a noticeable time)
+            pImpl->pWin->ClearHistory();
+            pImpl->pWin->OpenTemplateRoot();
+        }
+    }
+    else
+    {
+        // check if we really need to do the update
+        ::svt::TemplateFolderCache aCache;
+        if ( aCache.needsUpdate() )
+        {   // yes -> do it asynchronous (it will take a noticeable time)
 
-                // (but first store the current state)
-                aCache.storeState();
+            // (but first store the current state)
+            aCache.storeState();
 
-                // start the timer for the async update
-                pImpl->aUpdateTimer.SetTimeout( 300 );
-                pImpl->aUpdateTimer.SetTimeoutHdl( LINK( this, SvtDocumentTemplateDialog, UpdateHdl_Impl ) );
-                pImpl->aUpdateTimer.Start();
-            }
+            // start the timer for the async update
+            pImpl->aUpdateTimer.SetTimeout( 300 );
+            pImpl->aUpdateTimer.SetTimeoutHdl( LINK( this, SvtDocumentTemplateDialog, UpdateHdl_Impl ) );
+            pImpl->aUpdateTimer.Start();
         }
     }
     return 0;
@@ -1904,10 +1673,10 @@ IMPL_LINK ( SvtDocumentTemplateDialog, UpdateHdl_Impl, Timer*, _pEventSource )
 
 // ------------------------------------------------------------------------
 
-IMPL_LINK ( SvtDocumentTemplateDialog, OpenLinkHdl_Impl, svt::FixedHyperlink*, EMPTYARG )
+IMPL_LINK_NOARG(SvtDocumentTemplateDialog, OpenLinkHdl_Impl)
 {
     ::rtl::OUString sURL( aMoreTemplatesLink.GetURL() );
-    if ( sURL.getLength() > 0 )
+    if ( !sURL.isEmpty() )
     {
         localizeWebserviceURI(sURL);
         try
@@ -1919,7 +1688,7 @@ IMPL_LINK ( SvtDocumentTemplateDialog, OpenLinkHdl_Impl, svt::FixedHyperlink*, E
                     RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.system.SystemShellExecute" ) ) ),
                 uno::UNO_QUERY_THROW );
             if ( xSystemShell.is() )
-                xSystemShell->execute( sURL, ::rtl::OUString(), com::sun::star::system::SystemShellExecuteFlags::DEFAULTS );
+                xSystemShell->execute( sURL, ::rtl::OUString(), com::sun::star::system::SystemShellExecuteFlags::URIS_ONLY );
             EndDialog( RET_CANCEL );
         }
         catch( const uno::Exception& e )
