@@ -585,7 +585,7 @@ void HeaderBar::ImplDrawItem( OutputDevice* pDev,
                 else if ( nBits & HIB_BOTTOM )
                     nArrowY = aRect.Bottom()-HEAD_ARROWSIZE2-1;
                 else
-                    nArrowY = aRect.Top()+((aRect.GetHeight()-HEAD_ARROWSIZE2)/2);;
+                    nArrowY = aRect.Top()+((aRect.GetHeight()-HEAD_ARROWSIZE2)/2);
             }
             nArrowY -= HEAD_ARROWSIZE1-1;
             if ( nBits & HIB_DOWNARROW )
@@ -1117,7 +1117,7 @@ void HeaderBar::RequestHelp( const HelpEvent& rHEvt )
         else if ( rHEvt.GetMode() & HELPMODE_EXTENDED )
         {
             rtl::OUString aHelpId( rtl::OStringToOUString( GetHelpId( nItemId ), RTL_TEXTENCODING_UTF8 ) );
-            if ( aHelpId.getLength() )
+            if ( !aHelpId.isEmpty() )
             {
                 // Wenn eine Hilfe existiert, dann ausloesen
                 Help* pHelp = Application::GetHelp();
@@ -1216,33 +1216,6 @@ void HeaderBar::DoubleClick()
 
 // -----------------------------------------------------------------------
 
-void HeaderBar::InsertItem( sal_uInt16 nItemId, const Image& rImage,
-                            long nSize, HeaderBarItemBits nBits, sal_uInt16 nPos )
-{
-    DBG_ASSERT( nItemId, "HeaderBar::InsertItem(): ItemId == 0" );
-    DBG_ASSERT( GetItemPos( nItemId ) == HEADERBAR_ITEM_NOTFOUND,
-                "HeaderBar::InsertItem(): ItemId already exists" );
-
-    // Item anlegen und in die Liste einfuegen
-    ImplHeadItem* pItem = new ImplHeadItem;
-    pItem->mnId         = nItemId;
-    pItem->mnBits       = nBits;
-    pItem->mnSize       = nSize;
-    pItem->maImage      = rImage;
-    if ( nPos < mpItemList->size() ) {
-        ImplHeadItemList::iterator it = mpItemList->begin();
-        ::std::advance( it, nPos );
-        mpItemList->insert( it, pItem );
-    } else {
-        mpItemList->push_back( pItem );
-    }
-
-    // Ausgabe updaten
-    ImplUpdate( nPos, sal_True );
-}
-
-// -----------------------------------------------------------------------
-
 void HeaderBar::InsertItem( sal_uInt16 nItemId, const XubString& rText,
                             long nSize, HeaderBarItemBits nBits, sal_uInt16 nPos )
 {
@@ -1270,36 +1243,6 @@ void HeaderBar::InsertItem( sal_uInt16 nItemId, const XubString& rText,
 
 // -----------------------------------------------------------------------
 
-void HeaderBar::InsertItem( sal_uInt16 nItemId,
-                            const Image& rImage, const XubString& rText,
-                            long nSize, HeaderBarItemBits nBits,
-                            sal_uInt16 nPos )
-{
-    DBG_ASSERT( nItemId, "HeaderBar::InsertItem(): ItemId == 0" );
-    DBG_ASSERT( GetItemPos( nItemId ) == HEADERBAR_ITEM_NOTFOUND,
-                "HeaderBar::InsertItem(): ItemId already exists" );
-
-    // Item anlegen und in die Liste einfuegen
-    ImplHeadItem* pItem = new ImplHeadItem;
-    pItem->mnId         = nItemId;
-    pItem->mnBits       = nBits;
-    pItem->mnSize       = nSize;
-    pItem->maImage      = rImage;
-    pItem->maText       = rText;
-    if ( nPos < mpItemList->size() ) {
-        ImplHeadItemList::iterator it = mpItemList->begin();
-        ::std::advance( it, nPos );
-        mpItemList->insert( it, pItem );
-    } else {
-        mpItemList->push_back( pItem );
-    }
-
-    // Ausgabe updaten
-    ImplUpdate( nPos, sal_True );
-}
-
-// -----------------------------------------------------------------------
-
 void HeaderBar::RemoveItem( sal_uInt16 nItemId )
 {
     sal_uInt16 nPos = GetItemPos( nItemId );
@@ -1492,22 +1435,13 @@ XubString HeaderBar::GetItemText( sal_uInt16 nItemId ) const
 
 // -----------------------------------------------------------------------
 
-void HeaderBar::SetHelpText( sal_uInt16 nItemId, const XubString& rText )
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-    if ( nPos != HEADERBAR_ITEM_NOTFOUND )
-        (*mpItemList)[ nPos ]->maHelpText = rText;
-}
-
-// -----------------------------------------------------------------------
-
 XubString HeaderBar::GetHelpText( sal_uInt16 nItemId ) const
 {
     sal_uInt16 nPos = GetItemPos( nItemId );
     if ( nPos != HEADERBAR_ITEM_NOTFOUND )
     {
         ImplHeadItem* pItem = (*mpItemList)[ nPos ];
-        if ( !pItem->maHelpText.Len() && pItem->maHelpId.getLength() )
+        if ( !pItem->maHelpText.Len() && !pItem->maHelpId.isEmpty() )
         {
             Help* pHelp = Application::GetHelp();
             if ( pHelp )
@@ -1522,15 +1456,6 @@ XubString HeaderBar::GetHelpText( sal_uInt16 nItemId ) const
 
 // -----------------------------------------------------------------------
 
-void HeaderBar::SetHelpId( sal_uInt16 nItemId, const rtl::OString& rHelpId )
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-    if ( nPos != HEADERBAR_ITEM_NOTFOUND )
-        (*mpItemList)[ nPos ]->maHelpId = rHelpId;
-}
-
-// -----------------------------------------------------------------------
-
 rtl::OString HeaderBar::GetHelpId( sal_uInt16 nItemId ) const
 {
     sal_uInt16 nPos = GetItemPos( nItemId );
