@@ -37,7 +37,6 @@
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/svapp.hxx>
 #include <osl/mutex.hxx>
-#include <tools/debug.hxx>
 #include <tools/gen.hxx>
 #include <svl/smplhint.hxx>
 #include <toolkit/helper/convert.hxx>
@@ -736,39 +735,12 @@ void SAL_CALL SvxGraphCtrlAccessibleContext::deselectAccessibleChild( sal_Int32
 
 //=====  internals ========================================================
 
-void SvxGraphCtrlAccessibleContext::checkChildIndex( long nIndex ) throw( lang::IndexOutOfBoundsException )
-{
-    if( nIndex < 0 || nIndex >= getAccessibleChildCount() )
-        throw lang::IndexOutOfBoundsException();
-}
-
-//-----------------------------------------------------------------------------
-
 void SvxGraphCtrlAccessibleContext::checkChildIndexOnSelection( long nIndex ) throw( lang::IndexOutOfBoundsException )
 {
     if( nIndex < 0 || nIndex >= getSelectedAccessibleChildCount() )
         throw lang::IndexOutOfBoundsException();
 }
 
-//-----------------------------------------------------------------------------
-
-void SvxGraphCtrlAccessibleContext::setName( const OUString& rName )
-{
-    ::SolarMutexGuard aGuard;
-
-    msName = rName;
-}
-
-//-----------------------------------------------------------------------------
-
-void SvxGraphCtrlAccessibleContext::setDescription( const OUString& rDescr )
-{
-    ::SolarMutexGuard aGuard;
-
-    msDescription = rDescr;
-}
-
-
 
 
 /** Replace the model, page, and view pointers by the ones provided
