@@ -299,7 +299,7 @@ void SAL_CALL FormViewPageWindowAdapter::makeVisible( const Reference< XControl
 }
 
 //------------------------------------------------------------------------
-Reference< XFormController >  getControllerSearchChilds( const Reference< XIndexAccess > & xIndex, const Reference< XTabControllerModel > & xModel)
+Reference< XFormController >  getControllerSearchChildren( const Reference< XIndexAccess > & xIndex, const Reference< XTabControllerModel > & xModel)
 {
     if (xIndex.is() && xIndex->getCount())
     {
@@ -312,7 +312,7 @@ Reference< XFormController >  getControllerSearchChilds( const Reference< XIndex
                 return xController;
             else
             {
-                xController = getControllerSearchChilds(Reference< XIndexAccess > (xController, UNO_QUERY), xModel);
+                xController = getControllerSearchChildren(Reference< XIndexAccess > (xController, UNO_QUERY), xModel);
                 if ( xController.is() )
                     return xController;
             }
@@ -333,7 +333,7 @@ Reference< XFormController >  FormViewPageWindowAdapter::getController( const Re
             return *i;
 
         // the current-round controller isn't the right one. perhaps one of it's children ?
-        Reference< XFormController >  xChildSearch = getControllerSearchChilds(Reference< XIndexAccess > (*i, UNO_QUERY), xModel);
+        Reference< XFormController >  xChildSearch = getControllerSearchChildren(Reference< XIndexAccess > (*i, UNO_QUERY), xModel);
         if (xChildSearch.is())
             return xChildSearch;
     }
@@ -733,10 +733,14 @@ IMPL_LINK(FmXFormView, OnActivate, void*, /*EMPTYTAG*/)
                     continue;
 
                 Reference< XPropertySet > xFormSet( xForm, UNO_QUERY );
-                ENSURE_OR_CONTINUE( xFormSet.is(), "FmXFormView::OnActivate: a form which does not have properties?" );
+                if ( !xFormSet.is() )
+                {
+                    SAL_WARN( "svx.form", "FmXFormView::OnActivate: a form which does not have properties?" );
+                    continue;
+                }
 
                 const ::rtl::OUString aSource = ::comphelper::getString( xFormSet->getPropertyValue( FM_PROP_COMMAND ) );
-                if ( aSource.getLength() )
+                if ( !aSource.isEmpty() )
                 {
                     FmXFormShell* pShImpl =  m_pView->GetFormShell()->GetImpl();
                     if ( pShImpl )
@@ -908,7 +912,12 @@ Reference< XFormController > FmXFormView::getFormController( const Reference< XF
         )
     {
         const PFormViewPageWindowAdapter pAdapter( *pos );
-        ENSURE_OR_CONTINUE( pAdapter.get(), "FmXFormView::getFormController: invalid page window adapter!" );
+        if ( !pAdapter.get() )
+        {
+            SAL_WARN( "svx.form", "FmXFormView::getFormController: invalid page window adapter!" );
+            continue;
+        }
+
         if ( pAdapter->getWindow() != &_rDevice )
             // wrong device
             continue;
@@ -1145,9 +1154,9 @@ SdrObject* FmXFormView::implCreateFieldControl( const ::svx::ODataAccessDescript
         xConnection.reset( xExternalConnection, SharedConnection::NoTakeOwnership );
     }
 
-    if  (   !sCommand.getLength()
-        ||  !sFieldName.getLength()
-        ||  (   !sDataSource.getLength()
+    if  (   sCommand.isEmpty()
+        ||  sFieldName.isEmpty()
+        ||  (   sDataSource.isEmpty()
             &&  !xConnection.is()
             )
         )
@@ -1159,7 +1168,7 @@ SdrObject* FmXFormView::implCreateFieldControl( const ::svx::ODataAccessDescript
     SQLErrorEvent aError;
     try
     {
-        if ( xConnection.is() && !xDataSource.is() && !sDataSource.getLength() )
+        if ( xConnection.is() && !xDataSource.is() && sDataSource.isEmpty() )
         {
             Reference< XChild > xChild( xConnection, UNO_QUERY );
             if ( xChild.is() )
@@ -1575,7 +1584,7 @@ bool FmXFormView::createControlLabelPair( const ::comphelper::ComponentContext&
             ::rtl::OUString sLabel;
             if ( _rxField.is() && _rxField->getPropertySetInfo()->hasPropertyByName(FM_PROP_LABEL) )
                 _rxField->getPropertyValue(FM_PROP_LABEL) >>= sLabel;
-            if ( !sLabel.getLength() )
+            if ( sLabel.isEmpty() )
                 sLabel = sFieldName;
 
             xLabelModel->setPropertyValue( FM_PROP_LABEL, makeAny( sLabel + _rFieldPostfix ) );
