@@ -27,6 +27,7 @@
  ************************************************************************/
 
 
+#include <comphelper/string.hxx>
 #include <tools/vcompat.hxx>
 #include <ucbhelper/content.hxx>
 #include <unotools/ucbstreamhelper.hxx>
@@ -62,7 +63,7 @@ GalleryThemeEntry::GalleryThemeEntry( const INetURLObject& rBaseURL, const Strin
 {
     INetURLObject aURL( rBaseURL );
     DBG_ASSERT( aURL.GetProtocol() != INET_PROT_NOT_VALID, "invalid URL" );
-    String aFileName( String( RTL_CONSTASCII_USTRINGPARAM( "sg" ) ) );
+    String aFileName( String( "sg"  ) );
 
     aURL.Append( ( aFileName += String::CreateFromInt32( nFileNumber ) ) += String( RTL_CONSTASCII_USTRINGPARAM( ".thm" ) ) );
     aThmURL = ImplGetURLIgnoreCase( aURL );
@@ -76,9 +77,9 @@ GalleryThemeEntry::GalleryThemeEntry( const INetURLObject& rBaseURL, const Strin
     SetModified( _bNewFile );
 
     if( nId && bThemeNameFromResource )
-        aName = String( GAL_RESID( RID_GALLERYSTR_THEME_START + (sal_uInt16) nId ) );
+        aName = GAL_RESSTR( RID_GALLERYSTR_THEME_START + (sal_uInt16) nId );
 
-    if( !aName.Len() )
+    if( aName.isEmpty() )
         aName = rName;
 }
 
@@ -107,7 +108,7 @@ INetURLObject GalleryThemeEntry::ImplGetURLIgnoreCase( const INetURLObject& rURL
 
 // -----------------------------------------------------------------------------
 
-void GalleryThemeEntry::SetName( const String& rNewName )
+void GalleryThemeEntry::SetName( const rtl::OUString& rNewName )
 {
     if( aName != rNewName )
     {
@@ -132,16 +133,12 @@ void GalleryThemeEntry::SetId( sal_uInt32 nNewId, sal_Bool bResetThemeName )
 
 SvStream& operator<<( SvStream& rOut, const GalleryImportThemeEntry& rEntry )
 {
-    rOut.WriteByteString(rtl::OUStringToOString(rEntry.aThemeName, RTL_TEXTENCODING_UTF8));
-
-    rOut.WriteByteString(rtl::OUStringToOString(rEntry.aUIName, RTL_TEXTENCODING_UTF8));
-
-    rOut.WriteByteString(rtl::OUStringToOString(String(rEntry.aURL.GetMainURL( INetURLObject::NO_DECODE )), RTL_TEXTENCODING_UTF8));
-
-    rOut.WriteByteString(rtl::OUStringToOString(rEntry.aImportName, RTL_TEXTENCODING_UTF8));
-
-    rOut.WriteByteString(rtl::OUString());
+    write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rOut, rEntry.aThemeName, RTL_TEXTENCODING_UTF8);
+    write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rOut, rEntry.aUIName, RTL_TEXTENCODING_UTF8);
+    write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rOut, (rEntry.aURL.GetMainURL( INetURLObject::NO_DECODE )), RTL_TEXTENCODING_UTF8);
+    write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rOut, rEntry.aImportName, RTL_TEXTENCODING_UTF8);
 
+    write_lenPrefixed_uInt8s_FromOString<sal_uInt16>(rOut, rtl::OString());
     return rOut;
 }
 
@@ -149,22 +146,11 @@ SvStream& operator<<( SvStream& rOut, const GalleryImportThemeEntry& rEntry )
 
 SvStream& operator>>( SvStream& rIn, GalleryImportThemeEntry& rEntry )
 {
-    ByteString aTmpStr;
-
-    rIn.ReadByteString(aTmpStr);
-    rEntry.aThemeName = String( aTmpStr, RTL_TEXTENCODING_UTF8 );
-
-    rIn.ReadByteString(aTmpStr);
-    rEntry.aUIName = String( aTmpStr, RTL_TEXTENCODING_UTF8 );
-
-    rIn.ReadByteString(aTmpStr);
-    rEntry.aURL = INetURLObject( String( aTmpStr, RTL_TEXTENCODING_UTF8 ) );
-
-    rIn.ReadByteString(aTmpStr);
-    rEntry.aImportName = String( aTmpStr, RTL_TEXTENCODING_UTF8 );
-
-    rIn.ReadByteString(aTmpStr);
-
+    rEntry.aThemeName = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(rIn, RTL_TEXTENCODING_UTF8);
+    rEntry.aUIName = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(rIn, RTL_TEXTENCODING_UTF8);
+    rEntry.aURL = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(rIn, RTL_TEXTENCODING_UTF8);
+    rEntry.aImportName = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(rIn, RTL_TEXTENCODING_UTF8);
+    read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(rIn);
     return rIn;
 }
 
@@ -193,7 +179,7 @@ public:
 // - Gallery -
 // -----------
 
-Gallery::Gallery( const String& rMultiPath )
+Gallery::Gallery( const rtl::OUString& rMultiPath )
 :       nReadTextEncoding   ( osl_getThreadTextEncoding() )
 ,       nLastFileNumber     ( 0 )
 ,       bMultiPath          ( sal_False )
@@ -236,9 +222,9 @@ Gallery* Gallery::GetGalleryInstance()
 
 // ------------------------------------------------------------------------
 
-void Gallery::ImplLoad( const String& rMultiPath )
+void Gallery::ImplLoad( const rtl::OUString& rMultiPath )
 {
-    const sal_uInt16    nTokenCount = rMultiPath.GetTokenCount( ';' );
+    const sal_Int32 nTokenCount = comphelper::string::getTokenCount(rMultiPath, ';');
     sal_Bool        bIsReadOnlyDir;
 
     bMultiPath = ( nTokenCount > 0 );
@@ -251,11 +237,11 @@ void Gallery::ImplLoad( const String& rMultiPath )
 
     if( bMultiPath )
     {
-        aRelURL = INetURLObject( rMultiPath.GetToken( 0, ';' ) );
+        aRelURL = INetURLObject( comphelper::string::getToken(rMultiPath, 0, ';') );
 
-        for( sal_uInt16 i = 0UL; i < nTokenCount; i++ )
+        for( sal_Int32 i = 0; i < nTokenCount; ++i )
         {
-            aCurURL = INetURLObject(rMultiPath.GetToken( i, ';' ));
+            aCurURL = INetURLObject(comphelper::string::getToken(rMultiPath, i, ';'));
 
             ImplLoadSubDirs( aCurURL, bIsReadOnlyDir );
 
@@ -284,7 +270,7 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
         ::ucbhelper::Content                       aCnt( rBaseURL.GetMainURL( INetURLObject::NO_DECODE ), xEnv );
 
         uno::Sequence< OUString > aProps( 1 );
-        aProps.getArray()[ 0 ] = OUString(RTL_CONSTASCII_USTRINGPARAM("Url"));
+        aProps.getArray()[ 0 ] = OUString("Url");
 
         uno::Reference< sdbc::XResultSet > xResultSet( aCnt.createCursor( aProps, ::ucbhelper::INCLUDE_DOCUMENTS_ONLY ) );
 
@@ -299,7 +285,7 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
 
             if( pTestStm )
             {
-                *pTestStm << 1;
+                *pTestStm << sal_Int32(1);
 
                 if( pTestStm->GetError() )
                     rbDirIsReadOnly = sal_True;
@@ -326,16 +312,16 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
 
             if( xContentAccess.is() )
             {
-                static const ::rtl::OUString s_sTitle(RTL_CONSTASCII_USTRINGPARAM("Title"));
-                static const ::rtl::OUString s_sIsReadOnly(RTL_CONSTASCII_USTRINGPARAM("IsReadOnly"));
-                static const ::rtl::OUString s_sSDG_EXT(RTL_CONSTASCII_USTRINGPARAM("sdg"));
-                static const ::rtl::OUString s_sSDV_EXT(RTL_CONSTASCII_USTRINGPARAM("sdv"));
+                static const ::rtl::OUString s_sTitle("Title");
+                static const ::rtl::OUString s_sIsReadOnly("IsReadOnly");
+                static const ::rtl::OUString s_sSDG_EXT("sdg");
+                static const ::rtl::OUString s_sSDV_EXT("sdv");
 
                 while( xResultSet->next() )
                 {
                     INetURLObject aThmURL( xContentAccess->queryContentIdentifierString() );
 
-                    if(aThmURL.GetExtension().equalsIgnoreAsciiCaseAscii("thm"))
+                    if(aThmURL.GetExtension().equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("thm")))
                     {
                         INetURLObject   aSdgURL( aThmURL); aSdgURL.SetExtension( s_sSDG_EXT );
                         INetURLObject   aSdvURL( aThmURL ); aSdvURL.SetExtension( s_sSDV_EXT );
@@ -359,7 +345,7 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
                             {
                             }
 
-                            if( aTitle.getLength() )
+                            if( !aTitle.isEmpty() )
                             {
                                 try
                                 {
@@ -385,7 +371,7 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
                                     {
                                     }
 
-                                    if( aTitle.getLength() )
+                                    if( !aTitle.isEmpty() )
                                     {
                                         try
                                         {
@@ -413,7 +399,7 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
                                     {
                                     }
 
-                                    if( aTitle.getLength() )
+                                    if( !aTitle.isEmpty() )
                                     {
                                         try
                                         {
@@ -547,21 +533,23 @@ void Gallery::ImplWriteImportList()
 
 // ------------------------------------------------------------------------
 
-GalleryThemeEntry* Gallery::ImplGetThemeEntry( const String& rThemeName )
+GalleryThemeEntry* Gallery::ImplGetThemeEntry( const rtl::OUString& rThemeName )
 {
     GalleryThemeEntry* pFound = NULL;
 
-    if( rThemeName.Len() )
+    if( !rThemeName.isEmpty() )
+    {
         for ( size_t i = 0, n = aThemeList.size(); i < n && !pFound; ++i )
             if( rThemeName == aThemeList[ i ]->GetThemeName() )
                 pFound = aThemeList[ i ];
+    }
 
     return pFound;
 }
 
 // ------------------------------------------------------------------------
 
-GalleryImportThemeEntry* Gallery::ImplGetImportThemeEntry( const String& rImportName )
+GalleryImportThemeEntry* Gallery::ImplGetImportThemeEntry( const rtl::OUString& rImportName )
 {
     for ( size_t i = 0, n = aImportList.size(); i < n; ++i )
         if ( rImportName == aImportList[ i ]->aUIName )
@@ -571,7 +559,7 @@ GalleryImportThemeEntry* Gallery::ImplGetImportThemeEntry( const String& rImport
 
 // ------------------------------------------------------------------------
 
-String Gallery::GetThemeName( sal_uIntPtr nThemeId ) const
+rtl::OUString Gallery::GetThemeName( sal_uIntPtr nThemeId ) const
 {
     GalleryThemeEntry* pFound = NULL;
 
@@ -585,28 +573,45 @@ String Gallery::GetThemeName( sal_uIntPtr nThemeId ) const
     // try fallback, if no entry was found
     if( !pFound )
     {
-        ByteString      aFallback;
+        rtl::OString aFallback;
 
         switch( nThemeId )
         {
-            case( GALLERY_THEME_3D ): aFallback = "3D"; break;
-            case( GALLERY_THEME_BULLETS ): aFallback = "Bullets"; break;
-            case( GALLERY_THEME_HOMEPAGE ): aFallback = "Homepage"; break;
-            case( GALLERY_THEME_HTMLBUTTONS ): aFallback = "private://gallery/hidden/HtmlExportButtons"; break;
-            case( GALLERY_THEME_POWERPOINT ): aFallback = "private://gallery/hidden/imgppt"; break;
-            case( GALLERY_THEME_FONTWORK ): aFallback = "private://gallery/hidden/fontwork"; break;
-            case( GALLERY_THEME_FONTWORK_VERTICAL ): aFallback = "private://gallery/hidden/fontworkvertical"; break;
-            case( GALLERY_THEME_RULERS ): aFallback = "Rulers"; break;
-            case( GALLERY_THEME_SOUNDS ): aFallback = "Sounds"; break;
-
+            case( GALLERY_THEME_3D ):
+                aFallback = "3D";
+                break;
+            case( GALLERY_THEME_BULLETS ):
+                aFallback = "Bullets";
+                break;
+            case( GALLERY_THEME_HOMEPAGE ):
+                aFallback = "Homepage";
+                break;
+            case( GALLERY_THEME_HTMLBUTTONS ):
+                aFallback = "private://gallery/hidden/HtmlExportButtons";
+                break;
+            case( GALLERY_THEME_POWERPOINT ):
+                aFallback = "private://gallery/hidden/imgppt";
+                break;
+            case( GALLERY_THEME_FONTWORK ):
+                aFallback = "private://gallery/hidden/fontwork";
+                break;
+            case( GALLERY_THEME_FONTWORK_VERTICAL ):
+                aFallback = "private://gallery/hidden/fontworkvertical";
+                break;
+            case( GALLERY_THEME_RULERS ):
+                aFallback = "Rulers";
+                break;
+            case( GALLERY_THEME_SOUNDS ):
+                aFallback = "Sounds";
+                break;
             default:
-            break;
+                break;
         }
 
-        pFound = ( (Gallery*) this )->ImplGetThemeEntry( String::CreateFromAscii( aFallback.GetBuffer() ) );
+        pFound = const_cast<Gallery*>(this)->ImplGetThemeEntry(rtl::OStringToOUString(aFallback, RTL_TEXTENCODING_ASCII_US));
     }
 
-    return( pFound ? pFound->GetThemeName() : String() );
+    return( pFound ? pFound->GetThemeName() : rtl::OUString() );
 }
 
 // ------------------------------------------------------------------------
@@ -697,7 +702,7 @@ sal_Bool Gallery::RemoveTheme( const String& rThemeName )
 
             if( pImportEntry )
             {
-                for ( GalleryImportThemeList::iterator it = aImportList.begin(); it < aImportList.end(); ++it )
+                for ( GalleryImportThemeList::iterator it = aImportList.begin(); it != aImportList.end(); ++it )
                 {
                     if ( *it == pImportEntry )
                     {
@@ -727,7 +732,7 @@ sal_Bool Gallery::RemoveTheme( const String& rThemeName )
             }
         }
 
-        for ( GalleryThemeList::iterator it = aThemeList.begin(); it < aThemeList.end(); ++it )
+        for ( GalleryThemeList::iterator it = aThemeList.begin(); it != aThemeList.end(); ++it )
         {
             if ( pThemeEntry == *it ) {
                 delete pThemeEntry;
