@@ -30,6 +30,7 @@
 #include <unotools/streamwrap.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/string.hxx>
 #include <ucbhelper/content.hxx>
 #include <tools/resmgr.hxx>
 #include <tools/urlobj.hxx>
@@ -87,7 +88,7 @@ ResMgr* GetGalleryResMgr()
 
 BitmapEx GalleryResGetBitmapEx( sal_uInt32 nId )
 {
-    BitmapEx aBmpEx( GAL_RESID( nId ) );
+    BitmapEx aBmpEx( GAL_RES( nId ) );
 
     if( !aBmpEx.IsTransparent() )
             aBmpEx = BitmapEx( aBmpEx.GetBitmap(), COL_LIGHTMAGENTA );
@@ -115,7 +116,7 @@ sal_uInt16 GalleryGraphicImport( const INetURLObject& rURL, Graphic& rGraphic,
                              String& rFilterName, sal_Bool bShowProgress )
 {
     sal_uInt16      nRet = SGA_IMPORT_NONE;
-    SfxMedium   aMedium( rURL.GetMainURL( INetURLObject::NO_DECODE ), STREAM_READ, sal_True );
+    SfxMedium   aMedium( rURL.GetMainURL( INetURLObject::NO_DECODE ), STREAM_READ );
     String      aFilterName;
 
     aMedium.DownLoad();
@@ -232,7 +233,7 @@ String GetReducedString( const INetURLObject& rURL, sal_uIntPtr nMaxLen )
 {
     String aReduced( rURL.GetMainURL( INetURLObject::DECODE_UNAMBIGUOUS ) );
 
-    aReduced = aReduced.GetToken( aReduced.GetTokenCount( '/' ) - 1, '/' );
+    aReduced = aReduced.GetToken( comphelper::string::getTokenCount(aReduced, '/') - 1, '/' );
 
     if( INET_PROT_PRIV_SOFFICE != rURL.GetProtocol() )
     {
@@ -261,7 +262,7 @@ String GetSvDrawStreamNameFromURL( const INetURLObject& rSvDrawObjURL )
     String aRet;
 
     if( rSvDrawObjURL.GetProtocol() == INET_PROT_PRIV_SOFFICE &&
-        String(rSvDrawObjURL.GetMainURL( INetURLObject::NO_DECODE )).GetTokenCount( '/' ) == 3 )
+        comphelper::string::getTokenCount(rSvDrawObjURL.GetMainURL( INetURLObject::NO_DECODE ), '/') == 3 )
     {
         aRet = String(rSvDrawObjURL.GetMainURL( INetURLObject::NO_DECODE )).GetToken( 2, '/' );
     }
@@ -282,8 +283,8 @@ sal_Bool FileExists( const INetURLObject& rURL )
             ::ucbhelper::Content        aCnt( rURL.GetMainURL( INetURLObject::NO_DECODE ), uno::Reference< ucb::XCommandEnvironment >() );
             OUString    aTitle;
 
-            aCnt.getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Title")) ) >>= aTitle;
-            bRet = ( aTitle.getLength() > 0 );
+            aCnt.getPropertyValue( OUString("Title") ) >>= aTitle;
+            bRet = ( !aTitle.isEmpty() );
         }
         catch( const ucb::ContentCreationException& )
         {
@@ -316,11 +317,11 @@ sal_Bool CreateDir( const INetURLObject& rURL )
             uno::Sequence< OUString >               aProps( 1 );
             uno::Sequence< uno::Any >               aValues( 1 );
 
-            aProps.getArray()[ 0 ] = OUString(RTL_CONSTASCII_USTRINGPARAM("Title"));
+            aProps.getArray()[ 0 ] = OUString("Title");
             aValues.getArray()[ 0 ] = uno::makeAny( OUString( aNewFolderURL.GetName() ) );
 
         ::ucbhelper::Content aContent( aNewFolderURL.GetMainURL( INetURLObject::NO_DECODE ), aCmdEnv );
-        bRet = aParent.insertNewContent( OUString(RTL_CONSTASCII_USTRINGPARAM("application/vnd.sun.staroffice.fsys-folder")), aProps, aValues, aContent );
+        bRet = aParent.insertNewContent( OUString("application/vnd.sun.staroffice.fsys-folder"), aProps, aValues, aContent );
         }
         catch( const ucb::ContentCreationException& )
         {
@@ -346,7 +347,7 @@ sal_Bool CopyFile(  const INetURLObject& rSrcURL, const INetURLObject& rDstURL )
     {
         ::ucbhelper::Content aDestPath( rDstURL.GetMainURL( INetURLObject::NO_DECODE ), uno::Reference< ucb::XCommandEnvironment >() );
 
-        aDestPath.executeCommand( OUString(RTL_CONSTASCII_USTRINGPARAM("transfer")),
+        aDestPath.executeCommand( OUString("transfer"),
                                   uno::makeAny( ucb::TransferInfo( sal_False, rSrcURL.GetMainURL( INetURLObject::NO_DECODE ),
                                                 rDstURL.GetName(), ucb::NameClash::OVERWRITE ) ) );
         bRet = sal_True;
@@ -375,7 +376,7 @@ sal_Bool KillFile( const INetURLObject& rURL )
         try
         {
             ::ucbhelper::Content aCnt( rURL.GetMainURL( INetURLObject::NO_DECODE ), uno::Reference< ucb::XCommandEnvironment >() );
-            aCnt.executeCommand( OUString(RTL_CONSTASCII_USTRINGPARAM("delete")), uno::makeAny( sal_Bool( sal_True ) ) );
+            aCnt.executeCommand( OUString("delete"), uno::makeAny( sal_Bool( sal_True ) ) );
         }
         catch( const ucb::ContentCreationException& )
         {
@@ -406,7 +407,7 @@ GalleryProgress::GalleryProgress( GraphicFilter* pFilter ) :
     if( xMgr.is() )
     {
         uno::Reference< awt::XProgressMonitor > xMonitor( xMgr->createInstance(
-                                                      ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.XProgressMonitor")) ),
+                                                      ::rtl::OUString("com.sun.star.awt.XProgressMonitor") ),
                                                       uno::UNO_QUERY );
 
         if ( xMonitor.is() )
@@ -419,7 +420,7 @@ GalleryProgress::GalleryProgress( GraphicFilter* pFilter ) :
 
                 if( mpFilter )
                 {
-                    aProgressText = String( GAL_RESID( RID_SVXSTR_GALLERY_FILTER ) );
+                    aProgressText = GAL_RESSTR(RID_SVXSTR_GALLERY_FILTER);
 //                  mpFilter->SetUpdatePercentHdl( LINK( this, GalleryProgress, Update ) );     // sj: progress wasn't working up from SO7 at all
 //                                                                                              // so I am removing this. The gallery progress should
 //                                                                                              // be changed to use the XStatusIndicator instead of XProgressMonitor
@@ -438,8 +439,6 @@ GalleryProgress::GalleryProgress( GraphicFilter* pFilter ) :
 
 GalleryProgress::~GalleryProgress()
 {
-//  if( mpFilter )
-//      mpFilter->SetUpdatePercentHdl( Link() );
 }
 
 // ------------------------------------------------------------------------
