@@ -609,9 +609,8 @@ void SvxTableController::onInsert( sal_uInt16 nSId, const SfxItemSet* pArgs )
         StartSelection( aStart );
         UpdateSelection( aEnd );
     }
-    catch( Exception& e )
+    catch( Exception& )
     {
-        (void)e;
         OSL_FAIL("svx::SvxTableController::onInsert(), exception caught!");
     }
 }
@@ -900,9 +899,8 @@ void SvxTableController::SetTableStyle( const SfxItemSet* pArgs )
                         }
                     }
                 }
-                catch( Exception& e )
+                catch( Exception& )
                 {
-                    (void)e;
                     OSL_FAIL( "svx::SvxTableController::SetTableStyle(), exception caught!" );
                 }
             }
@@ -911,9 +909,8 @@ void SvxTableController::SetTableStyle( const SfxItemSet* pArgs )
                 pModel->EndUndo();
         }
     }
-    catch( Exception& e )
+    catch( Exception& )
     {
-        (void)e;
         OSL_FAIL( "svx::SvxTableController::SetTableStyle(), exception caught!" );
     }
 }
@@ -1576,27 +1573,6 @@ const CellPos& SvxTableController::getSelectionEnd()
 
 // --------------------------------------------------------------------
 
-Reference< XCellCursor > SvxTableController::getSelectionCursor()
-{
-    Reference< XCellCursor > xCursor;
-
-    if( mxTable.is() )
-    {
-        if( hasSelectedCells() )
-        {
-            CellPos aStart, aEnd;
-            getSelectedCells( aStart, aEnd );
-            xCursor = mxTable->createCursorByRange( mxTable->getCellRangeByPosition( aStart.mnCol, aStart.mnRow, aEnd.mnCol, aEnd.mnRow ) );
-        }
-        else
-        {
-            xCursor = mxTable->createCursor();
-        }
-    }
-
-    return xCursor;
-}
-
 void SvxTableController::MergeRange( sal_Int32 nFirstCol, sal_Int32 nFirstRow, sal_Int32 nLastCol, sal_Int32 nLastRow )
 {
     if( mxTable.is() ) try
@@ -1637,9 +1613,8 @@ void SvxTableController::checkCell( CellPos& rPos )
         if( rPos.mnRow >= mxTable->getRowCount() )
             rPos.mnRow = mxTable->getRowCount()-1;
     }
-    catch( Exception& e )
+    catch( Exception& )
     {
-        (void)e;
         OSL_FAIL("sdr::table::SvxTableController::checkCell(), exception caught!" );
     }
 }
@@ -1656,9 +1631,8 @@ void SvxTableController::findMergeOrigin( CellPos& rPos )
             ::findMergeOrigin( mxTable, rPos.mnCol, rPos.mnRow, rPos.mnCol, rPos.mnRow );
         }
     }
-    catch( Exception& e )
+    catch( Exception& )
     {
-        (void)e;
         OSL_FAIL("sdr::table::SvxTableController::findMergeOrigin(), exception caught!" );
     }
 }
@@ -1775,13 +1749,6 @@ bool SvxTableController::StopTextEdit()
 
 // --------------------------------------------------------------------
 
-void SvxTableController::DeleteTable()
-{
-    //
-}
-
-// --------------------------------------------------------------------
-
 void SvxTableController::getSelectedCells( CellPos& rFirst, CellPos& rLast )
 {
     if( mbCellSelectionMode )
@@ -1968,15 +1935,15 @@ void SvxTableController::updateSelectionOverlay()
                 SdrPaintWindow* pPaintWindow = mpView->GetPaintWindow(nIndex);
                 if( pPaintWindow )
                 {
-                    ::sdr::overlay::OverlayManager* pOverlayManager = pPaintWindow->GetOverlayManager();
-                    if( pOverlayManager )
+                    rtl::Reference < ::sdr::overlay::OverlayManager > xOverlayManager = pPaintWindow->GetOverlayManager();
+                    if( xOverlayManager.is() )
                     {
                         // sdr::overlay::CellOverlayType eType = sdr::overlay::CELL_OVERLAY_INVERT;
                         sdr::overlay::CellOverlayType eType = sdr::overlay::CELL_OVERLAY_TRANSPARENT;
 
                         sdr::overlay::OverlayObjectCell* pOverlay = new sdr::overlay::OverlayObjectCell( eType, aHighlight, aRanges );
 
-                        pOverlayManager->add(*pOverlay);
+                        xOverlayManager->add(*pOverlay);
                         mpSelectionOverlay = new ::sdr::overlay::OverlayObjectList;
                         mpSelectionOverlay->append(*pOverlay);
                     }
@@ -2595,7 +2562,7 @@ bool SvxTableController::ApplyFormatPaintBrush( SfxItemSet& rFormatSet, bool bNo
 
 // --------------------------------------------------------------------
 
-IMPL_LINK( SvxTableController, UpdateHdl, void *, EMPTYARG )
+IMPL_LINK_NOARG(SvxTableController, UpdateHdl)
 {
     mnUpdateEvent = 0;
 
