@@ -39,7 +39,6 @@
 #include <svx/dialogs.hrc>
 #include <svx/svdview.hxx>
 #include <svx/sdasitm.hxx>
-#include <svx/svdoashp.hxx>
 #include <com/sun/star/drawing/EnhancedCustomShapeAdjustmentValue.hpp>
 #include <sfx2/bindings.hxx>
 #include <editeng/eeitem.hxx>
@@ -160,7 +159,7 @@ void SetFontWorkShapeTypeState( SdrView* pSdrView, SfxItemSet& rSet )
                 rtl::OUString aType;
                 if ( *pAny >>= aType )
                 {
-                    if ( aFontWorkShapeType.getLength() )
+                    if ( !aFontWorkShapeType.isEmpty() )
                     {
                         if ( !aFontWorkShapeType.equals( aType ) )  // different FontWorkShapeTypes selected ?
                         {
@@ -183,8 +182,6 @@ void SetFontWorkShapeTypeState( SdrView* pSdrView, SfxItemSet& rSet )
 |*
 \************************************************************************/
 
-#define ShellClass FontworkBar
-
 SFX_SLOTMAP(FontworkBar)
 {
     { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }
@@ -477,7 +474,7 @@ void FontworkBar::execute( SdrView* pSdrView, SfxRequest& rReq, SfxBindings& rBi
                 const SfxStringItem& rItm = (const SfxStringItem&)pArgs->Get( rReq.GetSlot() );
                 aCustomShape = rItm.GetValue();
             }
-            if ( aCustomShape.getLength() )
+            if ( !aCustomShape.isEmpty() )
             {
                 const SdrMarkList& rMarkList = pSdrView->GetMarkedObjectList();
                 sal_uInt32 nCount = rMarkList.GetMarkCount(), i;
@@ -586,12 +583,6 @@ void FontworkBar::getState( SdrView* pSdrView, SfxItemSet& rSet )
 {
     sal_uInt32 nCheckStatus = 0;
 
-    /*
-    if ( rSet.GetItemState( SID_FONTWORK_SHAPE ) != SFX_ITEM_UNKNOWN )
-    {
-        sal_Bool bBreak = sal_True;
-    }
-    */
     if ( rSet.GetItemState( SID_FONTWORK_ALIGNMENT_FLOATER ) != SFX_ITEM_UNKNOWN )
     {
         if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
