@@ -84,10 +84,9 @@ String Ww1PlainText::GetText( sal_uLong ulOffset, sal_uLong nLen ) const
     sal_Size nPos = ulFilePos+ulOffset;
 
     bool bSeekOk = rFib.GetStream().Seek(nPos) == nPos;
-    rtl::OString a8BitStr = bSeekOk ?
-        read_uInt8s_AsOString(rFib.GetStream(), nLen) :
-        rtl::OString();
-    return rtl::OStringToOUString(a8BitStr, RTL_TEXTENCODING_MS_1252);
+    return bSeekOk ?
+        read_uInt8s_ToOUString(rFib.GetStream(), nLen, RTL_TEXTENCODING_MS_1252) :
+        rtl::OUString();
 }
 
 ///////////////////////////////////////////////////////////////// Style
@@ -160,7 +159,7 @@ sal_uInt16 Ww1Style::ReadName( sal_uInt8*&p, sal_uInt16& rnCountBytes, sal_uInt1
         size_t nSize(stc);
         if (!nSize)
             pStr = "W1 Normal";
-        else if (nSize - 222 >= sizeof(names) / sizeof(*names))
+        else if (nSize - 222 >= SAL_N_ELEMENTS(names))
             pStr = "?";
         else
             pStr = names[nSize-222];
@@ -590,15 +589,15 @@ sal_Bool Ww1Sprm::ReCalc()
 
 void Ww1Sprm::DeinitTab()
 {
-    for (size_t i=0; i < sizeof(aTab)/sizeof(*aTab); ++i)
+    for (size_t i=0; i < SAL_N_ELEMENTS(aTab); ++i)
         delete aTab[i];
-    memset(aTab, 0, sizeof(aTab)/sizeof(*aTab));
+    memset(aTab, 0, SAL_N_ELEMENTS(aTab));
     delete pSingleSprm;
 }
 
 void Ww1Sprm::InitTab()
 {
-    memset(aTab, 0, sizeof(aTab)/sizeof(*aTab));
+    memset(aTab, 0, SAL_N_ELEMENTS(aTab));
     pSingleSprm = new Ww1SingleSprm( 0, DUMPNAME(pUnknown));
 
     aTab[  2] = new Ww1SingleSprmByte(DUMPNAME("sprmPStc")); //   2 pap.istd (style code)
