@@ -58,7 +58,6 @@
 #include <svx/xmlgrhlp.hxx>
 #include <svx/xmleohlp.hxx>
 #include <sfx2/printer.hxx>
-#include <ForbiddenCharactersEnum.hxx>
 #include <xmloff/xmluconv.hxx>
 #include <unotools/saveopt.hxx>
 #include <tools/diagnose_ex.h>
@@ -1062,37 +1061,37 @@ void SwXMLImport::SetViewSettings(const Sequence < PropertyValue > & aViewProps)
 
     for (sal_Int32 i = 0; i < nCount ; i++)
     {
-        if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "ViewAreaTop" ) ) )
+        if ( pValue->Name == "ViewAreaTop" )
         {
             pValue->Value >>= nTmp;
             aRect.setY( static_cast< long >(bTwip ? MM100_TO_TWIP ( nTmp ) : nTmp) );
         }
-        else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "ViewAreaLeft" ) ) )
+        else if ( pValue->Name == "ViewAreaLeft" )
         {
             pValue->Value >>= nTmp;
             aRect.setX( static_cast< long >(bTwip ? MM100_TO_TWIP ( nTmp ) : nTmp) );
         }
-        else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "ViewAreaWidth" ) ) )
+        else if ( pValue->Name == "ViewAreaWidth" )
         {
             pValue->Value >>= nTmp;
             Size aSize( aRect.GetSize() );
             aSize.Width() = static_cast< long >(bTwip ? MM100_TO_TWIP ( nTmp ) : nTmp);
             aRect.SetSize( aSize );
         }
-        else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "ViewAreaHeight" ) ) )
+        else if ( pValue->Name == "ViewAreaHeight" )
         {
             pValue->Value >>= nTmp;
             Size aSize( aRect.GetSize() );
             aSize.Height() = static_cast< long >(bTwip ? MM100_TO_TWIP ( nTmp ) : nTmp);
             aRect.SetSize( aSize );
         }
-        else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "ShowRedlineChanges" ) ) )
+        else if ( pValue->Name == "ShowRedlineChanges" )
         {
             bShowRedlineChanges = *(sal_Bool *)(pValue->Value.getValue());
             bChangeShowRedline = sal_True;
         }
 // Headers and footers are not displayed in BrowseView anymore
-        else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "InBrowseMode" ) ) )
+        else if ( pValue->Name == "InBrowseMode" )
         {
             bBrowseMode = *(sal_Bool *)(pValue->Value.getValue());
             bChangeBrowseMode = sal_True;
@@ -1234,45 +1233,45 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
                 }
 
                 // did we find any of the non-default cases?
-                if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("PrinterIndependentLayout")) )
+                if ( pValues->Name == "PrinterIndependentLayout" )
                     bPrinterIndependentLayout = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("AddExternalLeading")) )
+                else if ( pValues->Name == "AddExternalLeading" )
                     bAddExternalLeading = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("AddParaSpacingToTableCells")) )
+                else if ( pValues->Name == "AddParaSpacingToTableCells" )
                     bAddParaSpacingToTableCells = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UseFormerLineSpacing")) )
+                else if ( pValues->Name == "UseFormerLineSpacing" )
                     bUseFormerLineSpacing = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UseFormerObjectPositioning")) )
+                else if ( pValues->Name == "UseFormerObjectPositioning" )
                     bUseFormerObjectPositioning = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UseFormerTextWrapping")) )
+                else if ( pValues->Name == "UseFormerTextWrapping" )
                     bUseFormerTextWrapping = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UseOldNumbering")) )
+                else if ( pValues->Name == "UseOldNumbering" )
                     bUseOldNumbering = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("OutlineLevelYieldsNumbering")) )
+                else if ( pValues->Name == "OutlineLevelYieldsNumbering" )
                     bOutlineLevelYieldsOutlineRule = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("ConsiderTextWrapOnObjPos")) )
+                else if ( pValues->Name == "ConsiderTextWrapOnObjPos" )
                     bConsiderWrapOnObjPos = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("IgnoreFirstLineIndentInNumbering")) )
+                else if ( pValues->Name == "IgnoreFirstLineIndentInNumbering" )
                     bIgnoreFirstLineIndentInNumbering = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("DoNotJustifyLinesWithManualBreak")) )
+                else if ( pValues->Name == "DoNotJustifyLinesWithManualBreak" )
                     bDoNotJustifyLinesWithManualBreak = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("DoNotResetParaAttrsForNumFont")) )
+                else if ( pValues->Name == "DoNotResetParaAttrsForNumFont" )
                     bDoNotResetParaAttrsForNumFont = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("LoadReadonly")) )
+                else if ( pValues->Name == "LoadReadonly" )
                     bLoadReadonly = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("DoNotCaptureDrawObjsOnPage")) )
+                else if ( pValues->Name == "DoNotCaptureDrawObjsOnPage" )
                     bDoNotCaptureDrawObjsOnPage = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("ClipAsCharacterAnchoredWriterFlyFrames")) )
+                else if ( pValues->Name == "ClipAsCharacterAnchoredWriterFlyFrames" )
                     bClipAsCharacterAnchoredWriterFlyFrames = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UnxForceZeroExtLeading")) )
+                else if ( pValues->Name == "UnxForceZeroExtLeading" )
                     bUnixForceZeroExtLeading = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UseOldPrinterMetrics")) )
+                else if ( pValues->Name == "UseOldPrinterMetrics" )
                     bUseOldPrinterMetrics = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("SmallCapsPercentage66")) )
+                else if ( pValues->Name == "SmallCapsPercentage66" )
                     bSmallCapsPercentage66 = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("TabOverflow")) )
+                else if ( pValues->Name == "TabOverflow" )
                     bTabOverflow = true;
-                else if( pValues->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UnbreakableNumberings")) )
+                else if ( pValues->Name == "UnbreakableNumberings" )
                     bUnbreakableNumberings = true;
             }
             catch( Exception& )
