@@ -1230,7 +1230,7 @@ uno::Reference< frame::XController >
     return aRet;
 }
 
-static const char* pEventNames[] =
+static const char* s_EventNames[] =
 {
     "OnPageCountChange",
     "OnMailMerge",
@@ -1239,6 +1239,7 @@ static const char* pEventNames[] =
     "OnFieldMergeFinished",
     "OnLayoutFinished"
 };
+static sal_Int32 const s_nEvents(sizeof(s_EventNames)/sizeof(s_EventNames[0]));
 
 Sequence< OUString >    SwDocShell::GetEventNames()
 {
@@ -1256,12 +1257,12 @@ Sequence< OUString >    SwDocShell::GetEventNames()
     return aRet;
 }
 
-static sal_Int32 nEvents=13;
-
 rtl::OUString SwDocShell::GetEventName( sal_Int32 nIndex )
 {
-    if ( nIndex<nEvents )
-        return ::rtl::OUString::createFromAscii(pEventNames[nIndex]);
+    if (nIndex < s_nEvents)
+    {
+        return ::rtl::OUString::createFromAscii(s_EventNames[nIndex]);
+    }
     return rtl::OUString();
 }
 
