@@ -224,7 +224,7 @@ sal_uInt16 AbstractSwBreakDlg_Impl:: GetPageNumber()
 }
 
 void AbstractSwConvertTableDlg_Impl::GetValues( sal_Unicode& rDelim,SwInsertTableOptions& rInsTblFlags,
-                                                SwTableAutoFmt *& prTAFmt )
+                                                SwTableAutoFmt const*& prTAFmt)
 {
     pDlg->GetValues(rDelim,rInsTblFlags, prTAFmt);
 }
@@ -372,8 +372,8 @@ void AbstractSwRenameXNamedDlg_Impl::SetForbiddenChars( const String& rSet )
 }
 
 void    AbstractSwRenameXNamedDlg_Impl::SetAlternativeAccess(
-             STAR_REFERENCE( container::XNameAccess ) & xSecond,
-             STAR_REFERENCE( container::XNameAccess ) & xThird )
+             ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & xSecond,
+             ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & xThird )
 {
     pDlg->SetAlternativeAccess( xSecond, xThird);
 }
@@ -1114,8 +1114,8 @@ SfxAbstractDialog*   SwAbstractDialogFactory_Impl::CreateSwFldEditDlg ( SwView&
 }
 
 AbstractSwRenameXNamedDlg * SwAbstractDialogFactory_Impl::CreateSwRenameXNamedDlg( Window* pParent,
-                                                                STAR_REFERENCE( container::XNamed ) & xNamed,
-                                                                STAR_REFERENCE( container::XNameAccess ) & xNameAccess,int nResId )
+                                                                ::com::sun::star::uno::Reference< ::com::sun::star::container::XNamed > & xNamed,
+                                                                ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & xNameAccess,int nResId )
 {
     SwRenameXNamedDlg* pDlg=NULL;
     switch ( nResId )
@@ -1612,6 +1612,7 @@ GlossarySetActGroup SwAbstractDialogFactory_Impl::SetGlossaryActGroupFunc( sal_u
     return 0;
 }
 
+
 //------------------ Factories for TabPages
 CreateTabPage SwAbstractDialogFactory_Impl::GetTabPageCreatorFunc( sal_uInt16 nId )
 {
@@ -1671,6 +1672,10 @@ CreateTabPage SwAbstractDialogFactory_Impl::GetTabPageCreatorFunc( sal_uInt16 nI
         case RID_SW_TP_MAILCONFIG:
             pRet = SwMailConfigPage::Create;
         break;
+        case RID_SW_TP_COMPARISON_OPT :
+        case TP_COMPARISON_OPT :
+            pRet = SwCompareOptionsTabPage::Create;
+        break;
     }
 
     return pRet;
