@@ -192,7 +192,7 @@ void SwFldVarPage::Reset(const SfxItemSet& )
     }
 }
 
-IMPL_LINK( SwFldVarPage, TypeHdl, ListBox *, EMPTYARG )
+IMPL_LINK_NOARG(SwFldVarPage, TypeHdl)
 {
     // save old ListBoxPos
     const sal_uInt16 nOld = GetTypeSel();
@@ -602,18 +602,18 @@ void SwFldVarPage::UpdateSubType()
     aSelectionLB.SetUpdateMode(sal_False);
     aSelectionLB.Clear();
 
-    SvStringsDtor aList;
+    std::vector<rtl::OUString> aList;
     GetFldMgr().GetSubTypes(nTypeId, aList);
-    sal_uInt16 nCount = aList.Count();
-    sal_uInt16 nPos;
+    size_t nCount = aList.size();
+    size_t nPos;
 
-    for (sal_uInt16 i = 0; i < nCount; ++i)
+    for(size_t i = 0; i < nCount; ++i)
     {
         if (nTypeId != TYP_INPUTFLD || i)
         {
             if (!IsFldEdit())
             {
-                nPos = aSelectionLB.InsertEntry(*aList[i]);
+                nPos = aSelectionLB.InsertEntry(aList[i]);
                 aSelectionLB.SetEntryData(nPos, reinterpret_cast<void*>(i));
             }
             else
@@ -623,7 +623,7 @@ void SwFldVarPage::UpdateSubType()
                 switch (nTypeId)
                 {
                     case TYP_INPUTFLD:
-                        if (*aList[i] == GetCurField()->GetPar1())
+                        if (aList[i] == GetCurField()->GetPar1())
                             bInsert = sal_True;
                         break;
 
@@ -632,13 +632,13 @@ void SwFldVarPage::UpdateSubType()
                         break;
 
                     case TYP_GETFLD:
-                        if (*aList[i] == ((SwFormulaField*)GetCurField())->GetFormula())
+                        if (aList[i].equals(((const SwFormulaField*)GetCurField())->GetFormula()))
                             bInsert = sal_True;
                         break;
 
                     case TYP_SETFLD:
                     case TYP_USERFLD:
-                        if (*aList[i] == GetCurField()->GetTyp()->GetName())
+                        if (aList[i] == GetCurField()->GetTyp()->GetName())
                         {
                             bInsert = sal_True;
                             if (GetCurField()->GetSubType() & nsSwExtendedSubType::SUB_INVISIBLE)
@@ -649,21 +649,21 @@ void SwFldVarPage::UpdateSubType()
                     case TYP_SETREFPAGEFLD:
                         if ((((SwRefPageSetField*)GetCurField())->IsOn() && i) ||
                             (!((SwRefPageSetField*)GetCurField())->IsOn() && !i))
-                            sOldSel = *aList[i];
+                            sOldSel = aList[i];
 
                         // allow all entries for selection:
-                        nPos = aSelectionLB.InsertEntry(*aList[i]);
+                        nPos = aSelectionLB.InsertEntry(aList[i]);
                         aSelectionLB.SetEntryData(nPos, reinterpret_cast<void*>(i));
                         break;
 
                     default:
-                        if (*aList[i] == GetCurField()->GetPar1())
+                        if (aList[i] == GetCurField()->GetPar1())
                             bInsert = sal_True;
                         break;
                 }
                 if (bInsert)
                 {
-                    nPos = aSelectionLB.InsertEntry(*aList[i]);
+                    nPos = aSelectionLB.InsertEntry(aList[i]);
                     aSelectionLB.SetEntryData(nPos, reinterpret_cast<void*>(i));
                     if (nTypeId != TYP_FORMELFLD)
                         break;
@@ -824,7 +824,7 @@ sal_uInt16 SwFldVarPage::FillFormatLB(sal_uInt16 nTypeId)
 /*--------------------------------------------------------------------
     Description: Modify
  --------------------------------------------------------------------*/
-IMPL_LINK( SwFldVarPage, ModifyHdl, Edit *, EMPTYARG )
+IMPL_LINK_NOARG(SwFldVarPage, ModifyHdl)
 {
     String sValue(aValueED.GetText());
     sal_Bool bHasValue = sValue.Len() != 0;
@@ -1098,7 +1098,7 @@ IMPL_LINK( SwFldVarPage, TBClickHdl, ToolBox *, pBox )
     return sal_True;
 }
 
-IMPL_LINK( SwFldVarPage, ChapterHdl, ListBox *, EMPTYARG )
+IMPL_LINK_NOARG(SwFldVarPage, ChapterHdl)
 {
     sal_Bool bEnable = aChapterLevelLB.GetSelectEntryPos() != 0;
 
@@ -1109,7 +1109,7 @@ IMPL_LINK( SwFldVarPage, ChapterHdl, ListBox *, EMPTYARG )
     return 0;
 }
 
-IMPL_LINK( SwFldVarPage, SeparatorHdl, Edit *, EMPTYARG )
+IMPL_LINK_NOARG(SwFldVarPage, SeparatorHdl)
 {
     sal_Bool bEnable = aSeparatorED.GetText().Len() != 0 ||
                     aChapterLevelLB.GetSelectEntryPos() == 0;
@@ -1167,7 +1167,7 @@ sal_Bool SwFldVarPage::FillItemSet(SfxItemSet& )
         {
             nSubType = (nFormat == ULONG_MAX) ? nsSwGetSetExpType::GSE_STRING : nsSwGetSetExpType::GSE_EXPR;
 
-            if (nFormat == ULONG_MAX && aNumFormatLB.GetSelectEntry() == SW_RESSTR(FMT_USERVAR_CMD))
+            if (nFormat == ULONG_MAX && aNumFormatLB.GetSelectEntry().Equals(SW_RESSTR(FMT_USERVAR_CMD)))
                 nSubType |= nsSwExtendedSubType::SUB_CMD;
 
             if (aInvisibleCB.IsChecked())
