@@ -30,12 +30,13 @@
 #include <string>
 #include <stdlib.h>
 #include <hintids.hxx>
+#include <comphelper/string.hxx>
+#include <officecfg/Office/Common.hxx>
 #include <rtl/logfile.hxx>
 #include <vcl/graph.hxx>
 #include <vcl/inputctx.hxx>
 #include <basic/sbxobj.hxx>
 #include <svl/eitem.hxx>
-#include <unotools/undoopt.hxx>
 #include <unotools/lingucfg.hxx>
 #include <unotools/useroptions.hxx>
 #include <sfx2/dispatch.hxx>
@@ -217,7 +218,7 @@ void SwView::GotFocus() const
     a request to put the form shell on the top of the dispatcher
     stack
  --------------------------------------------------------------------*/
-IMPL_LINK( SwView, FormControlActivated, FmFormShell*, EMPTYARG )
+IMPL_LINK_NOARG(SwView, FormControlActivated)
 {
     // if a form control has been activated, and the form shell is not on the top
     // of the dispatcher stack, then we need to activate it
@@ -488,7 +489,7 @@ extern "C"
     }
 }
 
-IMPL_LINK( SwView, AttrChangedNotify, SwWrtShell *, EMPTYARG )
+IMPL_LINK_NOARG(SwView, AttrChangedNotify)
 {
      if ( GetEditWin().IsChainMode() )
         GetEditWin().SetChainMode( sal_False );
@@ -537,7 +538,7 @@ IMPL_LINK( SwView, AttrChangedNotify, SwWrtShell *, EMPTYARG )
     return 0;
 }
 
-IMPL_LINK( SwView, TimeoutHdl, Timer *, EMPTYARG )
+IMPL_LINK_NOARG(SwView, TimeoutHdl)
 {
     DBG_PROFSTART(viewhdl);
 
@@ -945,7 +946,10 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         !pDocSh->GetVisArea(ASPECT_CONTENT).IsEmpty() )
         SetVisArea( pDocSh->GetVisArea(ASPECT_CONTENT),sal_False);
 
-    pWrtShell->DoUndo( 0 != SW_MOD()->GetUndoOptions().GetUndoCount() );
+    SAL_WARN_IF(
+        officecfg::Office::Common::Undo::Steps::get() <= 0,
+        "sw", "/org.openoffice.Office.Common/Undo/Steps <= 0");
+    pWrtShell->DoUndo( true );
 
     const sal_Bool bBrowse = pWrtShell->GetViewOptions()->getBrowseMode();
     // Disable "multiple window"
@@ -966,11 +970,14 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
 
     if( pWrtShell->GetDoc()->IsUpdateExpFld() )
     {
-        SET_CURR_SHELL( pWrtShell );
-        pWrtShell->StartAction();
-        pWrtShell->CalcLayout();
-        pWrtShell->GetDoc()->UpdateFlds(NULL, false);
-        pWrtShell->EndAction();
+        if (pWrtShell->GetDoc()->containsUpdatableFields())
+        {
+            SET_CURR_SHELL( pWrtShell );
+            pWrtShell->StartAction();
+            pWrtShell->CalcLayout();
+            pWrtShell->GetDoc()->UpdateFlds(NULL, false);
+            pWrtShell->EndAction();
+        }
         pWrtShell->GetDoc()->SetUpdateExpFldStat( sal_False );
     }
 
@@ -1115,9 +1122,9 @@ void SwView::WriteUserData( String &rUserData, sal_Bool bBrowse )
     rUserData += ';';
     rUserData += String::CreateFromInt32( rVis.Top() );
     rUserData += ';';
-    rUserData += String::CreateFromInt32( bBrowse ? LONG_MIN : rVis.Right());
+    rUserData += String::CreateFromInt32( bBrowse ? SAL_MIN_INT32 : rVis.Right());
     rUserData += ';';
-    rUserData += String::CreateFromInt32( bBrowse ? LONG_MIN : rVis.Bottom());
+    rUserData += String::CreateFromInt32( bBrowse ? SAL_MIN_INT32 : rVis.Bottom());
     rUserData += ';';
     rUserData += String::CreateFromInt32(
             (sal_uInt16)pWrtShell->GetViewOptions()->GetZoomType());//eZoom;
@@ -1144,7 +1151,7 @@ bool lcl_IsOwnDocument( SwView& rView )
 
 void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
 {
-    if ( rUserData.GetTokenCount() > 1 &&
+    if ( comphelper::string::getTokenCount(rUserData, ';') > 1 &&
         //Fuer Dokumente ohne Layout nur im OnlineLayout oder beim
         //Forward/Backward
          (!pWrtShell->IsNewLayout() || pWrtShell->GetViewOptions()->getBrowseMode() || bBrowse) )
@@ -1290,61 +1297,61 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
 
         for (sal_Int16 i = 0 ; i < nLength; i++)
         {
-            if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ViewLeft" ) ) )
+            if ( pValue->Name == "ViewLeft" )
             {
                pValue->Value >>= nX;
                nX = MM100_TO_TWIP( nX );
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ViewTop" ) ) )
+            else if ( pValue->Name == "ViewTop" )
             {
                pValue->Value >>= nY;
                nY = MM100_TO_TWIP( nY );
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "VisibleLeft" ) ) )
+            else if ( pValue->Name == "VisibleLeft" )
             {
                pValue->Value >>= nLeft;
                nLeft = MM100_TO_TWIP( nLeft );
                bGotVisibleLeft = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "VisibleTop" ) ) )
+            else if ( pValue->Name == "VisibleTop" )
             {
                pValue->Value >>= nTop;
                nTop = MM100_TO_TWIP( nTop );
                bGotVisibleTop = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "VisibleRight" ) ) )
+            else if ( pValue->Name == "VisibleRight" )
             {
                pValue->Value >>= nRight;
                nRight = MM100_TO_TWIP( nRight );
                bGotVisibleRight = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "VisibleBottom" ) ) )
+            else if ( pValue->Name == "VisibleBottom" )
             {
                pValue->Value >>= nBottom;
                nBottom = MM100_TO_TWIP( nBottom );
                bGotVisibleBottom = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ZoomType" ) ) )
+            else if ( pValue->Name == "ZoomType" )
             {
                pValue->Value >>= nZoomType;
                bGotZoomType = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ZoomFactor" ) ) )
+            else if ( pValue->Name == "ZoomFactor" )
             {
                pValue->Value >>= nZoomFactor;
                bGotZoomFactor = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ViewLayoutColumns" ) ) )
+            else if ( pValue->Name == "ViewLayoutColumns" )
             {
                pValue->Value >>= nViewLayoutColumns;
                bGotViewLayoutColumns = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ViewLayoutBookMode" ) ) )
+            else if ( pValue->Name == "ViewLayoutBookMode" )
             {
                bViewLayoutBookMode = * (sal_Bool *) pValue->Value.getValue();
                bGotViewLayoutBookMode = sal_True;
             }
-            else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "IsSelectedFrame" ) ) )
+            else if ( pValue->Name == "IsSelectedFrame" )
             {
                pValue->Value >>= bSelectedFrame;
                bGotIsSelectedFrame = sal_True;
