@@ -40,17 +40,13 @@
 #include "wntmsc.hxx"
 #include <tools/errinf.hxx>
 #include <tools/debug.hxx>
-#include <tools/wldcrd.hxx>
 #include <tools/fsys.hxx>
-#include <tools/bigint.hxx>
 #include <vector>
 
+#define INIT_WIN32_FIND_DATAA { 0, { 0, 0 }, { 0, 0 }, { 0, 0 }, 0, 0, 0, 0, { 0 }, { 0 } }
+
 int Sys2SolarError_Impl( int nSysErr );
 
-static sal_Bool   bLastCaseSensitive    = sal_False;
-
-//--------------------------------------------------------------------
-
 rtl::OString Upper_Impl(const rtl::OString &rStr)
 {
     std::vector<sal_Char> aBuffer(rStr.getLength());
@@ -155,13 +151,13 @@ String DirEntry::GetVolume() const
 
     String aRet;
     const DirEntry *pTop = ImpGetTopPtr();
-    rtl::OString aName = rtl::OString(pTop->aName).toAsciiLowerCase();
+    rtl::OString aTopName = rtl::OString(pTop->aName).toAsciiLowerCase();
 
     if ( ( pTop->eFlag == FSYS_FLAG_ABSROOT ||
            pTop->eFlag == FSYS_FLAG_RELROOT ||
            pTop->eFlag == FSYS_FLAG_VOLUME )
-         && !aName.equalsL(RTL_CONSTASCII_STRINGPARAM("a:"))
-         && !aName.equalsL(RTL_CONSTASCII_STRINGPARAM("b:")) && Exists() )
+         && !aTopName.equalsL(RTL_CONSTASCII_STRINGPARAM("a:"))
+         && !aTopName.equalsL(RTL_CONSTASCII_STRINGPARAM("b:")) && Exists() )
     {
         char sFileSysName[256];
         char sVolumeName[256];
@@ -240,7 +236,7 @@ USHORT DirReader_Impl::Init()
         {
             sDrive[0] = c;
             sRoot[0] = c;
-            DirEntry* pDrive = new DirEntry( sDrive, FSYS_FLAG_VOLUME, FSYS_STYLE_HOST );
+            DirEntry* pDrive = new DirEntry( sDrive, FSYS_FLAG_VOLUME );
             if ( pDir->aNameMask.Matches( String(rtl::OStringToOUString(sDrive, osl_getThreadTextEncoding())) ) && GetDriveType( sRoot ) != 1 )
             {
                 if ( pDir->pStatLst ) //Status fuer Sort gewuenscht?
@@ -315,15 +311,15 @@ USHORT DirReader_Impl::Read()
                 :   0 == strcmp( pDosEntry->d_name, ".." ) ? FSYS_FLAG_PARENT
                 :   FSYS_FLAG_NORMAL;
             DirEntry *pTemp = new DirEntry( rtl::OString(pDosEntry->d_name),
-                                            eFlag, FSYS_STYLE_NTFS );
+                                            eFlag );
 #ifdef FEAT_FSYS_DOUBLESPEED
-            pTemp->ImpSetStat( new FileStat( (void*) pDosDir, (void*) 0 ) );
+            pTemp->ImpSetStat( new FileStat( (void*) pDosDir ) );
 #endif
             if ( pParent )
                 pTemp->ImpChangeParent( new DirEntry( *pParent ), sal_False );
             if ( pDir->pStatLst ) //Status fuer Sort gewuenscht?
             {
-                FileStat *pNewStat = new FileStat( (void*) pDosDir, (void*) 0 );
+                FileStat *pNewStat = new FileStat( (void*) pDosDir );
                 pDir->ImpSortedInsert( pTemp, pNewStat );
             }
             else
@@ -406,8 +402,7 @@ void FileStat::ImpInit( void* p )
 |*
 *************************************************************************/
 
-FileStat::FileStat( const void *pInfo,      // struct dirent
-                    const void * ):         // dummy
+FileStat::FileStat( const void *pInfo ): // struct dirent
     aDateCreated(0),
     aTimeCreated(0),
     aDateModified(0),
@@ -669,9 +664,6 @@ sal_Bool FileStat::Update( const DirEntry& rDirEntry, sal_Bool bForceAccess )
 
         // Redirect
         String aPath( rDirEntry.GetFull() );
-#ifndef BOOTSTRAP
-        FSysRedirector::DoRedirect( aPath );
-#endif
         DirEntry aDirEntry( aPath );
 
         // ist ein Medium im Laufwerk?
@@ -683,11 +675,13 @@ sal_Bool FileStat::Update( const DirEntry& rDirEntry, sal_Bool bForceAccess )
                 ( pTop->eFlag == FSYS_FLAG_ABSROOT ||
                 pTop->eFlag == FSYS_FLAG_RELROOT ||
                 pTop->eFlag == FSYS_FLAG_VOLUME ) )
+        {
             if ( aName.equalsL(RTL_CONSTASCII_STRINGPARAM("a:")) ||
                  aName.equalsL(RTL_CONSTASCII_STRINGPARAM("b:")) )
                 bAccess = sal_False;
             else
                 OSL_TRACE( "FSys: will access removable device!" );
+        }
         if ( bAccess && ( aName.equalsL(RTL_CONSTASCII_STRINGPARAM("a:")) ||
                           aName.equalsL(RTL_CONSTASCII_STRINGPARAM("b:")) ) )
         {
@@ -740,7 +734,7 @@ sal_Bool FileStat::Update( const DirEntry& rDirEntry, sal_Bool bForceAccess )
 
         // Statusinformation vom Betriebssystem holen
         HANDLE h; //()
-        _WIN32_FIND_DATAA aEntry = {};
+        _WIN32_FIND_DATAA aEntry = INIT_WIN32_FIND_DATAA;
         DirEntry aAbsEntry( aDirEntry );
         if ( bAccess && aAbsEntry.ToAbs() )
         {
@@ -777,9 +771,9 @@ sal_Bool FileStat::Update( const DirEntry& rDirEntry, sal_Bool bForceAccess )
                 }
 
                 // UNC-Volume?
-                DirEntry *pTop = aAbsEntry.ImpGetTopPtr();
-                if ( pTop->GetFlag() == FSYS_FLAG_ABSROOT &&
-                     ( pTop->aName.getLength() > 1 && (pTop->aName[1] != ':' )) )
+                DirEntry *pTop2 = aAbsEntry.ImpGetTopPtr();
+                if ( pTop2->GetFlag() == FSYS_FLAG_ABSROOT &&
+                     ( pTop2->aName.getLength() > 1 && (pTop2->aName[1] != ':' )) )
                 {
                     if ( bForceAccess )
                     {
