@@ -860,7 +860,7 @@ void SAL_CALL Moderator::run()
         nIOErrorCode = r.Code;
         aResultType = INTERACTIVEIO;
     }
-    catch (const UnsupportedDataSinkException )
+    catch (const UnsupportedDataSinkException &)
     {
         aResultType = UNSUPPORTED;
     }
@@ -920,7 +920,7 @@ static sal_Bool UCBOpenContentSync(
     if(xContId.is())
         aScheme = xContId->getContentProviderScheme();
 
-    // now determine wether we use a timeout or not;
+    // now determine whether we use a timeout or not;
     if( ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("http"))                &&
         ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("https"))               &&
         ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("vnd.sun.star.webdav")) &&
@@ -1027,9 +1027,7 @@ static sal_Bool UCBOpenContentSync(
                     aExcep.Server = aURL.GetHost();
                     aExcep.Classification = InteractionClassification_ERROR;
                     aExcep.Message =
-                        rtl::OUString(
-                            RTL_CONSTASCII_USTRINGPARAM(
-                                "server not responding after five seconds"));
+                        rtl::OUString( "server not responding after five seconds");
                     Any request;
                     request <<= aExcep;
                     ucbhelper::InteractionRequest *ir =
@@ -1335,7 +1333,7 @@ sal_Bool UcbLockBytes::setInputStream_Impl( const Reference<XInputStream> &rxInp
             {
                 Reference < XMultiServiceFactory > xFactory = ::comphelper::getProcessServiceFactory();
                 Reference< XOutputStream > rxTempOut = Reference < XOutputStream > (
-                                    xFactory->createInstance ( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.io.TempFile")) ),
+                                    xFactory->createInstance ( ::rtl::OUString("com.sun.star.io.TempFile") ),
                                     UNO_QUERY );
 
                 if( rxTempOut.is() )
@@ -1591,7 +1589,7 @@ void UcbLockBytes::Cancel()
 }
 
 //----------------------------------------------------------------------------
-IMPL_LINK( UcbLockBytes, DataAvailHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG(UcbLockBytes, DataAvailHdl)
 {
     if ( hasInputStream_Impl() && m_xHandler.Is() )
         m_xHandler->Handle( UcbLockBytesHandler::DATA_AVAILABLE, this );
@@ -1602,7 +1600,7 @@ IMPL_LINK( UcbLockBytes, DataAvailHdl, void*, EMPTYARG )
 UcbLockBytesRef UcbLockBytes::CreateInputLockBytes( const Reference< XInputStream >& xInputStream )
 {
     if( !xInputStream.is() )
-        return NULL;;
+        return NULL;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes();
     xLockBytes->setDontClose_Impl();
@@ -1614,7 +1612,7 @@ UcbLockBytesRef UcbLockBytes::CreateInputLockBytes( const Reference< XInputStrea
 UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference< XStream >& xStream )
 {
     if( !xStream.is() )
-        return NULL;;
+        return NULL;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes();
     xLockBytes->setDontClose_Impl();
@@ -1627,7 +1625,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
         const Reference < XInputStream >& xPostData, const Reference < XInteractionHandler >& xInteractionHandler, UcbLockBytesHandler* pHandler )
 {
     if( !xContent.is() )
-        return NULL;;
+        return NULL;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes( pHandler );
     xLockBytes->SetSynchronMode( !pHandler );
@@ -1666,7 +1664,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
         StreamMode eOpenMode, const Reference < XInteractionHandler >& xInteractionHandler, UcbLockBytesHandler* pHandler )
 {
     if( !xContent.is() )
-        return NULL;;
+        return NULL;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes( pHandler );
     xLockBytes->SetSynchronMode( !pHandler );
@@ -1680,7 +1678,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
     {
         Reference < XCommandProcessor > xProcessor( xContent, UNO_QUERY );
         Command aCommand;
-        aCommand.Name     = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("setPropertyValues"));
+        aCommand.Name     = ::rtl::OUString("setPropertyValues");
         aCommand.Handle   = -1; /* unknown */
         aCommand.Argument <<= rProps;
         xProcessor->execute( aCommand, 0, Reference < XCommandEnvironment >() );
@@ -1691,7 +1689,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
     aArgument.Mode = OpenMode::DOCUMENT;
 
     Command aCommand;
-    aCommand.Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("open") );
+    aCommand.Name = ::rtl::OUString( "open" );
     aCommand.Argument <<= aArgument;
 
     Reference< XProgressHandler > xProgressHdl = new ProgressHandler_Impl( LINK( &xLockBytes, UcbLockBytes, DataAvailHdl ) );
