@@ -56,6 +56,11 @@
 #include <ole2.h>   // for _beginthreadex
 #endif
 
+#ifdef ANDROID
+#include <cppuhelper/bootstrap.hxx>
+#include <jni.h>
+#endif
+
 // [ed 5/14/02 Add in explicit check for quartz graphics.  OS X will define
 // unx for both quartz and X11 graphics, but we include svunx.h only if we're
 // building X11 graphics layers.
@@ -244,7 +249,7 @@ uno::Any SAL_CALL DesktopEnvironmentContext::getValueByName( const rtl::OUString
 {
     uno::Any retVal;
 
-    if (Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("system.desktop-environment")))
+    if ( Name == "system.desktop-environment" )
     {
         retVal = uno::makeAny( Application::GetDesktopEnvironment() );
     }
@@ -327,6 +332,23 @@ sal_Bool InitVCL( const ::com::sun::star::uno::Reference< ::com::sun::star::lang
     return sal_True;
 }
 
+#ifdef ANDROID
+
+extern "C" __attribute__ ((visibility("default"))) void
+InitVCLWrapper()
+{
+    uno::Reference<uno::XComponentContext> xContext( cppu::defaultBootstrap_InitialComponentContext() );
+    uno::Reference<lang::XMultiComponentFactory> xFactory( xContext->getServiceManager() );
+
+    uno::Reference<lang::XMultiServiceFactory> xSM( xFactory, uno::UNO_QUERY_THROW );
+
+    comphelper::setProcessServiceFactory( xSM );
+
+    InitVCL( xSM );
+}
+
+#endif
+
 namespace
 {
 
@@ -489,10 +511,14 @@ void DeInitVCL()
     pSVData->maAppData.mxMSF.clear();
 
     if( pSVData->mpApp )
+    {
+        sal_uLong nCount = Application::ReleaseSolarMutex();
         // call deinit to deinitialize application class
         // soffice/sfx implementation disposes the global service manager
         // Warning: After this call you can't call uno services
         pSVData->mpApp->DeInit();
+        Application::AcquireSolarMutex(nCount);
+    }
 
     if ( pSVData->maAppData.mpSettings )
     {
