@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include <tools/debug.hxx>
 
 #include <vcl/bitmap.hxx>
@@ -51,10 +50,6 @@
 #include <region.h>
 #include <outdata.hxx>
 
-#define BAND_MAX_SIZE 512000
-
-// =======================================================================
-
 DBG_NAMEEX( OutputDevice )
 
 // =======================================================================
@@ -79,8 +74,6 @@ DBG_NAMEEX( OutputDevice )
         return;                             \
 }
 
-#define TwoRect     SalTwoRect
-
 // -------------
 // - externals -
 // -------------
@@ -93,7 +86,7 @@ extern sal_uLong nVCLLut[ 256 ];
 
 // =======================================================================
 
-sal_uLong ImplAdjustTwoRect( TwoRect& rTwoRect, const Size& rSizePix )
+sal_uLong ImplAdjustTwoRect( SalTwoRect& rTwoRect, const Size& rSizePix )
 {
     sal_uLong nMirrFlags = 0;
 
@@ -152,19 +145,69 @@ sal_uLong ImplAdjustTwoRect( TwoRect& rTwoRect, const Size& rSizePix )
 
 // =======================================================================
 
-void OutputDevice::ImplDrawOutDevDirect( const OutputDevice* pSrcDev, void* pVoidPosAry )
+void ImplAdjustTwoRect( SalTwoRect& rTwoRect, const Rectangle& rValidSrcRect )
 {
-    TwoRect*            pPosAry = (TwoRect*)pVoidPosAry;
-    SalGraphics*        pGraphics2;
-
-    if ( pPosAry->mnSrcWidth && pPosAry->mnSrcHeight && pPosAry->mnDestWidth && pPosAry->mnDestHeight )
+    if( ( rTwoRect.mnSrcX < rValidSrcRect.Left() ) || ( rTwoRect.mnSrcX >= rValidSrcRect.Right() ) ||
+        ( rTwoRect.mnSrcY < rValidSrcRect.Top() ) || ( rTwoRect.mnSrcY >= rValidSrcRect.Bottom() ) ||
+        ( ( rTwoRect.mnSrcX + rTwoRect.mnSrcWidth ) > rValidSrcRect.Right() ) ||
+        ( ( rTwoRect.mnSrcY + rTwoRect.mnSrcHeight ) > rValidSrcRect.Bottom() ) )
     {
-        if ( this == pSrcDev )
-            pGraphics2 = NULL;
+        const Rectangle aSourceRect( Point( rTwoRect.mnSrcX, rTwoRect.mnSrcY ),
+                                     Size( rTwoRect.mnSrcWidth, rTwoRect.mnSrcHeight ) );
+        Rectangle       aCropRect( aSourceRect );
+
+        aCropRect.Intersection( rValidSrcRect );
+
+        if( aCropRect.IsEmpty() )
+            rTwoRect.mnSrcWidth = rTwoRect.mnSrcHeight = rTwoRect.mnDestWidth = rTwoRect.mnDestHeight = 0;
         else
         {
-            if ( (GetOutDevType() != pSrcDev->GetOutDevType()) ||
-                 (GetOutDevType() != OUTDEV_WINDOW) )
+            const double    fFactorX = ( rTwoRect.mnSrcWidth > 1 ) ? (double) ( rTwoRect.mnDestWidth - 1 ) / ( rTwoRect.mnSrcWidth - 1 ) : 0.0;
+            const double    fFactorY = ( rTwoRect.mnSrcHeight > 1 ) ? (double) ( rTwoRect.mnDestHeight - 1 ) / ( rTwoRect.mnSrcHeight - 1 ) : 0.0;
+
+            const long nDstX1 = rTwoRect.mnDestX + FRound( fFactorX * ( aCropRect.Left() - rTwoRect.mnSrcX ) );
+            const long nDstY1 = rTwoRect.mnDestY + FRound( fFactorY * ( aCropRect.Top() - rTwoRect.mnSrcY ) );
+            const long nDstX2 = rTwoRect.mnDestX + FRound( fFactorX * ( aCropRect.Right() - rTwoRect.mnSrcX ) );
+            const long nDstY2 = rTwoRect.mnDestY + FRound( fFactorY * ( aCropRect.Bottom() - rTwoRect.mnSrcY ) );
+
+            rTwoRect.mnSrcX = aCropRect.Left();
+            rTwoRect.mnSrcY = aCropRect.Top();
+            rTwoRect.mnSrcWidth = aCropRect.GetWidth();
+            rTwoRect.mnSrcHeight = aCropRect.GetHeight();
+            rTwoRect.mnDestX = nDstX1;
+            rTwoRect.mnDestY = nDstY1;
+            rTwoRect.mnDestWidth = nDstX2 - nDstX1 + 1;
+            rTwoRect.mnDestHeight = nDstY2 - nDstY1 + 1;
+        }
+    }
+}
+
+// =======================================================================
+
+void OutputDevice::ImplDrawOutDevDirect( const OutputDevice* pSrcDev, void* pVoidPosAry )
+{
+    SalTwoRect*            pPosAry = (SalTwoRect*)pVoidPosAry;
+    SalGraphics*        pGraphics2;
+
+    if ( this == pSrcDev )
+        pGraphics2 = NULL;
+    else
+    {
+        if ( (GetOutDevType() != pSrcDev->GetOutDevType()) ||
+             (GetOutDevType() != OUTDEV_WINDOW) )
+        {
+            if ( !pSrcDev->mpGraphics )
+            {
+                if ( !((OutputDevice*)pSrcDev)->ImplGetGraphics() )
+                    return;
+            }
+            pGraphics2 = pSrcDev->mpGraphics;
+        }
+        else
+        {
+            if ( ((Window*)this)->mpWindowImpl->mpFrameWindow == ((Window*)pSrcDev)->mpWindowImpl->mpFrameWindow )
+                pGraphics2 = NULL;
+            else
             {
                 if ( !pSrcDev->mpGraphics )
                 {
@@ -172,68 +215,38 @@ void OutputDevice::ImplDrawOutDevDirect( const OutputDevice* pSrcDev, void* pVoi
                         return;
                 }
                 pGraphics2 = pSrcDev->mpGraphics;
-            }
-            else
-            {
-                if ( ((Window*)this)->mpWindowImpl->mpFrameWindow == ((Window*)pSrcDev)->mpWindowImpl->mpFrameWindow )
-                    pGraphics2 = NULL;
-                else
+
+                if ( !mpGraphics )
                 {
-                    if ( !pSrcDev->mpGraphics )
-                    {
-                        if ( !((OutputDevice*)pSrcDev)->ImplGetGraphics() )
-                            return;
-                    }
-                    pGraphics2 = pSrcDev->mpGraphics;
-
-                    if ( !mpGraphics )
-                    {
-                        if ( !ImplGetGraphics() )
-                            return;
-                    }
-                    DBG_ASSERT( mpGraphics && pSrcDev->mpGraphics,
-                                "OutputDevice::DrawOutDev(): We need more than one Graphics" );
+                    if ( !ImplGetGraphics() )
+                        return;
                 }
+                DBG_ASSERT( mpGraphics && pSrcDev->mpGraphics,
+                            "OutputDevice::DrawOutDev(): We need more than one Graphics" );
             }
         }
+    }
 
-        // #102532# Offset only has to be pseudo window offset
-        Rectangle   aSrcOutRect( Point( pSrcDev->mnOutOffX, pSrcDev->mnOutOffY ),
+    // #102532# Offset only has to be pseudo window offset
+    const Rectangle aSrcOutRect( Point( pSrcDev->mnOutOffX, pSrcDev->mnOutOffY ),
                                  Size( pSrcDev->mnOutWidth, pSrcDev->mnOutHeight ) );
-        Rectangle   aSrcRect( Point( pPosAry->mnSrcX, pPosAry->mnSrcY ),
-                              Size( pPosAry->mnSrcWidth, pPosAry->mnSrcHeight ) );
-        const long  nOldRight = aSrcRect.Right();
-        const long  nOldBottom = aSrcRect.Bottom();
 
-        if ( !aSrcRect.Intersection( aSrcOutRect ).IsEmpty() )
+    ImplAdjustTwoRect( *pPosAry, aSrcOutRect );
+
+    if ( pPosAry->mnSrcWidth && pPosAry->mnSrcHeight && pPosAry->mnDestWidth && pPosAry->mnDestHeight )
+    {
+        // --- RTL --- if this is no window, but pSrcDev is a window
+        // mirroring may be required
+        // because only windows have a SalGraphicsLayout
+        // mirroring is performed here
+        if( (GetOutDevType() != OUTDEV_WINDOW) && pGraphics2 && (pGraphics2->GetLayout() & SAL_LAYOUT_BIDI_RTL) )
         {
-            if ( (pPosAry->mnSrcX+pPosAry->mnSrcWidth-1) > aSrcOutRect.Right() )
-            {
-                const long nOldWidth = pPosAry->mnSrcWidth;
-                pPosAry->mnSrcWidth -= (nOldRight - aSrcRect.Right());
-                pPosAry->mnDestWidth = pPosAry->mnDestWidth * pPosAry->mnSrcWidth / nOldWidth;
-            }
-
-            if ( (pPosAry->mnSrcY+pPosAry->mnSrcHeight-1) > aSrcOutRect.Bottom() )
-            {
-                const long nOldHeight = pPosAry->mnSrcHeight;
-                pPosAry->mnSrcHeight -= (nOldBottom - aSrcRect.Bottom());
-                pPosAry->mnDestHeight = pPosAry->mnDestHeight * pPosAry->mnSrcHeight / nOldHeight;
-            }
-
-            // --- RTL --- if this is no window, but pSrcDev is a window
-            // mirroring may be required
-            // because only windows have a SalGraphicsLayout
-            // mirroring is performed here
-            if( (GetOutDevType() != OUTDEV_WINDOW) && pGraphics2 && (pGraphics2->GetLayout() & SAL_LAYOUT_BIDI_RTL) )
-            {
-                SalTwoRect pPosAry2 = *pPosAry;
-                pGraphics2->mirror( pPosAry2.mnSrcX, pPosAry2.mnSrcWidth, pSrcDev );
-                mpGraphics->CopyBits( &pPosAry2, pGraphics2, this, pSrcDev );
-            }
-            else
-                mpGraphics->CopyBits( pPosAry, pGraphics2, this, pSrcDev );
+            SalTwoRect pPosAry2 = *pPosAry;
+            pGraphics2->mirror( pPosAry2.mnSrcX, pPosAry2.mnSrcWidth, pSrcDev );
+            mpGraphics->CopyBits( &pPosAry2, pGraphics2, this, pSrcDev );
         }
+        else
+            mpGraphics->CopyBits( pPosAry, pGraphics2, this, pSrcDev );
     }
 }
 
@@ -266,7 +279,7 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
 
     OUTDEV_INIT();
 
-    TwoRect aPosAry;
+    SalTwoRect aPosAry;
     aPosAry.mnSrcWidth   = ImplLogicWidthToDevicePixel( rSrcSize.Width() );
     aPosAry.mnSrcHeight  = ImplLogicHeightToDevicePixel( rSrcSize.Height() );
     aPosAry.mnDestWidth  = ImplLogicWidthToDevicePixel( rDestSize.Width() );
@@ -279,31 +292,13 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
         aPosAry.mnDestX      = ImplLogicXToDevicePixel( rDestPt.X() );
         aPosAry.mnDestY      = ImplLogicYToDevicePixel( rDestPt.Y() );
 
-        Rectangle   aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
-                                 Size( mnOutWidth, mnOutHeight ) );
-        Rectangle   aSrcRect( Point( aPosAry.mnSrcX, aPosAry.mnSrcY ),
-                              Size( aPosAry.mnSrcWidth, aPosAry.mnSrcHeight ) );
-        long        nOldRight = aSrcRect.Right();
-        long        nOldBottom = aSrcRect.Bottom();
+        const Rectangle aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
+                                     Size( mnOutWidth, mnOutHeight ) );
 
-        if ( !aSrcRect.Intersection( aSrcOutRect ).IsEmpty() )
-        {
-            if ( (aPosAry.mnSrcX+aPosAry.mnSrcWidth-1) > aSrcOutRect.Right() )
-            {
-                long nOldWidth = aPosAry.mnSrcWidth;
-                aPosAry.mnSrcWidth -= nOldRight-aSrcRect.Right();
-                aPosAry.mnDestWidth = aPosAry.mnDestWidth*aPosAry.mnSrcWidth/nOldWidth;
-            }
-
-            if ( (aPosAry.mnSrcY+aPosAry.mnSrcHeight-1) > aSrcOutRect.Bottom() )
-            {
-                long nOldHeight = aPosAry.mnSrcHeight;
-                aPosAry.mnSrcHeight -= nOldBottom-aSrcRect.Bottom();
-                aPosAry.mnDestHeight = aPosAry.mnDestHeight*aPosAry.mnSrcHeight/nOldHeight;
-            }
+        ImplAdjustTwoRect( aPosAry, aSrcOutRect );
 
+        if ( aPosAry.mnSrcWidth && aPosAry.mnSrcHeight && aPosAry.mnDestWidth && aPosAry.mnDestHeight )
             mpGraphics->CopyBits( &aPosAry, NULL, this, NULL );
-        }
     }
 
     if( mpAlphaVDev )
@@ -339,7 +334,7 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
 
     OUTDEV_INIT();
 
-    TwoRect aPosAry;
+    SalTwoRect aPosAry;
     aPosAry.mnSrcX       = rOutDev.ImplLogicXToDevicePixel( rSrcPt.X() );
     aPosAry.mnSrcY       = rOutDev.ImplLogicYToDevicePixel( rSrcPt.Y() );
     aPosAry.mnSrcWidth   = rOutDev.ImplLogicWidthToDevicePixel( rSrcSize.Width() );
@@ -401,7 +396,7 @@ void OutputDevice::CopyArea( const Point& rDestPt,
 
     OUTDEV_INIT();
 
-    TwoRect aPosAry;
+    SalTwoRect aPosAry;
     aPosAry.mnSrcWidth   = ImplLogicWidthToDevicePixel( rSrcSize.Width() );
     aPosAry.mnSrcHeight  = ImplLogicHeightToDevicePixel( rSrcSize.Height() );
 
@@ -411,22 +406,18 @@ void OutputDevice::CopyArea( const Point& rDestPt,
         aPosAry.mnSrcY       = ImplLogicYToDevicePixel( rSrcPt.Y() );
         aPosAry.mnDestX      = ImplLogicXToDevicePixel( rDestPt.X() );
         aPosAry.mnDestY      = ImplLogicYToDevicePixel( rDestPt.Y() );
+        aPosAry.mnDestWidth  = aPosAry.mnSrcWidth;
+        aPosAry.mnDestHeight = aPosAry.mnSrcHeight;
 
-        Rectangle   aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
-                                 Size( mnOutWidth, mnOutHeight ) );
-        Rectangle   aSrcRect( Point( aPosAry.mnSrcX, aPosAry.mnSrcY ),
-                              Size( aPosAry.mnSrcWidth, aPosAry.mnSrcHeight ) );
-        long        nOldRight = aSrcRect.Right();
-        long        nOldBottom = aSrcRect.Bottom();
+        const Rectangle aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
+                                     Size( mnOutWidth, mnOutHeight ) );
+        const Rectangle aSrcRect( Point( aPosAry.mnSrcX, aPosAry.mnSrcY ),
+                                  Size( aPosAry.mnSrcWidth, aPosAry.mnSrcHeight ) );
 
-        if ( !aSrcRect.Intersection( aSrcOutRect ).IsEmpty() )
+        ImplAdjustTwoRect( aPosAry, aSrcOutRect );
+
+        if ( aPosAry.mnSrcWidth && aPosAry.mnSrcHeight && aPosAry.mnDestWidth && aPosAry.mnDestHeight )
         {
-            if ( (aPosAry.mnSrcX+aPosAry.mnSrcWidth-1) > aSrcOutRect.Right() )
-                aPosAry.mnSrcWidth -= nOldRight-aSrcRect.Right();
-
-            if ( (aPosAry.mnSrcY+aPosAry.mnSrcHeight-1) > aSrcOutRect.Bottom() )
-                aPosAry.mnSrcHeight -= nOldBottom-aSrcRect.Bottom();
-
             if ( (meOutDevType == OUTDEV_WINDOW) && (nFlags & COPYAREA_WINDOWINVALIDATE) )
             {
                 ((Window*)this)->ImplMoveAllInvalidateRegions( aSrcRect,
@@ -483,7 +474,7 @@ void OutputDevice::ImplDrawFrameDev( const Point& rPt, const Point& rDevPt, cons
     else
         ImplSelectClipRegion( rRegion );
 
-    TwoRect aPosAry;
+    SalTwoRect aPosAry;
     aPosAry.mnSrcX       = rDevPt.X();
     aPosAry.mnSrcY       = rDevPt.Y();
     aPosAry.mnSrcWidth   = rDevSize.Width();
@@ -642,7 +633,7 @@ void OutputDevice::ImplDrawBitmap( const Point& rDestPt, const Size& rDestSize,
 
     if( !aBmp.IsEmpty() )
     {
-        TwoRect aPosAry;
+        SalTwoRect aPosAry;
 
         aPosAry.mnSrcX = rSrcPtPixel.X();
         aPosAry.mnSrcY = rSrcPtPixel.Y();
@@ -823,7 +814,7 @@ void OutputDevice::ImplDrawBitmapEx( const Point& rDestPt, const Size& rDestSize
                 // output, having alpha-induced grey levels is not
                 // acceptable.
                 Bitmap aMask( aBmpEx.GetAlpha().GetBitmap() );
-                aMask.MakeMono( 128 );
+                aMask.MakeMono( 129 );
                 aBmpEx = BitmapEx( aColorBmp, aMask );
             }
             else
@@ -889,7 +880,7 @@ void OutputDevice::ImplDrawBitmapEx( const Point& rDestPt, const Size& rDestSize
 
     if( !( !aBmpEx ) )
     {
-        TwoRect aPosAry;
+        SalTwoRect aPosAry;
 
         aPosAry.mnSrcX = rSrcPtPixel.X();
         aPosAry.mnSrcY = rSrcPtPixel.Y();
@@ -1136,7 +1127,7 @@ void OutputDevice::ImplDrawMask( const Point& rDestPt, const Size& rDestSize,
     const ImpBitmap* pImpBmp = rBitmap.ImplGetImpBitmap();
     if ( pImpBmp )
     {
-        TwoRect aPosAry;
+        SalTwoRect aPosAry;
 
         aPosAry.mnSrcX = rSrcPtPixel.X();
         aPosAry.mnSrcY = rSrcPtPixel.Y();
@@ -1169,6 +1160,44 @@ void OutputDevice::ImplDrawMask( const Point& rDestPt, const Size& rDestSize,
     }
 }
 
+namespace
+{
+    BitmapEx makeDisabledBitmap(const Bitmap &rBitmap)
+    {
+        const Size aTotalSize( rBitmap.GetSizePixel() );
+        Bitmap aGrey( aTotalSize, 8, &Bitmap::GetGreyPalette( 256 ) );
+        AlphaMask aGreyAlphaMask( aTotalSize );
+        BitmapReadAccess*  pBmp = const_cast<Bitmap&>(rBitmap).AcquireReadAccess();
+        BitmapWriteAccess* pGrey = aGrey.AcquireWriteAccess();
+        BitmapWriteAccess* pGreyAlphaMask = aGreyAlphaMask.AcquireWriteAccess();
+
+        if( pBmp && pGrey && pGreyAlphaMask )
+        {
+            BitmapColor aGreyVal( 0 );
+            BitmapColor aGreyAlphaMaskVal( 0 );
+            const int nLeft = 0, nRight = aTotalSize.Width();
+            const int nTop = 0, nBottom = nTop + aTotalSize.Height();
+
+            for( int nY = nTop; nY < nBottom; ++nY )
+            {
+                for( int nX = nLeft; nX < nRight; ++nX )
+                {
+                    aGreyVal.SetIndex( pBmp->GetLuminance( nY, nX ) );
+                    pGrey->SetPixel( nY, nX, aGreyVal );
+
+                    aGreyAlphaMaskVal.SetIndex( static_cast< sal_uInt8 >( 128ul ) );
+                    pGreyAlphaMask->SetPixel( nY, nX, aGreyAlphaMaskVal );
+                }
+            }
+        }
+
+        const_cast<Bitmap&>(rBitmap).ReleaseAccess( pBmp );
+        aGrey.ReleaseAccess( pGrey );
+        aGreyAlphaMask.ReleaseAccess( pGreyAlphaMask );
+        return BitmapEx( aGrey, aGreyAlphaMask );
+    }
+}
+
 // ------------------------------------------------------------------
 
 void OutputDevice::DrawImage( const Point& rPos, const Image& rImage, sal_uInt16 nStyle )
@@ -1181,7 +1210,13 @@ void OutputDevice::DrawImage( const Point& rPos, const Image& rImage, sal_uInt16
     switch( rImage.mpImplData->meType )
     {
         case IMAGETYPE_BITMAP:
-            DrawBitmap( rPos, *static_cast< Bitmap* >( rImage.mpImplData->mpData ) );
+        {
+            const Bitmap &rBitmap = *static_cast< Bitmap* >( rImage.mpImplData->mpData );
+            if( nStyle & IMAGE_DRAW_DISABLE )
+                DrawBitmapEx( rPos, makeDisabledBitmap(rBitmap) );
+            else
+                DrawBitmap( rPos, rBitmap );
+        }
         break;
 
         case IMAGETYPE_IMAGE:
@@ -1217,7 +1252,13 @@ void OutputDevice::DrawImage( const Point& rPos, const Size& rSize,
         switch( rImage.mpImplData->meType )
         {
             case IMAGETYPE_BITMAP:
-                DrawBitmap( rPos, rSize, *static_cast< Bitmap* >( rImage.mpImplData->mpData ) );
+            {
+                const Bitmap &rBitmap = *static_cast< Bitmap* >( rImage.mpImplData->mpData );
+                if( nStyle & IMAGE_DRAW_DISABLE )
+                    DrawBitmapEx( rPos, rSize, makeDisabledBitmap(rBitmap) );
+                else
+                    DrawBitmap( rPos, rSize, rBitmap );
+            }
             break;
 
             case IMAGETYPE_IMAGE:
@@ -1303,7 +1344,7 @@ Bitmap OutputDevice::GetBitmap( const Point& rSrcPt, const Size& rSize ) const
                 {
                     if ( ((OutputDevice*)&aVDev)->mpGraphics || ((OutputDevice*)&aVDev)->ImplGetGraphics() )
                     {
-                        TwoRect aPosAry;
+                        SalTwoRect aPosAry;
 
                         aPosAry.mnSrcX = nX;
                         aPosAry.mnSrcY = nY;
@@ -1366,19 +1407,6 @@ BitmapEx OutputDevice::GetBitmapEx( const Point& rSrcPt, const Size& rSize ) con
 
 // ------------------------------------------------------------------
 
-void OutputDevice::ImplGetFrameBitmap( const Point& rDestPt, const Size& rSize,
-                                       Bitmap& rBitmap ) const
-{
-    DBG_CHKTHIS( OutputDevice, ImplDbgCheckOutputDevice );
-
-    sal_Bool bOldMap = mbMap;
-    ((OutputDevice*)this)->mbMap = sal_False;
-    rBitmap = GetBitmap( rDestPt, rSize );
-    ((OutputDevice*)this)->mbMap = bOldMap;
-}
-
-// ------------------------------------------------------------------
-
 Color OutputDevice::GetPixel( const Point& rPt ) const
 {
     DBG_CHKTHIS( OutputDevice, ImplDbgCheckOutputDevice );
@@ -1405,44 +1433,6 @@ Color OutputDevice::GetPixel( const Point& rPt ) const
 
 // ------------------------------------------------------------------
 
-Color* OutputDevice::GetPixel( const Polygon& rPts ) const
-{
-    DBG_CHKTHIS( OutputDevice, ImplDbgCheckOutputDevice );
-
-    Color*          pColors = NULL;
-    const sal_uInt16    nSize = rPts.GetSize();
-
-    if( nSize )
-    {
-        if ( mpGraphics || ((OutputDevice*)this)->ImplGetGraphics() )
-        {
-            if ( mbInitClipRegion )
-                ((OutputDevice*)this)->ImplInitClipRegion();
-
-            if ( !mbOutputClipped )
-            {
-                pColors = new Color[ nSize ];
-
-                for( sal_uInt16 i = 0; i < nSize; i++ )
-                {
-                    Color&          rCol = pColors[ i ];
-                    const Point&    rPt = rPts[ i ];
-                    const SalColor  aSalCol( mpGraphics->GetPixel( ImplLogicXToDevicePixel( rPt.X() ),
-                                                                   ImplLogicYToDevicePixel( rPt.Y() ) , this) );
-
-                    rCol.SetRed( SALCOLOR_RED( aSalCol ) );
-                    rCol.SetGreen( SALCOLOR_GREEN( aSalCol ) );
-                    rCol.SetBlue( SALCOLOR_BLUE( aSalCol ) );
-                }
-            }
-        }
-    }
-
-    return pColors;
-}
-
-// -----------------------------------------------------------------------
-
 void OutputDevice::DrawPixel( const Point& rPt )
 {
     OSL_TRACE( "OutputDevice::DrawPixel()" );
@@ -1484,40 +1474,7 @@ void OutputDevice::DrawPixel( const Point& rPt, const Color& rColor )
     OSL_TRACE( "OutputDevice::DrawPixel()" );
     DBG_CHKTHIS( OutputDevice, ImplDbgCheckOutputDevice );
 
-    Color aColor( rColor );
-
-    if( mnDrawMode & ( DRAWMODE_BLACKLINE | DRAWMODE_WHITELINE |
-                       DRAWMODE_GRAYLINE | DRAWMODE_GHOSTEDLINE |
-                       DRAWMODE_SETTINGSLINE ) )
-    {
-        if( !ImplIsColorTransparent( aColor ) )
-        {
-            if( mnDrawMode & DRAWMODE_BLACKLINE )
-            {
-                aColor = Color( COL_BLACK );
-            }
-            else if( mnDrawMode & DRAWMODE_WHITELINE )
-            {
-                aColor = Color( COL_WHITE );
-            }
-            else if( mnDrawMode & DRAWMODE_GRAYLINE )
-            {
-                const sal_uInt8 cLum = aColor.GetLuminance();
-                aColor = Color( cLum, cLum, cLum );
-            }
-            else if( mnDrawMode & DRAWMODE_SETTINGSLINE )
-            {
-                aColor = GetSettings().GetStyleSettings().GetFontColor();
-            }
-
-            if( mnDrawMode & DRAWMODE_GHOSTEDLINE )
-            {
-                aColor = Color( ( aColor.GetRed() >> 1 ) | 0x80,
-                                ( aColor.GetGreen() >> 1 ) | 0x80,
-                                ( aColor.GetBlue() >> 1 ) | 0x80 );
-            }
-        }
-    }
+    Color aColor = ImplDrawModeToColor( rColor );
 
     if ( mpMetaFile )
         mpMetaFile->AddAction( new MetaPixelAction( rPt, aColor ) );
@@ -1614,12 +1571,45 @@ void OutputDevice::DrawPixel( const Polygon& rPts, const Color& rColor )
 
 namespace
 {
-    sal_uInt8 lcl_calcColor( const sal_uInt8 nSourceColor, const sal_uInt8 nSourceOpaq, const sal_uInt8 nDestColor )
+    // Co = Cs + Cd*(1-As) premultiplied alpha -or-
+    // Co = (AsCs + AdCd*(1-As)) / Ao
+    inline sal_uInt8 lcl_calcColor( const sal_uInt8 nSourceColor, const sal_uInt8 nSourceAlpha,
+                                    const sal_uInt8 nDstAlpha, const sal_uInt8 nResAlpha, const sal_uInt8 nDestColor )
     {
-        int c = ( (int)nDestColor * ( 255 - nSourceOpaq ) )
-            +     (int)nSourceOpaq * (int)nSourceColor;
-        return sal_uInt8( c / 255 );
+        int c = nResAlpha ? ( (int)nSourceAlpha*nSourceColor + (int)nDstAlpha*nDestColor -
+                              (int)nDstAlpha*nDestColor*nSourceAlpha/255 ) / (int)nResAlpha : 0;
+        return sal_uInt8( c );
     }
+
+inline BitmapColor lcl_AlphaBlend( int nX,               int nY,
+                                   const long            nMapX,
+                                   const long            nMapY,
+                                   BitmapReadAccess*     pP,
+                                   BitmapReadAccess*     pA,
+                                   BitmapReadAccess*     pB,
+                                   BitmapWriteAccess*    pAlphaW,
+                                   sal_uInt8&            nResAlpha )
+{
+    BitmapColor aDstCol,aSrcCol;
+    aSrcCol = pP->GetColor( nMapY, nMapX );
+    aDstCol = pB->GetColor( nY, nX );
+
+    // vcl stores transparency, not alpha - invert it
+    const sal_uInt8 nSrcAlpha = 255 - pA->GetPixel( nMapY, nMapX ).GetBlueOrIndex();
+    const sal_uInt8 nDstAlpha = 255 - pAlphaW->GetPixel( nY, nX ).GetBlueOrIndex();
+
+    // Perform porter-duff compositing 'over' operation
+    //
+    // Co = Cs + Cd*(1-As)
+    // Ad = As + Ad*(1-As)
+    nResAlpha = (int)nSrcAlpha + (int)nDstAlpha - (int)nDstAlpha*nSrcAlpha/255;
+
+    aDstCol.SetRed( lcl_calcColor( aSrcCol.GetRed(), nSrcAlpha, nDstAlpha, nResAlpha, aDstCol.GetRed() ) );
+    aDstCol.SetBlue( lcl_calcColor( aSrcCol.GetBlue(), nSrcAlpha, nDstAlpha, nResAlpha, aDstCol.GetBlue() ) );
+    aDstCol.SetGreen( lcl_calcColor( aSrcCol.GetGreen(), nSrcAlpha, nDstAlpha, nResAlpha, aDstCol.GetGreen() ) );
+
+    return aDstCol;
+}
 }
 
 // ------------------------------------------------------------------------
@@ -1635,9 +1625,10 @@ Bitmap OutputDevice::ImplBlendWithAlpha( Bitmap              aBmp,
                                          const long*         pMapX,
                                          const long*         pMapY )
 {
-    BitmapColor aDstCol,aSrcCol;
+    BitmapColor aDstCol;
     Bitmap      res;
     int         nX, nY;
+    sal_uInt8   nResAlpha;
 
     OSL_ENSURE(mpAlphaVDev,
                "ImplBlendWithAlpha(): call me only with valid alpha VDev!" );
@@ -1670,29 +1661,16 @@ Bitmap OutputDevice::ImplBlendWithAlpha( Bitmap              aBmp,
                     const long  nMapX = pMapX[ nX ];
                     const sal_uLong nD = nVCLDitherLut[ nModY | ( nOutX & 0x0FL ) ];
 
-                    aSrcCol = pP->GetColor( nMapY, nMapX );
-                    aDstCol = pB->GetColor( nY, nX );
-                    const sal_uInt8 nSrcOpaq = 255 - pA->GetPixel( nMapY, nMapX ).GetBlueOrIndex();
-                    const sal_uInt8 nDstOpaq  = 255 - pAlphaW->GetPixel( nY, nX ).GetBlueOrIndex();
-
-                    aDstCol.SetRed( lcl_calcColor( aSrcCol.GetRed(), nSrcOpaq, aDstCol.GetRed() ) );
-                    aDstCol.SetBlue( lcl_calcColor( aSrcCol.GetBlue(), nSrcOpaq, aDstCol.GetBlue() ) );
-                    aDstCol.SetGreen( lcl_calcColor( aSrcCol.GetGreen(), nSrcOpaq, aDstCol.GetGreen() ) );
+                    aDstCol = lcl_AlphaBlend( nX, nY, nMapX, nMapY, pP, pA, pB, pAlphaW, nResAlpha );
 
                     aIndex.SetIndex( (sal_uInt8) ( nVCLRLut[ ( nVCLLut[ aDstCol.GetRed() ] + nD ) >> 16UL ] +
                                               nVCLGLut[ ( nVCLLut[ aDstCol.GetGreen() ] + nD ) >> 16UL ] +
                                               nVCLBLut[ ( nVCLLut[ aDstCol.GetBlue() ] + nD ) >> 16UL ] ) );
                     pW->SetPixel( nY, nX, aIndex );
 
-                    // Have to perform the compositing 'algebra' in
-                    // the inverse alpha space (with 255 meaning
-                    // opaque), otherwise, transitivity is not
-                    // achieved.
-                    const sal_uInt8 nSrcAlpha = 255-COLOR_CHANNEL_MERGE( 255, (sal_uInt8)nDstOpaq, nSrcOpaq );
-
-                    aIndex.SetIndex( (sal_uInt8) ( nVCLRLut[ ( nVCLLut[ nSrcAlpha ] + nD ) >> 16UL ] +
-                                              nVCLGLut[ ( nVCLLut[ nSrcAlpha ] + nD ) >> 16UL ] +
-                                              nVCLBLut[ ( nVCLLut[ nSrcAlpha ] + nD ) >> 16UL ] ) );
+                    aIndex.SetIndex( (sal_uInt8) ( nVCLRLut[ ( nVCLLut[ 255-nResAlpha ] + nD ) >> 16UL ] +
+                                                   nVCLGLut[ ( nVCLLut[ 255-nResAlpha ] + nD ) >> 16UL ] +
+                                                   nVCLBLut[ ( nVCLLut[ 255-nResAlpha ] + nD ) >> 16UL ] ) );
                     pAlphaW->SetPixel( nY, nX, aIndex );
                 }
             }
@@ -1714,25 +1692,10 @@ Bitmap OutputDevice::ImplBlendWithAlpha( Bitmap              aBmp,
                 for( nX = 0; nX < nDstWidth; nX++ )
                 {
                     const long nMapX = pMapX[ nX ];
-
-                    aSrcCol = pP->GetColor( nMapY, nMapX );
-                    aDstCol = pB->GetColor( nY, nX );
-                    const sal_uInt8 nSrcOpaq  = 255 - pA->GetPixel( nMapY, nMapX ).GetBlueOrIndex();
-                    const sal_uInt8 nDstOpaq  = 255 - pAlphaW->GetPixel( nY, nX ).GetBlueOrIndex();
-
-                    aDstCol.SetRed( lcl_calcColor( aSrcCol.GetRed(), nSrcOpaq, aDstCol.GetRed() ) );
-                    aDstCol.SetBlue( lcl_calcColor( aSrcCol.GetBlue(), nSrcOpaq, aDstCol.GetBlue() ) );
-                    aDstCol.SetGreen( lcl_calcColor( aSrcCol.GetGreen(), nSrcOpaq, aDstCol.GetGreen() ) );
+                    aDstCol = lcl_AlphaBlend( nX, nY, nMapX, nMapY, pP, pA, pB, pAlphaW, nResAlpha );
 
                     pB->SetPixel( nY, nX, aDstCol );
-
-                    // Have to perform the compositing 'algebra' in
-                    // the inverse alpha space (with 255 meaning
-                    // opaque), otherwise, transitivity is not
-                    // achieved.
-                    const sal_uInt8 nSrcAlpha = 255-COLOR_CHANNEL_MERGE( 255, (sal_uInt8)nDstOpaq, nSrcOpaq );
-
-                    pAlphaW->SetPixel( nY, nX, Color(nSrcAlpha, nSrcAlpha, nSrcAlpha) );
+                    pAlphaW->SetPixel( nY, nX, Color(255L-nResAlpha, 255L-nResAlpha, 255L-nResAlpha) );
                 }
             }
         }
