@@ -52,7 +52,7 @@ OString getTempFileName(const OUString& fileName)
   OUString ousTmpUrl;
   FileBase::getTempDirURL(ousTmpUrl);
   if (!ousTmpUrl.endsWithIgnoreAsciiCaseAsciiL("/", 1))
-    ousTmpUrl += OUString(RTL_CONSTASCII_USTRINGPARAM("/"));
+    ousTmpUrl += OUString("/");
   ousTmpUrl += fileName;
 
   OUString sysTmpPath;
@@ -207,7 +207,7 @@ public:
 
         pb->clear();
 
-        CPPUNIT_ASSERT_MESSAGE("Clearing property bag failed", pb->size() == 0);
+        CPPUNIT_ASSERT_MESSAGE("Clearing property bag failed", pb->empty());
     }
 
     void testSortPropertyBag()
@@ -276,12 +276,12 @@ public:
 
         pool->insert(ps4);
 
-        OString tmpFileName = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testPropertyPool_int.dot")));
+        OString tmpFileName = getTempFileName(OUString("testPropertyPool_int.dot"));
         printf("Pool dump: %s\n", tmpFileName.getStr());
         FileLoggerImpl fl(tmpFileName.getStr());
         pool->dump(&fl);
 
-        OString tmpFileName2 = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testPropertyPool_ext.dot")));
+        OString tmpFileName2 = getTempFileName(OUString("testPropertyPool_ext.dot"));
         printf("Pool dump: %s\n", tmpFileName2.getStr());
         ExternalViewLoggerImpl evl(tmpFileName2.getStr());
         pool->dump(&evl);
@@ -376,12 +376,12 @@ public:
 
         CPPUNIT_ASSERT_MESSAGE("paraProps == failed failed", paraProps == paragraphProps);
 
-        OString tmpFileName = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testComplexParaProps_int.dot")));
+        OString tmpFileName = getTempFileName(OUString("testComplexParaProps_int.dot"));
         printf("Pool dump: %s\n", tmpFileName.getStr());
         FileLoggerImpl fl(tmpFileName.getStr());
         pool->dump(&fl);
 
-        OString tmpFileName2 = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testComplexParaProps_ext.dot")));
+        OString tmpFileName2 = getTempFileName(OUString("testComplexParaProps_ext.dot"));
         printf("Pool dump: %s\n", tmpFileName2.getStr());
         ExternalViewLoggerImpl evl(tmpFileName2.getStr());
         pool->dump(&evl);
@@ -393,7 +393,7 @@ public:
         PropertyBag_Pointer_t pb = createPropertyBag();
         PropertyPoolHandle_Pointer_t ph = pool->insert(pb);
 
-        CPPUNIT_ASSERT_MESSAGE("Inserting empty property bag failed", ph->getPropertyBag()->size() == 0);
+        CPPUNIT_ASSERT_MESSAGE("Inserting empty property bag failed", ph->getPropertyBag()->empty());
     }
 
     void testDumpPropertyPool()
@@ -508,21 +508,21 @@ public:
             pb2->insert(createStringProperty(NS_style::LN_font_face, "Roman"));
             PropertyPoolHandle_Pointer_t ph2 = pool->insert(pb2);
 
-            OString tmpFileName = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testPropPoolGarbageColl_1.dot")));
+            OString tmpFileName = getTempFileName(OUString("testPropPoolGarbageColl_1.dot"));
             printf("Pool dump: %s\n", tmpFileName.getStr());
             FileLoggerImpl fl(tmpFileName.getStr());
             pool->dump(&fl);
 
         }
 
-        OString tmpFileName = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testPropPoolGarbageColl_2.dot")));
+        OString tmpFileName = getTempFileName(OUString("testPropPoolGarbageColl_2.dot"));
         printf("Pool dump: %s\n", tmpFileName.getStr());
         FileLoggerImpl fl(tmpFileName.getStr());
         pool->dump(&fl);
 
         pool->garbageCollection();
 
-        OString tmpFileName2 = getTempFileName(OUString(RTL_CONSTASCII_USTRINGPARAM("testPropPoolGarbageColl_after.dot")));
+        OString tmpFileName2 = getTempFileName(OUString("testPropPoolGarbageColl_after.dot"));
         printf("Pool dump: %s\n", tmpFileName2.getStr());
         FileLoggerImpl fl2(tmpFileName2.getStr());
         pool->dump(&fl2);
