@@ -29,14 +29,17 @@
 #include <ooxml/resourceids.hxx>
 #include <DomainMapper_Impl.hxx>
 #include <ConversionHelper.hxx>
-#include <i18npool/paper.hxx>
+#include <i18nutil/paper.hxx>
+#include <rtl/oustringostreaminserter.hxx>
 #include <com/sun/star/beans/PropertyValue.hpp>
+#include <com/sun/star/beans/XMultiPropertySet.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/table/BorderLine2.hpp>
 #include <com/sun/star/container/XEnumeration.hpp>
 #include <com/sun/star/container/XEnumerationAccess.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/style/BreakType.hpp>
+#include <com/sun/star/style/PageStyleLayout.hpp>
 #include <com/sun/star/text/RelOrientation.hpp>
 #include <com/sun/star/text/WritingMode.hpp>
 #include <com/sun/star/text/XTextColumns.hpp>
@@ -368,7 +371,7 @@ uno::Reference< beans::XPropertySet > SectionPropertyMap::GetPageStyle(
     {
         if( bFirst )
         {
-            if( !m_sFirstPageStyleName.getLength() && xPageStyles.is() )
+            if( m_sFirstPageStyleName.isEmpty() && xPageStyles.is() )
             {
                 uno::Sequence< ::rtl::OUString > aPageStyleNames = xPageStyles->getElementNames();
                 m_sFirstPageStyleName = lcl_FindUnusedPageStyleName(aPageStyleNames);
@@ -386,7 +389,7 @@ uno::Reference< beans::XPropertySet > SectionPropertyMap::GetPageStyle(
         }
         else
         {
-            if( !m_sFollowPageStyleName.getLength() && xPageStyles.is() )
+            if( m_sFollowPageStyleName.isEmpty() && xPageStyles.is() )
             {
                 uno::Sequence< ::rtl::OUString > aPageStyleNames = xPageStyles->getElementNames();
                 m_sFollowPageStyleName = lcl_FindUnusedPageStyleName(aPageStyleNames);
@@ -444,17 +447,17 @@ void SectionPropertyMap::ApplyBorderToPageStyles(
     switch( nValue & 0x07)
     {
         case 0: /*all styles*/
-            if ( m_sFollowPageStyleName.getLength( ) > 0 )
+            if ( !m_sFollowPageStyleName.isEmpty() )
                 xFirst = GetPageStyle( xPageStyles, xTextFactory, false );
-            if ( m_sFirstPageStyleName.getLength( ) > 0 )
+            if ( !m_sFirstPageStyleName.isEmpty() )
                 xSecond = GetPageStyle( xPageStyles, xTextFactory, true );
         break;
         case 1: /*first page*/
-            if ( m_sFirstPageStyleName.getLength( ) > 0 )
+            if ( !m_sFirstPageStyleName.isEmpty() )
                 xFirst = GetPageStyle( xPageStyles, xTextFactory, true );
         break;
         case 2: /*left and right*/
-            if ( m_sFollowPageStyleName.getLength( ) > 0 )
+            if ( !m_sFollowPageStyleName.isEmpty() )
                 xFirst  = GetPageStyle( xPageStyles, xTextFactory, false );
         break;
         case 3: //whole document?
@@ -498,17 +501,20 @@ void SectionPropertyMap::ApplyBorderToPageStyles(
         }
         if( m_nBorderDistances[nBorder] >= 0 )
         {
+            sal_uInt32 nLineWidth = 0;
+            if (m_pBorderLines[nBorder])
+                nLineWidth = m_pBorderLines[nBorder]->LineWidth;
             SetBorderDistance( xFirst, aMarginIds[nBorder], aBorderDistanceIds[nBorder],
-                  m_nBorderDistances[nBorder], nOffsetFrom );
+                  m_nBorderDistances[nBorder], nOffsetFrom, nLineWidth );
             if(xSecond.is())
                 SetBorderDistance( xSecond, aMarginIds[nBorder], aBorderDistanceIds[nBorder],
-                      m_nBorderDistances[nBorder], nOffsetFrom );
+                      m_nBorderDistances[nBorder], nOffsetFrom, nLineWidth );
         }
     }
 }
 
 void SectionPropertyMap::SetBorderDistance( uno::Reference< beans::XPropertySet > xStyle,
-        PropertyIds eMarginId, PropertyIds eDistId, sal_Int32 nDistance, sal_Int32 nOffsetFrom )
+        PropertyIds eMarginId, PropertyIds eDistId, sal_Int32 nDistance, sal_Int32 nOffsetFrom, sal_uInt32 nLineWidth )
 {
     PropertyNameSupplier& rPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
 
@@ -520,8 +526,8 @@ void SectionPropertyMap::SetBorderDistance( uno::Reference< beans::XPropertySet
         sal_Int32 nMargin = 0;
         aMargin >>= nMargin;
 
-        // Change the margins with the border distance
-        xStyle->setPropertyValue( sMarginName, uno::makeAny( nDistance ) );
+        // Change the margins with the ( border distance - line width )
+        xStyle->setPropertyValue( sMarginName, uno::makeAny( nDistance - nLineWidth ) );
 
         // Set the distance to ( Margin - distance )
         nDist = nMargin - nDistance;
@@ -632,9 +638,7 @@ bool SectionPropertyMap::HasFooter(bool bFirstPage) const
 
 void SectionPropertyMap::CopyLastHeaderFooter( bool bFirstPage, DomainMapper_Impl& rDM_Impl )
 {
-#if DEBUG
-    clog << "START>>> SectionPropertyMap::CopyLastHeaderFooter()" << endl;
-#endif
+    SAL_INFO("writerfilter", "START>>> SectionPropertyMap::CopyLastHeaderFooter()");
     SectionPropertyMap* pLastContext = rDM_Impl.GetLastSectionContext( );
     if ( pLastContext )
     {
@@ -692,10 +696,7 @@ void SectionPropertyMap::CopyLastHeaderFooter( bool bFirstPage, DomainMapper_Imp
 
                 if ( ( bIsHeader && bCopyHeader ) || ( !bIsHeader && bCopyFooter ) )
                 {
-#if DEBUG
-                    clog << "Copying ";
-                    clog << rtl::OUStringToOString( sName, RTL_TEXTENCODING_UTF8 ).getStr( ) << endl;
-#endif
+                    SAL_INFO("writerfilter", "Copying " << sName);
                     // TODO has to be copied
                     uno::Reference< text::XTextCopy > xTxt;
                     if (xStyle.is())
@@ -711,17 +712,10 @@ void SectionPropertyMap::CopyLastHeaderFooter( bool bFirstPage, DomainMapper_Imp
         }
         catch ( const uno::Exception& e )
         {
-#if DEBUG
-            clog << "An exception occurred in SectionPropertyMap::CopyLastHeaderFooter( ) - ";
-            clog << rtl::OUStringToOString( e.Message, RTL_TEXTENCODING_UTF8 ).getStr( ) << endl;
-#else
-            (void) e;
-#endif
+            SAL_INFO("writerfilter", "An exception occurred in SectionPropertyMap::CopyLastHeaderFooter( ) - " << e.Message);
         }
     }
-#if DEBUG
-    clog << "END>>> SectionPropertyMap::CopyLastHeaderFooter()" << endl;
-#endif
+    SAL_INFO("writerfilter", "END>>> SectionPropertyMap::CopyLastHeaderFooter()");
 }
 
 void SectionPropertyMap::PrepareHeaderFooterProperties( bool bFirstPage )
@@ -792,11 +786,12 @@ void SectionPropertyMap::PrepareHeaderFooterProperties( bool bFirstPage )
     sal_Int32 nHeaderHeight = 0, nFooterHeight = 0;
     if (bFirstPage)
     {
+        PropertyNameSupplier& rPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
         // make sure the height of the header/footer is added to the top/bottom margin if necessary
         if (m_aFollowPageStyle.is() && !HasHeader(true) && HasHeader(false))
-            m_aFollowPageStyle->getPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("HeaderHeight"))) >>= nHeaderHeight;
+            m_aFollowPageStyle->getPropertyValue(rPropNameSupplier.GetName(PROP_HEADER_HEIGHT)) >>= nHeaderHeight;
         if (m_aFollowPageStyle.is() && !HasFooter(true) && HasFooter(false))
-            m_aFollowPageStyle->getPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FooterHeight"))) >>= nFooterHeight;
+            m_aFollowPageStyle->getPropertyValue(rPropNameSupplier.GetName(PROP_FOOTER_HEIGHT)) >>= nFooterHeight;
     }
     operator[]( PropertyDefinition( PROP_TOP_MARGIN, false )) = uno::makeAny( m_nTopMargin + nHeaderHeight );
     operator[]( PropertyDefinition( PROP_BOTTOM_MARGIN, false )) = uno::makeAny( m_nBottomMargin + nFooterHeight );
@@ -1009,8 +1004,14 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
             0 - No break 1 - New Colunn 2 - New page 3 - Even page 4 - odd page */
                 xRangeProperties->setPropertyValue(rPropNameSupplier.GetName( PROP_PAGE_DESC_NAME ),
                     uno::makeAny( m_bTitlePage ? m_sFirstPageStyleName : m_sFollowPageStyleName ));
-    //  todo: page breaks with odd/even page numbering are not available - find out current page number to check how to change the number
-    //  or add even/odd page break types
+                // handle page breaks with odd/even page numbering
+                style::PageStyleLayout nPageStyleLayout(style::PageStyleLayout_ALL);
+                if (m_nBreakType == 3)
+                    nPageStyleLayout = style::PageStyleLayout_LEFT;
+                else if (m_nBreakType == 4)
+                    nPageStyleLayout = style::PageStyleLayout_RIGHT;
+                if (nPageStyleLayout)
+                    xFollowPageStyle->setPropertyValue(rPropNameSupplier.GetName(PROP_PAGE_STYLE_LAYOUT), uno::makeAny(nPageStyleLayout));
                 if(m_bPageNoRestart || m_nPageNumber >= 0)
                 {
                     sal_Int16 nPageNumber = m_nPageNumber >= 0 ? static_cast< sal_Int16 >(m_nPageNumber) : 1;
@@ -1019,18 +1020,40 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
                 }
             }
         }
-        catch( const uno::Exception& rEx)
+        catch (const uno::Exception&)
         {
             OSL_FAIL( "Exception in SectionPropertyMap::CloseSectionGroup");
-            (void)rEx;
         }
     }
+    rDM_Impl.SetIsFirstParagraphInSection(true);
 }
 
 
 void SectionPropertyMap::_ApplyProperties( uno::Reference< beans::XPropertySet > xStyle )
 {
     PropertyNameSupplier& rPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
+    uno::Reference<beans::XMultiPropertySet> const xMultiSet(xStyle,
+            uno::UNO_QUERY);
+    if (xMultiSet.is())
+    {   // FIXME why is "this" a STL container???
+        uno::Sequence<rtl::OUString> names(this->size());
+        uno::Sequence<uno::Any> values(this->size());
+        PropertyMap::iterator it = this->begin();
+        for (size_t i = 0; it != this->end(); ++it, ++i)
+        {
+            names[i] = rPropNameSupplier.GetName(it->first.eId);
+            values[i] = it->second;
+        }
+        try
+        {
+            xMultiSet->setPropertyValues(names, values);
+        }
+        catch( const uno::Exception& )
+        {
+            OSL_FAIL( "Exception in <PageStyle>::setPropertyValue");
+        }
+        return;
+    }
     PropertyMap::iterator aMapIter = begin();
     while( aMapIter != end())
     {
