@@ -50,7 +50,6 @@
 #include <xmloff/shapeexport.hxx>
 #include "sdpropls.hxx"
 #include <tools/debug.hxx>
-#include <tools/urlobj.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <xmloff/xmlexp.hxx>
 #include <xmloff/xmluconv.hxx>
@@ -108,13 +107,13 @@ void XMLShapeExport::ImpExportNewTrans_GetB2DHomMatrix(::basegfx::B2DHomMatrix&
     uno::Any aAny;
     if ( ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 &&
          xPropSet->getPropertySetInfo()->hasPropertyByName(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("TransformationInHoriL2R"))) )
+            OUString("TransformationInHoriL2R")) )
     {
-        aAny = xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("TransformationInHoriL2R")));
+        aAny = xPropSet->getPropertyValue(OUString("TransformationInHoriL2R"));
     }
     else
     {
-        aAny = xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("Transformation")));
+        aAny = xPropSet->getPropertyValue(OUString("Transformation"));
     }
     drawing::HomogenMatrix3 aMatrix;
     aAny >>= aMatrix;
@@ -253,17 +252,17 @@ sal_Bool XMLShapeExport::ImpExportPresentationAttributes( const uno::Reference<
         sal_Bool bTemp = false;
 
         // is empty pes shape?
-        if( xPropSetInfo.is() && xPropSetInfo->hasPropertyByName(OUString(RTL_CONSTASCII_USTRINGPARAM("IsEmptyPresentationObject"))))
+        if( xPropSetInfo.is() && xPropSetInfo->hasPropertyByName(OUString("IsEmptyPresentationObject")))
         {
-            xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("IsEmptyPresentationObject"))) >>= bIsEmpty;
+            xPropSet->getPropertyValue(OUString("IsEmptyPresentationObject")) >>= bIsEmpty;
             if( bIsEmpty )
                 mrExport.AddAttribute(XML_NAMESPACE_PRESENTATION, XML_PLACEHOLDER, XML_TRUE);
         }
 
         // is user-transformed?
-        if( xPropSetInfo.is() && xPropSetInfo->hasPropertyByName(OUString(RTL_CONSTASCII_USTRINGPARAM("IsPlaceholderDependent"))))
+        if( xPropSetInfo.is() && xPropSetInfo->hasPropertyByName(OUString("IsPlaceholderDependent")))
         {
-            xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("IsPlaceholderDependent"))) >>= bTemp;
+            xPropSet->getPropertyValue(OUString("IsPlaceholderDependent")) >>= bTemp;
             if(!bTemp)
                 mrExport.AddAttribute(XML_NAMESPACE_PRESENTATION, XML_USER_TRANSFORMED, XML_TRUE);
         }
@@ -424,7 +423,7 @@ void XMLShapeExport::ImpExportEvents( const uno::Reference< drawing::XShape >& x
 
         OUString aEventQName(
             mrExport.GetNamespaceMap().GetQNameByKey(
-                    XML_NAMESPACE_DOM, OUString( RTL_CONSTASCII_USTRINGPARAM( "click" ) ) ) );
+                    XML_NAMESPACE_DOM, OUString(  "click"  ) ) );
         mrExport.AddAttribute( XML_NAMESPACE_SCRIPT, XML_EVENT_NAME, aEventQName );
         mrExport.AddAttribute( XML_NAMESPACE_PRESENTATION, XML_ACTION, eStrAction );
 
@@ -492,7 +491,7 @@ void XMLShapeExport::ImpExportEvents( const uno::Reference< drawing::XShape >& x
 
         if( eClickAction == presentation::ClickAction_VANISH || eClickAction == presentation::ClickAction_SOUND )
         {
-            if( ( nFound & FOUND_SOUNDURL ) && aStrSoundURL.getLength() != 0 )
+            if( ( nFound & FOUND_SOUNDURL ) && !aStrSoundURL.isEmpty() )
             {
                 mrExport.AddAttribute(XML_NAMESPACE_XLINK, XML_HREF, GetExport().GetRelativeReference(aStrSoundURL) );
                 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
@@ -514,18 +513,17 @@ void XMLShapeExport::ImpExportEvents( const uno::Reference< drawing::XShape >& x
             mrExport.AddAttribute( XML_NAMESPACE_SCRIPT, XML_LANGUAGE,
                         mrExport.GetNamespaceMap().GetQNameByKey(
                             XML_NAMESPACE_OOO,
-                            OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                            "starbasic" ) ) ) );
+                            OUString( "starbasic"  ) ) );
             OUString aEventQName(
                 mrExport.GetNamespaceMap().GetQNameByKey(
-                        XML_NAMESPACE_DOM, OUString( RTL_CONSTASCII_USTRINGPARAM( "click" ) ) ) );
+                        XML_NAMESPACE_DOM, OUString(  "click"  ) ) );
             mrExport.AddAttribute( XML_NAMESPACE_SCRIPT, XML_EVENT_NAME, aEventQName );
 
             if( nFound & FOUND_LIBRARY )
             {
                 OUString sLocation( GetXMLToken(
-                    (aStrLibrary.equalsIgnoreAsciiCaseAscii("StarOffice") ||
-                     aStrLibrary.equalsIgnoreAsciiCaseAscii("application") ) ? XML_APPLICATION
+                    (aStrLibrary.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("StarOffice")) ||
+                     aStrLibrary.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("application")) ) ? XML_APPLICATION
                                                                        : XML_DOCUMENT ) );
                 OUStringBuffer sTmp( sLocation.getLength() + aStrMacro.getLength() + 1 );
                 sTmp = sLocation;
@@ -553,7 +551,7 @@ void XMLShapeExport::ImpExportEvents( const uno::Reference< drawing::XShape >& x
                          XML_NAMESPACE_OOO, GetXMLToken(XML_SCRIPT) ) );
                 OUString aEventQName(
                     mrExport.GetNamespaceMap().GetQNameByKey(
-                            XML_NAMESPACE_DOM, OUString( RTL_CONSTASCII_USTRINGPARAM( "click" ) ) ) );
+                            XML_NAMESPACE_DOM, OUString(  "click"  ) ) );
                 mrExport.AddAttribute( XML_NAMESPACE_SCRIPT, XML_EVENT_NAME, aEventQName );
                 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_HREF, aStrMacro );
 
@@ -574,16 +572,16 @@ void XMLShapeExport::ImpExportDescription( const uno::Reference< drawing::XShape
         OUString aDescription;
 
         uno::Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY_THROW );
-        xProps->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "Title" )) ) >>= aTitle;
-        xProps->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "Description" )) ) >>= aDescription;
+        xProps->getPropertyValue( OUString( "Title" ) ) >>= aTitle;
+        xProps->getPropertyValue( OUString( "Description" ) ) >>= aDescription;
 
-        if(aTitle.getLength())
+        if(!aTitle.isEmpty())
         {
             SvXMLElementExport aEventElemt(mrExport, XML_NAMESPACE_SVG, XML_TITLE, sal_True, sal_False);
             mrExport.Characters( aTitle );
         }
 
-        if(aDescription.getLength())
+        if(!aDescription.isEmpty())
         {
             SvXMLElementExport aEventElemt(mrExport, XML_NAMESPACE_SVG, XML_DESC, sal_True, sal_False );
             mrExport.Characters( aDescription );
@@ -710,7 +708,7 @@ void XMLShapeExport::ImpExportTextBoxShape(
 
         // evtl. corner radius?
         sal_Int32 nCornerRadius(0L);
-        xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("CornerRadius"))) >>= nCornerRadius;
+        xPropSet->getPropertyValue(OUString("CornerRadius")) >>= nCornerRadius;
         if(nCornerRadius)
         {
             OUStringBuffer sStringBuffer;
@@ -746,7 +744,7 @@ void XMLShapeExport::ImpExportRectangleShape(
 
         // evtl. corner radius?
         sal_Int32 nCornerRadius(0L);
-        xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("CornerRadius"))) >>= nCornerRadius;
+        xPropSet->getPropertyValue(OUString("CornerRadius")) >>= nCornerRadius;
         if(nCornerRadius)
         {
             OUStringBuffer sStringBuffer;
@@ -798,7 +796,7 @@ void XMLShapeExport::ImpExportLineShape(
         awt::Point aBasePosition(FRound(aTRTranslate.getX()), FRound(aTRTranslate.getY()));
 
         // get the two points
-        uno::Any aAny(xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("Geometry"))));
+        uno::Any aAny(xPropSet->getPropertyValue(OUString("Geometry")));
         drawing::PointSequenceSequence* pSourcePolyPolygon = (drawing::PointSequenceSequence*)aAny.getValue();
 
         if(pSourcePolyPolygon)
@@ -899,14 +897,14 @@ void XMLShapeExport::ImpExportEllipseShape(
         ImpExportNewTrans(xPropSet, nFeatures, pRefPoint);
 
         drawing::CircleKind eKind = drawing::CircleKind_FULL;
-        xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("CircleKind")) ) >>= eKind;
+        xPropSet->getPropertyValue( OUString("CircleKind") ) >>= eKind;
         if( eKind != drawing::CircleKind_FULL )
         {
             OUStringBuffer sStringBuffer;
             sal_Int32 nStartAngle = 0;
             sal_Int32 nEndAngle = 0;
-            xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("CircleStartAngle")) ) >>= nStartAngle;
-            xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("CircleEndAngle")) ) >>= nEndAngle;
+            xPropSet->getPropertyValue( OUString("CircleStartAngle") ) >>= nStartAngle;
+            xPropSet->getPropertyValue( OUString("CircleEndAngle") ) >>= nEndAngle;
 
             const double dStartAngle = nStartAngle / 100.0;
             const double dEndAngle = nEndAngle / 100.0;
@@ -988,7 +986,7 @@ void XMLShapeExport::ImpExportPolygonShape(
         if(bBezier)
         {
             // get PolygonBezier
-            uno::Any aAny( xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("Geometry"))) );
+            uno::Any aAny( xPropSet->getPropertyValue(OUString("Geometry")) );
             drawing::PolyPolygonBezierCoords* pSourcePolyPolygon =
                 (drawing::PolyPolygonBezierCoords*)aAny.getValue();
 
@@ -1001,7 +999,7 @@ void XMLShapeExport::ImpExportPolygonShape(
                 if(pOuterSequence && pOuterFlags)
                 {
                     // prepare svx:d element export
-                    SdXMLImExSvgDElement aSvgDElement(aViewBox);
+                    SdXMLImExSvgDElement aSvgDElement(aViewBox, GetExport());
 
                     for(sal_Int32 a(0L); a < nOuterCnt; a++)
                     {
@@ -1031,7 +1029,7 @@ void XMLShapeExport::ImpExportPolygonShape(
         else
         {
             // get non-bezier polygon
-            uno::Any aAny( xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("Geometry"))) );
+            uno::Any aAny( xPropSet->getPropertyValue(OUString("Geometry")) );
             drawing::PointSequenceSequence* pSourcePolyPolygon = (drawing::PointSequenceSequence*)aAny.getValue();
 
             if(pSourcePolyPolygon && pSourcePolyPolygon->getLength())
@@ -1068,7 +1066,7 @@ void XMLShapeExport::ImpExportPolygonShape(
                     if(pOuterSequence)
                     {
                         // prepare svx:d element export
-                        SdXMLImExSvgDElement aSvgDElement(aViewBox);
+                        SdXMLImExSvgDElement aSvgDElement(aViewBox, GetExport());
 
                         for(sal_Int32 a(0L); a < nOuterCnt; a++)
                         {
@@ -1130,11 +1128,11 @@ void XMLShapeExport::ImpExportGraphicObjectShape(
                 OUString aStreamURL;
                 OUString aStr;
 
-                xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("GraphicStreamURL"))) >>= aStreamURL;
-                xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("GraphicURL"))) >>= sImageURL;
+                xPropSet->getPropertyValue( OUString("GraphicStreamURL")) >>= aStreamURL;
+                xPropSet->getPropertyValue( OUString("GraphicURL")) >>= sImageURL;
 
                 OUString aResolveURL( sImageURL );
-                const rtl::OUString sPackageURL( RTL_CONSTASCII_USTRINGPARAM("vnd.sun.star.Package:") );
+                const rtl::OUString sPackageURL( "vnd.sun.star.Package:" );
 
                     // sj: trying to preserve the filename
                 if ( aStreamURL.match( sPackageURL, 0 ) )
@@ -1146,9 +1144,9 @@ void XMLShapeExport::ImpExportGraphicObjectShape(
                     nLastIndex = sRequestedName.lastIndexOf( '.' );
                     if ( nLastIndex >= 0 )
                         sRequestedName = sRequestedName.copy( 0, nLastIndex );
-                    if ( sRequestedName.getLength() )
+                    if ( !sRequestedName.isEmpty() )
                     {
-                        aResolveURL = aResolveURL.concat( OUString(RTL_CONSTASCII_USTRINGPARAM("?requestedName=")));
+                        aResolveURL = aResolveURL.concat( OUString("?requestedName="));
                         aResolveURL = aResolveURL.concat( sRequestedName );
                     }
                 }
@@ -1156,18 +1154,18 @@ void XMLShapeExport::ImpExportGraphicObjectShape(
                 aStr = mrExport.AddEmbeddedGraphicObject( aResolveURL );
                 mrExport.AddAttribute(XML_NAMESPACE_XLINK, XML_HREF, aStr );
 
-                if( aStr.getLength() )
+                if( !aStr.isEmpty() )
                 {
                     if( aStr[ 0 ] == '#' )
                     {
-                        aStreamURL = OUString(RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.Package:" ));
+                        aStreamURL = OUString( "vnd.sun.star.Package:" );
                         aStreamURL = aStreamURL.concat( aStr.copy( 1, aStr.getLength() - 1 ) );
                     }
 
                     // update stream URL for load on demand
                     uno::Any aAny;
                     aAny <<= aStreamURL;
-                    xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("GraphicStreamURL")), aAny );
+                    xPropSet->setPropertyValue( OUString("GraphicStreamURL"), aAny );
 
                     mrExport.AddAttribute(XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
                     mrExport.AddAttribute(XML_NAMESPACE_XLINK, XML_SHOW, XML_EMBED );
@@ -1186,7 +1184,7 @@ void XMLShapeExport::ImpExportGraphicObjectShape(
             {
                 SvXMLElementExport aOBJ(mrExport, XML_NAMESPACE_DRAW, XML_IMAGE, sal_True, sal_True);
 
-                if( sImageURL.getLength() )
+                if( !sImageURL.isEmpty() )
                 {
                     // optional office:binary-data
                     mrExport.AddEmbeddedGraphicObjectAsBase64( sImageURL );
@@ -1259,7 +1257,7 @@ void XMLShapeExport::ImpExportConnectorShape(
 
     // export connection kind
     drawing::ConnectorType eType = drawing::ConnectorType_STANDARD;
-    uno::Any aAny = xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EdgeKind")));
+    uno::Any aAny = xProps->getPropertyValue(OUString("EdgeKind"));
     aAny >>= eType;
 
     if( eType != drawing::ConnectorType_STANDARD )
@@ -1272,11 +1270,11 @@ void XMLShapeExport::ImpExportConnectorShape(
     // export line skew
     sal_Int32 nDelta1 = 0, nDelta2 = 0, nDelta3 = 0;
 
-    aAny = xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EdgeLine1Delta")));
+    aAny = xProps->getPropertyValue(OUString("EdgeLine1Delta"));
     aAny >>= nDelta1;
-    aAny = xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EdgeLine2Delta")));
+    aAny = xProps->getPropertyValue(OUString("EdgeLine2Delta"));
     aAny >>= nDelta2;
-    aAny = xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EdgeLine3Delta")));
+    aAny = xProps->getPropertyValue(OUString("EdgeLine3Delta"));
     aAny >>= nDelta3;
 
     if( nDelta1 != 0 || nDelta2 != 0 || nDelta3 != 0 )
@@ -1319,17 +1317,17 @@ void XMLShapeExport::ImpExportConnectorShape(
     */
     if ( ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 &&
          xProps->getPropertySetInfo()->hasPropertyByName(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("StartPositionInHoriL2R"))) &&
+            OUString("StartPositionInHoriL2R")) &&
          xProps->getPropertySetInfo()->hasPropertyByName(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("EndPositionInHoriL2R"))) )
+            OUString("EndPositionInHoriL2R")) )
     {
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartPositionInHoriL2R"))) >>= aStart;
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndPositionInHoriL2R"))) >>= aEnd;
+        xProps->getPropertyValue(OUString("StartPositionInHoriL2R")) >>= aStart;
+        xProps->getPropertyValue(OUString("EndPositionInHoriL2R")) >>= aEnd;
     }
     else
     {
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartPosition"))) >>= aStart;
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndPosition"))) >>= aEnd;
+        xProps->getPropertyValue(OUString("StartPosition")) >>= aStart;
+        xProps->getPropertyValue(OUString("EndPosition")) >>= aEnd;
     }
 
     if( pRefPoint )
@@ -1381,13 +1379,13 @@ void XMLShapeExport::ImpExportConnectorShape(
     uno::Reference< uno::XInterface > xRefE;
 
     // export start connection
-    xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartShape") ) ) >>= xRefS;
+    xProps->getPropertyValue(OUString("StartShape" ) ) >>= xRefS;
     if( xRefS.is() )
     {
         const OUString& rShapeId = mrExport.getInterfaceToIdentifierMapper().getIdentifier( xRefS );
         mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_START_SHAPE, rShapeId);
 
-        aAny = xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartGluePointIndex")) );
+        aAny = xProps->getPropertyValue(OUString("StartGluePointIndex") );
         sal_Int32 nGluePointId = 0;
         if( aAny >>= nGluePointId )
         {
@@ -1399,13 +1397,13 @@ void XMLShapeExport::ImpExportConnectorShape(
     }
 
     // export end connection
-    xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndShape")) ) >>= xRefE;
+    xProps->getPropertyValue(OUString("EndShape") ) >>= xRefE;
     if( xRefE.is() )
     {
         const OUString& rShapeId = mrExport.getInterfaceToIdentifierMapper().getIdentifier( xRefE );
         mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_END_SHAPE, rShapeId);
 
-        aAny = xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndGluePointIndex")) );
+        aAny = xProps->getPropertyValue(OUString("EndGluePointIndex") );
         sal_Int32 nGluePointId = 0;
         if( aAny >>= nGluePointId )
         {
@@ -1416,7 +1414,7 @@ void XMLShapeExport::ImpExportConnectorShape(
         }
     }
 
-    if( xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM("PolyPolygonBezier") ) ) >>= aAny )
+    if( xProps->getPropertyValue( OUString( "PolyPolygonBezier" ) ) >>= aAny )
     {
         // get PolygonBezier
         drawing::PolyPolygonBezierCoords* pSourcePolyPolygon =
@@ -1434,7 +1432,7 @@ void XMLShapeExport::ImpExportConnectorShape(
                 awt::Point aPoint( 0, 0 );
                 awt::Size aSize( 1, 1 );
                 SdXMLImExViewBox aViewBox( 0, 0, 1, 1 );
-                SdXMLImExSvgDElement aSvgDElement(aViewBox);
+                SdXMLImExSvgDElement aSvgDElement(aViewBox, GetExport());
 
                 for(sal_Int32 a(0L); a < nOuterCnt; a++)
                 {
@@ -1454,24 +1452,6 @@ void XMLShapeExport::ImpExportConnectorShape(
         }
     }
 
-    // get matrix
-    ::basegfx::B2DHomMatrix aMatrix;
-    ImpExportNewTrans_GetB2DHomMatrix(aMatrix, xProps);
-
-    // decompose and correct about pRefPoint
-    ::basegfx::B2DTuple aTRScale;
-    double fTRShear(0.0);
-    double fTRRotate(0.0);
-    ::basegfx::B2DTuple aTRTranslate;
-    ImpExportNewTrans_DecomposeAndRefPoint(aMatrix, aTRScale, fTRShear,
-            fTRRotate, aTRTranslate, pRefPoint);
-
-    // fdo#49678: create and export ViewBox
-    awt::Point aPoint(0, 0);
-    awt::Size aSize(FRound(aTRScale.getX()), FRound(aTRScale.getY()));
-    SdXMLImExViewBox aViewBox(0, 0, aSize.Width, aSize.Height);
-    mrExport.AddAttribute(XML_NAMESPACE_SVG, XML_VIEWBOX, aViewBox.GetExportString());
-
     // write connector shape. Add Export later.
     sal_Bool bCreateNewline( (nFeatures & SEF_EXPORT_NO_WS) == 0 ); // #86116#/#92210#
     SvXMLElementExport aOBJ(mrExport, XML_NAMESPACE_DRAW, XML_CONNECTOR, bCreateNewline, sal_True);
@@ -1511,17 +1491,17 @@ void XMLShapeExport::ImpExportMeasureShape(
     */
     if ( ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 &&
          xProps->getPropertySetInfo()->hasPropertyByName(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("StartPositionInHoriL2R"))) &&
+            OUString("StartPositionInHoriL2R")) &&
          xProps->getPropertySetInfo()->hasPropertyByName(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("EndPositionInHoriL2R"))) )
+            OUString("EndPositionInHoriL2R")) )
     {
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartPositionInHoriL2R"))) >>= aStart;
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndPositionInHoriL2R"))) >>= aEnd;
+        xProps->getPropertyValue(OUString("StartPositionInHoriL2R")) >>= aStart;
+        xProps->getPropertyValue(OUString("EndPositionInHoriL2R")) >>= aEnd;
     }
     else
     {
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartPosition"))) >>= aStart;
-        xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndPosition"))) >>= aEnd;
+        xProps->getPropertyValue(OUString("StartPosition")) >>= aStart;
+        xProps->getPropertyValue(OUString("EndPosition")) >>= aEnd;
     }
 
     if( pRefPoint )
@@ -1625,7 +1605,7 @@ void XMLShapeExport::ImpExportOLE2Shape(
             OUString sClassId;
             OUString sURL;
             sal_Bool bInternal = false;
-            xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("IsInternal"))) >>= bInternal;
+            xPropSet->getPropertyValue(OUString("IsInternal")) >>= bInternal;
 
             if( !bIsEmptyPresObj )
             {
@@ -1634,28 +1614,28 @@ void XMLShapeExport::ImpExportOLE2Shape(
                 {
                     // OOo internal links have no storage persistance, URL is stored in the XML file
                     // the result LinkURL is empty in case the object is not a link
-                    xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "LinkURL" )) ) >>= sURL;
+                    xPropSet->getPropertyValue( OUString( "LinkURL" ) ) >>= sURL;
                 }
 
-                xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "PersistName" ) ) ) >>= sPersistName;
-                if ( !sURL.getLength() )
+                xPropSet->getPropertyValue( OUString( "PersistName"  ) ) >>= sPersistName;
+                if ( sURL.isEmpty() )
                 {
-                    if( sPersistName.getLength() )
+                    if( !sPersistName.isEmpty() )
                     {
-                        sURL = OUString( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.EmbeddedObject:" ) );
+                        sURL = OUString(  "vnd.sun.star.EmbeddedObject:"  );
                         sURL += sPersistName;
                     }
                 }
 
                 if( !bInternal )
-                    xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("CLSID"))) >>= sClassId;
+                    xPropSet->getPropertyValue(OUString("CLSID")) >>= sClassId;
 
-                if( sClassId.getLength() )
+                if( !sClassId.isEmpty() )
                     mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_CLASS_ID, sClassId );
                 if(!bExportEmbedded)
                 {
                     // xlink:href
-                    if( sURL.getLength() )
+                    if( !sURL.isEmpty() )
                     {
                         // #96717# in theorie, if we don't have a url we shouldn't even
                         // export this ole shape. But practical its to risky right now
@@ -1680,7 +1660,7 @@ void XMLShapeExport::ImpExportOLE2Shape(
                 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_ACTUATE, XML_ONLOAD );
             }
 
-            enum XMLTokenEnum eElem = sClassId.getLength() ? XML_OBJECT_OLE : XML_OBJECT;
+            enum XMLTokenEnum eElem = sClassId.isEmpty() ? XML_OBJECT : XML_OBJECT_OLE ;
             SvXMLElementExport aElem( mrExport, XML_NAMESPACE_DRAW, eElem, sal_True, sal_True );
 
             if(bExportEmbedded && !bIsEmptyPresObj)
@@ -1690,7 +1670,7 @@ void XMLShapeExport::ImpExportOLE2Shape(
                 {
                     // embedded XML
                     uno::Reference< lang::XComponent > xComp;
-                    xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Model") ) ) >>= xComp;
+                    xPropSet->getPropertyValue( OUString("Model" ) ) >>= xComp;
                     DBG_ASSERT( xComp.is(), "no xModel for own OLE format" );
                     mrExport.ExportEmbeddedOwnObject( xComp );
                 }
@@ -1702,14 +1682,14 @@ void XMLShapeExport::ImpExportOLE2Shape(
 
                     ::rtl::OUString sURLRequest( sURL );
                     if ( ( mrExport.getExportFlags() & EXPORT_OASIS ) == 0 )
-                        sURLRequest += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "?oasis=false" ) );
+                        sURLRequest += ::rtl::OUString(  "?oasis=false"  );
                     mrExport.AddEmbeddedObjectAsBase64( sURLRequest );
                 }
             }
         }
         if( !bIsEmptyPresObj )
         {
-            OUString sURL( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.GraphicObject:" ) );
+            OUString sURL(  "vnd.sun.star.GraphicObject:"  );
             sURL += sPersistName;
             if( !bExportEmbedded )
             {
@@ -1747,7 +1727,7 @@ void XMLShapeExport::ImpExportPageShape(
 
         // export page number used for this page
         uno::Reference< beans::XPropertySetInfo > xPropSetInfo( xPropSet->getPropertySetInfo() );
-        const OUString aPageNumberStr(RTL_CONSTASCII_USTRINGPARAM("PageNumber"));
+        const OUString aPageNumberStr("PageNumber");
         if( xPropSetInfo.is() && xPropSetInfo->hasPropertyByName(aPageNumberStr))
         {
             sal_Int32 nPageNumber = 0;
@@ -1785,7 +1765,7 @@ void XMLShapeExport::ImpExportCaptionShape(
 
         // evtl. corner radius?
         sal_Int32 nCornerRadius(0L);
-        xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("CornerRadius"))) >>= nCornerRadius;
+        xPropSet->getPropertyValue(OUString("CornerRadius")) >>= nCornerRadius;
         if(nCornerRadius)
         {
             OUStringBuffer sStringBuffer;
@@ -1795,7 +1775,7 @@ void XMLShapeExport::ImpExportCaptionShape(
         }
 
         awt::Point aCaptionPoint;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "CaptionPoint" ) ) ) >>= aCaptionPoint;
+        xPropSet->getPropertyValue( OUString(  "CaptionPoint"  ) ) >>= aCaptionPoint;
 
         mrExport.GetMM100UnitConverter().convertMeasureToXML(msBuffer,
                 aCaptionPoint.X);
@@ -1841,15 +1821,15 @@ void XMLShapeExport::ImpExportFrameShape(
 
         // export frame url
         OUString aStr;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "FrameURL" ) ) ) >>= aStr;
+        xPropSet->getPropertyValue( OUString(  "FrameURL"  ) ) >>= aStr;
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_HREF, GetExport().GetRelativeReference(aStr) );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_SHOW, XML_EMBED );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_ACTUATE, XML_ONLOAD );
 
         // export name
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "FrameName" ) ) ) >>= aStr;
-        if( aStr.getLength() )
+        xPropSet->getPropertyValue( OUString(  "FrameName"  ) ) >>= aStr;
+        if( !aStr.isEmpty() )
             mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_FRAME_NAME, aStr );
 
         // write floating frame
@@ -1877,24 +1857,24 @@ void XMLShapeExport::ImpExportAppletShape(
 
         // export frame url
         OUString aStr;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "AppletCodeBase" ) ) ) >>= aStr;
+        xPropSet->getPropertyValue( OUString(  "AppletCodeBase"  ) ) >>= aStr;
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_HREF, GetExport().GetRelativeReference(aStr) );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_SHOW, XML_EMBED );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_ACTUATE, XML_ONLOAD );
 
         // export draw:applet-name
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "AppletName" ) ) ) >>= aStr;
-        if( aStr.getLength() )
+        xPropSet->getPropertyValue( OUString(  "AppletName"  ) ) >>= aStr;
+        if( !aStr.isEmpty() )
             mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_APPLET_NAME, aStr );
 
         // export draw:code
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "AppletCode" ) ) ) >>= aStr;
+        xPropSet->getPropertyValue( OUString(  "AppletCode"  ) ) >>= aStr;
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_CODE, aStr );
 
         // export draw:may-script
         sal_Bool bIsScript = false;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "AppletIsScript" ) ) ) >>= bIsScript;
+        xPropSet->getPropertyValue( OUString(  "AppletIsScript"  ) ) >>= bIsScript;
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_MAY_SCRIPT, bIsScript ? XML_TRUE : XML_FALSE );
 
         {
@@ -1903,7 +1883,7 @@ void XMLShapeExport::ImpExportAppletShape(
 
             // export parameters
             uno::Sequence< beans::PropertyValue > aCommands;
-            xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "AppletCommands" ) ) ) >>= aCommands;
+            xPropSet->getPropertyValue( OUString(  "AppletCommands"  ) ) >>= aCommands;
             const sal_Int32 nCount = aCommands.getLength();
             for( sal_Int32 nIndex = 0; nIndex < nCount; nIndex++ )
             {
@@ -1934,7 +1914,7 @@ void XMLShapeExport::ImpExportPluginShape(
 
         // export plugin url
         OUString aStr;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "PluginURL" ) ) ) >>= aStr;
+        xPropSet->getPropertyValue( OUString(  "PluginURL"  ) ) >>= aStr;
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_HREF, GetExport().GetRelativeReference(aStr) );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_SHOW, XML_EMBED );
@@ -1942,8 +1922,8 @@ void XMLShapeExport::ImpExportPluginShape(
 
 
         // export mime-type
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "PluginMimeType" ) ) ) >>= aStr;
-        if(aStr.getLength())
+        xPropSet->getPropertyValue( OUString(  "PluginMimeType"  ) ) >>= aStr;
+        if(!aStr.isEmpty())
             mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_MIME_TYPE, aStr );
 
         {
@@ -1952,7 +1932,7 @@ void XMLShapeExport::ImpExportPluginShape(
 
             // export parameters
             uno::Sequence< beans::PropertyValue > aCommands;
-            xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "PluginCommands" ) ) ) >>= aCommands;
+            xPropSet->getPropertyValue( OUString(  "PluginCommands"  ) ) >>= aCommands;
             const sal_Int32 nCount = aCommands.getLength();
             for( sal_Int32 nIndex = 0; nIndex < nCount; nIndex++ )
             {
@@ -1982,19 +1962,19 @@ static void lcl_CopyStream(
     {
         SAL_WARN("xmloff", "no output stream");
         throw uno::Exception(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("no output stream")),0);
+            ::rtl::OUString("no output stream"),0);
     }
     uno::Reference< beans::XPropertySet > const xStreamProps(xStream,
         uno::UNO_QUERY);
     if (xStreamProps.is()) { // this is NOT supported in FileSystemStorage
         xStreamProps->setPropertyValue(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MediaType")),
-            uno::makeAny(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            ::rtl::OUString("MediaType"),
+            uno::makeAny(::rtl::OUString(
             //FIXME how to detect real media type?
             //but currently xmloff has this one hardcoded anyway...
-                    "application/vnd.sun.star.media"))));
+                    "application/vnd.sun.star.media")));
         xStreamProps->setPropertyValue( // turn off compression
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Compressed")),
+            ::rtl::OUString("Compressed"),
             uno::makeAny(sal_False));
     }
     ::comphelper::OStorageHelper::CopyInputToOutput(xInStream, xOutStream);
@@ -2019,7 +1999,7 @@ lcl_StoreMediaAndGetURL(SvXMLExport & rExport,
                     rExport.GetTargetStorage(), uno::UNO_QUERY_THROW);
             uno::Reference<io::XInputStream> xInStream;
             xPropSet->getPropertyValue(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PrivateStream")))
+                ::rtl::OUString("PrivateStream"))
                     >>= xInStream;
 
             if (!xInStream.is())
@@ -2067,7 +2047,7 @@ void XMLShapeExport::ImpExportMediaShape(
 
         // export media url
         OUString aMediaURL;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "MediaURL" ) ) ) >>= aMediaURL;
+        xPropSet->getPropertyValue( OUString(  "MediaURL"  ) ) >>= aMediaURL;
         OUString const persistentURL =
             lcl_StoreMediaAndGetURL(GetExport(), xPropSet, aMediaURL);
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_HREF, persistentURL );
@@ -2076,55 +2056,55 @@ void XMLShapeExport::ImpExportMediaShape(
         mrExport.AddAttribute ( XML_NAMESPACE_XLINK, XML_ACTUATE, XML_ONLOAD );
 
         // export mime-type
-        mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_MIME_TYPE, OUString( RTL_CONSTASCII_USTRINGPARAM( "application/vnd.sun.star.media" ) ) );
+        mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_MIME_TYPE, OUString(  "application/vnd.sun.star.media"  ) );
 
         // write plugin
         SvXMLElementExport aOBJ(mrExport, XML_NAMESPACE_DRAW, XML_PLUGIN, !( nFeatures & SEF_EXPORT_NO_WS ), sal_True);
 
         // export parameters
-        const OUString aFalseStr( RTL_CONSTASCII_USTRINGPARAM( "false" ) ), aTrueStr( RTL_CONSTASCII_USTRINGPARAM( "true" ) );
+        const OUString aFalseStr(  "false"  ), aTrueStr(  "true"  );
 
         sal_Bool bLoop = false;
-        const OUString aLoopStr( RTL_CONSTASCII_USTRINGPARAM( "Loop" ) );
+        const OUString aLoopStr(  "Loop"  );
         xPropSet->getPropertyValue( aLoopStr ) >>= bLoop;
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_NAME, aLoopStr );
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_VALUE, bLoop ? aTrueStr : aFalseStr );
         delete( new SvXMLElementExport( mrExport, XML_NAMESPACE_DRAW, XML_PARAM, sal_False, sal_True ) );
 
         sal_Bool bMute = false;
-        const OUString aMuteStr( RTL_CONSTASCII_USTRINGPARAM( "Mute" ) );
+        const OUString aMuteStr(  "Mute"  );
         xPropSet->getPropertyValue( aMuteStr ) >>= bMute;
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_NAME, aMuteStr );
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_VALUE, bMute ? aTrueStr : aFalseStr );
         delete( new SvXMLElementExport( mrExport, XML_NAMESPACE_DRAW, XML_PARAM, sal_False, sal_True ) );
 
         sal_Int16 nVolumeDB = 0;
-        const OUString aVolumeDBStr( RTL_CONSTASCII_USTRINGPARAM( "VolumeDB" ) );
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "VolumeDB" ) ) ) >>= nVolumeDB;
+        const OUString aVolumeDBStr(  "VolumeDB"  );
+        xPropSet->getPropertyValue( OUString(  "VolumeDB"  ) ) >>= nVolumeDB;
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_NAME, aVolumeDBStr );
         mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_VALUE, OUString::valueOf( static_cast< sal_Int32 >( nVolumeDB ) ) );
         delete( new SvXMLElementExport( mrExport, XML_NAMESPACE_DRAW, XML_PARAM, sal_False, sal_True ) );
 
         media::ZoomLevel eZoom;
-        const OUString aZoomStr( RTL_CONSTASCII_USTRINGPARAM( "Zoom" ) );
+        const OUString aZoomStr(  "Zoom"  );
         OUString aZoomValue;
-        xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "Zoom" ) ) ) >>= eZoom;
+        xPropSet->getPropertyValue( OUString(  "Zoom"  ) ) >>= eZoom;
         switch( eZoom )
         {
-            case( media::ZoomLevel_ZOOM_1_TO_4 ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "25%" ) ); break;
-            case( media::ZoomLevel_ZOOM_1_TO_2 ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "50%" ) ); break;
-            case( media::ZoomLevel_ORIGINAL ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "100%" ) ); break;
-            case( media::ZoomLevel_ZOOM_2_TO_1 ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "200%" ) ); break;
-            case( media::ZoomLevel_ZOOM_4_TO_1 ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "400%" ) ); break;
-            case( media::ZoomLevel_FIT_TO_WINDOW ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "fit" ) ); break;
-            case( media::ZoomLevel_FIT_TO_WINDOW_FIXED_ASPECT ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "fixedfit" ) ); break;
-            case( media::ZoomLevel_FULLSCREEN ): aZoomValue = OUString( RTL_CONSTASCII_USTRINGPARAM( "fullscreen" ) ); break;
+            case( media::ZoomLevel_ZOOM_1_TO_4 ): aZoomValue = OUString(  "25%"  ); break;
+            case( media::ZoomLevel_ZOOM_1_TO_2 ): aZoomValue = OUString(  "50%"  ); break;
+            case( media::ZoomLevel_ORIGINAL ): aZoomValue = OUString(  "100%"  ); break;
+            case( media::ZoomLevel_ZOOM_2_TO_1 ): aZoomValue = OUString(  "200%"  ); break;
+            case( media::ZoomLevel_ZOOM_4_TO_1 ): aZoomValue = OUString(  "400%"  ); break;
+            case( media::ZoomLevel_FIT_TO_WINDOW ): aZoomValue = OUString(  "fit"  ); break;
+            case( media::ZoomLevel_FIT_TO_WINDOW_FIXED_ASPECT ): aZoomValue = OUString(  "fixedfit"  ); break;
+            case( media::ZoomLevel_FULLSCREEN ): aZoomValue = OUString(  "fullscreen"  ); break;
 
             default:
             break;
         }
 
-        if( aZoomValue.getLength() )
+        if( !aZoomValue.isEmpty() )
         {
             mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_NAME, aZoomStr );
             mrExport.AddAttribute( XML_NAMESPACE_DRAW, XML_VALUE, aZoomValue );
